@@ -1,5 +1,5 @@
 <?php
-/* $Id: albanian-iso-8859-1.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: albanian-iso-8859-1.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /**
  * Translated by: Laurent Dhima <laurenti at users.sourceforge.net>
@@ -60,7 +60,6 @@ $strAscending = 'Ngjitje';
 $strAtBeginningOfTable = 'N fillim t tabels';
 $strAtEndOfTable = 'N fund t tabels';
 $strAttr = 'Pronsi';
-$strAutodetect = 'Zbulim automatik';
 $strAutomaticLayout = 'Faqosje automatike';
 
 $strBack = 'Mbrapa';
@@ -140,7 +139,6 @@ $strCreatePdfFeat = 'Krijimi i PDF-ve';
 $strCreationDates = 'Datat e Krijimit/Prditsimit/Kontrollit';
 $strCriteria = 'Kriteri';
 $strCroatian = 'Kroate';
-$strCSVOptions = 'Opcione CSV';
 $strCyrillic = 'Cyrillic';
 $strCzech = 'ekisht';
 $strCzechSlovak = 'eko-Sllovak';  
@@ -150,7 +148,6 @@ $strDatabase = 'Databazat';
 $strDatabaseEmpty = 'Emri i databazs mungon!'; 
 $strDatabaseExportOptions = 'Opcione t eksportimit t databazs';
 $strDatabaseHasBeenDropped = 'Databaza %s u eleminua.';
-$strDatabaseNoTable = 'Kjo databaz nuk prmban tabela!';
 $strDatabases = 'Databazat';
 $strDatabasesDropped = '%s databaza u eleminuan korrektsisht.';
 $strDatabasesStatsDisable = 'Disaktivo Statistikat';
@@ -210,7 +207,6 @@ $strEnglishPrivileges = 'Shnim: emrat e t drejtave t MySQL jan n Anglisht';
 $strError = 'Gabim';
 $strEstonian = 'Estoneze';
 $strExcelEdition = 'Edicion i Excel';
-$strExcelOptions = 'Opcione t Excel';
 $strExecuteBookmarked = 'Zbaton query nga librshnuesi';
 $strExplain = 'Shpjego SQL';
 $strExport = 'Eksporto';
@@ -220,7 +216,6 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Prpjekje t dshtuara';
 $strField = 'Fusha';
 $strFieldHasBeenDropped = 'Fusha %s u eleminua';
-$strFieldsEmpty = ' Numratori i fushave sht bosh! ';
 $strFieldsEnclosedBy = 'Fush e prbr nga';
 $strFieldsEscapedBy = 'Fush e kufizuar nga';
 $strFields = 'Fusha';
@@ -254,7 +249,6 @@ $strHasBeenAltered = 'u ndryshua.';
 $strHasBeenCreated = 'u krijua.';
 $strHaveToShow = 'Zgjidh t paktn nj kolon pr t par';
 $strHebrew = 'Hebraike';
-$strHexForBinary = 'Prdor hexadecimale pr fushat binare';  
 $strHomepageOfficial = 'Faqja zyrtare e phpMyAdmin';
 $strHome = 'Shtpia';
 $strHostEmpty = 'Emri i host sht bosh!';
@@ -300,7 +294,6 @@ $strLatexContinued = '(vazhdon)';
 $strLatexIncludeCaption = 'Prfshi nntitullin e tabels';
 $strLatexLabel = 'Kyi i etikets';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Opcione LaTeX';
 $strLatexStructure = 'Struktura e tabels __TABLE__';
 $strLatvian = 'Letone';  
 $strLengthSet = 'Gjatsia/Set*';
@@ -553,7 +546,6 @@ $strSpaceUsage = 'Hapsira e prdorur';
 $strSpanish = 'Spanjisht';  
 $strSplitWordsWithSpace = 'Fjalt jan t ndara me nj hapsir (" ").';
 $strSQLExportType = 'Lloji i Eksportit';  
-$strSQLOptions = 'Opcione SQL';
 $strSQLParserBugMessage = 'Ka mundsi q ka nj bug tek parser-i SQL. Ju lutem, kontrolloni query tuaj me kujdes, dhe kontrolloni q presjet t jen ku duhet dhe jo t gabuara. Nj shkak tjetr i mundshm i gabimit mund t jet q po mundoheni t uploadoni nj file binar jasht nj zone teksti t kufizuar me presje. Mund edhe t provoni query tuaj MySQL nga interfaqja e shkruar e komandave. Gabimi i mposhtm i kthyer nga server-i MySQL, nse ekziston nj i till, mund tju ndihmoj n diagnostikimin e problemit. Nse ka akoma probleme, apo n.q.s. parser-i SQL i phpMyAdmin gabon kur prkundrazi nga interfaqja e komandave t thjeshta nuk rezultojn probleme, ju lutem zvogloni query tuaj SQL n hyrje n query e vetme q shkakton probleme, dhe drgoni nj bug raportim me t dhnat rezultuese nga seksioni CUT i mposhtm:';
 $strSQLParserUserError = 'Mesa duket ekziston nj gabim tek query juaj SQL e futur. Gabimi i serverit MySQL i treguar m posht, nse ekziston, mund t\'ju ndihmoj n diagnostikimin e problemit';
 $strSQLQuery = 'query SQL';
@@ -703,7 +695,6 @@ $strCopy = 'Copy';  //to translate
 $strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 
 $strDataPages = 'Pages containing data';  //to translate
 $strDBCopy = 'Copy database to';  //to translate
@@ -733,18 +724,13 @@ $strGeneratePassword = 'Generate Password';  //to translate
 
 $strHandler = 'Handler';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
 $strImport = 'Import';  //to translate
 $strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
 $strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
 $strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
 $strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
@@ -770,11 +756,9 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
 
@@ -807,7 +791,6 @@ $strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPersian = 'Persian';  //to translate
@@ -905,7 +888,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -944,7 +927,6 @@ $strSkipQueries = 'Number of records(queries) to skip from start';  //to transla
 $strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 $strSorting = 'Sorting';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
@@ -981,16 +963,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1006,7 +984,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1051,4 +1028,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
