@@ -1,5 +1,5 @@
 <?php
-/* $Id: arabic-windows-1256.inc.php,v 2.142 2006/08/09 12:55:35 lem9 Exp $ */
+/* $Id: arabic-windows-1256.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /**
  * Original translation to Arabic by Fisal <fisal77 at hotmail.com>
@@ -24,7 +24,6 @@ $datefmt = '%d %B %Y  %H:%M';
 $timespanfmt = '%s  %s ɡ %s  %s ';
 
 $strAbortedClients = '';
-$strAbsolutePathToDocSqlDir = '         docSQL';
 $strAccessDenied = ' ';
 $strAccessDeniedExplanation = ' phpMyAdmin   MySQL   .     ݡ         config.inc.php            MySQL.';
 $strAction = '';
@@ -32,8 +31,6 @@ $strAddAutoIncrement = '  AUTO_INCREMENT';
 $strAddConstraints = ' ';
 $strAddDeleteColumn = '/  ';
 $strAddDeleteRow = '/  ';
-$strAddedColumnComment = '   ';
-$strAddedColumnRelation = '   ';
 $strAddIntoComments = '  ';
 $strAddNewField = '  ';
 $strAddPrivilegesOnDb = '     ';
@@ -63,7 +60,6 @@ $strAscending = '';
 $strAtBeginningOfTable = '  ';
 $strAtEndOfTable = '  ';
 $strAttr = '';
-$strAutodetect = ' ';
 $strAutomaticLayout = ' ';
 
 $strBack = '';
@@ -140,7 +136,6 @@ $strCreatePdfFeat = '  PDF';
 $strCreationDates = ' //';
 $strCriteria = '';
 $strCroatian = '';
-$strCSVOptions = '    )CSV(';
 $strCyrillic = '';
 $strCzech = '';
 
@@ -149,7 +144,6 @@ $strData = '';
 $strDatabase = ' ';
 $strDatabaseExportOptions = '   ';
 $strDatabaseHasBeenDropped = '  %s .';
-$strDatabaseNoTable = '      !';
 $strDatabases = ' ';
 $strDatabasesDropped = '    %s .';
 $strDatabasesStats = '  ';
@@ -159,15 +153,6 @@ $strDatabasesStatsHeavyTraffic = ':               MySQL.';
 $strDataDict = ' ';
 $strDataOnly = ' ';
 $strDBComment = '  : ';
-$strDBGContext = '';
-$strDBGContextID = ' ';
-$strDBGHits = '';
-$strDBGLine = '';
-$strDBGMaxTimeMs = ' ʡ ';
-$strDBGMinTimeMs = ' ʡ ';
-$strDBGModule = '';
-$strDBGTimePerHitMs = '/ ';
-$strDBGTotalTimeMs = '  ';
 $strDbPrivileges = '   ';
 $strDbSpecific = '  ';
 $strDefault = '';
@@ -212,7 +197,6 @@ $strEnglishPrivileges = ' :   MySQL      ';
 $strError = '';
 $strEstonian = '';
 $strExcelEdition = ' ';
-$strExcelOptions = ' ';
 $strExecuteBookmarked = '    ';
 $strExplain = ' SQL';
 $strExport = '';
@@ -223,7 +207,6 @@ $strFailedAttempts = ' ';
 $strField = '';
 $strFieldHasBeenDropped = '  %s';
 $strFields = '  ';
-$strFieldsEmpty = '   ! ';
 $strFieldsEnclosedBy = '  ';
 $strFieldsEscapedBy = '  ';
 $strFieldsTerminatedBy = '  ';
@@ -264,8 +247,6 @@ $strHungarian = '';
 $strId = '';
 $strIdxFulltext = ' ';
 $strIgnore = '';
-$strIgnoringFile = '  %s';
-$strImportDocSQL = '  docSQL';
 $strImportFiles = ' ';
 $strIndex = '';
 $strIndexes = '';
@@ -300,7 +281,6 @@ $strLatexContinued = '()';
 $strLatexContinuedCaption = '  ';
 $strLatexIncludeCaption = '  ';
 $strLatexLabel = 'Label key';
-$strLaTeXOptions = ' ';
 $strLatexStructure = '  __TABLE__';
 $strLengthSet = '/*';
 $strLimitNumRows = '   ';
@@ -325,7 +305,7 @@ $strMIME_nodescription = '     .<br />  ѡ   %s.';
 $strMIME_transformation = ' ';
 $strMIME_transformation_note = '       MIME  ǡ   %s %s';
 $strMIME_transformation_options = ' ';
-$strMIME_transformation_options_note = '       : \'a\',\'b\',\'c\'...<br />      ("\")    ("\'")       )   \'\\\\xyz\'  \'a\\\'b\'(.';
+$strMIME_transformation_options_note = '       : \'a\', 100, b,\'c\'...<br />      ("\")    ("\'")       )   \'\\\\xyz\'  \'a\\\'b\'(.';
 $strMIME_without = ' MIME         ';
 $strModifications = ' ';
 $strModify = '';
@@ -538,7 +518,6 @@ $strSortByKey = '  ';
 $strSpaceUsage = ' ';
 $strSplitWordsWithSpace = '    (" ").';
 $strSQLExportType = ' ';
-$strSQLOptions = ' SQL';
 $strSQLParserBugMessage = '        SQL.    ɡ       .                  .        MySQL.      MySQL     ɡ   .              ѡ        ɡ           :';
 $strSQLParserUserError = '      SQL.       MySQL    ɡ    ɡ.';
 $strSQLQuery = '-SQL';
@@ -579,7 +558,6 @@ $strTblPrivileges = '  ';
 $strTextAreaLength = '  ,<br />         ';
 $strThai = '';
 $strThisHost = ' ';
-$strThisNotDirectory = '   ';
 $strThreadSuccessfullyKilled = '   %s .';
 $strTime = '';
 $strToggleScratchboard = 'toggle scratchboard';
@@ -590,7 +568,6 @@ $strTraffic = ' ';
 $strTransformation_image_jpeg__inline = '    ǡ :  ֡   )   (.';
 $strTransformation_image_jpeg__link = '    (direct blob download, i.e.).';
 $strTransformation_image_png__inline = ' /jpeg:  ';
-$strTransformation_text_plain__dateformat = ' TIME, TIMESTAMP  DATETIME       .     ))     timestamp )  (.           PHP strftime().';
 $strTransformation_text_plain__external = ' :           .    .    Tidy     HTML  .  ɡ      libraries/transformations/text_plain__external.inc.php        .                .    ˡ    1    htmlspecialchars() )  1(.  ڡ    1    NOWRAP           )  1(.';
 $strTransformation_text_plain__formatted = '   .     Escaping.';
 $strTransformation_text_plain__imagelink = '  ء     ݡ      "http://domain.com/"        .';
@@ -641,8 +618,6 @@ $strWestEuropean = ' ';
 $strWildcard = ' ';
 $strWindowNotFound = '     .              .';
 $strWithChecked = ':  ';
-$strWritingCommentNotPossible = '   ';
-$strWritingRelationNotPossible = '   ';
 $strWrongUser = '  / .  .';
 
 $strXML = 'XML';
@@ -692,7 +667,6 @@ $strCopy = 'Copy';  //to translate
 $strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 $strCzechSlovak = 'Czech-Slovak';  //to translate
 
 $strDatabaseEmpty = 'The database name is empty!';  //to translate
@@ -729,11 +703,8 @@ $strGeneratePassword = 'Generate Password';  //to translate
 $strGeorgian = 'Georgian';  //to translate
 
 $strHandler = 'Handler';  //to translate
-$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIcelandic = 'Icelandic';  //to translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
@@ -741,10 +712,7 @@ $strIgnoreInserts = 'Use ignore inserts';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
 $strImport = 'Import';  //to translate
 $strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
 $strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
 $strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
 $strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
@@ -770,12 +738,10 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLatvian = 'Latvian';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
 
@@ -813,7 +779,6 @@ $strOperator = 'Operator';  //to translate
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPersian = 'Persian';  //to translate
@@ -917,7 +882,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -959,7 +924,6 @@ $strSocketProblem = '(or the local MySQL server\'s socket is not correctly confi
 $strSorting = 'Sorting';  //to translate
 $strSpanish = 'Spanish';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
@@ -1001,16 +965,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1023,4 +983,73 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
