@@ -1,5 +1,5 @@
 <?php
-/* $Id: azerbaijani-iso-8859-9.inc.php,v 2.143 2006/08/09 12:55:35 lem9 Exp $ */
+/* $Id: azerbaijani-iso-8859-9.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 // tercmedeki eksiklerimi ve ya sehv olduunu dndynz yerleri shehriyari@trcomm.net adresine gndere bilersiniz...
 // ehriyar manov 30 Avqust 2003... Shehi
@@ -19,14 +19,11 @@ $datefmt = '%d %B, %Y saat %H:%M';
 $timespanfmt = '%s gn, %s saat, %s deqiqe ve %s saniye';
 
 $strAbortedClients = 'Dayandrlm Elaqeler';
-$strAbsolutePathToDocSqlDir = 'Xahi edirik, docSQL direktoriyasna webserver-deki mtleq yolu (absolute path) gsterin.';
 $strAccessDenied = 'Giri Tesdiq Edilmedi';
 $strAction = 'Fealiyyetler';
 $strAddAutoIncrement = 'AUTO_INCREMENT deyeri elave et';
 $strAddDeleteColumn = 'Sahe Stunlarn Elave Et/Sil';
 $strAddDeleteRow = 'Kriteria Setirlerini Elave Et/Sil';
-$strAddedColumnComment = 'Bu stun n qsa izahat elave edildi';
-$strAddedColumnRelation = 'Stun n elaqe elave edildi';
 $strAddHeaderComment = 'Bala xlase me\'lumat elave et (\\n yeni setire keir)';
 $strAddIntoComments = 'Xlaseye elave et';
 $strAddNewField = 'Yeni sahe elave et';
@@ -59,7 +56,6 @@ $strAscending = 'Artan srada';
 $strAtBeginningOfTable = 'Cedvelin bana';
 $strAtEndOfTable = 'Cedvelin sonuna';
 $strAttr = 'Xsusiyyetler';
-$strAutodetect = 'Avtomatik';
 $strAutomaticLayout = 'Automatik ablon';
 
 $strBack = 'Geri';
@@ -126,7 +122,6 @@ $strCreate = 'Qur';
 $strCreationDates = 'Qurulu/Deyidirilme/Yoxlama tarixleri';
 $strCriteria = 'Kriteriyalar';
 $strCroatian = 'Xorvat Dili';
-$strCSVOptions = 'CSV variantlar';
 $strCyrillic = 'Kiril';
 $strCzechSlovak = 'ex-Slovak';
 
@@ -143,15 +138,6 @@ $strDataDict = 'Me\'lumat leti';
 $strData = 'Me\'lumat';
 $strDataOnly = 'Sadece me\'lumat';
 $strDBComment = 'Baza qsa izahat: ';
-$strDBGContextID = 'Kontekst Nmresi';
-$strDBGContext = 'Metn (kontekst)';
-$strDBGHits = 'Hit-ler';
-$strDBGLine = 'Setr';
-$strDBGMaxTimeMs = 'Min. mddet, ms';
-$strDBGMinTimeMs = 'Maks. mddet, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Vaxt/Hit, ms';
-$strDBGTotalTimeMs = 'Toplam mddet, ms';
 $strDbPrivileges = 'Me\'lumat Bazasna Mexsus Selahiyyetler';
 $strDbSpecific = 'bazayaxas';
 $strDefault = 'Balanc deyeri';
@@ -198,7 +184,6 @@ $strEnglishPrivileges = ' Qeyd: MySQL selahiyyet adlar ingilis dilinde ifade edi
 $strError = 'Xeta';
 $strEstonian = 'Eston Dili';
 $strExcelEdition = 'Excel versiyas';
-$strExcelOptions = 'Excel variantlar';
 $strExplain = 'SQL-i zah Et';
 $strExport = 'Eksport';
 $strExtendedInserts = 'Geniletilmi girili';
@@ -207,7 +192,6 @@ $strExtra = 'Elave Xs.';
 $strFailedAttempts = 'Uursuz Cehdler';
 $strFieldHasBeenDropped = '%s sahesi lev edildi';
 $strField = 'Sahe';
-$strFieldsEmpty = ' Sahe sayac bodur! ';
 $strFieldsEnclosedBy = 'Saheler ehate edildiyi iare';
 $strFieldsEscapedBy = 'Sahelerin escape edildiyi iare';
 $strFields = 'Sahe say';
@@ -239,22 +223,17 @@ $strHasBeenAltered = 'deyidirildi.';
 $strHasBeenCreated = 'quruldu.';
 $strHaveToShow = 'Gsterilmesi n en az bir stun semelisiniz';
 $strHebrew = 'brani Dili';
-$strHexForBinary = 'kili saheler n hekzadesimaldan istifade et';
 $strHome = 'Balanc';
 $strHomepageOfficial = 'phpMyAdmin Resmi nternet Sehifesi';
 $strHostEmpty = 'Host ad bodur!';
 $strHost = 'Host';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 eksport variantlar';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 eksport variantlar';
 $strHungarian = 'Macar Dili';
 
 $strId = 'Nmre';
 $strIdxFulltext = 'Tam metn (Fulltext)';
 $strIgnore = 'Diqqete Alma';
-$strIgnoringFile = '%s Diqqete Almama (Ignore) fayl';
-$strImportDocSQL = 'docSQL Fayllarn mport Et';
 $strImportFiles = 'Fayllar import et';
 $strIndexes = 'Indeksler';
 $strIndexHasBeenDropped = '%s indeksi lev edildi';
@@ -284,7 +263,6 @@ $strLatexContinued = '(davam)';
 $strLatexIncludeCaption = 'Cedvel baln daxil et';
 $strLatexLabel = 'Etiket aar';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX variantlar';
 $strLengthSet = 'Uzunluq/Deyerler*';
 $strLimitNumRows = 'Sehife bana den setir say';
 $strLinesTerminatedBy = 'Setir levedicisi (Lines terminated by)';
@@ -307,7 +285,7 @@ $strMIME_MIMEtype = 'MIME-tipi';
 $strMIME_nodescription = 'No Description is available for this transformation.<br />Please ask the author, what %s does.';
 $strMIME_transformation = 'Browser transformation';
 $strMIME_transformation_note = 'For a list of available transformation options and their MIME-type transformations, click on %stransformation descriptions%s';
-$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\', 100, b,\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_transformation_options = 'Transformasiya variantlar';
 $strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function';
 $strModifications = 'Modifications have been saved';
@@ -517,7 +495,6 @@ $strSort = 'Srala';
 $strSpaceUsage = 'Yer istifadesi';
 $strSplitWordsWithSpace = 'Szler boluq ifadesi (" ") ile ayrlmdr.';
 $strSQLExportType = 'Eksport ekli';
-$strSQLOptions = 'SQL variantlar';
 $strSQLParserBugMessage = 'There is a chance that you may have found a bug in the SQL parser. Please examine your query closely, and check that the quotes are correct and not mis-matched. Other possible failure causes may be that you are uploading a file with binary outside of a quoted text area. You can also try your query on the MySQL command line interface. The MySQL server error output below, if there is any, may also help you in diagnosing the problem. If you still have problems or if the parser fails where the command line interface succeeds, please reduce your SQL query input to the single query that causes problems, and submit a bug report with the data chunk in the CUT section below:';
 $strSQLParserUserError = 'There seems to be an error in your SQL query. The MySQL server error output below, if there is any, may also help you in diagnosing the problem';
 $strSQLQuery = 'SQL sorusu';
@@ -557,7 +534,6 @@ $strTableStructure = 'Table structure for table';
 $strTblPrivileges = 'Cedvelexas selahiyyetler';
 $strTextAreaLength = ' Uzun olduuna gre,<br /> bu sahedeki me\'lumatlar deyidirilmeye biler ';
 $strThisHost = 'Bu Host';
-$strThisNotDirectory = 'Bu direktoriya deyildi';
 $strThreadSuccessfullyKilled = 'Thread %s uurla sndrld (killed).';
 $strTime = 'Mddet';
 $strTotal = 'cemi';
@@ -567,7 +543,6 @@ $strTraffic = 'Neqliyyat';
 $strTransformation_image_jpeg__inline = 'Displays a clickable thumbnail; options: width,height in pixels (keeps the original ratio)';
 $strTransformation_image_jpeg__link = 'Displays a link to this image (direct blob download, i.e.).';
 $strTransformation_image_png__inline = 'See image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';
 $strTransformation_text_plain__external = 'LINUX ONLY: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';
 $strTransformation_text_plain__formatted = 'Preserves original formatting of the field. No Escaping is done.';
 $strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';
@@ -613,8 +588,6 @@ $strWelcome = '%s - e Xo Gelmisiniz!';
 $strWestEuropean = 'Qerbi Avropa';
 $strWildcard = 'xsusi iare';
 $strWithChecked = 'Seilenleri:';
-$strWritingCommentNotPossible = 'Qsa izahat yazl mmkn deyil';
-$strWritingRelationNotPossible = 'Elaqe yazl mmkn deyil';
 $strWrongUser = 'Yanl istifadei ad ve ya parol. Giri tesdiq edilmedi.';
 
 $strXML = 'XML';
@@ -626,7 +599,7 @@ $strZip = '"zip"lenmi';
 
 // To translate:
 $strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
-$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in config.inc.php and make sure that they correspond to the information given by the administrator of the MySQL server.';  //to translate
+$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in your configuration and make sure that they correspond to the information given by the administrator of the MySQL server.';  //to translate
 $strAddConstraints = 'Add constraints';  //to translate
 $strAddFields = 'Add %s field(s)';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
@@ -673,12 +646,10 @@ $strCopy = 'Copy';  //to translate
 $strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 $strCzech = 'Czech';  //to translate
 
 $strDanish = 'Danish';  //to translate
 $strDatabaseEmpty = 'The database name is empty!';  //to translate
-$strDatabaseNoTable = 'This database contains no table!';//to translate
 $strDataPages = 'Pages containing data';  //to translate
 $strDBCopy = 'Copy database to';  //to translate
 $strDBRename = 'Rename database to';  //to translate
@@ -719,10 +690,7 @@ $strIgnoreInserts = 'Use ignore inserts';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
 $strImport = 'Import';  //to translate
 $strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
 $strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
 $strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
 $strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
@@ -752,14 +720,12 @@ $strJoins = 'Joins';  //to translate
 $strKeyCache = 'Key cache';  //to translate
 $strKorean = 'Korean';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLatexContent = 'Content of table __TABLE__';//to translate
 $strLatexStructure = 'Structure of table __TABLE__';//to translate
 $strLatvian = 'Latvian';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLogServer = 'Server';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
@@ -794,7 +760,6 @@ $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPaperSize = 'Paper size';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPersian = 'Persian';  //to translate
@@ -903,7 +868,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -947,7 +912,6 @@ $strSortByKey = 'Sort by key';  //to translate
 $strSorting = 'Sorting';  //to translate
 $strSpanish = 'Spanish';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStrucNativeExcel = 'Native MS Excel data';  //to translate
 $strSwedish = 'Swedish';  //to translate
@@ -996,16 +960,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1018,4 +978,73 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
