@@ -1,5 +1,5 @@
 <?php
-/* $Id: azerbaijani-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: azerbaijani-utf-8.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 // tercümedeki eksiklerimi ve ya sehv olduğunu düşündüyünüz yerleri shehriyari@trcomm.net adresine göndere bilersiniz...
 // Şehriyar İmanov 30 Avqust 2003... Shehi
@@ -57,7 +57,6 @@ $strAscending = 'Artan sırada';
 $strAtBeginningOfTable = 'Cedvelin başına';
 $strAtEndOfTable = 'Cedvelin sonuna';
 $strAttr = 'Xüsusiyyetler';
-$strAutodetect = 'Avtomatik';
 $strAutomaticLayout = 'Automatik şablon';
 
 $strBack = 'Geri';
@@ -124,7 +123,6 @@ $strCreate = 'Qur';
 $strCreationDates = 'Quruluş/Deyişdirilme/Yoxlama tarixleri';
 $strCriteria = 'Kriteriyalar';
 $strCroatian = 'Xorvat Dili';
-$strCSVOptions = 'CSV variantları';
 $strCyrillic = 'Kiril';
 $strCzechSlovak = 'Çex-Slovak';
 
@@ -187,7 +185,6 @@ $strEnglishPrivileges = ' Qeyd: MySQL selahiyyet adları ingilis dilinde ifade e
 $strError = 'Xeta';
 $strEstonian = 'Eston Dili';
 $strExcelEdition = 'Excel versiyası';
-$strExcelOptions = 'Excel variantları';
 $strExplain = 'SQL-i İzah Et';
 $strExport = 'Eksport';
 $strExtendedInserts = 'Genişletilmiş girişli';
@@ -196,7 +193,6 @@ $strExtra = 'Elave Xüs.';
 $strFailedAttempts = 'Uğursuz Cehdler';
 $strFieldHasBeenDropped = '%s sahesi leğv edildi';
 $strField = 'Sahe';
-$strFieldsEmpty = ' Sahe sayğacı boşdur! ';
 $strFieldsEnclosedBy = 'Saheler ehate edildiyi işare';
 $strFieldsEscapedBy = 'Sahelerin escape edildiyi işare';
 $strFields = 'Sahe sayı';
@@ -228,15 +224,12 @@ $strHasBeenAltered = 'deyişdirildi.';
 $strHasBeenCreated = 'quruldu.';
 $strHaveToShow = 'Gösterilmesi üçün en az bir sütun seçmelisiniz';
 $strHebrew = 'İbrani Dili';
-$strHexForBinary = 'İkili saheler üçün hekzadesimaldan istifade et';
 $strHome = 'Başlanğıc';
 $strHomepageOfficial = 'phpMyAdmin Resmi İnternet Sehifesi';
 $strHostEmpty = 'Host adı boşdur!';
 $strHost = 'Host';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 eksport variantları';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 eksport variantları';
 $strHungarian = 'Macar Dili';
 
 $strId = 'Nömre';
@@ -245,8 +238,8 @@ $strIgnore = 'Diqqete Alma';
 $strImportFiles = 'Faylları import et';
 $strIndexes = 'Indeksler';
 $strIndexHasBeenDropped = '%s indeksi leğv edildi';
-$strIndex = 'İndeks';
 $strIndexName = 'İndex adı&nbsp;:';
+$strIndex = 'İndeks';
 $strIndexType = 'İndex tipi&nbsp;:';
 $strInnodbStat = 'InnoDB Status';
 $strInsecureMySQL = 'Konfiqurasiya faylınızda MySQL başlanğıc deyerleri (parolsuz root istifadeçisi) mövcuddur ki, bu da tehlükesizlik nöqteyi nezerinden e\'tibarlı deyildir.';
@@ -271,7 +264,6 @@ $strLatexContinued = '(davamı)';
 $strLatexIncludeCaption = 'Cedvel başlığını daxil et';
 $strLatexLabel = 'Etiket açarı';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX variantları';
 $strLengthSet = 'Uzunluq/Deyerler*';
 $strLimitNumRows = 'Sehife başına düşen setir sayı';
 $strLinesTerminatedBy = 'Setir leğvedicisi (Lines terminated by)';
@@ -491,8 +483,8 @@ $strShowAll = 'Hamısını göster';
 $strShowColor = 'Rengini göster';
 $strShowDatadictAs = 'Data Dictionary Format';
 $strShowFullQueries = 'Emrleri Tam Olaraq Göster';
-$strShow = 'Göster';
 $strShowGrid = 'Show grid';
+$strShow = 'Göster';
 $strShowingRecords = 'Gösterilen setirler';
 $strShowPHPInfo = 'PHPInfo() me\'lumatını göster';
 $strShowTableDimension = 'Cedvellerin ölçülerini göster';
@@ -504,7 +496,6 @@ $strSort = 'Sırala';
 $strSpaceUsage = 'Yer istifadesi';
 $strSplitWordsWithSpace = 'Sözler boşluq ifadesi (" ") ile ayrılmışdır.';
 $strSQLExportType = 'Eksport şekli';
-$strSQLOptions = 'SQL variantları';
 $strSQLParserBugMessage = 'There is a chance that you may have found a bug in the SQL parser. Please examine your query closely, and check that the quotes are correct and not mis-matched. Other possible failure causes may be that you are uploading a file with binary outside of a quoted text area. You can also try your query on the MySQL command line interface. The MySQL server error output below, if there is any, may also help you in diagnosing the problem. If you still have problems or if the parser fails where the command line interface succeeds, please reduce your SQL query input to the single query that causes problems, and submit a bug report with the data chunk in the CUT section below:';
 $strSQLParserUserError = 'There seems to be an error in your SQL query. The MySQL server error output below, if there is any, may also help you in diagnosing the problem';
 $strSQLQuery = 'SQL sorğusu';
@@ -575,12 +566,12 @@ $strUseBackquotes = 'Cedvel ve sahe adlarını tek dırnaq arasına al';
 $strUseHostTable = 'Use Host Table';
 $strUserAlreadyExists = '%s istifadeçisi mövcuddur!';
 $strUserEmpty = 'İstifadeçi adı boş qaldı!';
-$strUser = 'İstifadeçi';
 $strUserName = 'İstifadeçi adı';
 $strUserNotFound = 'The selected user was not found in the privilege table.';
 $strUserOverview = 'User overview';
 $strUsersDeleted = 'The selected users have been deleted successfully.';
 $strUsersHavingAccessToDb = 'Users having access to &quot;%s&quot;';
+$strUser = 'İstifadeçi';
 $strUseTables = 'Use Tables';
 $strUseTextField = 'Use text field';
 
@@ -609,7 +600,7 @@ $strZip = '"zip"lenmiş';
 
 // To translate:
 $strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
-$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in config.inc.php and make sure that they correspond to the information given by the administrator of the MySQL server.';  //to translate
+$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in your configuration and make sure that they correspond to the information given by the administrator of the MySQL server.';  //to translate
 $strAddConstraints = 'Add constraints';  //to translate
 $strAddFields = 'Add %s field(s)';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
@@ -656,12 +647,10 @@ $strCopy = 'Copy';  //to translate
 $strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 $strCzech = 'Czech';  //to translate
 
 $strDanish = 'Danish';  //to translate
 $strDatabaseEmpty = 'The database name is empty!';  //to translate
-$strDatabaseNoTable = 'This database contains no table!';//to translate
 $strDataPages = 'Pages containing data';  //to translate
 $strDBCopy = 'Copy database to';  //to translate
 $strDBRename = 'Rename database to';  //to translate
@@ -702,10 +691,7 @@ $strIgnoreInserts = 'Use ignore inserts';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
 $strImport = 'Import';  //to translate
 $strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
 $strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
 $strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
 $strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
@@ -735,14 +721,12 @@ $strJoins = 'Joins';  //to translate
 $strKeyCache = 'Key cache';  //to translate
 $strKorean = 'Korean';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLatexContent = 'Content of table __TABLE__';//to translate
 $strLatexStructure = 'Structure of table __TABLE__';//to translate
 $strLatvian = 'Latvian';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLogServer = 'Server';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
@@ -777,7 +761,6 @@ $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPaperSize = 'Paper size';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPersian = 'Persian';  //to translate
@@ -886,7 +869,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -930,7 +913,6 @@ $strSortByKey = 'Sort by key';  //to translate
 $strSorting = 'Sorting';  //to translate
 $strSpanish = 'Spanish';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStrucNativeExcel = 'Native MS Excel data';  //to translate
 $strSwedish = 'Swedish';  //to translate
@@ -964,7 +946,7 @@ $strUnsupportedCompressionDetected = 'You attempted to load file with unsupporte
 $strUpgrade = 'You should upgrade to %s %s or later.';  //to translate
 $strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
 $strUsedPhpExtensions = 'Used PHP extensions';  //to translate
-$strUseTabKey = 'TAB düymesine basaraq bir sonrakı deyere, ve ya CTRL+Ox kombinasiyasını istifade ederek istediyiniz yöne keçe bilersiniz.';  //to translate
+$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
 $strUseThisValue = 'Use this value';  //to translate
 
 $strVersionInformation = 'Version information';  //to translate
@@ -979,16 +961,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1004,7 +982,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1049,4 +1026,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
