@@ -1,5 +1,5 @@
 <?php
-/* $Id: belarusian_cyrillic-windows-1251.inc.php 9853 2007-01-19 18:14:44Z lem9 $ */
+/* $Id: belarusian_cyrillic-windows-1251.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /**
  *     Translated by:
@@ -32,7 +32,7 @@ $strAddClause = ' %s';
 $strAddConstraints = ' ';
 $strAddDeleteColumn = '/  ';
 $strAddDeleteRow = '/  ';
-$strAddFields = '  ';
+$strAddFields = ' %s  ';
 $strAddHeaderComment = '     (\\n  )';
 $strAddIntoComments = '  ';
 $strAddNewField = '  ';
@@ -68,7 +68,6 @@ $strAscending = '';
 $strAtBeginningOfTable = '  ';
 $strAtEndOfTable = '  ';
 $strAttr = '';
-$strAutodetect = '';
 $strAutomaticLayout = ' ';
 
 $strBack = '';
@@ -179,8 +178,6 @@ $strCreationDates = '// ';
 $strCriteria = '';
 $strCroatian = '';
 $strCSV = 'CSV';
-$strCSVImportOptions = ' CSV';
-$strCSVOptions = ' CSV';
 $strCyrillic = 'ʳ';
 $strCzechSlovak = '';
 $strCzech = '';
@@ -191,7 +188,6 @@ $strDatabase = ' ';
 $strDatabaseEmpty = '    !';
 $strDatabaseExportOptions = '   ';
 $strDatabaseHasBeenDropped = '  %s  .';
-$strDatabaseNoTable = '     !';
 $strDatabases = ' ';
 $strDatabasesDropped = '%s     .';
 $strDatabasesStatsDisable = ' ';
@@ -264,7 +260,6 @@ $strEscapeWildcards = '  _  %     \    ';
 $strEsperanto = '';
 $strEstonian = '';
 $strExcelEdition = ' Excel';
-$strExcelOptions = ' Excel';
 $strExecuteBookmarked = '   ';
 $strExplain = ' SQL';
 $strExportMustBeFile = '        !';
@@ -275,7 +270,6 @@ $strExtra = '';
 $strFailedAttempts = ' ';
 $strFieldHasBeenDropped = ' %s  ';
 $strField = '';
-$strFieldsEmpty = '    븢! ';
 $strFieldsEnclosedBy = '  ';
 $strFieldsEscapedBy = ' ';
 $strFields = '';
@@ -322,15 +316,12 @@ $strHasBeenAltered = ' .';
 $strHasBeenCreated = ' .';
 $strHaveToShow = '       ';
 $strHebrew = '';
-$strHexForBinary = '     븢';
 $strHome = ' ';
 $strHomepageOfficial = '  phpMyAdmin';
 $strHostEmpty = '  !';
 $strHost = '';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = ' Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = ' Microsoft Word 2000';
 $strHungarian = '';
 
 $strIcelandic = '';
@@ -348,10 +339,7 @@ $strIndexes = '';
 $strIndexHasBeenDropped = ' %s  ';
 $strIndexName = ' :';
 $strIndexType = ' :';
-$strIndexWarningMultiple = '   %s      `%s`';
-$strIndexWarningPrimary = '  PRIMARY  INDEX      `%s`';
 $strIndexWarningTable = '     `%s`';
-$strIndexWarningUnique = '  UNIQUE  INDEX      `%s`';
 $strInnoDBAutoextendIncrement = ' ';
 $strInnoDBAutoextendIncrementDesc = '        ,   .';
 $strInnoDBBufferPoolSizeDesc = '   ,  InnoDB       .';
@@ -397,7 +385,6 @@ $strKill = '';
 $strKorean = '';
 
 $strLandscape = '';
-$strLanguageFileNotFound = '  "%1$s"  .';
 $strLanguage = '';
 $strLanguageUnknown = ' : %1$s.';
 $strLatchedPages = 'Գ ';
@@ -408,11 +395,9 @@ $strLatexContinued = '()';
 $strLatexIncludeCaption = '  ';
 $strLatexLabel = ' ';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = ' LaTeX';
 $strLatexStructure = '  __TABLE__';
 $strLatvian = '';
 $strLDI = 'CSV   LOAD DATA';
-$strLDIImportOptions = ' CSV-,  LOAD DATA';
 $strLDILocal = '   LOCAL';
 $strLengthSet = '/*';
 $strLimitNumRows = '   ';
@@ -513,8 +498,6 @@ $strNumTables = '';
 
 $strOK = 'OK';
 $strOpenDocumentSpreadsheet = ' Open Document';
-$strOpenDocumentSpreadsheetOptions = '  Open Document';
-$strOpenDocumentTextOptions = '  Open Document';
 $strOpenDocumentText = ' Open Document';
 $strOpenNewWindow = '   phpMyAdmin';
 $strOperations = '';
@@ -537,7 +520,6 @@ $strPasswordNotSame = '  !';
 $strPdfDbSchema = '  "%s"   %s';
 $strPdfInvalidTblName = ' "%s"  !';
 $strPdfNoTables = ' ';
-$strPDFOptions = ' PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(     )';
 $strPDFReportTitle = ' ';
@@ -781,7 +763,7 @@ $strShowStatusKey_readsDescr = '      .   Key_reads ,  key_buffer_size, ,  .
 $strShowStatusKey_write_requestsDescr = '       .';
 $strShowStatusKey_writesDescr = '      .';
 $strShowStatusLast_query_costDescr = '    ,   .        .    0 ,       .';
-$strShowStatusNot_flushed_delayed_rowsDescr = '   ,   INSERT DELAY.';
+$strShowStatusNot_flushed_delayed_rowsDescr = '   ,   INSERT DELAYED.';
 $strShowStatusOpened_tablesDescr = ' ,   .    ,      .';
 $strShowStatusOpen_filesDescr = '  .';
 $strShowStatusOpen_streamsDescr = '   (   ).';
@@ -834,8 +816,6 @@ $strSpanish = 'ó';
 $strSplitWordsWithSpace = '   (" ").';
 $strSQLCompatibility = '  SQL';
 $strSQLExportType = ' ';
-$strSQLImportOptions = ' SQL';
-$strSQLOptions = ' SQL';
 $strSQLParserBugMessage = ',     SQL-.  ,         .       ,        -  ,  .           MySQL.     MySQL  ,       .           ,      ,  ,    SQL-   ,   ,        ,    CUT :';
 $strSQLParserUserError = ',  SQL-  .     MySQL  , ,      ';
 $strSQLQuery = 'SQL-';
@@ -856,7 +836,6 @@ $strStrucCSV = 'CSV';
 $strStrucData = '  ';
 $strStrucExcelCSV = 'CSV   MS Excel';
 $strStrucNativeExcel = '  MS Excel';
-$strStrucNativeExcelOptions = '    Excel';
 $strStrucOnly = ' ';
 $strStructPropose = '  ';
 $strStructure = '';
@@ -972,7 +951,6 @@ $strWithChecked = ' :';
 $strWriteRequests = ' ';
 $strWrongUser = ' /.   .';
 
-$strXMLOptions = ' XML';
 $strXML = 'XML';
 
 $strYes = '';
@@ -983,7 +961,6 @@ $strZip = '  zip';
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1028,4 +1005,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
