@@ -1,5 +1,5 @@
 <?php
-/* $Id: bosnian-windows-1250.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: bosnian-windows-1250.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /**
  *     Translated by:
@@ -57,7 +57,6 @@ $strAscending = 'Rastui';
 $strAtBeginningOfTable = 'Na poetku tabele';
 $strAtEndOfTable = 'Na kraju tabele';
 $strAttr = 'Atributi';
-$strAutodetect = 'automatski';
 $strAutomaticLayout = 'Automatski raspored';
 
 $strBack = 'Nazad';
@@ -129,7 +128,6 @@ $strCreatePage = 'Napravi novu stranu';
 $strCreatePdfFeat = 'Pravljenje PDF-ova';
 $strCriteria = 'Kriterijum';
 $strCroatian = 'Hrvatski';
-$strCSVOptions = 'CSV opcije';
 $strCyrillic = 'irilini';
 $strCzech = 'eki';
 
@@ -137,7 +135,6 @@ $strDanish = 'Danski';
 $strDatabase = 'Baza podataka';
 $strDatabaseExportOptions = 'Opcije za izvoz baze';
 $strDatabaseHasBeenDropped = 'Baza %s je odbaena.';
-$strDatabaseNoTable = 'Baza ne sadri tabele!';
 $strDatabases = 'Baze';
 $strDatabasesDropped = '%s baza je uspjeno odbaena.';
 $strDatabasesStatsDisable = 'Iskljui statistike';
@@ -190,7 +187,6 @@ $strEnglish = 'Engleski';
 $strEnglishPrivileges = ' Napomena: MySQL imena privilegija moraju da budu na engleskom ';
 $strError = 'Greka';
 $strEstonian = 'Estonski';
-$strExcelOptions = 'Excel opcije';
 $strExecuteBookmarked = 'Izvri upamen upit';
 $strExplain = 'Objasni SQL';
 $strExport = 'Izvoz';
@@ -200,7 +196,6 @@ $strExtra = 'Dodatno';
 $strFailedAttempts = 'Neuspelih pokuaja';
 $strFieldHasBeenDropped = 'Polje %s je obrisano';
 $strField = 'Polje';
-$strFieldsEmpty = ' Broj polja je nula! ';
 $strFieldsEnclosedBy = 'Polja ograniena sa';
 $strFieldsEscapedBy = 'Escape karakter &nbsp; &nbsp; &nbsp;';
 $strFields = 'Polja';
@@ -268,7 +263,6 @@ $strKorean = 'Korejski';
 
 $strLandscape = 'Poloeno';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX opcije';
 $strLengthSet = 'Duina/Vrijednost*';
 $strLimitNumRows = 'Broj redova po strani';
 $strLinesTerminatedBy = 'Linije se zavravaju sa';
@@ -501,7 +495,6 @@ $strSize = 'Veliina';
 $strSort = 'Sortiranje';
 $strSpaceUsage = 'Zauzee';
 $strSplitWordsWithSpace = 'Rijei se odvajaju razmakom (" ").';
-$strSQLOptions = 'SQL opcije';
 $strSQLParserBugMessage = 'Postoji mogunost da ste pronali gresku u SQL parseru. Molimo ispitajte svoj upit paljivo, i provjerite da su navodnici ispravni i da ne nedostaju. Ostali mogui razlozi greke mogu biti da ste poslali binarni fajl van oblasti za obian tekst. Moete probati svoj upit u MySQL interfejsu komandne linije. Donja poruka o greci MySQL servera, ako je ima, moe vam pomoi u otkrivanju problema. Ako i dalje imate probleme ili ako parser ne uspjeva tamo gde uspeva interfejs komandne linije, svedite svoj SQL upit na jedan jedini upit koji stvara probleme i poaljite nam izvjetaj o greci sa delom koda u donjoj REZ sekciji:';
 $strSQLParserUserError = 'Izgleda da postoji greka u vaem SQL upitu. Ovde je poruka o greki MySQL servera, koja vam moe pomoi u otkrivanju problema';
 $strSQLQuery = 'SQL upit';
@@ -656,7 +649,6 @@ $strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCreationDates = 'Creation/Update/Check dates';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 $strCzechSlovak = 'Czech-Slovak';  //to translate
 
 $strDatabaseEmpty = 'The database name is empty!';  //to translate
@@ -695,11 +687,8 @@ $strGeneratePassword = 'Generate Password';  //to translate
 $strGeorgian = 'Georgian';  //to translate
 
 $strHandler = 'Handler';  //to translate
-$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIcelandic = 'Icelandic';  //to translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
@@ -707,10 +696,7 @@ $strIgnoreInserts = 'Use ignore inserts';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
 $strImport = 'Import';  //to translate
 $strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
 $strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
 $strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
 $strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
@@ -738,7 +724,6 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLatexCaption = 'Table caption';  //to translate
@@ -750,7 +735,6 @@ $strLatexLabel = 'Label key';  //to translate
 $strLatexStructure = 'Structure of table __TABLE__';  //to translate
 $strLatvian = 'Latvian';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLogServer = 'Server';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
@@ -789,7 +773,6 @@ $strOperator = 'Operator';  //to translate
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPersian = 'Persian';  //to translate
@@ -894,7 +877,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -938,7 +921,6 @@ $strSorting = 'Sorting';  //to translate
 $strSpanish = 'Spanish';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
 $strSQLExportType = 'Export type';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
@@ -981,16 +963,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1006,7 +984,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1051,4 +1028,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
