@@ -1,16 +1,11 @@
 <?php
-/* $Id: brazilian_portuguese-iso-8859-1.inc.php,v 2.143.2.2 2006/08/30 10:43:14 nijel Exp $ */
-
-/**
- * translated by: 
-   Airon Luis Pereira <aironp@pop.com.br> 
-*/ 
+/* $Id: brazilian_portuguese-iso-8859-1.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
+/* translated by: Airon Luis Pereira <airon(dot)pereira(at)gmail(dot)com> */ 
 
 $charset = 'iso-8859-1'; 
-$text_dir = 'ltr'; 
+$text_dir = 'ltr';  // ('ltr' da esquerda para direita, 'rtl' da direita para esquerda)
 $number_thousands_separator = ','; 
 $number_decimal_separator = '.'; 
-
 // abreviaes para Byte, Kilo, Mega, Giga, Tera, Peta, Exa 
 $byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB'); 
 
@@ -18,7 +13,6 @@ $mysql_4_1_doc_lang = 'pt';
 
 $day_of_week = array('Dom', 'Seg', 'Ter', 'Qua', 'Qui', 'Sex', 'Sab'); 
 $month = array('Jan', 'Fev', 'Mar', 'Abr', 'Mai', 'Jun', 'Jul', 'Ago', 'Set', 'Out', 'Nov', 'Dez'); 
-
 // Veja http://www.php.net/manual/en/function.strftime.php para definir
 // as variveis abaixo
 $datefmt = '%B %d, %Y as %I:%M %p'; 
@@ -26,18 +20,15 @@ $datefmt = '%B %d, %Y as %I:%M %p';
 $timespanfmt = '%s dias, %s horas, %s minutos e %s segundos'; 
 
 $strAbortedClients = 'Abortado'; 
-$strAbsolutePathToDocSqlDir = 'Digite o caminho absoluto do diretrio docSQL do servidor Web'; 
 $strAccessDenied = 'Acesso negado'; 
 $strAccessDeniedCreateConfig = 'A provvel razo para isso  que voc no criou o arquivo de configurao. Voc deve usar o %1$ssetup script%2$s para criar um.';
-$strAccessDeniedExplanation = 'phpMyAdmin tentou se conectar no servidor MySQL e a conxo foi recusada. Voc deve checar o host, nome de usurio e senha no config.inc.php e se certificar que correspondam com as informaes fornecidas pelo administrador do servidor MySQL.'; 
-$strAction = 'Aes'; 
+$strAccessDeniedExplanation = 'phpMyAdmin tentou se conectar no servidor MySQL e a conxo foi recusada. Voc deve checar o servidor, nome de usurio e senha no config.inc.php e se certificar que correspondam com as informaes fornecidas pelo administrador do servidor MySQL.'; 
+$strAction = 'Ao'; 
 $strAddAutoIncrement = 'Adicionar valor AUTO_INCREMENT'; 
 $strAddClause = 'Adicionar %s';
 $strAddConstraints = 'Adicionar restries'; 
 $strAddDeleteColumn = 'Adicionar/Remover colunas'; 
-$strAddDeleteRow = 'Adicionar/Remover condies de busca'; 
-$strAddedColumnComment = 'Adicionado comentrio para a coluna'; 
-$strAddedColumnRelation = 'Adicionada relao para a coluna'; 
+$strAddDeleteRow = 'Adicionar/Remover critrios de busca'; 
 $strAddFields = 'Adicionar %s campo(s)'; 
 $strAddHeaderComment = 'Adicionar comentrio pessoal no cabealho (\\n quebra linhas)'; 
 $strAddIntoComments = 'Adicionar nos comentrios'; 
@@ -62,6 +53,7 @@ $strAlterOrderBy = 'Alterar tabela ordenada por';
 $strAnalyzeTable = 'Analizar tabela'; 
 $strAnd = 'E'; 
 $strAndThen = 'e ento';
+$strAngularLinks = 'Links Angulares';
 $strAnIndex = 'Um ndice foi adicionado a %s'; 
 $strAnyHost = 'Qualquer servidor'; 
 $strAny = 'Qualquer'; 
@@ -74,7 +66,6 @@ $strAscending = 'Ascendente';
 $strAtBeginningOfTable = 'No incio da tabela'; 
 $strAtEndOfTable = 'No final da tabela'; 
 $strAttr = 'Atributos'; 
-$strAutodetect = 'Auto-detectar'; 
 $strAutomaticLayout = 'Leiaute automtico'; 
 
 $strBack = 'Voltar'; 
@@ -114,6 +105,7 @@ $strBzError = 'phpMyAdmin no foi capaz de comprimir o dump devido a um defeito n
 $strBzip = '"compactado com bzip"'; 
 
 $strCalendar = 'Calendrio'; 
+$strCancel = 'Cancelar';
 $strCanNotLoadExportPlugins = 'No pode carregar exportao dos plugins, verifique sua instalao!';
 $strCanNotLoadImportPlugins = 'No foi possvel importar plugins, verifique sua instalao!';
 $strCannotLogin = 'No foi possvel se logar no servidor MySQL'; 
@@ -162,6 +154,7 @@ $strConnectionError = 'No pode conectar: configuraes invlidas.';
 $strConnections = 'Conexes'; 
 $strConstraintsForDumped = 'Restries para as tabelas dumpadas'; 
 $strConstraintsForTable = 'Restries para a tabela'; 
+$strControluserFailed = 'Conexo para controle do usurio como definido nas configuraes falhou.';
 $strCookiesRequired = 'Cookies devem estar ativos aps este ponto.'; 
 $strCopy = 'Copiar';
 $strCopyDatabaseOK = 'Banco de Dados %s copiado para %s'; 
@@ -177,6 +170,8 @@ $strCreateNewDatabase = 'Criar novo Banco de Dados';
 $strCreateNewTable = 'Criar nova tabela no Banco de Dados %s'; 
 $strCreatePage = 'Criar uma nova pgina'; 
 $strCreatePdfFeat = 'Criao de PDFs'; 
+$strCreateRelation = 'Criar relacionamento';
+$strCreateTable  = 'Criar tabela';
 $strCreateUserDatabase = 'Banco de Dados para usurio';
 $strCreateUserDatabaseName = 'Criar Banco de Dados com o mesmo nome e conceder todos os privilgios';
 $strCreateUserDatabaseNone = 'Nenhum';
@@ -185,8 +180,6 @@ $strCreationDates = 'Criar/Atualizar/Verificar datas';
 $strCriteria = 'Critrio'; 
 $strCroatian = 'Croata'; 
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Opes CSV';
-$strCSVOptions = 'Opes CSV'; 
 $strCyrillic = 'Cirlico'; 
 $strCzechSlovak = 'Tcheco-Eslovquio'; 
 $strCzech = 'Tcheco'; 
@@ -196,7 +189,6 @@ $strDatabase = 'Banco de Dados';
 $strDatabaseEmpty = 'O nome do Banco de Dados est em branco!'; 
 $strDatabaseExportOptions = 'Opes de exportao do Banco de Dados'; 
 $strDatabaseHasBeenDropped = 'Banco de Dados %s foi eliminado.'; 
-$strDatabaseNoTable = 'Esse Banco de Dados no possui tabelas!'; 
 $strDatabases = 'Banco de Dados'; 
 $strDatabasesDropped = 'Banco de Dados %s foi eliminado com sucesso!'; 
 $strDatabasesStatsDisable = 'Disabilitar estatsticas'; 
@@ -209,15 +201,7 @@ $strDataOnly = 'Dados apenas';
 $strDataPages = 'Pginas contendo dados';
 $strDBComment = 'Comentrio do Banco de Dados: '; 
 $strDBCopy = 'Copiar Banco de Dados para'; 
-$strDBGContext = 'Contexto'; 
-$strDBGContextID = 'ID do contexto'; 
-$strDBGHits = 'Hits'; 
-$strDBGLine = 'Linha'; 
-$strDBGMaxTimeMs = 'Tempo mx, ms'; 
-$strDBGMinTimeMs = 'Tempo min, ms'; 
-$strDBGModule = 'Mdulo'; 
-$strDBGTimePerHitMs = 'Tempo/Hit, ms'; 
-$strDBGTotalTimeMs = 'Tempo total, ms'; 
+$strDbIsEmpty = 'Banco de Dados parece estar vazio!';
 $strDbPrivileges = 'Privilgios especficos do Banco de Dados'; 
 $strDBRename = 'Renomear Banco de Dados para'; 
 $strDbSpecific = 'Especfico do Banco de Dados'; 
@@ -231,13 +215,17 @@ $strDeleteAndFlushDescr = 'Esse  o caminho mais claro, mas recarregar os privilg
 $strDeleted = 'Registro eliminado'; 
 $strDeletedRows = 'Registros eliminados:'; 
 $strDeleteNoUsersSelected = 'Nenhum usurio selecionado para excluso!';
+$strDeleteRelation = 'Apagar relacionamento';
 $strDelete = 'Remover'; 
 $strDeleting = 'Eliminando %s'; 
 $strDelimiter = 'Delimitadores';
 $strDelOld = 'A Pgina atual contm referncias para uma tabela que no existe. Gostaria de eliminar estas referncias?'; 
 $strDescending = 'Descendente'; 
 $strDescription = 'Descrio'; 
+$strDesigner = 'Designer';
+$strDesignerHelpDisplayField = 'O campo de exibio est em rosa. Para ajustar/desajustar um campo como campo de exibio, clique no cone "Escolher campo para exibio", ento clique no nome do campo apropriado.';
 $strDictionary = 'dicionrio'; 
+$strDirectLinks = 'Links diretos';
 $strDirtyPages = 'Pginas sujas';
 $strDisabled = 'Desabilitado'; 
 $strDisableForeignChecks = 'Desabilitar verificao de chaves estrangeiras'; 
@@ -245,8 +233,9 @@ $strDisplayFeat = 'Exibir recursos';
 $strDisplayOrder = 'Ordenado por:'; 
 $strDisplayPDF = 'Exibir esquema PDF'; 
 $strDoAQuery = 'Faa uma "consulta por exemplo" (coringa: "%")'; 
+$strDocSQL = 'DocSQL';
 $strDocu = 'Documentao'; 
-$strDoYouReally = 'Confirmar: '; 
+$strDoYouReally = 'Confirmar'; 
 $strDropDatabaseStrongWarning = 'Voc est prestes  DESTRUIR completamente o Banco de Dados!'; 
 $strDrop = 'Eliminar'; 
 $strDropUsersDb = 'Eliminar o Banco de Dados que possui o mesmo nome dos usurios.'; 
@@ -259,7 +248,7 @@ $strEdit = 'Editar';
 $strEditPDFPages = 'Editar Pginas PDF'; 
 $strEditPrivileges = 'Editar Privilgios'; 
 $strEffective = 'Efetivo'; 
-$strEmpty = 'Limpa'; 
+$strEmpty = 'Limpar'; 
 $strEmptyResultSet = 'MySQL retornou um conjunto vazio (ex. zero registros).'; 
 $strEnabled = 'Habilitado'; 
 $strEncloseInTransaction = 'Encapsular exportao numa transao'; 
@@ -268,21 +257,25 @@ $strEnd = 'Fim';
 $strEndRaw = 'FIM CRU'; 
 $strEngineAvailable = '%s est disponvel neste servidor MySQL.';
 $strEngineDisabled = '%s est desabilitado neste servidor MySQL.';
-$strEngines = 'Engines';
+$strEngines = 'Engines'; //sem traducao
 $strEngineUnsupported = 'Esse servidor MySQL no suporta o stored engine %s.';
 $strEnglish = 'Ingls'; 
 $strEnglishPrivileges = ' Nota: nomes de privilgios do MySQL so expressos em ingls '; 
 $strError = 'Erro'; 
 $strErrorInZipFile = 'Erro no arquivo ZIP:';
+$strErrorRelationAdded = 'Erro: relacionamento no adicionado.';
+$strErrorRelationExists = 'Erro: relacionamento j existe.';
 $strErrorRenamingTable = 'Erro ao renomear tabela %1$s para %2$s';
+$strErrorSaveTable = 'Erro ao salvar coordenada para o Designer.';
 $strEscapeWildcards = 'Coringas _ e % precisam ser precedidos com uma \ para serem usados literalmente'; 
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estoniano'; 
+$strEvent = 'Evento';
 $strExcelEdition = 'Edio do Excel'; 
-$strExcelOptions = 'Opes do Excel'; 
 $strExecuteBookmarked = 'Executar consulta marcada'; 
 $strExplain = 'Explicar SQL'; 
 $strExport = 'Exportar'; 
+$strExportImportToScale = 'Exportar/Importar para escala';
 $strExportMustBeFile = 'Tipo de exportao selecionada tem que ser salva no arquivo!';
 $strExtendedInserts = 'Inseres extendidas'; 
 $strExtra = 'Extra'; 
@@ -290,8 +283,8 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Tentativas falharam'; 
 $strField = 'Campo'; 
 $strFieldHasBeenDropped = 'Campo %s foi deletado'; 
+$strFieldInsertFromFileTempDirNotExists = 'Erro ao mover o arquivo carregado, veja FAQ 1.11';
 $strFields = 'Campos'; 
-$strFieldsEmpty = ' O campo count esta vazio! '; 
 $strFieldsEnclosedBy = 'Campos delimitados por'; 
 $strFieldsEscapedBy = 'Campos contornados por'; 
 $strFieldsTerminatedBy = 'Campos terminados por'; 
@@ -303,6 +296,7 @@ $strFileNameTemplateDescriptionServer = 'nome do servidor';
 $strFileNameTemplateDescriptionTable = 'nome da tabela';
 $strFileNameTemplate = 'Nome do arquivo do modelo'; 
 $strFileNameTemplateRemember = 'lembrar modelo'; 
+$strFiles = 'Arquivos';
 $strFileToImport = 'Arquivo para importar';
 $strFixed = 'fixo'; 
 $strFlushPrivilegesNote = 'Nota: O phpMyAdmin recebe os privilgios dos usurio diretamente da tabela de privilgios do MySQL. O contedo destas tabelas pode divergir dos privilgios que o servidor usa se alteraes manuais forem feitas nele. Neste caso, voc deve usar %sRELOAD PRIVILEGES%s antes de continuar..'; 
@@ -310,6 +304,7 @@ $strFlushQueryCache = 'Nivelar cache da consulta';  //est correto isso?
 $strFlushTable = 'Limpar a tabela ("LIMPAR")'; 
 $strFlushTables = 'Nivelar (fechar) todas as tabelas';  //est correto isso?
 $strFontSize = 'Tamanho da fonte';
+$strForeignKeyError = 'Erro na criao da chave estrangeira (cheque o tipo de dado)';
 $strFormat = 'Formato'; 
 $strFormEmpty = 'Faltando valores no formulrio!'; 
 $strFreePages = 'Pginas livres';
@@ -337,38 +332,38 @@ $strHasBeenAltered = 'foi alterado.';
 $strHasBeenCreated = 'foi criado.'; 
 $strHaveToShow = 'Deve escolher pelo menos uma coluna para exibir'; 
 $strHebrew = 'Hebreu'; 
-$strHexForBinary = 'Usar hexadecimal para campos binrios'; 
+$strHelp = 'Ajuda';
+$strHexForBLOB = 'Usar hexadecimal para BLOB';
+$strHide = 'Ocultar';
+$strHideShowAll = 'Ocultar/Exibir tudo';
+$strHideShowNoRelation = 'Ocultar/Exibir Tabelas sem relacionamento';
 $strHomepageOfficial = 'Pgina Oficial do phpMyAdmin'; 
 $strHome = 'Principal'; 
 $strHostEmpty = 'O nome do servidor est vazio!'; 
 $strHost = 'Servidor'; 
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Opes de exportao: Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Opes de exportao: Microsoft Word 2000';
 $strHungarian = 'Hngaro'; 
 
 $strIcelandic = 'Islands'; 
 $strId = 'ID'; 
 $strIdxFulltext = 'Texto completo'; 
+$strIEUnsupported = 'Internet Explorer no suporta esta funo.';
 $strIgnoreDuplicates = 'Ignorar linhas duplicadas';
 $strIgnore = 'Ignorar'; 
 $strIgnoreInserts = 'Usar inseres ignoradas'; 
-$strIgnoringFile = 'Ignorar arquivo %s'; 
-$strImportDocSQL = 'Importar arquivos docSQL'; 
+$strImportExportCoords = 'Importar/Exportar coordenadas para esquema PDF';
 $strImportFiles = 'Importar arquivos'; 
 $strImportFormat = 'Formato do arquivo importado';
 $strImport = 'Importar';
 $strImportSuccessfullyFinished = 'Importao finalizada com sucesso, %d consultas executadas.';
 $strIndexes = 'ndices'; 
+$strIndexesSeemEqual = 'Os seguintes ndices parecem ser idnticos e um deles deve ser removido:';
 $strIndexHasBeenDropped = 'ndice %s foi eliminado'; 
 $strIndex = 'ndice'; 
 $strIndexName = 'Nome do ndice:'; 
 $strIndexType = 'Tipo de ndice:'; 
-$strIndexWarningMultiple = 'Mais de uma %s chave foi criada para a coluna `%s`'; 
-$strIndexWarningPrimary = 'Chaves PRIMARY e INDEX no podem ser usadas juntas para a coluna `%s`'; 
 $strIndexWarningTable = 'Problemas com o ndice da tabela `%s`'; 
-$strIndexWarningUnique = 'Chaves UNIQUE e INDEX no podem ser usadas juntas para a coluna `%s`'; 
 $strInnoDBAutoextendIncrementDesc = 'O tamanho do incremento para extender o tamanho de um tamanho de tabela autoextendida quando ela comear  ficar cheia.';
 $strInnoDBAutoextendIncrement = 'Incremento autoextendido';
 $strInnoDBBufferPoolSizeDesc = 'O tamanho do buffer de memria que o InnoDB usa para dados do cache e ndices nas suas tabelas.';
@@ -377,18 +372,20 @@ $strInnoDBDataFilePath = 'Arquivos de dados';
 $strInnoDBDataHomeDirDesc = 'A parte comum do caminho do diretrio para todos os arquivos de dados do InnoDB.';
 $strInnoDBDataHomeDir = 'Diretrio raiz de dados';
 $strInnoDBPages = 'pginas';
+$strInnoDBRelationAdded = 'Adicionado relacionamento InnoDB';
 $strInnodbStat = 'Status do InnoDB'; 
 $strInsecureMySQL = 'O seu arquivo de configurao contm configuraes (root sem senha) que correspondem  conta privilegiada padro do MySQL. O servidor MySQL rodando com esse padro estar aberto a invases, voc realmente deveria corrigir este furo de segurana.'; 
-$strInsertAsNewRow = 'Inserir uma nova coluna'; 
+$strInsertAsNewRow = 'Inserir como um novo registro'; 
 $strInsertedRowId = 'Inserir ID do registro:'; 
 $strInsertedRows = 'Registros inseridos:'; 
 $strInsert = 'Inserir'; 
 $strInternalNotNecessary = '* No  necessria uma relao interna quando tambm j existe na InnoDB.'; 
+$strInternalRelationAdded = 'Adicionado relacionamento Interno';
 $strInternalRelations = 'Relaes internas'; 
 $strInUse = 'em uso'; 
 $strInvalidAuthMethod = 'Mtodo de autenticao invlido informado nas configuraes:';
 $strInvalidColumn = 'Coluna especificada (%s)  invlida!';
-$strInvalidColumnCount = 'Contador da coluna deve ser mais largo que zero.';
+$strInvalidColumnCount = 'Contador da coluna deve ser maior que zero.';
 $strInvalidCSVFieldCount = 'Contador de campo invlido na linha %d da entrada CSV.';
 $strInvalidCSVFormat = 'Formato invlido na linha %d da entrada CSV.';
 $strInvalidCSVParameter = 'Parmetro invlido para importao CSV: %s';
@@ -397,7 +394,7 @@ $strInvalidFieldAddCount = 'Voc deve adicionar pelo menos um campo.';
 $strInvalidFieldCount = 'Tabela deve ter pelo menos um campo.';
 $strInvalidLDIImport = 'Esse plugin no suporta importaes comprimidas!';
 $strInvalidRowNumber = '%d no  um nmero de linha vlido.';
-$strInvalidServerHostname = 'Nome de host invlido para o servidor %1$s. Verifique suas configuraes.';
+$strInvalidServerHostname = 'Nome de serivdor invlido para o servidor %1$s. Verifique suas configuraes.';
 $strInvalidServerIndex = 'ndice de servidor invlido: "%s"';
 $strInvalidTableName = 'Nome de tabela invlida';
 
@@ -411,10 +408,10 @@ $strKeepPass = 'No mudar a senha';
 $strKeyCache = 'Chave do cache';
 $strKeyname = 'Nome chave'; 
 $strKill = 'Matar'; 
+$strKnownExternalBug = 'A funcionalidade %s  afetada por um bug conhecido, veja %s';
 $strKorean = 'Coreano'; 
 
 $strLandscape = 'Paisagem'; 
-$strLanguageFileNotFound = 'Arquivo da linguagem "%1$s" no encontrado.';
 $strLanguage = 'Linguagem';
 $strLanguageUnknown = 'Linguagem desconhecida: %1$s.';
 $strLatchedPages = 'Pginas trancadas';
@@ -425,11 +422,9 @@ $strLatexContinued = '(continuao)';
 $strLatexIncludeCaption = 'Incluir legenda da tabela'; 
 $strLatexLabel = 'Rtulo da chave'; 
 $strLaTeX = 'LaTeX'; 
-$strLaTeXOptions = 'Opes LaTeX'; 
 $strLatexStructure = 'Estrutura da tabela __TABLE__'; 
 $strLatvian = 'Letons'; 
 $strLDI = 'CSV usando LOAD DATA';
-$strLDIImportOptions = 'Opes para importao CSV usando LOAD DATA';
 $strLDILocal = 'Usar palavra-chave LOCAL';
 $strLengthSet = 'Tamanho/Definir*'; 
 $strLimitNumRows = 'registros por pgina'; 
@@ -458,7 +453,7 @@ $strMIME_description = 'Descrio';
 $strMIME_MIMEtype = 'MIME-type'; // MIME-types nao tem traducao
 $strMIME_nodescription = 'Sem descrio disponvel para essa transformao.<br />Pergunte ao autor o que %s faz.'; 
 $strMIME_transformation_note = 'Para uma lista de opes de transformao disponveis e suas transformaes MIME-type, clique em %sdescrio de transformaes%s'; 
-$strMIME_transformation_options_note = 'Digite os valores para as opes de transformao usando este formato: \'a\',\'b\',\'c\'...<br />Se por acaso precisar inserir uma contra-barra ("\") ou aspas ("\'") no meio desses valores, faa-o usando outra contra-barra (por exemplo \'\\\\xyz\' ou \'a\\\'b\').'; 
+$strMIME_transformation_options_note = 'Digite os valores para as opes de transformao usando este formato: \'a\', 100, b,\'c\'...<br />Se por acaso precisar inserir uma contra-barra ("\") ou aspas ("\'") no meio desses valores, faa-o usando outra contra-barra (por exemplo \'\\\\xyz\' ou \'a\\\'b\').'; 
 $strMIME_transformation_options = 'Opes de transformao'; 
 $strMIME_transformation = 'Transformaes do navegador'; 
 $strMIMETypesForTable = 'MIME-TYPES PARA AS TABELAS'; 
@@ -466,6 +461,7 @@ $strMIME_without = 'MIME-types em itlico no tm uma funo de transformao separada'
 $strModifications = 'Modificaes foram salvas'; 
 $strModifyIndexTopic = 'Modificar um ndice'; 
 $strModify = 'Modificar'; 
+$strMoveMenu = 'Mover Menu';
 $strMoveTable = 'Mover tabela para (Banco de Dados<b>.</b>tabela):'; 
 $strMoveTableOK = 'Tabela %s foi movida para %s.'; 
 $strMoveTableSameNames = 'No pode mover a tabela para ela mesma!'; 
@@ -485,6 +481,7 @@ $strMyISAMSortBufferSize = 'Tamanho do buffer de ordenao';
 $strMySQLCharset = 'Conjunto de caracteres MySQL'; 
 $strMysqlClientVersion = 'Verso do cliente MySQL';
 $strMySQLConnectionCollation = 'Collation de conexo do MySQL'; // Collation nao tem traducao
+$strMysqlLibDiffersServerVersion = 'Sua verso %s da biblioteca MySQL do PHP difere da verso %s do seu servidor MySQL. Isso pode causar um comportamento estranho.';
 $strMySQLSaid = 'Mensagens do MySQL : '; 
 $strMySQLShowProcess = 'Mostrar os Processos'; 
 $strMySQLShowStatus = 'Mostrar informao de runtime do MySQL'; 
@@ -524,19 +521,19 @@ $strNoUsersFound = 'Nenhum usurio(s) encontrado.';
 $strNoValidateSQL = 'Pular validao SQL'; 
 $strNull = 'Nulo'; 
 $strNumberOfFields = 'Nmero de arquivos';
+$strNumberOfTables = 'Numero de tabelas';
 $strNumSearchResultsInTable = '%s resultado(s) dentro da tabela <i>%s</i>'; 
 $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> resultado(s)'; 
 $strNumTables = 'Tabelas'; 
 
 $strOK = 'OK'; 
 $strOpenDocumentSpreadsheet = 'Abrir Documento Planilha';
-$strOpenDocumentSpreadsheetOptions = 'Abrir opes do Documento Planilha';
 $strOpenDocumentText = 'Abrir Documento de Texto';
-$strOpenDocumentTextOptions = 'Abrir opes do Documento de Texto';
 $strOpenNewWindow = 'Abrir nova janela do phpMyAdmin';
 $strOperations = 'Operaes'; 
 $strOperator = 'Operador'; 
 $strOptimizeTable = 'Otimizar tabela'; 
+$strOptions = 'Opes';
 $strOr = 'Ou'; 
 $strOverhead = 'Sobrecarga'; 
 $strOverwriteExisting = 'Sobrescrever arquivo(s) existente(s)'; 
@@ -554,7 +551,6 @@ $strPassword = 'Senha';
 $strPdfDbSchema = 'Esquema do Banco de Dados "%s" - Pgina %s'; 
 $strPdfInvalidTblName = 'A tabela "%s" no existe!'; 
 $strPdfNoTables = 'Sem tabelas'; 
-$strPDFOptions = 'Opes PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Gerado um relatrio contendo dados da tabela simples)';
 $strPDFReportTitle = 'Ttulo do Relatrio';
@@ -566,8 +562,10 @@ $strPhoneBook = 'Agenda de telefones';
 $strPHP40203 = 'Voc est usando o PHP 4.2.3, que possui um grave defeito usando strings multi-byte (mbstring). Veja relatrio 19404 de erros do PHP. Essa verso no  recomendada para uso com o phpMyAdmin.'; 
 $strPhp = 'Criar cdigo PHP'; 
 $strPHPVersion = 'Verso do PHP'; 
+$strPleaseSelectPrimaryOrUniqueKey = 'Por favor, selecione uma chave primria ou uma chave nica';
 $strPmaDocumentation = 'Documentao do phpMyAdmin '; 
 $strPmaUriError = 'A varivel <tt>$cfg[\'PmaAbsoluteUri\']</tt> deve ser setada'; 
+$strPmaWiki = 'Wiki phpMyAdmin';
 $strPolish = 'Polons'; 
 $strPortrait = 'Retrato'; 
 $strPos1 = 'Incio'; 
@@ -638,16 +636,19 @@ $strQueryWindowLock = 'No sobrescrever esta consulta fora desta janela';
 
 $strReadRequests = 'Leitura requisitada';
 $strReceived = 'Recebido'; 
+$strRecommended = 'recomendado';
 $strRecords = 'Registros'; 
 $strReferentialIntegrity = 'Verificar integridade referencial:'; 
 $strRefresh = 'Atualizar'; 
 $strRelationalSchema = 'Esquema relacional'; 
+$strRelationDeleted = 'Relacionamento apagado';
 $strRelationNotWorking = 'Os recursos adicionais para trabalhar com tabelas linkadas foram desativadas. Para descobrir o motivo clique %saqui%s.'; 
 $strRelationsForTable = 'RELAES PARA A TABELA'; 
 $strRelations = 'Relaes'; 
 $strRelationView = 'Ver relaes'; 
 $strReloadingThePrivileges = 'Recarregando os privilgios'; 
 $strReloadPrivileges = 'Recarregar privilgios';
+$strReload = 'Recarregar';
 $strRemoveSelectedUsers = 'Remover os usurios selecionados'; 
 $strRenameDatabaseOK = 'O Banco de Dados %s foi renomeado para %s'; 
 $strRenameTableOK = 'Tabela %s renomeada para %s'; 
@@ -658,21 +659,24 @@ $strReplaceTable = 'Substituir os dados da tabela pelos do arquivo';
 $strReplication = 'Replicao';
 $strReset = 'Resetar'; 
 $strResourceLimits = 'Limite dos recursos'; 
+$strRestartInsertion = 'Reiniciar insero com %s registros';
 $strReType = 'Re-digite'; 
 $strRevokeAndDeleteDescr = 'Os usurios mantero o privilgio de USAGE at que os privilgios sejam recarregados.'; 
 $strRevokeAndDelete = 'Revogar todos os privilgios ativos dos usuarios e depois apagar eles.'; 
 $strRevokeMessage = 'Voc revogou os privilgios para %s'; 
 $strRevoke = 'Revogar'; 
 $strRomanian = 'Romno'; 
-$strRowLength = 'Tamanho da coluna'; 
-$strRows = 'Colunas'; 
-$strRowsFrom = 'colunas comeando de'; 
+$strRoutineReturnType = 'Tipo de returno';
+$strRoutines = 'Rotinas';
+$strRowLength = 'Tamanho do registro'; 
+$strRowsFrom = 'registro(s) comeando de'; 
 $strRowSize = ' Tamanho do registro '; 
 $strRowsModeFlippedHorizontal = 'horizontal (cabealhos rotacionados)'; 
 $strRowsModeHorizontal = 'horizontal'; 
 $strRowsModeOptions = 'no modo %s e repetindo cabealhos aps %s clulas'; 
 $strRowsModeVertical = 'vertical'; 
-$strRowsStatistic = 'Estatsticas da coluna'; 
+$strRows = 'Registros'; 
+$strRowsStatistic = 'Estatsticas do registros'; 
 $strRunning = 'Rodando em %s'; 
 $strRunQuery = 'Enviar consulta SQL'; 
 $strRunSQLQuery = 'Fazer consulta SQL no Banco de Dados %s'; 
@@ -680,6 +684,7 @@ $strRunSQLQueryOnServer = 'Rodar consulta(s) SQL no servidor %s';
 $strRussian = 'Russo'; 
 
 $strSaveOnServer = 'Salvar no servidor no diretrio %s'; 
+$strSavePosition = 'Salvar posio';
 $strSave = 'Salvar'; 
 $strScaleFactorSmall = 'A escala  muito pequena para ajustar o esquema em uma pgina'; 
 $strSearchFormTitle = 'Procurar no Banco de Dados'; 
@@ -697,7 +702,9 @@ $strSelectADb = 'Selecionar um Banco de Dados';
 $strSelectAll = 'Selecionar Todos'; 
 $strSelectBinaryLog = 'Selecionar log binrio para exibir'; 
 $strSelectFields = 'Selecionar os campos (no mnimo 1)'; 
+$strSelectForeignKey = 'Selecionar Chave Estrangeira';
 $strSelectNumRows = 'na consulta'; 
+$strSelectReferencedKey = 'Seleciona chave referenciada';
 $strSelectTables = 'Tabelas selecionadas'; 
 $strSend = 'Enviado'; 
 $strSent = 'Enviar'; 
@@ -712,6 +719,7 @@ $strServerTabVariables = 'Variveis';
 $strServerTrafficNotes = '<b>Trfico do servidor</b>: Essas tabelas mostram as estatsticas do trfico da rede neste servidor MySQL desde o incio.'; 
 $strServerVars = 'Variveis e configuraes do servidor'; 
 $strServerVersion = 'Verso do Servidor'; 
+$strSessionStartupErrorGeneral = 'No pde iniciar a sesso sem erros, cheque os erros ocorridos nos logs do PHP e/ou do seu servidor web e configure a instalao do PHP corretamente.';
 $strSessionValue = 'Valor da sesso'; 
 $strSetEnumVal = 'Se um tipo de campo  "enum" ou "set", por favor entre valores usando este formato: \'a\',\'b\',\'c\'...<br />Se voc for colocar uma barra contrria ("\") ou aspas simples ("\'") entre os valores, coloque uma barra contrria antes (por exemplo \'\\\\xyz\' ou \'a\\\'b\').'; 
 $strShowAll = 'Mostrar todos'; 
@@ -719,12 +727,15 @@ $strShowColor = 'Mostrar cor';
 $strShowDatadictAs = 'Formato do dicionrio de dados'; 
 $strShowFullQueries = 'Mostrar consultas completas'; 
 $strShowGrid = 'Mostrar grade'; 
+$strShowHideLeftMenu = 'Exibir/Ocultar menu da esquerda';
 $strShowingBookmark = 'Exibindo marcadores';
+$strShowingPhp = 'Exibindo como cdigo PHP';
 $strShowingRecords = 'Mostrando registros '; 
+$strShowingSQL = 'Exibindo consulta SQL';
 $strShow = 'Mostrar'; 
 $strShowOpenTables = 'Exibir tabelas abertas';
 $strShowPHPInfo = 'Mostrar informaes do PHP'; 
-$strShowSlaveHosts = 'Exibir hosts escravos';
+$strShowSlaveHosts = 'Exibir servidores escravos';
 $strShowSlaveStatus = 'Exibir status dos escravos';
 $strShowStatusBinlog_cache_disk_useDescr = 'O nmero de transaes que usaram o cache do log binrio temporrio mas que excederam o valor do binlog_cache_size e usaram o arquivo temporrio para armazenar enunciados da transao.';
 $strShowStatusBinlog_cache_useDescr = 'O nmero de transaes que usaram o cache do log binrio temporrio.';
@@ -798,7 +809,7 @@ $strShowStatusKey_readsDescr = 'O nmero de leituras fsicas de um bloco chave do
 $strShowStatusKey_write_requestsDescr = 'O nmero de requisies para escrever um bloco chave para o cache.';
 $strShowStatusKey_writesDescr = 'O nmero de escritas fsicas para um bloco chave para o disco.';
 $strShowStatusLast_query_costDescr = 'O custo total da ltima consulta compilada como computado pelo otimizador de consultas. til para comparar o custo de diferentes planos de consulta para a mesma consulta. O valor padro 0 significa que nenhuma consulta foi compilada ainda.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'O nmero de linhas esperando para serem escritas na fila de INSERT DELAY.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'O nmero de linhas esperando para serem escritas na fila de INSERT DELAYED.';
 $strShowStatusOpened_tablesDescr = 'O nmero de tabelas que devem estar abertas. Se aberta, as tabelas so grandes, o valor do cache de suas tabelas  provavelmente muito pequeno.';
 $strShowStatusOpen_filesDescr = 'O nmero de arquivos que esto abertos.';
 $strShowStatusOpen_streamsDescr = 'O nmero de streams que esto abertos (usados principalmente para log).';
@@ -842,6 +853,8 @@ $strSize = 'Tamanho';
 $strSkipQueries = 'Nmero de registros (consultas) ignoradas no incio';
 $strSlovak = 'Eslovquio'; 
 $strSlovenian = 'Eslovnio'; 
+$strSmallBigAll = 'Tudo Pequeno/Grande';
+$strSnapToGrid = 'Ajustar  grade';
 $strSocketProblem = '(ou o soquete do servidor MySQL local no est configurado corretamente)';
 $strSortByKey = 'Ordenar pela chave'; 
 $strSorting = 'Ordenando';
@@ -851,8 +864,6 @@ $strSpanish = 'Espanhol';
 $strSplitWordsWithSpace = 'Palavras so separadas por um caracter de espao (" ").'; 
 $strSQLCompatibility = 'Modo de compatibilidade SQL';
 $strSQLExportType = 'Tipo de exportao'; 
-$strSQLImportOptions = 'Opes SQL';
-$strSQLOptions = 'Opes SQL'; 
 $strSQLParserBugMessage = 'Talvez tenha encontrado um bug no analizador (parser) do SQL. Analise a sua Consulta SQL com ateno, e verifique se as aspas esto corretas e no esto desencontradas. Outra possibilidade de falha  o fato de estar tentando subir um arquivo com sada binria de uma rea de texto citada. Pode tambm experimentar a sua consulta SQL no prompt de comandos do MySQL. A sada de erro do MySQL, isto se existir alguma, tambm poder ajudar a diagnosticar o problema. Se continuar a ter problemas ou se o analisador (parser) falhar onde a interface da linha de comandos tiver sucesso, reduza por favor a entrada da consulta SQL at aquele que causou o problema, e envie o relatrio de bug com os dados do chunk da seo CORTE abaixo:'; 
 $strSQLParserUserError = 'Parece haver um erro na sua consulta SQL. A sada do servidor MySQL abaixo, isto se existir alguma, tambm poder ajudar a diagnosticar o problema.'; 
 $strSQLQuery = 'consulta SQL'; 
@@ -861,6 +872,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Identificador invlido'; 
 $strSQPBugUnclosedQuote = 'Aspas no fechada'; 
 $strSQPBugUnknownPunctuation = 'String de pontuao desconhecida'; 
+$strStandInStructureForView = 'Estrutura stand-in para visualizar';
 $strStatCheckTime = 'ltima verificao'; 
 $strStatCreateTime = 'Criao'; 
 $strStatement = 'Comandos'; 
@@ -873,10 +885,10 @@ $strStrucCSV = 'Dados CSV';
 $strStrucData = 'Estrutura e dados'; 
 $strStrucExcelCSV = 'CSV para dados MS Excel'; 
 $strStrucNativeExcel = 'Dados nativos do MS Excel'; 
-$strStrucNativeExcelOptions = 'Opes de exportao nativa do Excel';
 $strStrucOnly = 'Somente estrutura'; 
 $strStructPropose = 'Propor estrutura da tabela'; 
 $strStructure = 'Estrutura'; 
+$strStructureForView = 'Estrutura para visualizar';
 $strSubmit = 'Submeter'; 
 $strSuccess = 'Seu comando SQL foi executado com sucesso'; 
 $strSum = 'Soma'; 
@@ -890,7 +902,9 @@ $strTableEmpty = 'O Nome da Tabela est vazio!';
 $strTableHasBeenDropped = 'Tabela %s foi eliminada'; 
 $strTableHasBeenEmptied = 'Tabela %s foi esvaziada'; 
 $strTableHasBeenFlushed = 'Tabela %s foi limpa'; 
+$strTableIsEmpty = 'Tabela para estar vazia!';
 $strTableMaintenance = 'Tabela de Manuteno'; 
+$strTableName = 'Nome da Tabela';
 $strTableOfContents = 'Tabela de contedos'; 
 $strTableOptions = 'Opes da tabela'; 
 $strTables = '%s tabela(s)'; 
@@ -907,15 +921,17 @@ $strThemeNotFound = 'Tema %s no encontrado!';
 $strThemeNoValidImgPath = 'Encontrado caminho invlido para imagens para o tema %s!';
 $strThemePathNotFound = 'Encontrado caminho invlido para o tema %s!';
 $strTheme = 'Tema / Estilo'; 
-$strThisHost = 'Esse Host'; 
-$strThisNotDirectory = 'Isso no  um diretrio'; 
+$strThisHost = 'Esse Servidor'; 
 $strThreads = 'Processos';
 $strThreadSuccessfullyKilled = 'Processo %s foi morto com sucesso.'; 
 $strTimeoutInfo = 'Importao anterior passou do tempo limite, depois de reenviar, ir continuar na posio %d.';
 $strTimeoutNothingParsed = 'Entretanto na ltima vez nenhum dado foi passado, isso normalmente significa que o phpMyAdmin no  capaz de finalizar essa importao  menos que voc aumente o tempo limite do PHP.';
 $strTimeoutPassed = 'Script passou do tempo limite, se voc deseja terminar a importao, reenvie o mesmo arquivo que a importao ser resumida.';
 $strTime = 'Tempo'; 
+$strToFromPage = 'pgina de/para';
 $strToggleScratchboard = 'mudar o estado do Scratchboard'; //isso est correto? mas nao descobri o q eh
+$strToggleSmallBig = 'Mudar para pequeno/grande';
+$strToSelectRelation = 'Para selecionar relacionamento, clique :';
 $strTotal = 'total'; 
 $strTotalUC = 'Total'; 
 $strTraditionalChinese = 'Chins Tradicional'; 
@@ -923,17 +939,18 @@ $strTraditionalSpanish = 'Espanhol Traditional';
 $strTraffic = 'Trfego'; 
 $strTransactionCoordinator = 'Coordenador da transao';
 $strTransformation_application_octetstream__download = 'Mostrar o link para baixar os dados binrios do campo. Primeira opo  o nome do arquivo binrio. Segunda opo  um possvel nome de campo de uma linha da tabela que contm o nome do arquivo. Se voc usar a segunda opo precisa colocar na primeira opo uma string em branco'; 
-$strTransformation_application_octetstream__hex = 'Exibir representao hexadecimal dos dados. Primeiro parmetro opcional especifica como frequentemente espaos sero adicionados (padro para 2 mordidelas).';  //ta certo isso? nibbles, traduzi como moridelas
+$strTransformation_application_octetstream__hex = 'Exibir representao hexadecimal dos dados. Primeiro parmetro opcional especifica como frequentemente espaos sero adicionados (padro para 2 mordidelas).';  //ta certo isso? nibbles, traduzi como mordidelas
 $strTransformation_image_jpeg__inline = 'Mostrar uma miniatura clicvel; opes: largura,altura em pixels (mantm a proporo original)'; 
 $strTransformation_image_jpeg__link = 'Mostrar o link para esta imagem (ex.: blob download direto).'; 
-$strTransformation_image_png__inline = 'Ver imagem/jpeg: inline'; 
-$strTransformation_text_plain__dateformat = 'Use um campo TIME, TIMESTAMP ou DATETIME e formate usando sua formatao de data local. Primeira opo  o offset (em horas) que ser adicionado ao timestamp (Padro: 0). Segunda opo  uma formatao de data diferente de acordo com os parmetros disponveis no strftime() do PHP.'; 
+$strTransformation_image_png__inline = 'Ver imagem/jpeg: em linha'; 
+$strTransformation_text_plain__dateformat = 'Exibir um TIME, TIMESTAMP, DATETIME ou campo numrico unix timestamp formatado como data. A primeira opo  o offset (em horas) que ser adicionado ao timestamp (Padro: 0). Use a segunda opo para especificar uma string de formatao data/tempo diferente. A terceira opo determina se voc deseja ver data local ou UTC (use a string "local" ou "utc") para isso. De acordo com isso, o formatdo da data ter valores diferentes - para "local" veja a documentao do PHP para funo strftime() e para "utc" isso  feito usando a funo gmdate().';
 $strTransformation_text_plain__external = 'LINUX APENAS: Rode uma aplicao externa e alimente os campos de dados pela entrada padro. Retorna a sada padro da aplicao. Padro  Limpo, para uma bonita impresso do cdigo HTML. Por razes de segurana, voc deve editar manualmente o arquivo libraries/transformations/text_plain__external.inc.php e inserir as ferramentas que voc permite rodar. A primeira opo  o nmero do programa que voc quer rodar e a segunda opo so os parmetros para o programa. A terceira opo, se setada para 1 ir converter a sada usando htmlspecialchars() (Padro  1). A quarta opo, se setada como 1 ir por um NOWRAP para o contedo da clula, de forma que a sada inteira ser mostrada sem reformatao(Padro  1)'; 
 $strTransformation_text_plain__formatted = 'Preservar a formatao original campo. Sem escape.'; 
 $strTransformation_text_plain__imagelink = 'Mostrar uma imagem e um link, o campo contm um nome de arquivo; primeira opo  um prefixo tipo "http://domain.com/", segunda opo  a largura em pixels, o terceiro  a altura.'; 
 $strTransformation_text_plain__link = 'Mostrar um link, o campo contm o nome do arquivo, primeira opo  um prefixo tipo "http://domain.com/", segunda opo  um ttulo para o link.'; 
 $strTransformation_text_plain__sql = 'Formatar texto como consulta SQL com sntaxe colorida.';
 $strTransformation_text_plain__substr = 'Mostrar apenas parte da string. Primeira opo  um offset para definir onde a sada do seu texto deve iniciar (Padro: 0). Segunda opo  o quanto do texto dever ser retornado. Se estiver em branco, retorna todo o restante do texto. Terceira opo define quais caracteres sero acrescentados na substring retornada (Padro: ...).'; 
+$strTriggers = 'Gatilhos';
 $strTruncateQueries = 'Truncar as consultas SQL exibidas'; 
 $strTurkish = 'Turco'; 
 $strType = 'Tipo'; 
@@ -950,12 +967,19 @@ $strUpdateProfileMessage = 'A configurao foi atualizada.';
 $strUpdateQuery = 'Atualizar a consulta SQL'; 
 $strUpdComTab = 'Consulte a documentao sobre como atualizar sua tabela Column_comments'; 
 $strUpgrade = 'Voc deveria atualizar para %s %s ou posterior.'; 
+$strUploadErrorCantWrite = 'Falhou ao salvar arquivo no disco.';
+$strUploadErrorExtension = 'Carregamento do arquivo parado pela exteno.';
+$strUploadErrorFormSize = 'O arquivo carregado excede o tamanho definido na diretriz MAX_FILE_SIZE do formulrio HTM.';
+$strUploadErrorIniSize = 'O arquivo carregado excede o tamanho definido na diretriz upload_max_filesize no php.ini.';
+$strUploadErrorNoTempDir = 'Pasta temporria no encontrada.';
+$strUploadErrorPartial = 'Carregamento do arquivo foi apenas parcial.';
+$strUploadErrorUnknown = 'Erro desconhecido no carregamento do arquivo.';
 $strUploadLimit = 'Voc provavelmente tentou carregar um arquivo muito grande. Veja referncias na %sdocumentation%s para burlar esses limites.';
 $strUploadsNotAllowed = 'No  permitido subir arquivos neste servidor.';
 $strUsage = 'Uso'; 
 $strUseBackquotes = 'Usar aspas simples nos nomes de tabelas e campos'; 
-$strUsedPhpExtensions = 'Usadas extenses PHP';
-$strUseHostTable = 'Usar Tabela de Host'; 
+$strUsedPhpExtensions = 'Extenses PHP usadas';
+$strUseHostTable = 'Usar Tabela do Servidor'; 
 $strUserAlreadyExists = 'O usurio %s j existe!'; 
 $strUserEmpty = 'O nome do usurio est em branco!'; 
 $strUserName = 'Nome do usurio'; 
@@ -979,6 +1003,7 @@ $strViewDumpDB = 'Ver o esquema do Banco de Dados';
 $strViewDump = 'Ver o esquema da tabela'; 
 $strViewHasBeenDropped = 'Viso %s foi apagada';
 $strViewMaxExactCount = 'Essa viso tem mais que %s linhas. Veja referncias na %sdocumentation%s.';
+$strViewName = 'Nome da VISO';
 $strView = 'Viso';
 
 $strWebServerUploadDirectoryError = 'O diretrio que voc especificou para subir arquivos no foi encontrado.'; 
@@ -989,11 +1014,8 @@ $strWildcard = 'coringa';
 $strWindowNotFound = 'A janela alvo do navegador no pode ser atualizada. Talvez voc tenha fechado a janela alvo ou o seu navegador tenha bloqueado a comunicao entre janelas nas configuraes de segurana.'; 
 $strWithChecked = 'Com marcados:'; 
 $strWriteRequests = 'Escrita requisitada';
-$strWritingCommentNotPossible = 'No foi possvel escrever o comentrio'; 
-$strWritingRelationNotPossible = 'No foi possvel escrever a relao'; 
 $strWrongUser = 'Usurio ou senha incorreta. Acesso negado.'; 
 
-$strXMLOptions = 'Opes XML';
 $strXML = 'XML'; 
 
 $strYes = 'Sim'; 
@@ -1001,4 +1023,5 @@ $strYes = 'Sim';
 $strZeroRemovesTheLimit = 'Nota: Ajustar essa opo para 0 (zero) remove os limites.'; 
 $strZip = '"compactado com zip"'; 
 
+$strProfiling = 'Profiling';  //to translate
 ?>
