@@ -1,5 +1,5 @@
 <?php
-/* $Id: bulgarian-koi8-r.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: bulgarian-koi8-r.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /**
  * Translated by Stanislav Yordanov <stanprog at stanprog.com>
@@ -65,7 +65,6 @@ $strAscending = '';
 $strAtBeginningOfTable = '   ';
 $strAtEndOfTable = '   ';
 $strAttr = '';
-$strAutodetect = ' ';
 $strAutomaticLayout = ' ';
 
 $strBack = '';
@@ -157,8 +156,6 @@ $strCreatePdfFeat = '  PDF-';
 $strCreationDates = '//  ';
 $strCriteria = '';
 $strCroatian = '';
-$strCSVImportOptions = 'CSV ';
-$strCSVOptions = 'CSV ';
 $strCyrillic = '';
 $strCzech = '';
 $strCzechSlovak = '';
@@ -168,7 +165,6 @@ $strDatabase = '';
 $strDatabaseEmpty = '      !';
 $strDatabaseExportOptions = '      ';
 $strDatabaseHasBeenDropped = '  %s  .';
-$strDatabaseNoTable = '    !';
 $strDatabasesDropped = '%s      .';
 $strDatabasesStatsDisable = ' ';
 $strDatabasesStatsEnable = '  ';
@@ -240,7 +236,6 @@ $strErrorRenamingTable = '     %1$s  %2$s';
 $strEsperanto = '';
 $strEstonian = '';
 $strExcelEdition = '  Excel';
-$strExcelOptions = '  Excel';
 $strExecuteBookmarked = '   SQL-';
 $strExplain = 'Explain SQL';
 $strExport = '';
@@ -249,7 +244,6 @@ $strExtra = '';
 
 $strFailedAttempts = '  ';
 $strFieldHasBeenDropped = ' %s  ';
-$strFieldsEmpty = '     ! ';
 $strFieldsEnclosedBy = '   ';
 $strFieldsEscapedBy = '   ';
 $strFieldsTerminatedBy = '  ';
@@ -292,13 +286,10 @@ $strHasBeenAltered = ' .';
 $strHasBeenCreated = ' .';
 $strHaveToShow = '       ';
 $strHebrew = '';
-$strHexForBinary = '      ';
 $strHome = '';
 $strHomepageOfficial = '    phpMyAdmin ';
 $strHostEmpty = '    !';
 $strHost = '';
-$strHTMLExcelOptions = '    Microsoft Excel 2000';
-$strHTMLWordOptions = '    Microsoft Word 2000';
 $strHungarian = '';
 
 $strIcelandic = '';
@@ -316,8 +307,6 @@ $strIndexHasBeenDropped = ' %s  ';
 $strIndexName = '  &nbsp;:';
 $strIndex = '';
 $strIndexType = '  &nbsp;:';
-$strIndexWarningMultiple = '   %s      `%s`';
-$strIndexWarningPrimary = ' `%s`         ';
 $strIndexWarningTable = '     `%s`';
 $strInnoDBPages = '';
 $strInnodbStat = 'InnoDB ';
@@ -348,7 +337,6 @@ $strKill = '';
 $strKorean = '';
 
 $strLandscape = '';
-$strLanguageFileNotFound = '  "%1$s"   .';
 $strLanguage = '';
 $strLatexCaption = '  ';
 $strLatexContent = '   __TABLE__';
@@ -357,11 +345,9 @@ $strLatexContinued = '()';
 $strLatexIncludeCaption = '    ';
 $strLatexLabel = '  ';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX ';
 $strLatexStructure = '   __TABLE__';
 $strLatvian = '';
 $strLDI = 'CSV  LOAD DATA';
-$strLDIImportOptions = '  CSV   LOAD DATA';
 $strLDILocal = '    LOCAL ';
 $strLengthSet = '/*';
 $strLimitNumRows = '  ';
@@ -467,7 +453,6 @@ $strPassword = '';
 $strPdfDbSchema = '     "%s" -  %s';
 $strPdfInvalidTblName = ' "%s"  !';
 $strPdfNoTables = ' ';
-$strPDFOptions = 'PDF ';
 $strPDFReportExplanation = '(      )';
 $strPDFReportTitle = '  ';
 $strPerHour = ' ';
@@ -657,8 +642,6 @@ $strSpanish = '';
 $strSplitWordsWithSpace = '       (" ").';
 $strSQLCompatibility = '    SQL';
 $strSQLExportType = '  ';
-$strSQLImportOptions = 'SQL ';
-$strSQLOptions = '   SQL';
 $strSQLParserBugMessage = '        SQL .   -,     .        ,           .                MySQL.    MySQL  -,   ,         .                  ,    SQL     ,           CUT  -:';
 $strSQLParserUserError = ',     SQL  .    MySQL   ,   ,         ';
 $strSQLQuery = 'SQL ';
@@ -782,7 +765,6 @@ $strWindowNotFound = '       .                        ';
 $strWithChecked = '  :';
 $strWrongUser = ' /.  .';
 
-$strXMLOptions = 'XML ';
 $strXML = 'XML';
 
 $strYes = '';
@@ -829,7 +811,6 @@ $strHandler = 'Handler';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
 
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
 $strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
 $strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
 $strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
@@ -868,9 +849,7 @@ $strNoDataReceived = 'No data was received to import. Either no file name was su
 $strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
 
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
@@ -951,7 +930,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
 $strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
@@ -985,7 +964,6 @@ $strShowStatusThreads_runningDescr = 'The number of threads that are not sleepin
 $strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStrucNativeExcel = 'Native MS Excel data';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 
 $strTakeIt = 'take it';  //to translate
 $strThemeNoPreviewAvailable = 'No preview available.';  //to translate
@@ -1003,7 +981,6 @@ $strWriteRequests = 'Write requests';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1048,4 +1025,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
