@@ -1,5 +1,5 @@
 <?php
-/* $Id: catalan-iso-8859-1.inc.php 9879 2007-01-29 17:36:33Z lem9 $ */
+/* $Id: catalan-iso-8859-1.inc.php 10558 2007-08-11 23:52:58Z lem9 $ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr'; // ('ltr' d'esquerra a dreta, 'rtl' de dreta a esquerra)
@@ -62,7 +62,6 @@ $strAscending = 'Ascendent';
 $strAtBeginningOfTable = 'Al principi de la taula';
 $strAtEndOfTable = 'Al final de la taula';
 $strAttr = 'Atributs';
-$strAutodetect = 'Autodetectar';
 $strAutomaticLayout = 'Disseny automtic';
 
 $strBack = 'Enrere';
@@ -151,6 +150,7 @@ $strConnectionError = 'No puc connectar: parmetres incorrectes.';
 $strConnections = 'Connexions';
 $strConstraintsForDumped = 'Restriccions per taules bolcades';
 $strConstraintsForTable = 'Restriccions per la taula';
+$strControluserFailed = 'La connexi de l\'usuari de control ha fallat, tal com est definida ara a la configuraci.';
 $strCookiesRequired = 'A partir d\'aquest punt s necessari tenir les galetes (cookies) activades.';
 $strCopy = 'Copiar'; 
 $strCopyDatabaseOK = 'La Base de dades %s s\'ha copiat a %s';
@@ -176,8 +176,6 @@ $strCreationDates = 'Datas de Creaci/Modificaci/Comprovaci';
 $strCriteria = 'Criteris';
 $strCroatian = 'Croata';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Opcions de CSV';
-$strCSVOptions = 'Opcions CSV';
 $strCyrillic = 'Cirl.lic';
 $strCzechSlovak = 'Txec-Eslovac';
 $strCzech = 'Txec';
@@ -187,7 +185,6 @@ $strDatabase = 'Base de dades';
 $strDatabaseEmpty = 'El nom de la base de dades s buit!';
 $strDatabaseExportOptions = 'Opcions d\'exportaci de Bases de Dades';
 $strDatabaseHasBeenDropped = 'La Base de Dades %s s\'ha eliminat.';
-$strDatabaseNoTable = 'Aquesta base de dades no t taules!';
 $strDatabases = 'bases de dades';
 $strDatabasesDropped = '%s Bases de dades s\'han esborrat correctament.';
 $strDatabasesStatsDisable = 'Desactiva Estadstiques';
@@ -233,7 +230,6 @@ $strDisplayOrder = 'Ordre del llistat:';
 $strDisplayPDF = 'Mostrar esquema PDF';
 $strDoAQuery = 'Fer una "petici segons exemple" (comod: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'Opcions de DocSQL';
 $strDocu = 'Documentaci';
 $strDoYouReally = 'Realment vols fer?';
 $strDropDatabaseStrongWarning = 'Ets a punt d\' ELIMINAR completament una base de dades!';
@@ -270,8 +266,8 @@ $strErrorSaveTable = 'Error desant coordenades per al Dissenyador.';
 $strEscapeWildcards = 'Els comodins _ i % han de marcar-se amb una \ per usar-los literalment';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estoni ';
+$strEvent = 'Esdevenivent';
 $strExcelEdition = 'Edici per Excel';
-$strExcelOptions = 'Opcions d\'Excel';
 $strExecuteBookmarked = 'Executa una consulta desada';
 $strExplain = 'Explicaci de l\'SQL';
 $strExport = 'Exportar';
@@ -283,8 +279,8 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Intents erronis';
 $strField = 'Camp';
 $strFieldHasBeenDropped = 'S\'ha esborrat el camp %s';
+$strFieldInsertFromFileTempDirNotExists = 'Error movent l\'arxiu pujat, consulta la FAQ 1.11';
 $strFields = 'Camps';
-$strFieldsEmpty = ' El comptador de camps s buit! ';
 $strFieldsEnclosedBy = 'Camps englobats per';
 $strFieldsEscapedBy = 'Camps amb marca d\'escapada';
 $strFieldsTerminatedBy = 'Camps acabats per';
@@ -296,6 +292,7 @@ $strFileNameTemplateDescriptionServer = 'nom de servidor';
 $strFileNameTemplateDescriptionTable = 'nom de taula';
 $strFileNameTemplate = 'Nom d\'arxiu de plantilla';
 $strFileNameTemplateRemember = 'Recordar plantilla';
+$strFiles = 'Arxius';
 $strFileToImport = 'Arxiu a importar';
 $strFixed = 'fixe';
 $strFlushPrivilegesNote = 'Nota: phpMyAdmin obt els permissos de l\'usuari directament de les taules de permissos de l\' MySQL. El contingut d\'aquestes taules pot diferir dels permissos que utilitza el servidor si s\'han fet canvis manualment. En aquest cas, es necessari %srecarregar els permissos%s abans de continuar.';
@@ -332,7 +329,7 @@ $strHasBeenCreated = 'ha estat creada.';
 $strHaveToShow = 'Has de triar al menys una columna per mostrar';
 $strHebrew = 'Hebreu';
 $strHelp = 'Ajuda';
-$strHexForBinary = 'Usa hexadecimal per camps binaris';
+$strHexForBLOB = 'Usa hexadecimal per a BLOB';
 $strHide         = 'Amaga';
 $strHideShowAll = 'Amaga/Mostra tot';
 $strHideShowNoRelation = 'Amaga/Mostra taules sense relacions';
@@ -341,9 +338,7 @@ $strHomepageOfficial = 'Pgina oficial del phpMyAdmin';
 $strHostEmpty = 'El nom del servidor s buit!';
 $strHost = 'Servidor';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Opcions d\'exportaci de Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Opcions d\'exportaci de Microsoft Word 2000';
 $strHungarian = 'Hngar';
 
 $strIcelandic = 'Islands';
@@ -359,14 +354,12 @@ $strImportFormat = 'Format de l\'arxiu importat';
 $strImport = 'Importar';
 $strImportSuccessfullyFinished = 'Importaci finalitzada correctament, %d consultes executades.';
 $strIndexes = 'Indexos';
+$strIndexesSeemEqual = 'Els seguents indexos semblen iguals i un d\'ells s\'ha d\'esborrar:';
 $strIndexHasBeenDropped = 'S\'ha esborrat l\'ndex %s';
 $strIndex = 'ndex';
 $strIndexName = 'Nom d\'ndex:';
 $strIndexType = 'Tipus d\'ndex:';
-$strIndexWarningMultiple = 'S\'ha creat ms d\'una clau %s per a la columna `%s`';
-$strIndexWarningPrimary = 'Les claus PRIMARY i INDEX no es poden establir alhora per a la columna `%s`';
 $strIndexWarningTable = 'Problemes amb els index de la taula `%s`';
-$strIndexWarningUnique = 'Les claus UNIQUE i INDEX no es poden establir alhora per a la columna `%s`';
 $strInnoDBAutoextendIncrementDesc = ' La quantitat a incrementar per ampliar el tamany d\'una taula autoextensible quan estigui a punt d\'omplir-se.';
 $strInnoDBAutoextendIncrement = 'Increment d\'autoextensi';
 $strInnoDBBufferPoolSizeDesc = 'El tamany de memria intermitja que InnoDB fa servir per desar les dades i indexos de les seves taules.';
@@ -415,7 +408,6 @@ $strKnownExternalBug = 'La funcionalitat %s es veu afectada per un error conegut
 $strKorean = 'Core';
 
 $strLandscape = 'Horitzontal';
-$strLanguageFileNotFound = 'Arxiu d\'idioma "%1$s" no trobat.';
 $strLanguage = 'Idioma';
 $strLanguageUnknown = 'Idioma desconegut: %1$s.';
 $strLatchedPages = 'Pgines inalterables';
@@ -426,11 +418,9 @@ $strLatexContinued = '(contina)';
 $strLatexIncludeCaption = 'Inclusi del titol de taula';
 $strLatexLabel = 'Etiqueta de clau';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Opcions LaTeX';
 $strLatexStructure = 'Estructura de la taula __TABLE__';
 $strLatvian = 'Let';
 $strLDI = 'CSV usant LOAD DATA';
-$strLDIImportOptions = 'Opcions per importaci CSV usant LOAD DATA';
 $strLDILocal = 'Usa clau LOCAL';
 $strLengthSet = 'Longitud/Valors*';
 $strLimitNumRows = 'registres per pgina';
@@ -487,6 +477,7 @@ $strMyISAMSortBufferSize = 'Tamany de l\'rea de classificaci';
 $strMySQLCharset = 'Joc de carcters de MySQL';
 $strMysqlClientVersion = 'Versi del client MySQL';
 $strMySQLConnectionCollation = 'Ordenaci de la connexi MySQL'; 
+$strMysqlLibDiffersServerVersion = 'La teva llibreria MySQL de PHP MySQL versi %s s diferent del teu servidor MySQL versi %s. Aix pot provocar comportaments inesperats.';
 $strMySQLSaid = 'MySQL diu: ';
 $strMySQLShowProcess = 'Mostrar processos';
 $strMySQLShowStatus = 'Mostra la informaci de funcionament del MySQL';
@@ -533,13 +524,12 @@ $strNumTables = 'Taules';
 
 $strOK = 'Correcte';
 $strOpenDocumentSpreadsheet = 'Full de clcul Open Document';
-$strOpenDocumentSpreadsheetOptions = 'Opcions de full de clcul Open Document';
-$strOpenDocumentTextOptions = 'Opcions de text en format Open Document';
 $strOpenDocumentText = 'Text format Open Document';
 $strOpenNewWindow = 'Obrir nova finestra de phpMyAdmin';
 $strOperations = 'Operacions';
 $strOperator = 'Operador';
 $strOptimizeTable = 'Optimitza la taula';
+$strOptions = 'Opcions';
 $strOr = 'O';
 $strOverhead = 'Defragmentat';
 $strOverwriteExisting = 'Sobreescriure arxiu(s) existent(s)';
@@ -557,7 +547,6 @@ $strPasswordNotSame = 'Les contrasenyes no coincideixen!';
 $strPdfDbSchema = 'Esquema de la base de dades "%s" - Pgina %s';
 $strPdfInvalidTblName = 'La taula "%s" no existeix!';
 $strPdfNoTables = 'No hi ha taules';
-$strPDFOptions = 'Opcions PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Crea un llistat que cont les dades d\'una sola taula)';
 $strPDFReportTitle = 'Ttol de llistat';
@@ -625,6 +614,7 @@ $strPrivilegesReloaded = 'Els permissos s\'han recarregat correctament.';
 $strProcedures = 'Procediments';
 $strProcesses = 'Processos';
 $strProcesslist = 'Llista de processos';
+$strProfiling = 'Perfils';
 $strProtocolVersion = 'Versi del protocol';
 $strPutColNames = 'Posa els noms de camp a la primera fila';
 
@@ -666,12 +656,15 @@ $strReplaceTable = 'Canviar les dades de la taula per l\'arxiu ';
 $strReplication = 'Replicaci';
 $strReset = 'Esborrar';
 $strResourceLimits = 'Limit de recursos';
+$strRestartInsertion = 'Reiniciar l\'inserci amb %s files';
 $strReType = 'Reescriure';
 $strRevokeAndDelete = 'Denega tots els permissos actius dels usuaris i els esborra desprs.';
 $strRevokeAndDeleteDescr = 'Els usuaris encara tindran el perms USAGE fins que es recarreguin els permissos.';
 $strRevokeMessage = 'Has tret els permissos per %s';
 $strRevoke = 'Treure';
 $strRomanian = 'Romans';
+$strRoutineReturnType = 'Tipus de retorn';
+$strRoutines = 'Rutines';
 $strRowLength = 'Tamany de fila';
 $strRows = 'Fila';
 $strRowsFrom = 'Files comenant des de';
@@ -723,6 +716,7 @@ $strServerTabVariables = 'Variables';
 $strServerTrafficNotes = '<b>Ocupaci de servidor</b>: Aquestes taules mostren la ocupaci de la xarxa d\'aquest servidor MySQL des de l\'ltim inici.';
 $strServerVars = 'Variables i configuracions del servidor';
 $strServerVersion = 'Versi del servidor';
+$strSessionStartupErrorGeneral = 'No es pot iniciar una sessi sense errors, comprova els error obtinguts al teu registre de PHP i/o servidor web i configura el teu entorn de PHP acuradament.';
 $strSessionValue = 'Valor de sessi';
 $strSetEnumVal = 'Si el tipus de camp s "enum" o "set", entra els valors fent servir el format: \'a\',\'b\',\'c\'...<br />Si mai necessites escriure la barra invertida ("\") o la cometa simple ("\'") abans d\'aquests valors, escriu barres invertides (per exemple \'\\\\xyz\' o \'a\\\'b\').';
 $strShowAll = 'Mostra tot';
@@ -812,7 +806,7 @@ $strShowStatusKey_readsDescr = 'El nombre de lectures fsiques d\'un bloc de clau
 $strShowStatusKey_write_requestsDescr = 'El nombre de peticions d\'escriptura d\'un bloc de clau a la memria cau.';
 $strShowStatusKey_writesDescr = 'El nombre d\'escriptures fsiques d\'un bloc de clau a disc.';
 $strShowStatusLast_query_costDescr = 'El cost total de la darrera consulta compilada tal com el valora l\'optimitzador de consultes. s til per comparar el cost de diferents plans de consulta per a la mateixa consulta. El valor 0 vol dr que encara no s\'ha compilat cap consulta.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'El nombre de files esperant a ser escrites en cues INSERT DELAY.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'El nombre de files esperant a ser escrites en cues INSERT DELAYED.';
 $strShowStatusOpened_tablesDescr = 'El nombre de taules que han estat obertes. Si el nombre de taules obertes s gran, probablement el valor de memria cau de taula s massa petit.';
 $strShowStatusOpen_filesDescr = 'El nombre d\'arxius que estn oberts.';
 $strShowStatusOpen_streamsDescr = 'El nombre de fluxes que estn oberts (usats principalment per a registre).';
@@ -867,8 +861,6 @@ $strSpanish = 'Espanyol';
 $strSplitWordsWithSpace = 'Paraules separades per un espai (" ").';
 $strSQLCompatibility = 'Modus de compatibilitat SQL';
 $strSQLExportType = 'Tipus d\' Exportaci';
-$strSQLImportOptions = 'Opcions SQL';
-$strSQLOptions = 'Opcions SQL';
 $strSQLParserBugMessage = 's possible que hagueu trobat un error a l\'intrpret SQL. Si us plau, comproveu la sintaxi de la consulta i verifiqueu que les cometes estiguin al seu lloc i facin parelles. Un altra possible causa de l\'errada s que estigueu pujant un arxiu amb dades binries per fora de l\'rea de text delimitada. Tamb podeu provar la consulta a la interfcie de comandes de MySQL. La sortida segent generada pel servidor MySQL, si n\'hi ha, pot ajudar-vos a diagnosticar el problema. Si encara teniu problemes o si l\'intrpret falla i l\'interfcie de comandes funciona, reduu la consulta a la part de l\'SQL que produeix l\'errada, i envieu un informe d\'error amb la cadena de dades de la secci de TALL indicada avall:';
 $strSQLParserUserError = 'Sembla que hi ha un error a la consulta SQL. La sortida segent generada pel servidor MySQL, si n\'hi ha, pot ajudar-vos a diagnosticar el problema';
 $strSQLQuery = 'crida SQL';
@@ -890,7 +882,6 @@ $strStrucCSV = 'dades CSV ';
 $strStrucData = 'Estructura i dades';
 $strStrucExcelCSV = 'CSV per dades de MS Excel';
 $strStrucNativeExcel = 'Dades Natives MS Excel';
-$strStrucNativeExcelOptions = 'Opcions d\'exportaci natives d\'Excel';
 $strStrucOnly = 'Noms l\'estructura';
 $strStructPropose = 'Proposa una estructura de taula';
 $strStructure = 'Estructura';
@@ -956,6 +947,7 @@ $strTransformation_text_plain__imagelink = 'Mostra una imatge i un enlla, el cam
 $strTransformation_text_plain__link = 'Mostra un enlla, el camp cont el nom de l\'arxiu; la primera opci s un prefixe com "http://domini.com/", la segona opci s el titol del enlla.';
 $strTransformation_text_plain__sql = 'Formateig del text com a consulta SQL amb resaltat de sintaxi.';
 $strTransformation_text_plain__substr = 'Mostra una part d\'una cadena de text. La primera opci s el nombre de caracters a saltar des de l\'inici de la cadena (Per defecte 0). La segona opci s el nombre de caracters a retornar (Per defecte: fins al final de la cadena). La tercera opci s la cadena a afegir a l\'inici o al final quan hi ha truncament (Per defecte: "...").';
+$strTriggers = 'Disparadors';
 $strTruncateQueries = 'Talla les consultes mostrades';
 $strTurkish = 'Turc';
 $strType = 'Tipus';
@@ -972,6 +964,13 @@ $strUpdateProfileMessage = 'S\'ha actualitzat el perfil.';
 $strUpdateQuery = 'Actualitza consulta';
 $strUpdComTab = 'Mira a la documentaci cm actualitzar la teva Taula de Comentaris de les Columnes';
 $strUpgrade = 'Es necessari actualitzar a %s %s o posterior.';
+$strUploadErrorCantWrite = 'Error en gravar l\'arxiu al disc.';
+$strUploadErrorExtension = 'Pujada de l\'arxiu aturada per l\'extensi.';
+$strUploadErrorFormSize = 'El tamany d\'arxiu pujat supera la directiva MAX_FILE_SIZE especificada al formulari HTML.';
+$strUploadErrorIniSize = 'El tamany d\'arxiu pujat supera la directiva upload_max_filesize de php.ini.';
+$strUploadErrorNoTempDir = 'No es troba la carpeta temporal.';
+$strUploadErrorPartial = 'Noms s\'ha pujat parcialment l\'arxiu.';
+$strUploadErrorUnknown = 'Error desconegut al pujar l\'arxiu.';
 $strUploadLimit = 'Probablement has triat d\'enviar un arxiu massa gran. Consulta la %sdocumentaci%s per trobar formes de modificar aquest lmit.';
 $strUploadsNotAllowed = 'No es permet pujar arxius en aquest servidor.';
 $strUsage = 's';
@@ -1001,6 +1000,7 @@ $strViewDumpDB = 'Veure l\'esquema de la base de dades';
 $strViewDump = 'Veure un esquema de la taula';
 $strViewHasBeenDropped = 'Vista %s esborrada';
 $strViewMaxExactCount = 'Aquesta vista t ms de %d arxius. Consulteu a %sdocumentaci%s.';
+$strViewName = 'Nom de VISTA';
 $strView = 'Vista';
 
 $strWebServerUploadDirectory = 'Directori de pujada d\'arxius del servidor web';
@@ -1013,7 +1013,6 @@ $strWithChecked = 'Amb marca:';
 $strWriteRequests = 'Peticions d\'escriptura';
 $strWrongUser = 'Usuari i/o clau erronis. Accs denegat.';
 
-$strXMLOptions = 'Opcions XML';
 $strXML = 'XML';
 
 $strYes = 'Si';
