@@ -1,5 +1,5 @@
 <?php
-/* $Id: chinese_simplified-gb2312.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: chinese_simplified-gb2312.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /**
  * Last translation by: Funda Wang <fundawang@en2china.com>
@@ -65,7 +65,6 @@ $strAscending = '';
 $strAtBeginningOfTable = 'ڱͷ';
 $strAtEndOfTable = 'ڱβ';
 $strAttr = '';
-$strAutodetect = 'Զ';
 $strAutomaticLayout = 'Զøʽ';
 
 $strBack = '';
@@ -154,7 +153,6 @@ $strCreatePdfFeat = ' PDF';
 $strCreationDates = '//ڼ';
 $strCriteria = '';
 $strCroatian = '޵';
-$strCSVOptions = 'CSV ѡ';
 $strCyrillic = '';
 $strCzech = 'ݿ';
 $strCzechSlovak = 'ݿ˹工';
@@ -165,7 +163,6 @@ $strDatabase = 'ݿ';
 $strDatabaseEmpty = 'ݿǿգ';
 $strDatabaseExportOptions = 'ݿ⵼ѡ';
 $strDatabaseHasBeenDropped = 'ݿ %s ѱɾ';
-$strDatabaseNoTable = 'ݿûб';
 $strDatabases = 'ݿ';
 $strDatabasesDropped = 'Ѿɹɾ %s ݿ⡣';
 $strDatabasesStats = 'ݿͳ';
@@ -226,7 +223,6 @@ $strError = '';
 $strEscapeWildcards = 'ͨ _  % Ӧȷؼ \ ';
 $strEstonian = 'ɳ';
 $strExcelEdition = 'Excel 汾';
-$strExcelOptions = 'Excel ѡ';
 $strExecuteBookmarked = 'ִǩеĲѯ';
 $strExplain = ' SQL';
 $strExport = '';
@@ -237,7 +233,6 @@ $strFailedAttempts = 'ʧ';
 $strField = 'ֶ';
 $strFieldHasBeenDropped = 'ֶ %s ѱɾ';
 $strFields = 'ֶ';
-$strFieldsEmpty = ' ֶǿյģ';
 $strFieldsEnclosedBy = 'ֶεַ';
 $strFieldsEscapedBy = 'תֶεַ';
 $strFieldsTerminatedBy = 'ֶָεַ';
@@ -270,7 +265,6 @@ $strHasBeenAltered = 'Ѿ޸ġ';
 $strHasBeenCreated = 'Ѿ';
 $strHaveToShow = 'Ҫѡʾһ';
 $strHebrew = 'ϣ';
-$strHexForBinary = 'ʹʮʾ';
 $strHome = 'Ŀ¼';
 $strHomepageOfficial = 'phpMyAdmin ٷվ';
 $strHost = '';
@@ -288,10 +282,7 @@ $strIndexes = '';
 $strIndexHasBeenDropped = ' %s ѱɾ';
 $strIndexName = 'ƣ';
 $strIndexType = 'ͣ';
-$strIndexWarningMultiple = '棺һ %s  ֶ `%s`';
-$strIndexWarningPrimary = '棺PRIMARYINDEXӦͬʱֶ `%s` ';
 $strIndexWarningTable = '棺ݱ `%s`';
-$strIndexWarningUnique = '棺ΨһUNIQUEINDEXӦͬʱֶ `%s` ';
 $strInnodbStat = 'InnoDB ״̬';
 $strInsecureMySQL = 'ļе趨 MySQL ĬȨ˻Ӧ(û root) MySQL ʹĬֵеȻû⣬ĻֵĿԻܴӦȲȫ©';
 $strInsert = '';
@@ -320,7 +311,6 @@ $strLatexContinuedCaption = 'ıı';
 $strLatexIncludeCaption = 'ı';
 $strLatexLabel = 'ؼǩ';
 $strLaTeX = 'LaTeX';  // use eng
-$strLaTeXOptions = 'LaTeX ѡ';
 $strLatexStructure = '__TABLE__ Ľṹ';
 $strLatvian = 'ά';
 $strLengthSet = '/ֵ*';
@@ -580,7 +570,6 @@ $strSpaceUsage = 'ʹÿռ';
 $strSpanish = '';
 $strSplitWordsWithSpace = 'ÿԿո (" ") ָ';
 $strSQLExportType = '';
-$strSQLOptions = 'SQL ѡ';
 $strSQLParserBugMessage = 'п SQL ĳ档ϸĲѯǷȷǷƥ䡣ܵʧԭϴ˳ıĶݡ MySQL нһĲѯܵĻ»г MySQL ĴܶһİáȻ⣬нִгɹ뽫 SQL ѯĳһ䣬Ȼеһύһ汨棺';
 $strSQLParserUserError = ' SQL ѯдܵĻ»г MySQL Ĵܶһİá';
 $strSQLQuery = 'SQL ѯ';
@@ -720,7 +709,6 @@ $strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"'
 $strCopy = 'Copy';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 
 $strDataPages = 'Pages containing data';  //to translate
 $strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
@@ -748,9 +736,7 @@ $strGeneratePassword = 'Generate Password';  //to translate
 
 $strHandler = 'Handler';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
@@ -781,11 +767,9 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
 
@@ -813,7 +797,6 @@ $strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
 
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
@@ -909,7 +892,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -948,7 +931,6 @@ $strSkipQueries = 'Number of records(queries) to skip from start';  //to transla
 $strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 $strSorting = 'Sorting';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
@@ -983,16 +965,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1008,7 +986,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1053,4 +1030,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
