@@ -1,5 +1,5 @@
 <?php
-/* $Id: croatian-iso-8859-2.inc.php 9853 2007-01-19 18:14:44Z lem9 $ */
+/* $Id: croatian-iso-8859-2.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /**
  *   Croatian language file by
@@ -66,7 +66,6 @@ $strAscending = 'Uzlazno';
 $strAtBeginningOfTable = 'Pri poetku tablice';
 $strAtEndOfTable = 'Pri zavretku tablice';
 $strAttr = 'Atributi';
-$strAutodetect = 'Automatski prepoznaj';
 $strAutomaticLayout = 'Automatski raspored';
 
 $strBack = 'Nazad';
@@ -177,8 +176,6 @@ $strCreationDates = 'Izrada/Auriranje/Provjera datuma';
 $strCriteria = 'Kriterij';
 $strCroatian = 'Hrvatski';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'CSV opcije';
-$strCSVOptions = 'CSV opcije';
 $strCyrillic = 'irilica';
 $strCzech = 'eki';
 $strCzechSlovak = 'eki ili Slovaki';
@@ -188,7 +185,6 @@ $strDatabase = 'Baza podataka';
 $strDatabaseEmpty = 'Naziv baze podataka je prazan!';
 $strDatabaseExportOptions = 'Opcije izvoza baze podataka';
 $strDatabaseHasBeenDropped = 'Baza podataka %s je odbaena.';
-$strDatabaseNoTable = 'Ova baza podataka ne sadri tablice!';
 $strDatabases = 'Baze podataka';
 $strDatabasesDropped = 'Baza podataka %s uspjeno je odbaena.';
 $strDatabasesStatsDisable = 'Onemogui statistike';
@@ -262,7 +258,6 @@ $strEscapeWildcards = 'Da bi mogli biti upotrebljavani u doslovnom smislu, doker
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estonski';
 $strExcelEdition = 'Excel izdanje';
-$strExcelOptions = 'Excel opcije';
 $strExecuteBookmarked = 'Izvri favorizirani upit';
 $strExplain = 'Objasni SQL';
 $strExport = 'Izvoz';
@@ -273,7 +268,6 @@ $strExtra = 'Dodatno';
 $strFailedAttempts = 'Neuspjeli pokuaji';
 $strFieldHasBeenDropped = 'Polje %s je odbaeno';
 $strField = 'Polje';
-$strFieldsEmpty = ' Prebrojavanje polja je prazno!  ';
 $strFieldsEnclosedBy = 'Polja obuhvaena po';
 $strFieldsEscapedBy = 'Polja izostavljena po';
 $strFields = 'Polja';
@@ -320,15 +314,12 @@ $strHasBeenAltered = 'izmijenjeno je.';
 $strHasBeenCreated = 'izraeno je.';
 $strHaveToShow = 'Morate odabrati najmanje jedan stupac za prikazivanje';
 $strHebrew = 'Hebrejski';
-$strHexForBinary = 'Upotrijebi heksadecimalno za binarna polja';
 $strHomepageOfficial = 'Slubena stranica programa phpMyAdmin';
 $strHome = 'Poetna stranica';
 $strHostEmpty = 'Naziv raunala je prazan!';
 $strHost = 'Raunalo';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 opcije izvoza';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft  Excel 2000 opcije izvoza';
 $strHungarian = 'Maarski';
 
 $strIcelandic = 'Islandski';
@@ -346,10 +337,7 @@ $strIndexHasBeenDropped = 'Index %s je odbaen';
 $strIndex = 'Indeks';
 $strIndexName = 'Naziv indeksa:';
 $strIndexType = 'Vrsta indeksa:';
-$strIndexWarningMultiple = 'Izraeno je vie od jednog kljua %s za stupac `%s`';
-$strIndexWarningPrimary = 'Kljuevi PRIMARY i INDEX ne bi smjeli istovremeno biti zadani za stupac `%s`';
 $strIndexWarningTable = 'Problemi s indeksima tablice `%s`';
-$strIndexWarningUnique = 'Kljuevi UNIQUE i INDEX ne bi smjeli istovremeno biti zadani za stupac `%s`';
 $strInnoDBAutoextendIncrementDesc = ' Veliina koraka za proirivanje veliine automatski proirujueg prostora tablice u sluaju njezinog ispunjavanja.';
 $strInnoDBAutoextendIncrement = 'Korak autoproirenja';
 $strInnoDBBufferPoolSizeDesc = 'Veliina memorijskog meuspremnika koju InnoDB upotrebljava za privremenu pohranu podataka i indeksa svojih tablica.';
@@ -395,7 +383,6 @@ $strKill = 'Eliminiraj';
 $strKorean = 'Korejski';
 
 $strLandscape = 'Poloeno';
-$strLanguageFileNotFound = 'Jezina datoteka "%1$s" nije pronaena.';
 $strLanguage = 'Jezik';
 $strLanguageUnknown = 'Nepoznati jezik: %1$s.';
 $strLatchedPages = 'Vezane stranice';
@@ -406,11 +393,9 @@ $strLatexContinued = '(nastavljeno)';
 $strLatexIncludeCaption = 'Ukljui naslov tablice';
 $strLatexLabel = 'Klju oznake';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX opcije';
 $strLatexStructure = 'Struktura tablice __TABLE__';
 $strLatvian = 'Latvijski';
 $strLDI = 'CSV upotrebom LOAD DATA';
-$strLDIImportOptions = 'Opcije za CSV uvoz upotrebom naredbe LOAD DATA';
 $strLDILocal = 'Upotrijebi lokalnu kljunu rije';
 $strLengthSet = 'Duljina/Vrijednosti';
 $strLimitNumRows = 'Broj redaka po stranici';
@@ -510,9 +495,7 @@ $strNumSearchResultsTotal = '<b>Ukupno:</b> <i>%s</i> poklapanja';
 $strNumTables = 'Tablice';
 
 $strOK = 'U redu  ';
-$strOpenDocumentSpreadsheetOptions = 'Otvori opcije izraunske tablice dokumenta';
 $strOpenDocumentSpreadsheet = 'Otvori izraunsku tablicu dokumenta';
-$strOpenDocumentTextOptions = 'Otvori opcije teksta dokumenta';
 $strOpenDocumentText = 'Otvori tekst dokumenta';
 $strOpenNewWindow = 'Otvori novi phpMyAdmin prozor';
 $strOperations = 'Operacije';
@@ -535,7 +518,6 @@ $strPasswordNotSame = 'Lozinke se ne podudaraju!';
 $strPdfDbSchema = 'Shema "%s" baza podataka - stranica %s';
 $strPdfInvalidTblName = 'Tablica "%s" ne postoji!';
 $strPdfNoTables = 'Nema tablica';
-$strPDFOptions = 'PDF opcije';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Generira izvjetaj koji sadri podatke samo jedne tablice)';
 $strPDFReportTitle = 'Naslov izvjetaja';
@@ -779,7 +761,7 @@ $strShowStatusKey_readsDescr = 'Broj fizikih itanja kljunih blokova s diska. Ako
 $strShowStatusKey_write_requestsDescr = 'Broj zahtjeva za zapisivanje kljunog bloka u pohranu.';
 $strShowStatusKey_writesDescr = 'Broj fizikih zapisivanja kljunih blokova na disk. ';
 $strShowStatusLast_query_costDescr = 'Ukupan troak posljednjeg sloenog upita, izraunat od strane optimizatora upita. Korisno za usporeivanje trokova razliitih planova upita za isti upit. Zadana vrijednost je 0 i podrazumijeva da jo nema sloenog upita.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'Broj redaka koji ekaju svoje upisivanje u red ekanja INSERT DELAY.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'Broj redaka koji ekaju svoje upisivanje u red ekanja INSERT DELAYED.';
 $strShowStatusOpened_tablesDescr = 'Broj tablica koje su otvorene. Ako je iznos otvorenih tablica velik, vaa vrijednost za pohranu tablica vjerojatno je premala.';
 $strShowStatusOpen_filesDescr = 'Broj otvorenih datoteka.';
 $strShowStatusOpen_streamsDescr = 'Broj otvorenih protoka (uglavnom se upotrebljava za voenje zapisnika).';
@@ -832,8 +814,6 @@ $strSpanish = 'panjolski';
 $strSplitWordsWithSpace = 'Rijei su razdvojene znakom razmaka (" ").';
 $strSQLCompatibility = 'Nain rada SQL kompatibilnosti';
 $strSQLExportType = 'Vrsta izvoza';
-$strSQLImportOptions = 'SQL opcije';
-$strSQLOptions = 'SQL opcije';
 $strSQLParserBugMessage = 'Postoji mogunost da ste pronali nedostatak u SQL ralanjivau. Temeljito prouite va upit i provjerite ispravan unos navodnika. Jedan od moguih razloga je i da ste uitali datoteku s binarnim vrijednosti izvan prostora s navodnicima. Va upit takoer moete provjeriti u naredbenom retku MySQL-a. Ispis pogreke MySQL posluitelja moe vam pomoi u dijagnosticiranju problema. Ako i dalje postoje problemi ili ako ralanjiva ne uspijeva u zadacima koji uspijevaju u naredbenom retku, suzite svoj unos SQL upita na samo onaj upit koji izaziva probleme i podnesite prijavu o nedostatku zajedno s dijelom podatka u donjem odjeljku CUT:';
 $strSQLParserUserError = 'Izgleda da postoji pogreka u vaem SQL upitu. Ispis pogreke MySQL posluitelja moe vam pomoi u dijagnosticiranju problema.';
 $strSQLQuery = 'SQL upit';
@@ -854,7 +834,6 @@ $strStrucCSV = 'CSV';
 $strStrucData = 'Strukturu i podatke';
 $strStrucExcelCSV = 'CSV za MS Excel';
 $strStrucNativeExcel = 'Izvorno MS Excel oblikovanje';
-$strStrucNativeExcelOptions = 'Opcije izvornog Excel izvoza';
 $strStrucOnly = 'Samo strukturu';
 $strStructPropose = 'Predloi strukturu tablice';
 $strStructure = 'Strukturu';
@@ -970,7 +949,6 @@ $strWithChecked = 'S odabirom:';
 $strWriteRequests = 'Zahtjevi zapisivanja';
 $strWrongUser = 'Pogreno korisniko ime ili lozinka. Pristup odbijen.';
 
-$strXMLOptions = 'XML opcije';
 $strXML = 'XML';
 
 $strYes = 'Da';
@@ -981,7 +959,6 @@ $strZip = '"zipano"';
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1026,4 +1003,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
