@@ -1,5 +1,5 @@
 <?php
-/* $Id: czech-utf-8.inc.php 9857 2007-01-22 15:24:43Z nijel $ */
+/* $Id: czech-utf-8.inc.php 10509 2007-07-19 19:45:46Z nijel $ */
 
 /**
  * Czech language file by
@@ -9,7 +9,7 @@
 $charset = 'utf-8';
 $allow_recoding = TRUE;
 $text_dir = 'ltr';
-$number_thousands_separator = ' ';
+$number_thousands_separator = ' ';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');
@@ -69,7 +69,6 @@ $strAscending = 'Vzestupně';
 $strAtBeginningOfTable = 'Na začátku tabulky';
 $strAtEndOfTable = 'Na konci tabulky';
 $strAttr = 'Vlastnosti';
-$strAutodetect = 'Automaticky zjistit';
 $strAutomaticLayout = 'automatické rozvržení';
 
 $strBack = 'Zpět';
@@ -114,7 +113,7 @@ $strCanNotLoadExportPlugins = 'Nepodařilo se nahrát pluginy pro export, zkontr
 $strCanNotLoadImportPlugins = 'Nepodařilo se nahrát pluginy pro import, zkontrolujte prosím vaší instalaci!';
 $strCannotLogin = 'Nepodařilo se přihlášení k&nbsp;MySQL serveru';
 $strCantLoad = 'nelze nahrát rozšíření %s,<br />zkontrolujte prosím nastavení PHP';
-$strCantLoadRecodeIconv = 'Nelze nahrát rozšíření iconv ani recode potřebná pro převod znakových sad. Upravte nastavení PHP tak, aby umožňovalo použít tyto rozšíření nebo vypněte převod znakových sad v&nbsp;phpMyAdminu.';
+$strCantLoadRecodeIconv = 'Nelze nahrát rozšíření iconv ani recode potřebná pro převod znakových sad. Upravte nastavení PHP tak, aby umožňovalo použít tyto rozšíření nebo vypněte převod znakových sad v&nbsp;phpMyAdminovi.';
 $strCantRenameIdxToPrimary = 'Index nemůžete přejmenovat na &bdquo;PRIMARY&ldquo;!';
 $strCantUseRecodeIconv = 'Nelze použít funkce iconv ani libiconv ani recode_string, přestože rozšíření jsou nahrána. Zkontrolujte nastavení PHP.';
 $strCardinality = 'Mohutnost';
@@ -151,13 +150,14 @@ $strCompatibleHashing = 'Kompatibilní s&nbsp;MySQL&nbsp;4.0';
 $strCompleteInserts = 'Úplné inserty';
 $strCompression = 'Komprese';
 $strCompressionWillBeDetected = 'Komprimace importovaného souboru bude automaticky rozpoznána. Podporovány jsou: %s';
-$strConfigDefaultFileError = 'Nepodařilo se nahrát výchozí konfiguraci ze soubouru: "%1$s"';
+$strConfigDefaultFileError = 'Nepodařilo se nahrát výchozí konfiguraci ze souboru: "%1$s"';
 $strConfigFileError = 'phpMyAdmin nemohl načíst konfigurační soubor!<br />Tato chyba může nastat, pokud v&nbsp;něm PHP najde chybu nebo nemůže tento soubor najít.<br />Po kliknutí na následující odkaz se PHP pokusí přímo interpretovat tento soubor a zobrazí informace o&nbsp;chybě, ke které došlo. Pak opravte tuto chybu (nejčastěji se jedná o&nbsp;chybějící středník).<br />Pokud získáte prázdnou stránku, všechno je v&nbsp;pořádku.';
 $strConfigureTableCoord = 'Prosím, nastavte souřadnice pro tabulku %s';
 $strConnectionError = 'Nepodařilo se připojit: chybné nastavení.';
 $strConnections = 'Připojení';
 $strConstraintsForDumped = 'Omezení pro exportované tabulky';
 $strConstraintsForTable = 'Omezení pro tabulku';
+$strControluserFailed = 'Nepodařilo se připojit jako controluser, který je nadefinován v nastaveních.';
 $strCookiesRequired = 'Přihlášení vyžaduje povolené cookies.';
 $strCopyDatabaseOK = 'Databáze %s byla zkopírována na %s';
 $strCopy = 'Kopírovat';
@@ -183,8 +183,6 @@ $strCreationDates = 'Datum vytvoření, poslední změny a kontroly';
 $strCriteria = 'Podmínka';
 $strCroatian = 'Chorvatština';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Nastavení CSV';
-$strCSVOptions = 'Nastavení CSV exportu';
 $strCyrillic = 'Cyrilika';
 $strCzech = 'Čeština';
 $strCzechSlovak = 'Čeština/Slovenština';
@@ -194,7 +192,6 @@ $strDatabase = 'Databáze';
 $strDatabaseEmpty = 'Jméno databáze je prázdné!';
 $strDatabaseExportOptions = 'Nastavení exportu databází';
 $strDatabaseHasBeenDropped = 'Databáze %s byla zrušena.';
-$strDatabaseNoTable = 'Tato databáze neobsahuje žádné tabulky!';
 $strDatabases = 'Databáze';
 $strDatabasesDropped = '%s databáze byla úspěšně zrušena.';
 $strDatabasesStatsDisable = 'Skrýt podrobnosti';
@@ -204,7 +201,7 @@ $strDatabasesStats = 'Statistiky databází';
 $strData = 'Data';
 $strDataDict = 'Datový slovník';
 $strDataOnly = ' Jen data';
-$strDataPages = 'Stránek obshahujících data';
+$strDataPages = 'Stránek obsahujících data';
 $strDBComment = 'Komentář k&nbsp;databázi: ';
 $strDBCopy = 'Zkopírovat databázi na';
 $strDbIsEmpty = 'Databáze se zdá být prázdná!';
@@ -217,7 +214,7 @@ $strDefault = 'Výchozí';
 $strDefragment = 'Defragmentovat tabulku';
 $strDelayedInserts = 'Používat zpožděné inserty';
 $strDeleteAndFlushDescr = 'Toto je nejčistší řešení, ale načítání oprávnění může trvat dlouho.';
-$strDeleteAndFlush = 'Odstranit uživatele a znovunačíst oprávnění.';
+$strDeleteAndFlush = 'Odstranit uživatele a znovu načíst oprávnění.';
 $strDeleted = 'Řádek byl smazán';
 $strDeletedRows = 'Smazané řádky:';
 $strDeleteNoUsersSelected = 'Musíte vybrat uživatele, které chcete odstranit!';
@@ -240,7 +237,6 @@ $strDisplayOrder = 'Seřadit podle:';
 $strDisplayPDF = 'Zobrazit jako schéma v&nbsp;PDF';
 $strDoAQuery = 'Provést &bdquo;dotaz podle příkladu&ldquo; (zástupný znak: &bdquo;%&ldquo;)';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'Nastavení pro DocSQL';
 $strDocu = 'Dokumentace';
 $strDoYouReally = 'Opravdu si přejete vykonat příkaz';
 $strDropDatabaseStrongWarning = 'Chystáte se ZRUŠIT celou databázi!';
@@ -277,8 +273,8 @@ $strErrorSaveTable = 'Chyba při ukládání souřadnic pro Návrháře.';
 $strEscapeWildcards = 'Zástupné znaky _ a % by měly být escapovány pomocí \, pokud je chcete použít jako znak';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estonština';
+$strEvent = 'Událost';
 $strExcelEdition = 'Verze Excelu';
-$strExcelOptions = 'Nastavení exportu do Excelu';
 $strExecuteBookmarked = 'Spustit oblíbený dotaz';
 $strExplain = 'Vysvětlit dotaz';
 $strExport = 'Export';
@@ -289,7 +285,7 @@ $strExtra = 'Extra';
 
 $strFailedAttempts = 'Nepovedených pokusů';
 $strFieldHasBeenDropped = 'Sloupec %s byl odstraněn';
-$strFieldsEmpty = ' Nebyl zadán počet sloupců! ';
+$strFieldInsertFromFileTempDirNotExists = 'Chyba při přejmenování nahraného soubory, viz FAQ 1.11';
 $strFieldsEnclosedBy = 'Názvy sloupců uzavřené';
 $strFieldsEscapedBy = 'Názvy sloupců escapovány';
 $strField = 'Sloupec';
@@ -303,9 +299,10 @@ $strFileNameTemplateDescriptionTable = 'jméno tabulky';
 $strFileNameTemplateDescription = 'Tato hodnota je interpretována pomocí %1$sstrftime%2$s, takže můžete použít libovolné řetězce pro formátování data a času. Dále budou provedena následující nahrazení: %3$s. Jakýkoliv jiný text zůstane zachován beze změny.';
 $strFileNameTemplateRemember = 'zapamatovat si hodnotu';
 $strFileNameTemplate = 'Vzor pro jméno souboru';
+$strFiles = 'Soubory';
 $strFileToImport = 'Soubor pro importování';
 $strFixed = 'pevný';
-$strFlushPrivilegesNote = 'Poznámka: phpMyAdmin získává oprávnění přímo z&nbsp;tabulek MySQL. Obsah těchto tabulek se může lišit od oprávnění, která server právě používá, pokud byly tyto tabulky upravovány. V&nbsp;tomto případě je vhodné provést %sznovunačtení oprávnění%s před pokračováním.';
+$strFlushPrivilegesNote = 'Poznámka: phpMyAdmin získává oprávnění přímo z&nbsp;tabulek MySQL. Obsah těchto tabulek se může lišit od oprávnění, která server právě používá, pokud byly tyto tabulky upravovány. V&nbsp;tomto případě je vhodné provést %snové načtení oprávnění%s před pokračováním.';
 $strFlushQueryCache = 'Vyprázdnit vyrovnávací paměť dotazů';
 $strFlushTables = 'Zavřít všechny tabulky';
 $strFlushTable = 'Vyprázdnit vyrovnávací paměť pro tabulku (&bdquo;FLUSH&ldquo;)';
@@ -339,7 +336,7 @@ $strHasBeenCreated = 'byla vytvořena.';
 $strHaveToShow = 'Musíte zvolit alespoň jeden sloupec, který chcete zobrazit.';
 $strHebrew = 'Hebrejština';
 $strHelp = 'Nápověda';
-$strHexForBinary = 'Binární pole vypisovat šestnáctkově';
+$strHexForBLOB = 'Použít šestnáctkové zobrazení pro BLOB';
 $strHideShowAll = 'Skrýt/Zobrazit vše';
 $strHideShowNoRelation = 'Skrýt/Zobrazit tabulky bez relací';
 $strHide         = 'Skrýt';
@@ -348,9 +345,7 @@ $strHomepageOfficial = 'Oficiální stránka phpMyAdmina';
 $strHostEmpty = 'Jméno počítače je prázdné!';
 $strHost = 'Počítač';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Nastavení exportu pro Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Nastavení exportu pro Microsoft Word 2000';
 $strHungarian = 'Maďarština';
 
 $strIcelandic = 'Islandština';
@@ -366,14 +361,12 @@ $strImportFormat = 'Formát importovaného souboru';
 $strImport = 'Import';
 $strImportSuccessfullyFinished = 'Import byl úspěšně dokončen, bylo provedeno %d dotazů.';
 $strIndexes = 'Indexy';
+$strIndexesSeemEqual = 'Následující indexy vypadají shodně a jeden z nich by měl být odstraněn:';
 $strIndexHasBeenDropped = 'Index %s byl odstraněn';
 $strIndex = 'Index';
 $strIndexName = 'Jméno indexu&nbsp;:';
 $strIndexType = 'Typ indexu&nbsp;:';
-$strIndexWarningMultiple = 'Pro sloupec `%s` je vytvořeno více indexů';
-$strIndexWarningPrimary = 'Sloupec `%s` by neměl být zároveň obsažen v&nbsp;PRIMARY a INDEX klíči';
 $strIndexWarningTable = 'Problémy s&nbsp;indexy v&nbsp;tabulce `%s`';
-$strIndexWarningUnique = 'Sloupec `%s` by neměl být zároveň obsažen v&nbsp;PRIMARY a UNIQUE klíči';
 $strInnoDBAutoextendIncrementDesc = 'Velikost o&nbsp;kterou je zvětšen soubor s&nbsp;daty, pokud je zaplněný.';
 $strInnoDBAutoextendIncrement = 'Krok automatického zvětšování';
 $strInnoDBBufferPoolSizeDesc = 'Velikost vyrovnávací paměti, kterou InnoDB používá pro vyrovnávací paměť dat a indexů tabulek.';
@@ -384,7 +377,7 @@ $strInnoDBDataHomeDir = 'Domovský adresář pro data';
 $strInnoDBPages = 'stránek';
 $strInnoDBRelationAdded = 'Vytvořena relace InnoDB';
 $strInnodbStat = 'Stav InnoDB';
-$strInsecureMySQL = 'Máte standardní nastavení hesla uživatele root v&nbsp;MySQL. Doporučujeme změnit toto nastavení a tím podstatně zvýšit bezpečnost vašeho serveru.';
+$strInsecureMySQL = 'Máte standardní nastavení hesla uživatele root v&nbsp;MySQL. Doporučujeme změnit toto nastavení a tím podstatně zvýšit zabezpečení vašeho serveru.';
 $strInsertAsNewRow = 'Vložit jako nový řádek';
 $strInsertedRowId = 'Id vloženého řádku:';
 $strInsertedRows = 'Vloženo řádků:';
@@ -411,7 +404,7 @@ $strInvalidTableName = 'Chybné jméno tabulky';
 $strJapanese = 'Japonština';
 $strJoins = 'Použité výběry';
 $strJumpToDB = 'Přejít na databázi &bdquo;%s&ldquo;.';
-$strJustDeleteDescr = 'Odstranění uživatelé stále budou mít přístup na server, dokud nebudou znovunačtena oprávnění.';
+$strJustDeleteDescr = 'Odstranění uživatelé stále budou mít přístup na server, dokud nebudou znovu načtena oprávnění.';
 $strJustDelete = 'Jen odstranit uživatele z&nbsp;tabulek s&nbsp;oprávněními.';
 
 $strKeepPass = 'Neměnit heslo';
@@ -422,7 +415,6 @@ $strKnownExternalBug = 'Funkčnost %s je omezena známou chybou, viz %s.';
 $strKorean = 'Korejština';
 
 $strLandscape = 'Na šířku';
-$strLanguageFileNotFound = 'Jazykový soubor "%1$s" nebyl nalezen.';
 $strLanguage = 'Jazyk';
 $strLanguageUnknown = 'Neznámý jazyk: %1$s.';
 $strLatchedPages = 'Zamčených stránek';
@@ -433,11 +425,9 @@ $strLatexContinued = '(pokračování)';
 $strLatexIncludeCaption = 'Použít titulek tabulky';
 $strLatexLabel = 'Návěstí';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Nastavení exportu do LaTeXu';
 $strLatexStructure = 'Struktura tabulky __TABLE__';
 $strLatvian = 'Lotyština';
 $strLDI = 'CSV pomocí LOAD DATA';
-$strLDIImportOptions = 'Nastavení CSV importu pomocí LOAD DATA';
 $strLDILocal = 'Použít klíčové slovo LOCAL';
 $strLengthSet = 'Délka/Množina';
 $strLimitNumRows = 'záznamů na stránku';
@@ -458,7 +448,7 @@ $strLongOperation = 'Tato operace může trvat velmi dlouho. Chcete je přesto p
 $strMaxConnects = 'Maximum současných připojení';
 $strMaximalQueryLength = 'Maximální velikost vytvořeného dotazu';
 $strMaximumSize = 'Maximální velikost: %s%s';
-$strMbExtensionMissing = 'Rozšíření mbstring pro PHP nebylo nalezeno a zdá se, že požíváte vícebajtovou znakovou sadu. Bez rozšíření mbstring neumí phpMyAdmin správně rozdělovat řetězce a proto to může mít nečekané následky.';
+$strMbExtensionMissing = 'Rozšíření mbstring pro PHP nebylo nalezeno a zdá se, že požíváte více bajtovou znakovou sadu. Bez rozšíření mbstring neumí phpMyAdmin správně rozdělovat řetězce a proto to může mít nečekané následky.';
 $strMbOverloadWarning = 'V&nbsp;nastavení PHP máte zapnuto mbstring.func_overload. Toto nastavení není kompatibilní s&nbsp;phpMyAdminem a může způsobit poškození dat!';
 $strMIME_available_mime = 'Dostupné MIME typy';
 $strMIME_available_transform = 'Dostupné transformace';
@@ -487,13 +477,14 @@ $strMyISAMMaxSortFileSizeDesc = 'Maximální velikost dočasných souborů, kter
 $strMyISAMMaxSortFileSize = 'Maximální velikost dočasných souborů pro řazení';
 $strMyISAMRecoverOptions = 'Automatický režim obnovy';
 $strMyISAMRecoverOptionsDesc = 'Režim automatické obnovy poškozených MyISAM tabulek. Nastavuje se parametrem --myisam-recover při spouštění serveru.';
-$strMyISAMRepairThreadsDesc = 'Pokud je tato hodnota větší než 1, indexy v&nbsp;MyISAM tabulkách jsou vytvářeny paraleleně (každý index vlastním threadem) při obnově nebo řazení.';
+$strMyISAMRepairThreadsDesc = 'Pokud je tato hodnota větší než 1, indexy v&nbsp;MyISAM tabulkách jsou vytvářeny paralelně (každý index vlastním threadem) při obnově nebo řazení.';
 $strMyISAMRepairThreads = 'Threadů pro opravování';
 $strMyISAMSortBufferSizeDesc = 'Paměť, která je alokována při řazení MyISAM indexů během jejich vytváření nebo opravování.';
 $strMyISAMSortBufferSize = 'Velikost paměti pro řazení';
 $strMySQLCharset = 'Znaková sada v&nbsp;MySQL';
 $strMysqlClientVersion = 'Verze MySQL klienta';
 $strMySQLConnectionCollation = 'Porovnávání pro toto připojení k&nbsp;MySQL';
+$strMysqlLibDiffersServerVersion = 'Používaný MySQL modul v PHP je kompilována pro MySQL %s a server používá verzi %s. Toto může způsobit problémy.';
 $strMySQLSaid = 'MySQL hlásí: ';
 $strMySQLShowProcess = 'Zobrazit procesy';
 $strMySQLShowStatus = 'Informace o&nbsp;stavu MySQL';
@@ -539,14 +530,13 @@ $strNumSearchResultsTotal = '<b>Celkem:</b> <i>%s</i> odpovídající(ch) zázna
 $strNumTables = 'Tabulek';
 
 $strOK = 'OK';
-$strOpenDocumentSpreadsheetOptions = 'Nastavení exportu do sešitu Open Document';
-$strOpenDocumentSpreadsheet = 'Sešit Open Document';
-$strOpenDocumentTextOptions = 'Nastavení exportu do textu Open Document';
-$strOpenDocumentText = 'Text Open Document';
+$strOpenDocumentSpreadsheet = 'Sešit OpenDocument';
+$strOpenDocumentText = 'Text OpenDocument';
 $strOpenNewWindow = 'Otevřít nové okno phpMyAdmina';
 $strOperations = 'Úpravy';
 $strOperator = 'Operátor';
 $strOptimizeTable = 'Optimalizovat tabulku';
+$strOptions = 'Nastavení';
 $strOr = 'nebo';
 $strOverhead = 'Navíc';
 $strOverwriteExisting = 'Přepsat existující soubor(y)';
@@ -564,7 +554,6 @@ $strPasswordNotSame = 'Hesla nejsou stejná!';
 $strPdfDbSchema = 'Schéma databáze &bdquo;%s&ldquo; - Strana %s';
 $strPdfInvalidTblName = 'Tabulka &bdquo;%s&ldquo; neexistuje!';
 $strPdfNoTables = 'žádné tabulky';
-$strPDFOptions = 'Nastavení PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Vygeneruje dokument obsahující data jedné tabulky)';
 $strPDFReportTitle = 'Název výpisu';
@@ -573,7 +562,7 @@ $strPerMinute = 'za minutu';
 $strPerSecond = 'za sekundu';
 $strPersian = 'Perština';
 $strPhoneBook = 'adresář';
-$strPHP40203 = 'Používáte PHP 4.2.3, které má závažnou chybu při práci s&nbsp;vícebajtovými znaky (mbstring), jedná se o&nbsp;chybu PHP číslo 19404. Nedoporučujeme používat tuto verzi PHP s&nbsp;phpMyAdminem.';
+$strPHP40203 = 'Používáte PHP 4.2.3, které má závažnou chybu při práci s&nbsp;více bajtovými znaky (mbstring), jedná se o&nbsp;chybu PHP číslo 19404. Nedoporučujeme používat tuto verzi PHP s&nbsp;phpMyAdminem.';
 $strPHPVersion = 'Verze PHP';
 $strPhp = 'Vytvořit PHP kód';
 $strPleaseSelectPrimaryOrUniqueKey = 'Zvolte, prosím, primární nebo unikátní klíč';
@@ -617,7 +606,7 @@ $strPrivDescMaxUserConnections = 'Omezuje počet současných připojení uživa
 $strPrivDescProcess3 = 'Umožňuje ukončit procesy jiným uživatelům.';
 $strPrivDescProcess4 = 'Umožňuje vidět celé dotazy v&nbsp;seznamu procesů.';
 $strPrivDescReferences = 'Nemá žádný vliv v&nbsp;této verzi MySQL.';
-$strPrivDescReload = 'Umožňuje znovunačtení nastavení a vyprázdnění vyrovnávacích pamětí MySQL serveru.';
+$strPrivDescReload = 'Umožňuje znovu načíst nastavení a vyprázdnění vyrovnávacích pamětí MySQL serveru.';
 $strPrivDescReplClient = 'Umožní uživateli zjistit, kde je hlavní / pomocný server.';
 $strPrivDescReplSlave = 'Potřebné pro replikaci pomocných serverů.';
 $strPrivDescSelect = 'Umožňuje vybírat data.';
@@ -628,10 +617,11 @@ $strPrivDescSuper = 'Umožňuje připojení, i když je dosažen maximální po
 $strPrivDescUpdate = 'Umožňuje měnit data.';
 $strPrivDescUsage = 'Žádná oprávnění.';
 $strPrivileges = 'Oprávnění';
-$strPrivilegesReloaded = 'Oprávnění byla znovunačtena úspěšně.';
+$strPrivilegesReloaded = 'Oprávnění byla načtena úspěšně.';
 $strProcedures = 'Procedury';
 $strProcesses = 'Procesy';
 $strProcesslist = 'Seznam procesů';
+$strProfiling = 'Profilování';
 $strProtocolVersion = 'Verze protokolu';
 $strPutColNames = 'Přidat jména sloupců na první řádek';
 
@@ -660,8 +650,8 @@ $strRelationNotWorking = 'Některé z&nbsp;rozšířených funkcí phpMyAdmina n
 $strRelationsForTable = 'RELACE PRO TABULKU';
 $strRelations = 'Relace';
 $strRelationView = 'Zobrazit relace';
-$strReloadingThePrivileges = 'Znovunačítám oprávnění';
-$strReloadPrivileges = 'Znovunačíst oprávnění';
+$strReloadingThePrivileges = 'Načítám oprávnění';
+$strReloadPrivileges = 'Znovu načíst oprávnění';
 $strReload = 'Znovu načíst';
 $strRemoveSelectedUsers = 'Odstranit vybrané uživatele';
 $strRenameDatabaseOK = 'Databáze %s byla přejmenována na %s';
@@ -673,12 +663,15 @@ $strReplaceTable = 'Přepsat data tabulky souborem';
 $strReplication = 'Replikace';
 $strReset = 'Původní';
 $strResourceLimits = 'Omezení zdrojů';
+$strRestartInsertion = 'Začít znovu vkládání s %s řádky';
 $strReType = 'Heslo znovu';
-$strRevokeAndDeleteDescr = 'Uživatelé budou mít oprávnění &bdquo;USAGE&ldquo; (používání), dokud nebudou znovunačtena oprávnění.';
+$strRevokeAndDeleteDescr = 'Uživatelé budou mít oprávnění &bdquo;USAGE&ldquo; (používání), dokud nebudou znovu načtena oprávnění.';
 $strRevokeAndDelete = 'Odebrat uživatelům veškerá oprávnění a poté je odstranit z&nbsp;tabulek.';
 $strRevokeMessage = 'Byla zrušena práva pro %s';
 $strRevoke = 'Zrušit';
 $strRomanian = 'Rumunština';
+$strRoutineReturnType = 'Návratový typ';
+$strRoutines = 'Rutiny';
 $strRowLength = 'Délka řádku';
 $strRowsFrom = 'řádků začínající od';
 $strRowSize = ' Velikost řádku ';
@@ -730,6 +723,7 @@ $strServerTabVariables = 'Proměnné';
 $strServerTrafficNotes = '<b>Provoz serveru</b>: Informace o&nbsp;síťovém provozu MySQL serveru od jeho spuštění.';
 $strServerVars = 'Proměnné a nastavení serveru';
 $strServerVersion = 'Verze MySQL';
+$strSessionStartupErrorGeneral = 'Vytváření sezení selhalo, prosím zkontrolujte chyby v logu PHP a/nebo webserveru a pečlivě nastavte podporu sezení v PHP.';
 $strSessionValue = 'Hodnota sezení';
 $strSetEnumVal = 'Pokud je sloupec typu &bdquo;enum&ldquo; nebo &bdquo;set", zadávejte hodnoty v&nbsp;následujícím formátu: \'a\',\'b\',\'c\'...<br />Pokud potřebujete zadat zpětné lomítko (&bdquo;\&ldquo;) nebo jednoduché uvozovky (&bdquo;\'&ldquo;) mezi těmito hodnotami, napište před ně zpětné lomítko (příklad: \'\\\\xyz\' nebo \'a\\\'b\').';
 $strShowAll = 'Zobrazit vše';
@@ -762,7 +756,7 @@ $strShowStatusHandler_read_firstDescr = 'Počet přečtení první položky inde
 $strShowStatusHandler_read_keyDescr = 'Počet požadavků na přečtení řádku vycházející z&nbsp;indexu. Vysoká hodnota znamená, že dotazy správně využívají indexy.';
 $strShowStatusHandler_read_nextDescr = 'Počet požadavků na přečtení dalšího řádku podle indexu. Tato hodnota se zvětšuje pokud provádíte dotaz na indexovaný sloupec s&nbsp;omezením rozsahu nebo prohledáváte index.';
 $strShowStatusHandler_read_prevDescr = 'Počet požadavků na přečtení předchozího řádku z&nbsp;indexu. Používané pro optimalizaci dotazů ORDER BY ... DESC.';
-$strShowStatusHandler_read_rndDescr = 'Počet požadavků na přečtení konkrétního řádku tabulky. Vysoká hodnota znamená, že provádíte mnoho dotazů, které vyřadují řazení výsledků. Pravděpodobně používáte mnoho dotazů, které vyžadují prohlížení celé tabulky nebo používáte spojení tabulek, která nevyužívají indexů.';
+$strShowStatusHandler_read_rndDescr = 'Počet požadavků na přečtení konkrétního řádku tabulky. Vysoká hodnota znamená, že provádíte mnoho dotazů, které vyžadují řazení výsledků. Pravděpodobně používáte mnoho dotazů, které vyžadují prohlížení celé tabulky nebo používáte spojení tabulek, která nevyužívají indexů.';
 $strShowStatusHandler_read_rnd_nextDescr = 'Počet požadavků na přečtení dalšího řádku ze souboru. Tato hodnota je vysoká pokud dotazy procházejí celé tabulky, pravděpodobně tedy nemají vhodné indexy.';
 $strShowStatusHandler_rollbackDescr = 'Počet interních příkazů ROLLBACK.';
 $strShowStatusHandler_updateDescr = 'Počet požadavků na aktualizaci řádku.';
@@ -785,8 +779,8 @@ $strShowStatusInnodb_data_pending_fsyncsDescr = 'Počet nevyřízených synchron
 $strShowStatusInnodb_data_pending_readsDescr = 'Počet nevyřízených čtení.';
 $strShowStatusInnodb_data_pending_writesDescr = 'Počet nevyřízených zápisů.';
 $strShowStatusInnodb_data_readDescr = 'Velikost přečtených dat, v&nbsp;bajtech.';
-$strShowStatusInnodb_data_readsDescr = 'Počet provedenách čtení dat.';
-$strShowStatusInnodb_data_writesDescr = 'Počet provedenách zápisů dat.';
+$strShowStatusInnodb_data_readsDescr = 'Počet provedených čtení dat.';
+$strShowStatusInnodb_data_writesDescr = 'Počet provedených zápisů dat.';
 $strShowStatusInnodb_data_writtenDescr = 'Velikost zapsaných dat, v&nbsp;bajtech.';
 $strShowStatusInnodb_dblwr_pages_writtenDescr = 'Počet provedených dvojitých zapsání a počet stránek, které byly takto zapsány.';
 $strShowStatusInnodb_dblwr_writesDescr = 'Počet provedených dvojitých zapsání a počet stránek, které byly takto zapsány.';
@@ -806,18 +800,18 @@ $strShowStatusInnodb_row_lock_time_avgDescr = 'Průměrný čas potřebný pro z
 $strShowStatusInnodb_row_lock_timeDescr = 'Celkový čas strávený čekáním na zámek řádku, v&nbsp;milisekundách.';
 $strShowStatusInnodb_row_lock_time_maxDescr = 'Maximální čas potřebný pro získání zámku řádku, v&nbsp;milisekundách.';
 $strShowStatusInnodb_row_lock_waitsDescr = 'Kolikrát se muselo čekat na zámek řádku.';
-$strShowStatusInnodb_rows_deletedDescr = 'Počet řádků ostraněných z&nbsp;InnoDB tabulek.';
+$strShowStatusInnodb_rows_deletedDescr = 'Počet řádků odstraněných z&nbsp;InnoDB tabulek.';
 $strShowStatusInnodb_rows_insertedDescr = 'Počet řádků vložených do InnoDB tabulek.';
 $strShowStatusInnodb_rows_readDescr = 'Počet řádků přečtených z&nbsp;InnoDB tabulek.';
 $strShowStatusInnodb_rows_updatedDescr = 'Počet řádků aktualizovaných v&nbsp;InnoDB tabulkách.';
 $strShowStatusKey_blocks_not_flushedDescr = 'Počet bloků ve vyrovnávací paměti klíčů, které byly změněny, ale nebyly zapsány na disk. Dříve se tato hodnota jmenovala Not_flushed_key_blocks.';
-$strShowStatusKey_blocks_unusedDescr = 'Počet nepoužitých bloků ve vyrovnávací paměti klíčů. Pomocí této hodoty poznáte jak moc je vyrovnávací paměť využitá.';
+$strShowStatusKey_blocks_unusedDescr = 'Počet nepoužitých bloků ve vyrovnávací paměti klíčů. Pomocí této hodnoty poznáte jak moc je vyrovnávací paměť využitá.';
 $strShowStatusKey_blocks_usedDescr = 'Počet použitých bloků ve vyrovnávací paměti klíčů. Tato hodnota určuje maximum bloků, které kdy byly obsazeny najednou.';
 $strShowStatusKey_read_requestsDescr = 'Počet požadavků na přečtení klíče z&nbsp;vyrovnávací paměti.';
 $strShowStatusKey_readsDescr = 'Počet skutečných čtení bloku zklíče z&nbsp;disku. Pokud je hodnota příliš velká, pravděpodobně máte malou vyrovnávací paměť (key_buffer_size). Úspěšnost vyrovnávací paměti můžete spočítat jako Key_reads/Key_read_requests.';
 $strShowStatusKey_write_requestsDescr = 'Počet požadavků na zápis bloku klíče na disk.';
 $strShowStatusKey_writesDescr = 'Počet skutečných zápisů bloku klíče na disk.';
-$strShowStatusLast_query_costDescr = 'Celková cena posledního kompilovaného dotazu spočítaná optimalizérem dotazů. Užitečné pro porovnání různých dotazů. Výchozí hodnota 0 znamená, že žádný dotaz ještě nebyl kompilován.';
+$strShowStatusLast_query_costDescr = 'Celková cena posledního kompilovaného dotazu spočítaná optimalizátorem dotazů. Užitečné pro porovnání různých dotazů. Výchozí hodnota 0 znamená, že žádný dotaz ještě nebyl kompilován.';
 $strShowStatusNot_flushed_delayed_rowsDescr = 'Počet řádků čekajících na zapsání ve frontě INSERT DELAYED.';
 $strShowStatusOpened_tablesDescr = 'Celkem otevřených tabulek. Pokud je tato hodnota příliš vysoká, pravděpodobně máte malou vyrovnávací paměť pro tabulky.';
 $strShowStatusOpen_filesDescr = 'Počet otevřených souborů.';
@@ -826,7 +820,7 @@ $strShowStatusOpen_tablesDescr = 'Počet aktuálně otevřených tabulek.';
 $strShowStatusQcache_free_blocksDescr = 'Počet volných bloků paměti ve vyrovnávací paměti dotazů.';
 $strShowStatusQcache_free_memoryDescr = 'Velikost volné paměti ve vyrovnávací paměti dotazů.';
 $strShowStatusQcache_hitsDescr = 'Počet zásahů vyrovnávací paměti dotazů.';
-$strShowStatusQcache_insertsDescr = 'Počet dotazůch přidaných do vyrovnávací paměti dotazů.';
+$strShowStatusQcache_insertsDescr = 'Počet dotazů přidaných do vyrovnávací paměti dotazů.';
 $strShowStatusQcache_lowmem_prunesDescr = 'Počet dotazů odstraněných z&nbsp;vyrovnávací paměti dotazů aby uvolnily místo pro nové. Tato hodnota může pomoci v&nbsp;nastavení velikosti vyrovnávací paměti. Vyrovnávací paměť používá strategii LRU (nejdéle nepoužité) pro vyřazování dotazů z&nbsp;vyrovnávací paměti.';
 $strShowStatusQcache_not_cachedDescr = 'Počet necachovaných dotazů (necachovatelných nebo necachovaných kvůli nastavení query_cache_type).';
 $strShowStatusQcache_queries_in_cacheDescr = 'Počet dotazů ve vyrovnávací paměti dotazů.';
@@ -836,19 +830,19 @@ $strShowStatusRpl_statusDescr = 'Stav failsafe replikace.';
 $strShowStatusSelect_full_joinDescr = 'Počet spojení, které nevyužívaly indexy. Pokud tato hodnota není 0, měli byste zkontrolovat indexy tabulek.';
 $strShowStatusSelect_full_range_joinDescr = 'Počet spojení, které používaly intervalové vyhledávání na referenční tabulce.';
 $strShowStatusSelect_range_checkDescr = 'Počet spojení bez klíčů, které kontrolovaly použití klíčů po každém řádku. Pokud tato hodnota není 0, měli byste zkontrolovat indexy tabulek.';
-$strShowStatusSelect_rangeDescr = 'Počet spojení, které použivaly intervalové vyhledávání na první tabulce. Tato hodnota obvykle není kritická i když je vysoká.';
+$strShowStatusSelect_rangeDescr = 'Počet spojení, které používaly intervalové vyhledávání na první tabulce. Tato hodnota obvykle není kritická i když je vysoká.';
 $strShowStatusSelect_scanDescr = 'Počet spojení, které prováděly kompletní procházení první tabulky.';
 $strShowStatusSlave_open_temp_tablesDescr = 'Počet dočasných tabulek v&nbsp;současné době otevřených podřízeným serverem.';
-$strShowStatusSlave_retried_transactionsDescr = 'Celkový poček, kolikrát musel podřízený server opakovat transakce.';
+$strShowStatusSlave_retried_transactionsDescr = 'Celkový počet, kolikrát musel podřízený server opakovat transakce.';
 $strShowStatusSlave_runningDescr = 'Tato položka je zapnutá, pokud server pracuje jako podřízený.';
-$strShowStatusSlow_launch_threadsDescr = 'Počet vláken jejihž vytvoření trvalo déle než slow_launch_time sekund.';
+$strShowStatusSlow_launch_threadsDescr = 'Počet vláken jejichž vytvoření trvalo déle než slow_launch_time sekund.';
 $strShowStatusSlow_queriesDescr = 'Počet dotazů, které trvaly déle než long_query_time sekund.';
 $strShowStatusSort_merge_passesDescr = 'Počet průchodů slučování, které musel provést řadicí algoritmus. Při příliš vysoké hodnotě zvažte zvýšení sort_buffer_size.';
 $strShowStatusSort_rangeDescr = 'Počet řazení, které byly omezeny rozsahem.';
 $strShowStatusSort_rowsDescr = 'Počet řazených řádek.';
 $strShowStatusSort_scanDescr = 'Počet řazení provedených procházením tabulky.';
-$strShowStatusTable_locks_immediateDescr = 'Poček okamžitých získání zámku tabulky.';
-$strShowStatusTable_locks_waitedDescr = 'Počet čekání na získání zámku tabulky. Pokud je tato hodnota vysoká a máte problémy s&nbsp;výkonem, měli byste optimalizovat dostazy a případně rozdělit tabulky nebo použít replikaci.';
+$strShowStatusTable_locks_immediateDescr = 'Počet okamžitých získání zámku tabulky.';
+$strShowStatusTable_locks_waitedDescr = 'Počet čekání na získání zámku tabulky. Pokud je tato hodnota vysoká a máte problémy s&nbsp;výkonem, měli byste optimalizovat dotazy a případně rozdělit tabulky nebo použít replikaci.';
 $strShowStatusThreads_cachedDescr = 'Počet vláken ve vyrovnávací paměti. Úspěšnost vyrovnávací paměti může být spočítána jako Threads_created/Connections. Pokud je tato hodnota červená, měli byste zvýšit thread_cache_size.';
 $strShowStatusThreads_connectedDescr = 'Počet aktuálně otevřených připojení.';
 $strShowStatusThreads_createdDescr = 'Počet vláken vytvořených pro obsluhu připojení. Pokud je hodnota příliš velká, můžete zvětšit parametr thread_cache_size. Na platformách, které mají dobrou implementaci vláken však toto nemá příliš velký vliv.';
@@ -865,7 +859,7 @@ $strSlovak = 'Slovenština';
 $strSlovenian = 'Slovinština';
 $strSmallBigAll = 'Vše malé/velké';
 $strSnapToGrid = 'Zachytávat na mřížku';
-$strSocketProblem = '(nebo není spávně nastaven lokální socket MySQL serveru)';
+$strSocketProblem = '(nebo není správně nastaven lokální socket MySQL serveru)';
 $strSortByKey = 'Setřídit podle klíče';
 $strSorting = 'Řazení';
 $strSort = 'Řadit';
@@ -874,8 +868,6 @@ $strSpanish = 'Španělština';
 $strSplitWordsWithSpace = 'Slova jsou oddělena mezerou (&bdquo; &ldquo;).';
 $strSQLCompatibility = 'Režim kompatibility SQL';
 $strSQLExportType = 'Typ vytvořených dotazů';
-$strSQLImportOptions = 'Nastavení SQL importu';
-$strSQLOptions = 'Nastavení SQL exportu';
 $strSQLParserBugMessage = 'Je možné, že jste našli chybu v&nbsp;SQL parseru. Prosím prozkoumejte podrobně SQL dotaz, především jestli jsou správně uvozovky a jestli nejsou proházené. Další možnost selhání je pokud nahráváte soubor s&nbsp;binárními daty nezapsanými v&nbsp;uvozovkách. Můžete také vyzkoušet příkazovou řádku MySQL. Níže uvedený výstup z&nbsp;MySQL serveru (pokud je nějaký) vám také může pomoci při zkoumání problému. Pokud stále máte problémy nebo pokud SQL parser ohlásí chybu u&nbsp;dotazu, který na příkazové řádce funguje, prosím pokuste se zredukovat dotaz na co nejmenší, ve kterém se problém ještě vyskytne, a ohlaste chybu na stránkách phpMyAdmina spolu se sekcí VÝPIS uvedenou níže:';
 $strSQLParserUserError = 'Pravděpodobně máte v&nbsp;SQL dotazu chybu. Níže uvedený výstup MySQL serveru (pokud je nějaký) vám také může pomoci při zkoumání problému';
 $strSQLQuery = 'SQL-dotaz';
@@ -897,7 +889,6 @@ $strStrucCSV = 'CSV';
 $strStrucData = 'Strukturu a data';
 $strStrucExcelCSV = 'CSV pro MS Excel';
 $strStrucNativeExcel = 'Nativní formát MS Excelu';
-$strStrucNativeExcelOptions = 'Nastavení exportu do Excelu';
 $strStrucOnly = 'Pouze strukturu';
 $strStructPropose = 'Navrhnout strukturu tabulky';
 $strStructureForView = 'Struktura pro pohled';
@@ -938,7 +929,7 @@ $strThisHost = 'Tento počítač';
 $strThreads = 'Počet vláken';
 $strThreadSuccessfullyKilled = 'Vlákno %s bylo úspěšně zabito.';
 $strTime = 'Čas';
-$strTimeoutInfo = 'Předchozí ímport vyčerpal veškerý čas, po dalším odeslání bude import pokračovat od pozize %d.';
+$strTimeoutInfo = 'Předchozí ímport vyčerpal veškerý čas, po dalším odeslání bude import pokračovat od pozice %d.';
 $strTimeoutNothingParsed = 'Bohužel během posledního pokusu nebyla žádná data načtena. Toto obvykle znamená, že phpMyAdmin nebude schopen načíst tento soubor, pokud nezvýšíte časové limity v&nbsp;PHP.';
 $strTimeoutPassed = 'Limit pro běh importu vypršel, prosím odešlete formulář znovu se stejným souborem a import bude pokračovat.';
 $strToFromPage = 'do/ze stránky';
@@ -952,7 +943,7 @@ $strTraditionalSpanish = 'Tradiční španělština';
 $strTraffic = 'Provoz';
 $strTransactionCoordinator = 'Koordinátor transakcí';
 $strTransformation_application_octetstream__download = 'Zobrazí odkaz na stáhnutí dat. První parametr je jméno souboru, druhý jméno sloupce v&nbsp;tabulce obsahující jméno souboru. Pokud zadáte druhý parametr, první musí být prázdný.';
-$strTransformation_application_octetstream__hex = 'Zobrazí data šestnáctkově. Nepovinný parameter určuje po kolika znacích má být přidána mezera (výchozí hodnota je 2).';
+$strTransformation_application_octetstream__hex = 'Zobrazí data šestnáctkově. Nepovinný parametr určuje po kolika znacích má být přidána mezera (výchozí hodnota je 2).';
 $strTransformation_image_jpeg__inline = 'Zobrazí náhled obrázku s&nbsp;odkazem na obrázek; parametry šířka a výška v&nbsp;bodech (poměr stran obrázku zůstane zachován)';
 $strTransformation_image_jpeg__link = 'Zobrazí odkaz na obrázek (například stáhnutí pole blob).';
 $strTransformation_image_png__inline = 'Viz image/jpeg: inline';
@@ -963,6 +954,7 @@ $strTransformation_text_plain__imagelink = 'Zobrazí obrázek a odkaz z&nbsp;pol
 $strTransformation_text_plain__link = 'Zobrazí odkaz z&nbsp;pole obsahujícího odkaz. První parametr je prefix URL (například &bdquo;http://mojedomena.cz/&ldquo;), druhý text odkazu.';
 $strTransformation_text_plain__sql = 'Zobrazí text jako SQL dotaz se zvýrazňováním syntaxe.';
 $strTransformation_text_plain__substr = 'Zobrazí jen část textu. První parametr je posun od začátku (výchozí je 0) a druhý určuje délku textu, který se má zobrazit, pokud není uveden, bude zobrazen zbytek textu. Třetí parametr určuje, jaký text má být přidán za zkrácený text (výchozí je ...).';
+$strTriggers = 'Spouště';
 $strTruncateQueries = 'Zobrazit zkrácené dotazy';
 $strTurkish = 'Turecky';
 $strType = 'Typ';
@@ -979,6 +971,13 @@ $strUpdateProfileMessage = 'Přístup byl změněn.';
 $strUpdateQuery = 'Aktualizovat dotaz';
 $strUpdComTab = 'Podívejte se prosím do dokumentace, jak aktualizovat tabulku s&nbsp;informacemi o&nbsp;sloupcích (tabulka column_comments)';
 $strUpgrade = 'Měli byste aktualizovat %s na verzi %s nebo vyšší.';
+$strUploadErrorCantWrite = 'Chyba při zapisování souboru na disk.';
+$strUploadErrorExtension = 'Nahrávání souboru zastaveno rozšířením.';
+$strUploadErrorFormSize = 'Velikost nahraného souboru přesahuje hodnotu MAX_FILE_SIZE, která byla zadána v HTML formuláři.';
+$strUploadErrorIniSize = 'Velikost nahraného souboru přesahuje nastavení upload_max_filesize v php.ini.';
+$strUploadErrorNoTempDir = 'Chybějící adresář pro dočasné soubory.';
+$strUploadErrorPartial = 'Soubor byl nahrán jen částečně.';
+$strUploadErrorUnknown = 'Neznámá chyba při nahrávání souboru.';
 $strUploadLimit = 'Pravděpodobně jste se pokusili nahrát příliš velký soubor. Přečtěte si prosím %sdokumentaci%s, jak toto omezení obejít.';
 $strUploadsNotAllowed = 'Upload souborů není na tomto serveru povolen.';
 $strUsage = 'Používá';
@@ -1008,6 +1007,7 @@ $strViewDumpDB = 'Export databáze';
 $strViewDump = 'Export tabulky';
 $strViewHasBeenDropped = 'Pohled %s byl odstraněn';
 $strViewMaxExactCount = 'Tento pohled má více než %d záznamů. Viz %sdokumentace%s.';
+$strViewName = 'Jméno pohledu';
 $strView = 'Pohled';
 
 $strWebServerUploadDirectoryError = 'Adresář určený pro upload souborů nemohl být otevřen';
@@ -1020,7 +1020,6 @@ $strWithChecked = 'Zaškrtnuté:';
 $strWriteRequests = 'Požadavků na čtení';
 $strWrongUser = 'Špatné uživatelské jméno nebo heslo. Přístup odepřen.';
 
-$strXMLOptions = 'Nastavení exportu do XML';
 $strXML = 'XML';
 
 $strYes = 'Ano';
