@@ -1,5 +1,5 @@
 <?php
-/* $Id: danish-utf-8.inc.php 10258 2007-04-07 15:27:37Z lem9 $ */ /* danish - Dansk v 2.162 (based on english 2.159) 2006/09/25 01:23:45 - oversætter AlleyKat kan kontaktes på < phpmyadmin (at) phpbb2.dk > */
+/* $Id: danish-utf-8.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */ /* danish - Dansk v 2.20 (based on english rev. 10226) 2007/04/03 01:23:45 - oversætter AlleyKat kan kontaktes på < phpmyadmin (at) phpbb2.dk > */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -19,7 +19,7 @@ $day_of_week  =  array('søn', 'man', 'tir', 'ons', 'tor', 'fre', 'lør');
 $month  =  array('jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'aug', 'sep', 'okt', 'nov', 'dec');
 // Se http://www.php.net/manual/en/function.strftime.php
 // for at definere variablen herunder
-$datefmt = '%d/%m %Y kl. %H:%M:%S';
+$datefmt = '%d. %m %Y kl. %H:%M:%S';
 $timespanfmt = '%s dage, %s timer, %s minutter og %s sekunder';
 
 $strAbortedClients = 'Afbrudt';
@@ -69,7 +69,6 @@ $strAscending = 'Stigende';
 $strAtBeginningOfTable = 'I begyndelsen af tabel';
 $strAtEndOfTable = 'I slutningen af tabel';
 $strAttr = 'Attributter';
-$strAutodetect = 'Fastslå automatisk';
 $strAutomaticLayout = 'Automatisk layout';
 
 $strBack = 'Tilbage';
@@ -158,19 +157,20 @@ $strConnectionError = 'Kan ikke forbinde: ugyldige indstillinger.';
 $strConnections = 'Forbindelser';
 $strConstraintsForDumped = 'Begrænsninger for dumpede tabeller';
 $strConstraintsForTable = 'Begrænsninger for tabel';
+$strControluserFailed = 'Forbindelse for kontrolbruger som defineret i din konfiguration slog fejl.';
 $strCookiesRequired = 'Herefter skal cookies være slået til.';
-$strCopyDatabaseOK = 'Database %s er blevet kopieret til %s';
 $strCopy = 'Kopi';
+$strCopyDatabaseOK = 'Database %s er blevet kopieret til %s';
 $strCopyTable = 'Kopier tabel til (database<b>.</b>tabel):';
 $strCopyTableOK = 'Tabellen %s er nu kopieret til: %s.';
 $strCopyTableSameNames = 'Kan ikke kopiere tabellen til den samme!';
 $strCouldNotKill = 'phpMyAdmin kunne ikke dræbe tråden %s. Den er sandsynligvis allerede lukket.';
+$strCreate = 'Opret';
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE før kopiering';
 $strCreateIndex = 'Dan et indeks på&nbsp;%s&nbsp;kolonner';
 $strCreateIndexTopic = 'Lav et nyt indeks';
 $strCreateNewDatabase = 'Opret ny database';
 $strCreateNewTable = 'Opret ny tabel i database %s';
-$strCreate = 'Opret';
 $strCreatePage = 'Opret en ny side';
 $strCreatePdfFeat = 'Oprettelse af PDFer';
 $strCreateRelation = 'Opret relation';
@@ -183,18 +183,15 @@ $strCreationDates = 'Oprettet/Opdateret/Check datoer';
 $strCriteria = 'Kriterier';
 $strCroatian = 'Kroatisk';
 $strCSV = 'CSV (kommasepareret)';
-$strCSVImportOptions = 'CSV-indstillinger';
-$strCSVOptions = 'CSV-indstillinger';
 $strCyrillic = 'Kyrillisk';
-$strCzechSlovak = 'Tjekkisk-Slovakisk';
 $strCzech = 'Tjekkisk';
+$strCzechSlovak = 'Tjekkisk-Slovakisk';
 
 $strDanish = 'Dansk';
 $strDatabase = 'Database';
 $strDatabaseEmpty = 'Databasenavnet er tomt!';
 $strDatabaseExportOptions = 'Database eksportindstillinger';
 $strDatabaseHasBeenDropped = 'Database %s er slettet.';
-$strDatabaseNoTable = 'Denne database indeholder ikke nogen tabel!';
 $strDatabases = 'Databaser';
 $strDatabasesDropped = '%s databaser er blevet droppet korrekt.';
 $strDatabasesStats = 'Databasestatistik';
@@ -211,17 +208,17 @@ $strDbIsEmpty = 'Database ser ud til at være tom!';
 $strDbPrivileges = 'Database-specifikke privilegier';
 $strDBRename = 'Omdøb database til';
 $strDbSpecific = 'database-specifik';
-$strDefaultEngine = '%s er standard datalageret på denne MySQL-server.';
 $strDefault = 'Standardværdi';
+$strDefaultEngine = '%s er standard datalageret på denne MySQL-server.';
 $strDefaultValueHelp = 'For standardværdier, indtast venligst kun en enkelt værdi, uden backslash escaping eller quotes, ud fra følgende format: a';
 $strDefragment = 'Defragmentér tabel';
 $strDelayedInserts = 'Brug forsinkede indsættelser';
 $strDeleteAndFlushDescr = 'Dette er den sikreste metode, men genindlæsning af privilegierne kan tage noget tid.';
 $strDeleteAndFlush = 'Slet brugerne og genindlæs privilegier bagefter.';
-$strDeleted = 'Rækken er slettet!';
-$strDeletedRows = 'Slettede rækker:';
-$strDeleteNoUsersSelected = 'Ingen brugere valgt til sletning!';
 $strDelete = 'Slet';
+$strDeletedRows = 'Slettede rækker:';
+$strDeleted = 'Rækken er slettet!';
+$strDeleteNoUsersSelected = 'Ingen brugere valgt til sletning!';
 $strDeleteRelation = 'Slet relation';
 $strDeleting = 'Sletter %s';
 $strDelimiter = 'Adskiller';
@@ -240,7 +237,6 @@ $strDisplayOrder = 'Rækkefølge af visning:';
 $strDisplayPDF = 'Vis PDF-skematik';
 $strDoAQuery = 'Kør en forespørgsel på felter (jokertegn: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'DocSQL indstillinger';
 $strDocu = 'Dokumentation';
 $strDoYouReally = 'Er du sikker på at du vil ';
 $strDropDatabaseStrongWarning = 'Du er ved at DESTRUERE en komplet database!';
@@ -278,7 +274,6 @@ $strEscapeWildcards = 'Jokertegn _ og % skal være escaped med en \ foran for at
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estisk';
 $strExcelEdition = 'Excel-udgave';
-$strExcelOptions = 'Excel-indstillinger';
 $strExecuteBookmarked = 'Udfør forespørgsel iflg. bogmærke';
 $strExplain = 'Forklar SQL';
 $strExport = 'Eksport';
@@ -290,7 +285,7 @@ $strExtra = 'Ekstra';
 $strFailedAttempts = 'Mislykkede forsøg';
 $strField = 'Feltnavn';
 $strFieldHasBeenDropped = 'Felt %s er slettet';
-$strFieldsEmpty = ' Felttallet har ingen værdi! ';
+$strFieldInsertFromFileTempDirNotExists = 'Fejl ved flytning af den uploadede fil, se FAQ 1.11';
 $strFieldsEnclosedBy = 'Felter indrammet med';
 $strFieldsEscapedBy = 'Felter escaped med';
 $strFields = 'Felter';
@@ -303,6 +298,7 @@ $strFileNameTemplateDescriptionServer = 'servernavn';
 $strFileNameTemplateDescriptionTable = 'tabelnavn';
 $strFileNameTemplateRemember = 'husk skabelonen';
 $strFileNameTemplate = 'Skabelon for filnavn';
+$strFiles = 'Filer';
 $strFileToImport = 'Fil til import';
 $strFixed = 'ordnet';
 $strFlushPrivilegesNote = 'Bemærk: phpMyAdmin henter brugernes privilegier direkte fra MySQLs privilegietabeller. Indholdet af disse tabeller kan være forskelligt fra privilegierne serveren i øjeblikket bruger hvis der er lavet manuelle ændringer i den. Hvis dette er tilfældet, bør du %sgenindlæse privilegierne%s før du fortsætter.';
@@ -339,7 +335,7 @@ $strHasBeenCreated = 'er oprettet.';
 $strHaveToShow = 'Du skal vælge mindst en kolonne der skal vises';
 $strHebrew = 'Hebræisk';
 $strHelp = 'Hjælp';
-$strHexForBinary = 'Brug hexadecimal til binære felter';
+$strHexForBLOB = 'Brug heksadecimal for BLOB';
 $strHide         = 'Skjul';
 $strHideShowAll = 'Skjul/Vis alle';
 $strHideShowNoRelation = 'Skjul/Vis tabeller uden relation';
@@ -348,9 +344,7 @@ $strHomepageOfficial = 'Officiel phpMyAdmin hjemmeside ';
 $strHostEmpty = 'Der er intet værtsnavn!';
 $strHost = 'Vært';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 eksportindstillinger';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 eksportindstillinger';
 $strHungarian = 'Ungarsk';
 
 $strIcelandic = 'Islandsk';
@@ -360,20 +354,18 @@ $strIEUnsupported = 'Internet Explorer understøtter ikke denne funktion.';
 $strIgnoreDuplicates = 'Ignorér gentagne rækker';
 $strIgnore = 'Ignorer';
 $strIgnoreInserts = 'Brug ignorér inserts';
-$strImportExportCoords = 'Importer/Eksporter koordinater for PDF-opstilling';
 $strImportFiles = 'Importér filer';
+$strImportExportCoords = 'Importer/Eksporter koordinater for PDF-opstilling';
 $strImportFormat = 'Format på importeret fil';
 $strImport = 'Import';
 $strImportSuccessfullyFinished = 'Importen er korrekt gennemført, %d forespørgsler udført.';
 $strIndexes = 'Indeks';
+$strIndexesSeemEqual = 'Følgende indeks ser ud til at være ens og et af dem burde fjernes:';
 $strIndexHasBeenDropped = 'Indeks %s er blevet slettet';
 $strIndex = 'Indeks';
 $strIndexName = 'Indeksnavn&nbsp;:';
 $strIndexType = 'Indekstype&nbsp;:';
-$strIndexWarningMultiple = 'Mere end en %s nøgle blev skabt for kolonne `%s`';
-$strIndexWarningPrimary = 'PRIMARY og INDEX nøgler burde ikke begge være sat for kolonne `%s`';
 $strIndexWarningTable = 'Problemer med indeksene på tabel `%s`';
-$strIndexWarningUnique = 'UNIQUE og INDEX nøgler burde ikke begge være sat for kolonne `%s`';
 $strInnoDBAutoextendIncrement = 'Autoextend forøgelse';
 $strInnoDBAutoextendIncrementDesc = ' Størrelsen på den udvidelse der vil forekomme, når pladsen i en autoudvidende tabel udvides fordi den løber fuld.';
 $strInnoDBBufferPoolSize = 'Buffer pool størrelse';
@@ -422,7 +414,6 @@ $strKnownExternalBug = 'Funktionaliteten af %s er påvirket af en kendt fejl, se
 $strKorean = 'Koreansk';
 
 $strLandscape = 'Liggende';
-$strLanguageFileNotFound = 'Sprogfil \"%1$s\" ikke fundet.';
 $strLanguage = 'Sprog';
 $strLanguageUnknown = 'Ukendt sprog: %1$s.';
 $strLatchedPages = 'Eksklusivt låste (latched) sider';
@@ -433,11 +424,9 @@ $strLatexContinued = '(fortsættes)';
 $strLatexIncludeCaption = 'Inkluder tabeloverskrift';
 $strLatexLabel = 'Mærke nøgle';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX indstillinger';
 $strLatexStructure = 'Struktur for tabel __TABLE__';
 $strLatvian = 'Lettisk';
 $strLDI = 'CSV vha. LOAD DATA';
-$strLDIImportOptions = 'Indstillinger for CSV import via LOAD DATA';
 $strLDILocal = 'Brug LOCAL nøgleord';
 $strLengthSet = 'Længde/Værdi*';
 $strLimitNumRows = 'poster pr. side';
@@ -494,6 +483,7 @@ $strMyISAMSortBufferSize = 'Sorterings-bufferstørrelse';
 $strMySQLCharset = 'MySQL Tegnsæt';
 $strMysqlClientVersion = 'MySQL klientversion';
 $strMySQLConnectionCollation = 'MySQL forbindelses-sammenkøring';
+$strMysqlLibDiffersServerVersion = 'Din PHP MySQL-biblioteks version %s afviger fra din MySQL server version %s. Dette kan forårsage uforudsigelige resultater.';
 $strMySQLSaid = 'MySQL returnerede: ';
 $strMySQLShowProcess = 'Vis tråde';
 $strMySQLShowStatus = 'Vis MySQL runtime-information';
@@ -540,13 +530,12 @@ $strNumTables = 'Tabeller';
 
 $strOK = 'OK';
 $strOpenDocumentSpreadsheet = 'Open Document regneark';
-$strOpenDocumentSpreadsheetOptions = 'Open Document regnearksindstillinger';
 $strOpenDocumentText = 'Open Document tekst';
-$strOpenDocumentTextOptions = 'Open Document tekstindstillinger';
 $strOpenNewWindow = 'Åbn nyt phpMyAdmin vindue';
 $strOperations = 'Operationer';
 $strOperator = 'Operatør';
 $strOptimizeTable = 'Optimer tabel';
+$strOptions = 'Indstillinger';
 $strOr = 'Eller';
 $strOverhead = 'Overhead';
 $strOverwriteExisting = 'Overskriv eksisterende fil(er)';
@@ -564,7 +553,6 @@ $strPasswordNotSame = 'De to kodeord er ikke ens!';
 $strPdfDbSchema = 'Skematik for databasen "%s" - Side %s';
 $strPdfInvalidTblName = 'Tabellen "%s" findes ikke!';
 $strPdfNoTables = 'Ingen tabeller';
-$strPDFOptions = 'PDF-indstillinger';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Genererer en rapport indeholdende dataene fra en enkelt tabel)';
 $strPDFReportTitle = 'Rapporttitel';
@@ -655,8 +643,8 @@ $strRecords = 'Poster';
 $strReferentialIntegrity = 'Check reference-integriteten';
 $strRefresh = 'Opdatér';
 $strRelationalSchema = 'Relationel skematik';
-$strRelationDeleted = 'Relation slettet';
 $strRelationNotWorking = 'De ekstra features for at arbejde med linkede tabeller er deaktiveret. For at se hvorfor, klik %sher%s.';
+$strRelationDeleted = 'Relation slettet';
 $strRelationsForTable = 'RELATIONS FOR TABLE (Relationer for tabellen)';
 $strRelations = 'Relationer';
 $strRelationView = 'Se Relationer';
@@ -679,6 +667,8 @@ $strRevokeAndDelete = 'Tilbagekald alle aktive privilegier fra brugerne og slet
 $strRevokeMessage = 'Du har tilbagekaldt privilegierne for %s';
 $strRevoke = 'Tilbagekald';
 $strRomanian = 'Rumænsk';
+$strRoutineReturnType = 'Retur type';
+$strRoutines = 'Rutiner';
 $strRowLength = 'Rækkelængde';
 $strRowsFrom = 'rækker startende fra post #';
 $strRowSize = ' Rækkestørrelse ';
@@ -694,9 +684,9 @@ $strRunSQLQuery = 'Kør SQL-forspørgsel(er) på database %s';
 $strRunSQLQueryOnServer = 'Kør SQL-forespørgsel/forespørgsler på server %s';
 $strRussian = 'Russisk';
 
-$strSave = 'Gem';
-$strSavePosition = 'Gem position';
 $strSaveOnServer = 'Gem på serveren i mappen %s ';
+$strSavePosition = 'Gem position';
+$strSave = 'Gem';
 $strScaleFactorSmall = 'Skaleringsfaktoren er for lille til at tilpasse skematikken til en side';
 $strSearchFormTitle = 'Søg i databasen';
 $strSearchInTables = 'Indeni tabel(ler):';
@@ -730,6 +720,7 @@ $strServerTabVariables = 'Variabler';
 $strServerTrafficNotes = '<b>Servertrafik</b>: Disse tabeller viser netværkstrafik-statistikkerne for denne MySQL-server siden dens opstart.';
 $strServerVars = 'Server-variabler og indstillinger';
 $strServerVersion = 'Serverversion';
+$strSessionStartupErrorGeneral = 'Kan ikke starte session uden fejl, tjek venligst fejl i din PHP og/eller webserver log fil og konfigurer din PHP installation ordentligt.';
 $strSessionValue = 'Sessionsværdi';
 $strSetEnumVal = 'Hvis et felt er af typen "enum" eller "set", skal værdierne angives på formen: \'a\',\'b\',\'c\'...<br />Skulle du få brug for en backslash ("\") eller et enkelt anførselstegn ("\'") blandt disse værdier, så tilføj en ekstra backslash (fx \'\\\\xyz\' eller \'a\\\'b\').';
 $strShowAll = 'Vis alle';
@@ -819,7 +810,7 @@ $strShowStatusKey_readsDescr = 'Antallet af fysiske læsninger af en nøgleblok
 $strShowStatusKey_write_requestsDescr = 'Antallet af anmodninger om at skrive en nøgleblok til mellemlageret.';
 $strShowStatusKey_writesDescr = 'Antallet af fysiske skrivninger af en nøgleblok til disk.';
 $strShowStatusLast_query_costDescr = 'Totale omkostninger for den seneste kompilerede forespørgsel som beregnet af forespørgsels-optimeringsrutinen. Brugbart til at sammenligne omkostninger på forskellige forespørgselsplaner for den samme forespørgsel. En standardværdi på 0 betyder at der ikke er kompileret nogen forespørgsler endnu.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'Antallet af rækker der venter på at blive skrevet i INSERT DELAY køer.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'Antallet af rækker der venter på at blive skrevet i INSERT DELAYED køer.';
 $strShowStatusOpened_tablesDescr = 'Antallet af tabeller der er blevet åbnet. Hvis åbnede tabeller er stor, er dit tabelmellemlager sandsynligvis for lille.';
 $strShowStatusOpen_filesDescr = 'Antallet af filer der er åbne.';
 $strShowStatusOpen_streamsDescr = 'Antallet af streams der er åbne (bruges hovedsageligt til logning).';
@@ -874,8 +865,6 @@ $strSpanish = 'Spansk';
 $strSplitWordsWithSpace = 'Ord adskilles af mellemrums-karakter (" ").';
 $strSQLCompatibility = 'SQL-kompatibilitetsmodus';
 $strSQLExportType = 'Eksporttype';
-$strSQLImportOptions = 'SQL-indstillinger';
-$strSQLOptions = 'SQL-indstillinger';
 $strSQLParserBugMessage = 'Det er muligt at du har fundet en fejl i SQL-parseren. Undersøg venligst din forespørgsel nøje, og check at anførselstegn er rigtige og ikke giver konflikter. Andre fejlårsager kan være at du uploader en fil med binær udenfor et lukket tekstområde. Du kan også prøve din forespørgsel i MySQL kommandolinje-interfacet. MySQL-serverens fejlmelding der følger herunder, hvis der er nogen, kan også hjælpe dig med at finde problemet. Hvis du stadig har probemer eller hvis parseren fejler hvor kommandolinjeinterfacet lykkes, reducer din SQL-forespørgselsinput til den ene forespørgsel der forårsager problemet, og indsend en fejlrapport med datablokken i KLIP-sektionen herunder:';
 $strSQLParserUserError = 'Der ser ud til at være en fejl i din SQL-forespørgsel. MySQL-serverens fejlmelding der følger herunder, hvis der er nogen, kan også hjælpe dig med at finde problemet.';
 $strSQLQuery = 'SQL-forespørgsel';
@@ -897,7 +886,6 @@ $strStrucCSV = 'CSV-data';
 $strStrucData = 'Struktur og data';
 $strStrucExcelCSV = 'CSV til MS Excel-data';
 $strStrucNativeExcel = 'Fødte MS Excel-data';
-$strStrucNativeExcelOptions = 'Fødte Excel eksportindstillinger';
 $strStrucOnly = 'Kun strukturen';
 $strStructPropose = 'Foreslå tabelstruktur';
 $strStructureForView = 'Struktur for visning';
@@ -915,7 +903,7 @@ $strTableEmpty = 'Intet tabelnavn!';
 $strTableHasBeenDropped = 'Tabel %s er slettet';
 $strTableHasBeenEmptied = 'Tabel %s er tømt';
 $strTableHasBeenFlushed = 'Tabel %s er blevet flushet';
-$strTableIsEmpty = 'Tabel ser ud til at være tom!';
+$strTableIsEmpty = 'Tabel ser ud til at være tom';
 $strTableMaintenance = 'Tabelvedligeholdelse';
 $strTableName = 'Tabelnavn';
 $strTableOfContents = 'Indholdsfortegnelse';
@@ -979,6 +967,13 @@ $strUpdateProfileMessage = 'Profilen er blevet opdateret.';
 $strUpdateQuery = 'Opdater forespørgsel';
 $strUpdComTab = 'Se venligst Dokumentationen for oplysninger om hvordan du opdaterer din Column_comments (kolonne-kommentarer) tabel';
 $strUpgrade = 'Du burde opdatere til %s %s eller senere.';
+$strUploadErrorCantWrite = 'Kunne ikke skrive fil til disk.';
+$strUploadErrorExtension = 'Filupload stoppet af udvidelse.';
+$strUploadErrorFormSize = 'Den uploadede fil overstiger MAX_FILE_SIZE direktivet som angivet i HTML-formularen.';
+$strUploadErrorIniSize = 'Den uploadede fil overstiger upload_max_filesize direktivet i php.ini.';
+$strUploadErrorNoTempDir = 'Mangler en midlertidig mappe.';
+$strUploadErrorPartial = 'Den uploadede fil blev kun delvist uploaded.';
+$strUploadErrorUnknown = 'Ukendt fejl i filupload.';
 $strUploadLimit = 'Du har sandsynligvis forsøgt at uploade en for stor fil. Se venligst %sdokumentationen%s for måder hvorpå du kan arbejde dig uden om denne begrænsning.';
 $strUploadsNotAllowed = 'Fil-uploads er ikke tilladte på denne server.';
 $strUsage = 'Benyttelse';
@@ -1008,6 +1003,7 @@ $strViewDumpDB = 'Vis dump (skema) af database';
 $strViewDump = 'Vis dump (skema) over tabel';
 $strViewHasBeenDropped = 'Visning %s er blevet droppet';
 $strViewMaxExactCount = 'Denne visning har mere end %d rækker. Se venligst %sdokumentationen%s.';
+$strViewName = 'VIEW navn';
 $strView = 'Visning';
 
 $strWebServerUploadDirectoryError = 'Mappen du har sat til upload-arbejde kan ikke findes';
@@ -1020,7 +1016,6 @@ $strWithChecked = 'Med det markerede:';
 $strWriteRequests = 'Write-anmodninger';
 $strWrongUser = 'Forkert brugernavn/kodeord. Adgang nægtet.';
 
-$strXMLOptions = 'XML-indstillinger';
 $strXML = 'XML';
 
 $strYes = 'Ja';
@@ -1028,4 +1023,8 @@ $strYes = 'Ja';
 $strZeroRemovesTheLimit = 'Bemærk: Indstilling af disse værdier til 0 (nul) fjerner begrænsningen.';
 $strZip = '"zippet"';
 
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
