@@ -1,11 +1,11 @@
 <?php
-/* $Id: dutch-iso-8859-1.inc.php,v 2.147 2006/08/09 12:55:36 lem9 Exp $ */
+/* $Id: dutch-iso-8859-15.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /*
  * Updated by "CaliMonk" <calimonk at gmx.net> on 2005/01/04.
  */
 
-$charset = 'iso-8859-1';
+$charset = 'iso-8859-15';
 $text_dir = 'ltr';
 $number_thousands_separator = '.';
 $number_decimal_separator = ',';
@@ -20,7 +20,6 @@ $datefmt = '%d %B %Y om %H:%M';
 $timespanfmt = '%s dagen, %s uren, %s minuten en %s seconden';
 
 $strAbortedClients = 'Afgehaakte';
-$strAbsolutePathToDocSqlDir = 'Geef een absoluut pad op de webserver aan naar de docSQL directory';
 $strAccessDeniedExplanation = 'phpMyAdmin probeerde met de MySQL server te verbinden maar de server weigerde de verbinding. Controleer de host, de gebruikersnaam en het wachtwoord in config.inc.php en zorg er voor dat deze overeenkomen met de informatie die u van de Beheerder van de MySQL server kreeg.';
 $strAccessDenied = 'Toegang geweigerd ';
 $strAction = 'Actie';
@@ -28,8 +27,6 @@ $strAddAutoIncrement = 'Voeg AUTO_INCREMENT waarde toe';
 $strAddConstraints = 'Voeg beperkingen toe';
 $strAddDeleteColumn = 'Toevoegen/Verwijderen Veld Kolommen';
 $strAddDeleteRow = 'Toevoegen/Verwijderen Criteria Rij';
-$strAddedColumnComment = 'Voeg commentaar toe aan de kolom';
-$strAddedColumnRelation = 'Voeg een relatie toe aan de kolom';
 $strAddFields = 'Voeg %s veld(en) toe';
 $strAddHeaderComment = 'Voeg een commentaar toe in de header (\\n om regels af te breken';
 $strAddIntoComments = 'Voeg toe in commentaar';
@@ -64,7 +61,6 @@ $strAscending = 'Oplopend';
 $strAtBeginningOfTable = 'Aan het begin van de tabel';
 $strAtEndOfTable = 'Aan het eind van de tabel';
 $strAttr = 'Attributen';
-$strAutodetect = 'Auto detectie';
 $strAutomaticLayout = 'Automatische lay-out';
 
 $strBack = 'Terug';
@@ -94,7 +90,7 @@ $strBzip = '"ge-bzipt"';
 
 $strCalendar = 'Kalender';
 $strCannotLogin = 'Kan niet inloggen op de MySQL server';
-$strCantLoad = 'Kan de %s extentie niet laden,<br />Controleer de PHP Configuratie';
+$strCantLoad = 'Kan de [a@http://php.net/%1$s@Documentation][em]%1$s[/em][/a]-extensie niet laden. Controleer de PHP configuratie.';
 $strCantLoadRecodeIconv = 'Kan iconv of recode extensies niet laden die nodig zijn voor de Karakterset conversie, configureer php om deze extensies toe te laten of schakel Karakterset conversie uit in phpMyAdmin';
 $strCantRenameIdxToPrimary = 'Kan index niet naar PRIMARY hernoemen';
 $strCantUseRecodeIconv = 'Kan iconv, libiconv en recode_string functies niet gebruiken zolang de extensies geladen moeten worden. Controleer de php configuratie.';
@@ -153,7 +149,6 @@ $strCreatePdfFeat = 'Aanmaken van PDF bestanden';
 $strCreationDates = 'Creatie/Update/Controleer datum';
 $strCriteria = 'Criteria';
 $strCroatian = 'Kroatisch';
-$strCSVOptions = 'CSV opties';
 $strCyrillic = 'Cyrillisch';
 $strCzechSlovak = 'Tsjechische-Slowaak';
 $strCzech = 'Tsjechisch';
@@ -163,7 +158,6 @@ $strDatabase = 'Database';
 $strDatabaseEmpty = 'De database naam is leeg!';
 $strDatabaseExportOptions = 'Database export opties';
 $strDatabaseHasBeenDropped = 'Database %s is vervallen.';
-$strDatabaseNoTable = 'Deze database bevat geen tabel!';
 $strDatabases = 'databases';
 $strDatabasesDropped = '%s databases zijn succesvol verwijderd.';
 $strDatabasesStats = 'Database statistieken';
@@ -175,15 +169,6 @@ $strDataDict = 'Data Woordenboek';
 $strDataOnly = 'Alleen data';
 $strDBComment = 'Database commentaar: ';
 $strDBCopy = 'Kopieer database naar';
-$strDBGContext = 'Context';
-$strDBGContextID = 'Context ID';
-$strDBGHits = 'Hits';
-$strDBGLine = 'Regel';
-$strDBGMaxTimeMs = 'Max tijd, ms';
-$strDBGMinTimeMs = 'Min tijd, ms';
-$strDBGModule = 'Module';
-$strDBGTimePerHitMs = 'Tijd/Hit, ms';
-$strDBGTotalTimeMs = 'Totaal tijd, ms';
 $strDbPrivileges = 'Database-specifieke privileges';
 $strDBRename = 'Hernoem database naar';
 $strDbSpecific = 'database-specifiek';
@@ -234,7 +219,6 @@ $strError = 'Fout';
 $strEscapeWildcards = 'Wildcards _ en % moeten worden ge-escaped met een \ om ze letterlijk te gebruiken';
 $strEstonian = 'Estlands';
 $strExcelEdition = 'Excel editie';
-$strExcelOptions = 'Excel opties';
 $strExecuteBookmarked = 'Voor de gebookmarkte query uit';
 $strExplain = 'Verklaar SQL';
 $strExport = 'Exporteer';
@@ -243,7 +227,6 @@ $strExtra = 'Extra';
 
 $strFailedAttempts = 'Mislukte pogingen';
 $strFieldHasBeenDropped = 'Veld %s is vervallen';
-$strFieldsEmpty = ' Het velden aantal is leeg! ';
 $strFieldsEnclosedBy = 'Velden ingesloten door';
 $strFieldsEscapedBy = 'Velden ontsnapt door';
 $strFieldsTerminatedBy = 'Velden beindigd door';
@@ -278,7 +261,6 @@ $strHasBeenAltered = 'is veranderd.';
 $strHasBeenCreated = 'is aangemaakt.';
 $strHaveToShow = 'Er moet ten minste 1 weer te geven kolom worden gekozen';
 $strHebrew = 'Hebreeuws';
-$strHexForBinary = 'Gebruik hexadecimale voor binaire velden';
 $strHome = 'Home';
 $strHomepageOfficial = 'Officile phpMyAdmin Website';
 $strHostEmpty = 'De host naam is leeg!';
@@ -290,18 +272,13 @@ $strId = 'ID';
 $strIdxFulltext = 'Volledige tekst';
 $strIgnoreInserts = 'Gebruik ignore inserts';
 $strIgnore = 'Negeer';
-$strIgnoringFile = 'Negeer bestand %s';
-$strImportDocSQL = 'Importeer docSQL Bestanden';
 $strImportFiles = 'Importeren bestanden';
 $strIndexes = 'Indexen';
 $strIndexHasBeenDropped = 'Index %s is vervallen';
 $strIndex = 'Index';
 $strIndexName = 'Index naam&nbsp;:';
 $strIndexType = 'Index type&nbsp;:';
-$strIndexWarningMultiple = 'Meer dan 1 %s sleutel was gecreerd voor de kolom `%s`';
-$strIndexWarningPrimary = 'PRIMARY en INDEX sleutels behoren niet beide ingesteld te zijn voor de kolom `%s`';
 $strIndexWarningTable = 'Problemen met de index(en) van de tabel `%s`';
-$strIndexWarningUnique = 'UNIQUE en INDEX sleutels behoren niet beide ingesteld te zijn voor de kolom `%s`';
 $strInnodbStat = 'InnoDB Status';
 $strInsecureMySQL = 'Uw configuratie bestand bevat instellingen (root zonder wachtwoord) die betrekking hebben tot de standaard MySQL account. Uw MySQL server draait met deze standaard waardes, en is open voor ongewilde toegang, het wordt dus aangeraden dit op te lossen.';
 $strInsertAsNewRow = 'Voeg toe als nieuwe rij';
@@ -330,7 +307,6 @@ $strLatexContinued = '(vervolgd)';
 $strLatexIncludeCaption = 'Voeg tabel titel toe';
 $strLatexLabel = 'Label sleutel';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX opties';
 $strLatexStructure = 'Structuur van de tabel __TABLE__';
 $strLatvian = 'Lets';
 $strLengthSet = 'Lengte/Waardes*';
@@ -346,7 +322,7 @@ $strLogin = 'Inloggen';
 $strLogout = 'Uitloggen';
 $strLogPassword = 'Wachtwoord:';
 $strLogServer = 'Server';
-$strLogUsername = 'Gebruikers naam:';
+$strLogUsername = 'Gebruikersnaam:';
 
 $strMaximumSize = 'Maximale grootte: %s%s';
 $strMbExtensionMissing = 'De mbstring PHP extensie werd niet gevonden en u lijkt een multibyte charset te gebruiken. Zonder de mbstring extensie kan phpMyAdmin strings niet correct splitsen wat tot onverwachte resultaten kan leiden.';
@@ -358,7 +334,7 @@ $strMIME_MIMEtype = 'MIME-type';
 $strMIME_nodescription = 'Geen beschrijving beschikbaar voor deze transformatie.<br />Raadpleeg de maker over wat %s doet.';
 $strMIME_transformation = 'Browser transformaties';
 $strMIME_transformation_note = 'Voor een lijst met beschikbare transformatie opties en MIME-type transformaties, klik op %sTransformatie opties%s';
-$strMIME_transformation_options_note = 'Voeg de waardes voor transformatie optie in het volgende formaat in: \'a\',\'b\',\'c\'...<br />Wanneer u een backslash ("\") of een enkele quote ("\'") moet invoegen in deze waardes, backslashes het dan (bijvoorbeeld \'\\\\xyz\' of \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Voeg de waardes voor transformatie optie in het volgende formaat in: \'a\', 100, b,\'c\'...<br />Wanneer u een backslash ("\") of een enkele quote ("\'") moet invoegen in deze waardes, backslashes het dan (bijvoorbeeld \'\\\\xyz\' of \'a\\\'b\').';
 $strMIME_transformation_options = 'Transformatie opties';
 $strMIMETypesForTable = 'MIME TYPES VOOR TABEL';
 $strMIME_without = 'MIME-types die in italic staan (Schuin) hebben geen aparte transformatie functies';
@@ -590,7 +566,6 @@ $strSpaceUsage = 'Ruimte gebruik';
 $strSpanish = 'Spaans';
 $strSplitWordsWithSpace = 'Woorden worden gesplit door een spatie karakter (" ").';
 $strSQLExportType = 'Export type';
-$strSQLOptions = 'SQL opties';
 $strSQLParserBugMessage = 'Er is een kans dat u een fout heeft aangetroffen in de SQL parser. Let er goed op, dat de query op de correcte plaatsen quotes heeft. Een ander mogelijkheid voor deze foutmelding kan zijn dat u het ge-quote text gedeelte in binairy mode heeft. U kunt ook uw query proberen in de command line van MySQL. De MySQL server foutmelding hieronder, mocht die aanwezig zijn, kan ook helpen met het opsporen van fouten. Blijft u problemen houden of als de parser fouten geeft terwijl het goed gaat in de command line van MySQL, probeer dan de SQL query in te korten en een bug report met het stukje data te sturen van het CUT gedeelte hieronder:';
 $strSQLParserUserError = 'Er schijnt een fout te zijn in uw SQL query. Mocht de MySQL server een error hebben terug gegeven, probeer dan of uw hiermee uw fout kunt oplossen.';
 $strSQLQuery = 'SQL-query';
@@ -635,7 +610,6 @@ $strTextAreaLength = ' Vanwege z\'n lengte,<br /> is dit veld misschien niet te
 $strThai = 'Thais';
 $strTheme = 'Thema / Stijl';
 $strThisHost = 'Deze Host';
-$strThisNotDirectory = 'Dit was geen directory';
 $strThreadSuccessfullyKilled = 'Thread %s is met succes afgesloten.';
 $strTime = 'Tijd';
 $strToggleScratchboard = 'toggle scratchboard';
@@ -648,7 +622,6 @@ $strTransformation_application_octetstream__download = 'Toon een link om de bina
 $strTransformation_image_jpeg__inline = 'Toont een klik bare thumbnail; opties: width,height in pixels (houdt de originele ratio)';
 $strTransformation_image_jpeg__link = 'Toont een link naar deze image (directe blob download, i.e.).';
 $strTransformation_image_png__inline = 'Zie image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Neemt een TIME, TIMESTAMP of DATETIME veld en vormt het naar uw lokale datum formaat. Eerst optie is de offset (in uren) welke zal worden toegevoegd aan de timestamp (Default: 0). De tweede opties is een ander datum formaat volgens de parameters beschikbaar volgens PHPs strftime().';
 $strTransformation_text_plain__external = 'ALLEEN LINUX: Lanceert een externe applicatie en voed het de veld data via standaard input. Geeft standaard output van de applicatie terug. Default is Netjes, om nette HTML code te tonen. Om beveiligings redenen zult u handmatig het bestand libraries/transformations/text_plain__external.inc.php moeten aanpassen en de tools die u mag draaien invoegen. De eerste opties is het nummer van het programma wat u wilt gebruiken, de tweede optie zijn de parameters voor dit programma. Het derde parameter, wanneer ingesteld op 1, zal de output omzetten door middel van htmlspecialchars() (Standaard is 1). Een vierde parameter, wanneer ingesteld als 1 zal NOWRAP aan de content cell toevoegen, zodat de gehele output getoond zal worden zonder te herstructureren (Standaard 1)';
 $strTransformation_text_plain__formatted = 'Preserveert het originele formaat van het veld. Er wordt geen Escaping toegepast.';
 $strTransformation_text_plain__imagelink = 'Toont een plaatje en een link, het veld bevat de bestandsnaam; De eerste optie is een prefix als "http://domein.com/", de tweede optie is de breedte in pixels, de derde is de hoogte.';
@@ -700,8 +673,6 @@ $strWestEuropean = 'West Europees';
 $strWildcard = 'joker teken';
 $strWindowNotFound = 'Het doel browser scherm kon niet worden bijgewerkt. Misschien heeft u het scherm gesloten of uw browser blokkeert bijwerkingen van uw browser beveiliging';
 $strWithChecked = 'Met geselecteerd:';
-$strWritingCommentNotPossible = 'Het toevoegen van commentaar is niet mogelijk';
-$strWritingRelationNotPossible = 'Toevoegen van een relatie is niet mogelijk';
 $strWrongUser = 'Verkeerde gebruikersnaam/wachtwoord. Toegang geweigerd.';
 
 $strXML = 'XML';
@@ -734,7 +705,6 @@ $strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"'
 $strCopy = 'Copy';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 
 $strDataPages = 'Pages containing data';  //to translate
 $strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
@@ -762,9 +732,7 @@ $strGeneratePassword = 'Generate Password';  //to translate
 
 $strHandler = 'Handler';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
@@ -795,11 +763,9 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
 
@@ -827,7 +793,6 @@ $strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
 
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
@@ -923,7 +888,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -962,7 +927,6 @@ $strSkipQueries = 'Number of records(queries) to skip from start';  //to transla
 $strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 $strSorting = 'Sorting';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
@@ -997,16 +961,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1019,4 +979,73 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
