@@ -1,5 +1,5 @@
 <?php
-/* $Id: english-iso-8859-15.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: english-iso-8859-15.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 $charset = 'iso-8859-15';
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
@@ -24,7 +24,7 @@ $timespanfmt = '%s days, %s hours, %s minutes and %s seconds';
 $strAbortedClients = 'Aborted';
 $strAccessDenied = 'Access denied';
 $strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';
-$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in config.inc.php and make sure that they correspond to the information given by the administrator of the MySQL server.';
+$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in your configuration and make sure that they correspond to the information given by the administrator of the MySQL server.';
 $strAction = 'Action';
 $strAddAutoIncrement = 'Add AUTO_INCREMENT value';
 $strAddClause = 'Add %s';
@@ -68,7 +68,6 @@ $strAscending = 'Ascending';
 $strAtBeginningOfTable = 'At Beginning of Table';
 $strAtEndOfTable = 'At End of Table';
 $strAttr = 'Attributes';
-$strAutodetect = 'Autodetect';
 $strAutomaticLayout = 'Automatic layout';
 
 $strBack = 'Back';
@@ -157,6 +156,7 @@ $strConnectionError = 'Cannot connect: invalid settings.';
 $strConnections = 'Connections';
 $strConstraintsForDumped = 'Constraints for dumped tables';
 $strConstraintsForTable = 'Constraints for table';
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';
 $strCookiesRequired = 'Cookies must be enabled past this point.';
 $strCopy = 'Copy';
 $strCopyDatabaseOK = 'Database %s has been copied to %s';
@@ -182,8 +182,6 @@ $strCreationDates = 'Creation/Update/Check dates';
 $strCriteria = 'Criteria';
 $strCroatian = 'Croatian';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'CSV options';
-$strCSVOptions = 'CSV options';
 $strCyrillic = 'Cyrillic';
 $strCzech = 'Czech';
 $strCzechSlovak = 'Czech-Slovak';
@@ -193,7 +191,6 @@ $strDatabase = 'Database';
 $strDatabaseEmpty = 'The database name is empty!';
 $strDatabaseExportOptions = 'Database export options';
 $strDatabaseHasBeenDropped = 'Database %s has been dropped.';
-$strDatabaseNoTable = 'This database contains no table!';
 $strDatabases = 'Databases';
 $strDatabasesDropped = '%s databases have been dropped successfully.';
 $strDatabasesStats = 'Databases statistics';
@@ -239,7 +236,6 @@ $strDisplayOrder = 'Display order:';
 $strDisplayPDF = 'Display PDF schema';
 $strDoAQuery = 'Do a "query by example" (wildcard: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'DocSQL options';
 $strDocu = 'Documentation';
 $strDoYouReally = 'Do you really want to ';
 $strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';
@@ -276,8 +272,8 @@ $strErrorSaveTable = 'Error saving coordinates for Designer.';
 $strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estonian';
+$strEvent = 'Event';
 $strExcelEdition = 'Excel edition';
-$strExcelOptions = 'Excel options';
 $strExecuteBookmarked = 'Execute bookmarked query';
 $strExplain = 'Explain SQL';
 $strExport = 'Export';
@@ -289,7 +285,7 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Failed attempts';
 $strField = 'Field';
 $strFieldHasBeenDropped = 'Field %s has been dropped';
-$strFieldsEmpty = ' The field count is empty! ';
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';
 $strFieldsEnclosedBy = 'Fields enclosed by';
 $strFieldsEscapedBy = 'Fields escaped by';
 $strFields = 'Fields';
@@ -302,6 +298,7 @@ $strFileNameTemplateDescriptionTable = 'table name';
 $strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';
 $strFileNameTemplate = 'File name template';
 $strFileNameTemplateRemember = 'remember template';
+$strFiles = 'Files';
 $strFileToImport = 'File to import';
 $strFixed = 'fixed';
 $strFlushPrivilegesNote = 'Note: phpMyAdmin gets the users\' privileges directly from MySQL\'s privilege tables. The content of these tables may differ from the privileges the server uses, if they have been changed manually. In this case, you should %sreload the privileges%s before you continue.';
@@ -338,7 +335,7 @@ $strHasBeenCreated = 'has been created.';
 $strHaveToShow = 'You have to choose at least one column to display';
 $strHebrew = 'Hebrew';
 $strHelp = 'Help';
-$strHexForBinary = 'Use hexadecimal for binary fields';
+$strHexForBLOB = 'Use hexadecimal for BLOB';
 $strHide         = 'Hide';
 $strHideShowAll = 'Hide/Show all';
 $strHideShowNoRelation = 'Hide/Show Tables with no relation';
@@ -347,9 +344,7 @@ $strHomepageOfficial = 'Official phpMyAdmin Homepage';
 $strHostEmpty = 'The host name is empty!';
 $strHost = 'Host';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';
 $strHungarian = 'Hungarian';
 
 $strIcelandic = 'Icelandic';
@@ -365,14 +360,12 @@ $strImportFormat = 'Format of imported file';
 $strImport = 'Import';
 $strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';
 $strIndexes = 'Indexes';
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';
 $strIndexHasBeenDropped = 'Index %s has been dropped';
 $strIndex = 'Index';
 $strIndexName = 'Index name:';
 $strIndexType = 'Index type:';
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';
 $strIndexWarningTable = 'Problems with indexes of table `%s`';
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';
 $strInnoDBAutoextendIncrement = 'Autoextend increment';
 $strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';
 $strInnoDBBufferPoolSize = 'Buffer pool size';
@@ -421,7 +414,6 @@ $strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s'
 $strKorean = 'Korean';
 
 $strLandscape = 'Landscape';
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';
 $strLanguage = 'Language';
 $strLanguageUnknown = 'Unknown language: %1$s.';
 $strLatchedPages = 'Latched pages';
@@ -432,11 +424,9 @@ $strLatexContinued = '(continued)';
 $strLatexIncludeCaption = 'Include table caption';
 $strLatexLabel = 'Label key';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX options';
 $strLatexStructure = 'Structure of table __TABLE__';
 $strLatvian = 'Latvian';
 $strLDI = 'CSV using LOAD DATA';
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';
 $strLDILocal = 'Use LOCAL keyword';
 $strLengthSet = 'Length/Values';
 $strLimitNumRows = 'Number of rows per page';
@@ -493,6 +483,7 @@ $strMyISAMSortBufferSize = 'Sort buffer size';
 $strMySQLCharset = 'MySQL charset';
 $strMysqlClientVersion = 'MySQL client version';
 $strMySQLConnectionCollation = 'MySQL connection collation';
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';
 $strMySQLSaid = 'MySQL said: ';
 $strMySQLShowProcess = 'Show processes';
 $strMySQLShowStatus = 'Show MySQL runtime information';
@@ -539,13 +530,12 @@ $strNumTables = 'Tables';
 
 $strOK = 'OK';
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';
 $strOpenDocumentText = 'Open Document Text';
-$strOpenDocumentTextOptions = 'Open Document Text options';
 $strOpenNewWindow = 'Open new phpMyAdmin window';
 $strOperations = 'Operations';
 $strOperator = 'Operator';
 $strOptimizeTable = 'Optimize table';
+$strOptions = 'Options';
 $strOr = 'Or';
 $strOverhead = 'Overhead';
 $strOverwriteExisting = 'Overwrite existing file(s)';
@@ -563,7 +553,6 @@ $strPassword = 'Password';
 $strPdfDbSchema = 'Schema of the the "%s" database - Page %s';
 $strPdfInvalidTblName = 'The "%s" table doesn\'t exist!';
 $strPdfNoTables = 'No tables';
-$strPDFOptions = 'PDF options';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';
 $strPDFReportTitle = 'Report title';
@@ -631,6 +620,7 @@ $strPrivilegesReloaded = 'The privileges were reloaded successfully.';
 $strProcedures = 'Procedures';
 $strProcesses = 'Processes';
 $strProcesslist = 'Process list';
+$strProfiling = 'Profiling';
 $strProtocolVersion = 'Protocol version';
 $strPutColNames = 'Put fields names in the first row';
 
@@ -672,12 +662,15 @@ $strReplaceTable = 'Replace table data with file';
 $strReplication = 'Replication';
 $strReset = 'Reset';
 $strResourceLimits = 'Resource limits';
+$strRestartInsertion = 'Restart insertion with %s rows';
 $strReType = 'Re-type';
 $strRevokeAndDeleteDescr = 'The users will still have the USAGE privilege until the privileges are reloaded.';
 $strRevokeAndDelete = 'Revoke all active privileges from the users and delete them afterwards.';
 $strRevokeMessage = 'You have revoked the privileges for %s';
 $strRevoke = 'Revoke';
 $strRomanian = 'Romanian';
+$strRoutineReturnType = 'Return type';
+$strRoutines = 'Routines';
 $strRowLength = 'Row length';
 $strRowsFrom = 'row(s) starting from record #';
 $strRowSize = ' Row size ';
@@ -729,6 +722,7 @@ $strServerTabVariables = 'Variables';
 $strServerTrafficNotes = '<b>Server traffic</b>: These tables show the network traffic statistics of this MySQL server since its startup.';
 $strServerVars = 'Server variables and settings';
 $strServerVersion = 'Server version';
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';
 $strSessionValue = 'Session value';
 $strSetEnumVal = 'If field type is "enum" or "set", please enter the values using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, precede it with a backslash (for example \'\\\\xyz\' or \'a\\\'b\').';
 $strShowAll = 'Show all';
@@ -818,7 +812,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';
@@ -873,8 +867,6 @@ $strSpanish = 'Spanish';
 $strSplitWordsWithSpace = 'Words are separated by a space character (" ").';
 $strSQLCompatibility = 'SQL compatibility mode';
 $strSQLExportType = 'Export type';
-$strSQLImportOptions = 'SQL options';
-$strSQLOptions = 'SQL options';
 $strSQLParserBugMessage = 'There is a chance that you may have found a bug in the SQL parser. Please examine your query closely, and check that the quotes are correct and not mis-matched. Other possible failure causes may be that you are uploading a file with binary outside of a quoted text area. You can also try your query on the MySQL command line interface. The MySQL server error output below, if there is any, may also help you in diagnosing the problem. If you still have problems or if the parser fails where the command line interface succeeds, please reduce your SQL query input to the single query that causes problems, and submit a bug report with the data chunk in the CUT section below:';
 $strSQLParserUserError = 'There seems to be an error in your SQL query. The MySQL server error output below, if there is any, may also help you in diagnosing the problem';
 $strSQLQuery = 'SQL query';
@@ -896,7 +888,6 @@ $strStrucCSV = 'CSV';
 $strStrucData = 'Structure and data';
 $strStrucExcelCSV = 'CSV for MS Excel';
 $strStrucNativeExcel = 'Native MS Excel format';
-$strStrucNativeExcelOptions = 'Native Excel export options';
 $strStrucOnly = 'Structure only';
 $strStructPropose = 'Propose table structure';
 $strStructureForView = 'Structure for view';
@@ -962,6 +953,7 @@ $strTransformation_text_plain__imagelink = 'Displays an image and a link; the fi
 $strTransformation_text_plain__link = 'Displays a link; the field contains the filename. The first option is a URL prefix like "http://www.example.com/". The second option is a title for the link.';
 $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';
 $strTransformation_text_plain__substr = 'Displays a part of a string. The first option is the number of characters to skip from the beginning of the string (Default 0). The second option is the number of characters to return (Default: until end of string). The third option is the string to append and/or prepend when truncation occurs (Default: "...").';
+$strTriggers = 'Triggers';
 $strTruncateQueries = 'Truncate Shown Queries';
 $strTurkish = 'Turkish';
 $strType = 'Type';
@@ -978,6 +970,13 @@ $strUpdateProfileMessage = 'The profile has been updated.';
 $strUpdateQuery = 'Update Query';
 $strUpdComTab = 'Please see the documentation on how to update your column_comments table';
 $strUpgrade = 'You should upgrade to %s %s or later.';
+$strUploadErrorCantWrite = 'Failed to write file to disk.';
+$strUploadErrorExtension = 'File upload stopped by extension.';
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';
+$strUploadErrorUnknown = 'Unknown error in file upload.';
 $strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';
 $strUsage = 'Usage';
@@ -1007,6 +1006,7 @@ $strViewDumpDB = 'View dump (schema) of database';
 $strViewDump = 'View dump (schema) of table';
 $strViewHasBeenDropped = 'View %s has been dropped';
 $strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';
+$strViewName = 'VIEW name';
 $strView = 'View';
 
 $strWebServerUploadDirectoryError = 'The directory you set for upload work cannot be reached';
@@ -1019,7 +1019,6 @@ $strWithChecked = 'With selected:';
 $strWriteRequests = 'Write requests';
 $strWrongUser = 'Wrong username/password. Access denied.';
 
-$strXMLOptions = 'XML options';
 $strXML = 'XML';
 
 $strYes = 'Yes';
