@@ -1,5 +1,5 @@
 <?php
-/* $Id: german-iso-8859-1.inc.php 10253 2007-04-06 20:04:46Z lem9 $ */
+/* $Id: german-iso-8859-1.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /**
  * For suggestions concerning this file please contact
@@ -71,7 +71,6 @@ $strAscending = 'aufsteigend';
 $strAtBeginningOfTable = 'An den Anfang der Tabelle';
 $strAtEndOfTable = 'An das Ende der Tabelle';
 $strAttr = 'Attribute';
-$strAutodetect = 'Autom. Erkennung';
 $strAutomaticLayout = 'Automatische Anordnung';
 
 $strBack = 'Zurck';
@@ -182,8 +181,6 @@ $strCreationDates = 'Erzeugungs- / Aktualisierungs- / berprfungszeiten';
 $strCriteria = 'Kriterium';
 $strCroatian = 'Kroatisch';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'CSV-Optionen';
-$strCSVOptions = 'CSV-Optionen';
 $strCyrillic = 'Kyrillisch';
 $strCzechSlovak = 'Tschechoslowakisch';
 $strCzech = 'Tschechisch';
@@ -193,7 +190,6 @@ $strDatabase = 'Datenbank';
 $strDatabaseEmpty = 'Der Datenbankname ist leer!';
 $strDatabaseExportOptions = 'Export-Optionen der Datenbank';
 $strDatabaseHasBeenDropped = 'Datenbank %s wurde gelscht.';
-$strDatabaseNoTable = 'Diese Datenbank enthlt keine Tabelle!';
 $strDatabases = 'Datenbanken';
 $strDatabasesDropped = 'Es wurden %s Datenbanken gelscht.';
 $strDatabasesStatsDisable = 'Datenbankstatistiken deaktivieren';
@@ -267,7 +263,6 @@ $strEscapeWildcards = 'Platzhalter _ und % sollten mit einem \ escaped werden, u
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estnisch';
 $strExcelEdition = 'Excel-Ausgabe';
-$strExcelOptions = 'Excel-Optionen';
 $strExecuteBookmarked = 'Gespeicherte SQL-Anfrage ausfhren';
 $strExplain = 'SQL erklren';
 $strExport = 'Exportieren';
@@ -278,7 +273,6 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Fehlgeschlagen';
 $strField = 'Feld';
 $strFieldHasBeenDropped = 'Spalte %s wurde entfernt.';
-$strFieldsEmpty = ' Sie mssen angeben wie viele Felder die Tabelle haben soll! ';
 $strFieldsEnclosedBy = 'Felder eingeschlossen von';
 $strFieldsEscapedBy = 'Felder escaped von';
 $strFields = 'Felder';
@@ -325,15 +319,12 @@ $strHasBeenAltered = 'wurde gendert.';
 $strHasBeenCreated = 'wurde erzeugt.';
 $strHaveToShow = 'Bitte whlen Sie mindestens eine anzuzeigende Spalte';
 $strHebrew = 'Hebrisch';
-$strHexForBinary = 'Hexadezimalschreibweise fr Binrfelder verwenden';
 $strHome = 'Home';
 $strHomepageOfficial = ' Offizielle phpMyAdmin-Homepage ';
 $strHostEmpty = 'Es wurde kein Host angegeben!';
 $strHost = 'Host';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Exportoptionen fr Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Exportoptionen fr Microsoft Word 2000';
 $strHungarian = 'Ungarisch';
 
 $strIcelandic = 'Islndisch';
@@ -351,10 +342,7 @@ $strIndexHasBeenDropped = 'Index %s wurde entfernt.';
 $strIndex = 'Index';
 $strIndexName = 'Indexname:';
 $strIndexType = 'Indextyp:';
-$strIndexWarningMultiple = 'Es sollte nicht mehr als ein Index des Typs %s fr die Spalte `%s` gesetzt sein';
-$strIndexWarningPrimary = 'Die Index-Typen INDEX und PRIMARY sollten nicht gleichzeitig fr die Spalte `%s` gesetzt sein';
 $strIndexWarningTable = 'Warnungen bei den Indizes der Tabelle `%s`';
-$strIndexWarningUnique = 'Die Index-Typen INDEX und UNIQUE sollten nicht gleichzeitig fr die Spalte `%s` gesetzt sein';
 $strInnoDBAutoextendIncrement = 'Autoerweiterungs-Schrittgre';
 $strInnoDBAutoextendIncrementDesc = 'Die Gre, um die ein Tablespace erweitert wird, wenn er voll ist.';
 $strInnoDBBufferPoolSizeDesc = 'Die Gre des Arbeitsspeicherpuffers, den InnoDB verwendet, um Daten und Indizes zwischenzuspeichern.';
@@ -401,7 +389,6 @@ $strKorean = 'Koreanisch';
 
 $strLandscape = 'Querformat';
 $strLanguage = 'Sprache';
-$strLanguageFileNotFound = 'Sprachdatei "%1$s" nicht gefunden.';
 $strLanguageUnknown = 'Unbekannte Sprache: "%1$s".';
 $strLatchedPages = 'Belegte Seiten';
 $strLatexCaption = 'Tabellenbeschriftung';
@@ -411,11 +398,9 @@ $strLatexContinued = '(Fortsetzung)';
 $strLatexIncludeCaption = 'Tabellenbeschriftung einfgen';
 $strLatexLabel = 'Kennzeichen';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX-Optionen';
 $strLatexStructure = 'Struktur der Tabelle __TABLE__';
 $strLatvian = 'Lettisch';
 $strLDI = 'CSV mit LOAD DATA';
-$strLDIImportOptions = 'Optionen fr den CSV-Import mit LOAD DATA';
 $strLDILocal = 'verwende LOCAL';
 $strLengthSet = 'Lnge/Set';
 $strLimitNumRows = 'Eintrge pro Seite';
@@ -516,9 +501,7 @@ $strNumTables = 'Tabellen';
 
 $strOK = 'OK';
 $strOpenDocumentSpreadsheet = 'Open Document Kalkulationstabelle';
-$strOpenDocumentSpreadsheetOptions = 'Open Document Kalkulationstabelle Optionen';
 $strOpenDocumentText = 'Open Document Text';
-$strOpenDocumentTextOptions = 'Open Document Text Optionen';
 $strOpenNewWindow = 'Neues phpMyAdmin-Fenster';
 $strOperations = 'Operationen';
 $strOperator = 'Operator';
@@ -541,7 +524,6 @@ $strPdfDbSchema = 'Schema der Datenbank "%s" - Seite %s';
 $strPdfInvalidTblName = 'Die Tabelle "%s" existiert nicht!';
 $strPdfNoTables = 'keine Tabellen';
 $strPDF = 'PDF';
-$strPDFOptions = 'PDF-Optionen';
 $strPDFReportExplanation = '(Erstellt einen Report mit den Daten einer Tabelle)';
 $strPDFReportTitle = 'Titel des Reports';
 $strPerHour = 'pro Stunde';
@@ -783,7 +765,7 @@ $strShowStatusKey_readsDescr = 'Die Anzahl physikalischer Lesezugriffe eines Sch
 $strShowStatusKey_write_requestsDescr = 'Die Anzahl der Anfragen, einen Schlssel-Block in den Cache zu schreiben.';
 $strShowStatusKey_writesDescr = 'Die Anzahl physikalischer Schreibvorgnge eines Schlssel-Blocks auf Platte.';
 $strShowStatusLast_query_costDescr = 'Die Kosten fr die zuletzt verarbeitete Abfrage wie vom Abfrage-Optimierer berechnet. Ntzlich um verschiedene Formulierungen fr eine Abfrage zu vergleichen. Der Wert 0 besagt das bisher keine Abfrage bersetzt wurde.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'Anzahl der Zeilen, die in INSERT-DELAY-Warteschleifen darauf warten, geschrieben zu werden.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'Anzahl der Zeilen, die in INSERT-DELAYED-Warteschleifen darauf warten, geschrieben zu werden.';
 $strShowStatusOpened_tablesDescr = 'Anzahl der Tabellen, die geffnet wurden. Wenn Opened_tables hoch ist, ist Ihre table_cache-Variable wahrscheinlich zu niedrig.';
 $strShowStatusOpen_filesDescr = 'Anzahl der geffneten Dateien.';
 $strShowStatusOpen_streamsDescr = 'Anzahl der geffneten Streams (hauptschlich zum Loggen benutzt).';
@@ -837,8 +819,6 @@ $strSpanish = 'Spanisch';
 $strSplitWordsWithSpace = 'Die Wrter werden durch Leerzeichen (" ") getrennt.';
 $strSQLCompatibility = 'SQL-Kompatibilittsmodus';
 $strSQLExportType = 'Exporttyp';
-$strSQLImportOptions = 'SQL-Optionen';
-$strSQLOptions = 'SQL-Optionen';
 $strSQLParserBugMessage = 'Mglicherweise haben Sie einen Bug im SQL-Parser entdeckt. Bitte berprfen Sie Ihre Abfrage genaustens, insbesondere auf falsch gesetzte oder nicht geschlossene Anfhrungszeichen. Eine weitere Ursache knnte darin liegen, dass Sie versuchen eine Datei mit binren Daten, welche nicht von Anfhrungszeichen eingeschlossen sind, hochzuladen. Sie knnen alternativ versuchen Ihre Abfrage ber das MySQL-Kommandozeileninterface zu senden. Die MySQL-Fehlerausgabe, falls vorhanden, kann Ihnen auch bei der Fehleranalyse helfen. Falls Sie weiterhin Probleme haben sollten oder der Parser dort versagt, wo die Kommandozeile erfolgreich ist, so reduzieren Sie bitte Ihre Abfrage auf den Befehl, welcher die Probleme verursacht, und senden Sie uns einen Fehlerbericht mit den Datenausschnitt, den Sie weiter unten auf dieser Seite finden.:';
 $strSQLParserUserError = 'Es scheint einen Fehler in Ihrer MySQL-Abfrage zu geben. Die MySQL-Fehlerausgabe, falls vorhanden, kann Ihnen auch bei der Fehleranalyse helfen.';
 $strSQLQuery = 'SQL-Befehl';
@@ -859,7 +839,6 @@ $strStrucCSV = 'CSV-Daten';
 $strStrucData = 'Struktur und Daten';
 $strStrucExcelCSV = 'CSV-Daten fr MS Excel';
 $strStrucNativeExcel = 'Excel-Datei';
-$strStrucNativeExcelOptions = 'Excel-Datei Export Optionen';
 $strStrucOnly = 'Nur Struktur';
 $strStructPropose = 'Tabellenstruktur analysieren';
 $strStructure = 'Struktur';
@@ -976,7 +955,6 @@ $strWriteRequests = 'Schreibanfragen';
 $strWrongUser = 'Falscher Benutzername/Passwort. Zugriff verweigert.';
 
 $strXML = 'XML';
-$strXMLOptions = 'XML Optionen';
 
 $strYes = 'Ja';
 
@@ -985,7 +963,6 @@ $strZip = 'Zip-komprimiert';
 $strPmaWiki = 'phpMyAdmin Wiki';
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'DocSQL Optionen';
 $strTableName = 'Tabellenname';
 $strTableIsEmpty = 'Die Tabelle scheint leer zu sein!';
 $strDbIsEmpty = 'Die Datenbank scheint leer zu sein!';
@@ -1030,4 +1007,26 @@ $strErrorRelationExists = 'Fehler: Verknpfung existiert bereits.';
 $strErrorSaveTable = 'Fehler beim speichern der Koordinaten fr den Designer.';
 $strSnapToGrid = 'Am Gitter anordnen';
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'Die hochgeladene Datei ist grer als der in der php.ini in upload_max_filesize angegebene Wert.';
+$strUploadErrorFormSize = 'Die hochgeladene Datei ist grer als der in MAX_FILE_SIZE des HTML Formulars angegebene Wert.';
+$strUploadErrorPartial = 'Die Datei wurde teilweise bertragen.';
+$strUploadErrorNoTempDir = 'Kein gltiges Temporres Verzeichnis fr hochgeladene Dateien.';
+$strUploadErrorCantWrite = 'Datei konnte gespeichert werden.';
+$strUploadErrorExtension = 'Dateihochladen durch eine Erweiterung gestoppt.';
+$strUploadErrorUnknown = 'Unbekannter Fehler beim Dateihochladen.';
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Fehler beim verschieben der hochgeladenen Datei, siehe FAQ 1.11';
+$strViewName = 'VIEW Name';
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
