@@ -1,5 +1,5 @@
 <?php
-/* $Id: indonesian-iso-8859-1.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: indonesian-iso-8859-1.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
@@ -58,7 +58,6 @@ $strAscending = 'Urutan menaik';
 $strAtBeginningOfTable = 'pada awal tabel';
 $strAtEndOfTable = 'pada akhir tabel';
 $strAttr = 'Atribut';
-$strAutodetect = 'Deteksi otomatis';
 $strAutomaticLayout = 'Layout otomatis';
 
 $strBack = 'Kembali';
@@ -157,7 +156,6 @@ $strCreatePdfFeat = 'Penciptaan PDF';
 $strCreationDates = 'Tanggal Penciptaan/Update/Pemeriksaan';
 $strCriteria = 'Kriteria';
 $strCroatian = 'Bahasa Kroatia';
-$strCSVOptions = 'Pilihan CSV';
 $strCyrillic = 'Bahasa Kirilia';
 $strCzech = 'Bahasa Ceko';
 $strCzechSlovak = 'Cecko-Slovakia';
@@ -167,7 +165,6 @@ $strDatabase = 'Database';
 $strDatabaseEmpty = 'Nama database kosong!';
 $strDatabaseExportOptions = 'Pilihan cara untuk mengekspor Database';
 $strDatabaseHasBeenDropped = 'Database %s telah dihapus.';
-$strDatabaseNoTable = 'Database ini tidak mengandung tabel!';
 $strDatabases = 'Database';
 $strDatabasesDropped = 'Sukses menghapus database %s.';
 $strDatabasesStatsDisable = 'Mencacatkan Statistik';
@@ -236,7 +233,6 @@ $strError = 'Error';
 $strEscapeWildcards = 'Wildcard _ dan % sebaiknya diakhiri dengan tanda \ untuk mengunakannya secara harfiah';
 $strEstonian = 'Bahasa Estonia';
 $strExcelEdition = 'Edisi Excel';
-$strExcelOptions = 'Pilihan Excel';
 $strExecuteBookmarked = 'Eksekusikan pencarian dengan mengikuti penunjuk halaman';
 $strExplain = 'Terangkan SQL';
 $strExport = 'Ekspor';
@@ -246,7 +242,6 @@ $strExtra = 'Ekstra';
 $strFailedAttempts = 'Gagal';
 $strField = 'Field';
 $strFieldHasBeenDropped = 'Field %s telah dihapus';
-$strFieldsEmpty = ' Jumlah field dalam tabel harus ditentukan! ';
 $strFieldsEnclosedBy = 'Field ditutup dengan';
 $strFieldsEscapedBy = 'Field dikembalikan oleh';
 $strFields = 'Field';
@@ -283,15 +278,12 @@ $strHasBeenAltered = 'telah diubah.';
 $strHasBeenCreated = 'telah diciptakan.';
 $strHaveToShow = 'Sekurang-kurangnya satu kolom harus dipilih untuk ditampilkan';
 $strHebrew = 'Bahasa Yahudi';
-$strHexForBinary = 'Gunakan cara hexadesimal untuk field binari';
 $strHome = 'Home';
 $strHomepageOfficial = 'Homepage resmi phpMyAdmin';
 $strHostEmpty = 'Nama Host harus diisi!';
 $strHost = 'Host';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Pilihan ekspor untuk Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Pilihan ekspor untuk Microsoft Word 2000';
 $strHungarian = 'Bahasa Hongaria';
 
 $strIcelandic = 'Islandia';
@@ -305,10 +297,7 @@ $strIndexHasBeenDropped = 'Indeks %s telah dihapus';
 $strIndex = 'Indeks';
 $strIndexName = 'Nama indeks&nbsp;:';
 $strIndexType = 'Tipe indeks&nbsp;:';
-$strIndexWarningMultiple = 'Lebih dari satu kunci %s untuk kolom `%s` telah dibuat ';
-$strIndexWarningPrimary = 'Kunci PRIMARY dan INDEKS sebaiknya jangan di-set secara bersamaan untuk kolom  `%s`';
 $strIndexWarningTable = 'Ditemukan masalah dengan indeks dalam tabel `%s`';
-$strIndexWarningUnique = 'Kunci UNIK and INDEKS sebaiknya jangan di-set secara bersamaan untuk kolom `%s`';
 $strInnoDBAutoextendIncrementDesc = ' Ukuran bertahap dari pembesaran ruang tabel otomatis bila ia mempenuh.';
 $strInnoDBAutoextendIncrement = 'Pembesaran otomatis';
 $strInnoDBBufferPoolSizeDesc = 'Ukuran Memory Buffer yang digunakan oleh InnoDB untuk meng-cache data dan indeks dari tabelnya.';
@@ -350,7 +339,6 @@ $strLatexContinued = '(dilanjutkan)';
 $strLatexIncludeCaption = 'Masukkan judul halaman tabel';
 $strLatexLabel = 'Kunci nama';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Pilihan LaTeX';
 $strLatexStructure = 'Struktur dari tabel __TABLE__';
 $strLatvian = 'Latvia';
 $strLengthSet = 'Ukuran Panjang/Nilai*';
@@ -633,7 +621,6 @@ $strSpaceUsage = 'Penggunaan tempat';
 $strSpanish = 'Bahasa Spanyol';
 $strSplitWordsWithSpace = 'Kata dipisahkan oleh karakter spasi (" ").';
 $strSQLExportType = 'Jenis Ekspor';
-$strSQLOptions = 'Pilihan SQL';
 $strSQLParserBugMessage = 'Mungkin Anda telah temukan sebuah Bug dalam parser SQL. Mohon periksa ulang pencarian SQL dengan teliti dan perhatikan apakah seluruh tanda kutip benar dan seimbang. Penyebab kegagalan bisa terjadi bila Anda meng-upload sebuah file binari diluar teks kutipan. Silakan menjalankan ulang pencarian tersebut dengan menggunakan command line interface. Hasil dari MySQL server error, jika tertampil, akan menolong Anda untuk mengetahui penyebab dari masalah ini. Bila masalah ini tetap muncul atau Parser dari kami masih juga gagal meskipun pencarian melalui command line interface berhasil mohon kurangi input pada SQL query sampai pencarian yang menyebabkan masalah ini ditemukan. Mohon kirimkan sebuah Bug Report dengan cara menyisipkan data di bagian bawah ini kepada kami:';
 $strSQLParserUserError = 'Rupanya ada Error pada Query SQL. Hasil dari MySQL server error dibawa ini, jika tertampil, akan menolong Anda untuk mengetahui penyebab dari problem tersebut.';
 $strSQLQuery = 'Pencarian SQL';
@@ -769,7 +756,6 @@ $strCanNotLoadImportPlugins = 'Could not load import plugins, please check your
 $strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
 $strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 
 $strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
 
@@ -803,10 +789,8 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 
 $strMaxConnects = 'max. concurrent connections';  //to translate
@@ -819,7 +803,6 @@ $strNumberOfFields = 'Number of fields';  //to translate
 $strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
 
 $strPartialImport = 'Partial import';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
@@ -908,7 +891,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -946,7 +929,6 @@ $strShowStatusThreads_runningDescr = 'The number of threads that are not sleepin
 $strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
 $strSorting = 'Sorting';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 
 $strTableAlreadyExists = 'Table %s already exists!';  //to translate
@@ -973,16 +955,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -998,7 +976,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1043,4 +1020,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
