@@ -1,10 +1,10 @@
 <?php
-/* $Id: italian-iso-8859-1.inc.php,v 2.150.2.2 2006/09/08 11:30:10 lem9 Exp $ */
+/* $Id: italian-iso-8859-1.inc.php 10538 2007-07-28 14:26:00Z lem9 $ */
 
 /**
  * translated by: Pietro Danesi <danone at users.sourceforge.net>  2002-03-29
  * Revised by:    "DPhantom" <dphantom at users.sourceforge.net>  2002-04-16
- * Revised by:    "Luca Rebellato" <rebeluca at users.sourceforge.net>  2006-08-10
+ * Revised by:    "Luca Rebellato" <rebeluca at users.sourceforge.net>  2007-07-26
  */
 
 $charset = 'iso-8859-1';
@@ -22,7 +22,6 @@ $datefmt = '%d %B, %Y at %I:%M %p'; //italian time
 $timespanfmt = '%s giorni, %s ore, %s minuti e %s secondi';
 
 $strAbortedClients = 'Fallito';
-$strAbsolutePathToDocSqlDir = 'Prego, immettere il path assoluto sul webserver della  directory di docSQL';
 $strAccessDenied = 'Accesso negato';
 $strAccessDeniedCreateConfig = 'La ragione di questo  che probabilmente non hai creato alcun file di configurazione. Potresti voler usare %1$ssetup script%2$s per crearne uno.';
 $strAccessDeniedExplanation = 'phpMyAdmin ha provato a connettersi al server MySQL, e il server ha rifiutato la connessione. Si dovrebbe controllare il nome dell\'host, l\'username e la password nel file config.inc.php ed assicurarsi che corrispondano alle informazioni fornite dall\'amministratore del server MySQL.';
@@ -32,8 +31,6 @@ $strAddClause = 'Aggiungi %s';
 $strAddConstraints = 'Aggiungi vincoli';
 $strAddDeleteColumn = 'Aggiungi/Cancella campo';
 $strAddDeleteRow = 'Aggiungi/Cancella criterio';
-$strAddedColumnComment = 'Agginto commento sulla colonna';
-$strAddedColumnRelation = 'Aggiunta Relazione per la colonna';
 $strAddFields = 'Aggiungi %s campo(i)';
 $strAddHeaderComment = 'Aggiunge un commento personalizzato all\'header (\\n per tornare a capo)';
 $strAddIntoComments = 'Aggiungi nei commenti';
@@ -58,6 +55,7 @@ $strAlterOrderBy = 'Altera tabella ordinata per';
 $strAnalyzeTable = 'Analizza tabella';
 $strAnd = 'e';
 $strAndThen = 'e quindi';
+$strAngularLinks = 'Men angolari';
 $strAnIndex = 'Un indice  stato aggiunto in %s';
 $strAnyHost = 'Qualsiasi host';
 $strAny = 'Qualsiasi';
@@ -70,7 +68,6 @@ $strAscending = 'Crescente';
 $strAtBeginningOfTable = 'All\'inizio della tabella';
 $strAtEndOfTable = 'Alla fine della tabella';
 $strAttr = 'Attributi';
-$strAutodetect = 'Autorilevazione';
 $strAutomaticLayout = 'Impaginazione automatica';
 
 $strBack = 'Indietro';
@@ -110,6 +107,7 @@ $strBzError = 'phpMyAdmin non  capace di comprimere il dump a causa dell\'estens
 $strBzip = '"compresso con bzip2"';
 
 $strCalendar = 'Calendario';
+$strCancel = 'Cancella';
 $strCanNotLoadExportPlugins = 'Non posso caricare i plugins di esportazione. Controlla l\'installazione!';
 $strCanNotLoadImportPlugins = 'Non posso caricare i plugins di importazione, controlla la tua configurazione!';
 $strCannotLogin = 'Impossibile eseguire il login nel server MySQL';
@@ -158,6 +156,7 @@ $strConnectionError = 'Impossibile connettersi: impostazioni non valide.';
 $strConnections = 'Connessioni';
 $strConstraintsForDumped = 'Limiti per le tabelle scaricate';
 $strConstraintsForTable = 'Limiti per la tabella';
+$strControluserFailed = 'Connessione per controluser come definito nella configurazione fallita.';
 $strCookiesRequired = 'Da questo punto in poi, i cookies devono essere abilitati.';
 $strCopy = 'Copia';
 $strCopyDatabaseOK = 'Il Database %s  stato copiato in %s';
@@ -173,16 +172,16 @@ $strCreateNewDatabase = 'Crea un nuovo database';
 $strCreateNewTable = 'Crea una nuova tabella nel database %s';
 $strCreatePage = 'Crea una nuova pagina';
 $strCreatePdfFeat = 'Creazione di PDF';
+$strCreateRelation = 'Crea relazioni';
+$strCreateTable  = 'Crea tabelle';
 $strCreateUserDatabase = 'Database per l\'utente';
 $strCreateUserDatabaseName = 'Crea un database con lo stesso nome e concedi tutti i privilegi';
 $strCreateUserDatabaseNone = 'None';
-$strCreateUserDatabaseWildcard = 'Concedi tutti i privilegi al nome con caratteri jolly (username_%)';
+$strCreateUserDatabaseWildcard = 'Concedi tutti i privilegi al nome con caratteri jolly (username\_%)';
 $strCreationDates = 'Creazione/Aggiornamento/Controllo date';
 $strCriteria = 'Criterio';
 $strCroatian = 'Croato';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'opzioni CSV';
-$strCSVOptions = 'Opzioni CSV';
 $strCyrillic = 'Cirillico';
 $strCzech = 'Ceco';
 $strCzechSlovak = 'Ceco-Slovacco';
@@ -192,7 +191,6 @@ $strDatabase = 'Database';
 $strDatabaseEmpty = 'Il nome del DataBase  vuoto!';
 $strDatabaseExportOptions = 'Opzioni di esportazione del database';
 $strDatabaseHasBeenDropped = 'Il Database %s  stato eliminato.';
-$strDatabaseNoTable = 'Questo database non contiene tabelle!';
 $strDatabases = 'Database';
 $strDatabasesDropped = '%s databases sono stati cancellati correttamente.';
 $strDatabasesStatsDisable = 'Disabilita le Statistiche';
@@ -205,15 +203,7 @@ $strDataOnly = 'Solo dati';
 $strDataPages = 'Pagine contenenti dati';
 $strDBComment = 'Commento al Database: ';
 $strDBCopy = 'Copia il Database in';
-$strDBGContext = 'Contesto';
-$strDBGContextID = 'ID del Contesto';
-$strDBGHits = 'Hits';
-$strDBGLine = 'Linea';
-$strDBGMaxTimeMs = 'Tempo massimo, ms';
-$strDBGMinTimeMs = 'Tempo minimo, ms';
-$strDBGModule = 'Modulo';
-$strDBGTimePerHitMs = 'Tempo/Hit, ms';
-$strDBGTotalTimeMs = 'Tempo totale, ms';
+$strDbIsEmpty = 'Il databse sembra essere vuoto!';
 $strDbPrivileges = 'Privilegi specifici al database';
 $strDBRename = 'Rinomina il DataBase in';
 $strDbSpecific = 'specifico del database';
@@ -228,12 +218,16 @@ $strDelete = 'Cancella';
 $strDeleted = 'La riga  stata cancellata';
 $strDeletedRows = 'Righe cancellate:';
 $strDeleteNoUsersSelected = 'Nessun utente selezionato per la cancellazione!';
+$strDeleteRelation = 'Cancella relazione';
 $strDeleting = 'Cancellazione in corso di %s';
 $strDelimiter = 'Delimitatori';
 $strDelOld = 'La Pagina corrente contiene Riferimenti a Tabelle che non esistono pi. Volete cancellare questi Riferimenti?';
 $strDescending = 'Decrescente';
 $strDescription = 'Descrizione';
+$strDesigner = 'Designer';
+$strDesignerHelpDisplayField = 'Il campi da mostrare sono in colore rosa. Per impostare/togliere un campo come campo da mostrare, clicca l\'icona "Scegli il campo da mostrare", e poi clicca sul nome appropriato del campo.';
 $strDictionary = 'dizionario';
+$strDirectLinks = 'Link diretti';
 $strDirtyPages = 'Pagine sporche';
 $strDisabled = 'Disabilitata';
 $strDisableForeignChecks = 'Disabilita i controlli sulle chiavi straniere';
@@ -241,6 +235,7 @@ $strDisplayFeat = 'Mostra Caratteristiche';
 $strDisplayOrder = 'Ordine di visualizzazione:';
 $strDisplayPDF = 'Mostra lo schema del PDF';
 $strDoAQuery = 'Esegui "query da esempio" (carattere jolly: "%")';
+$strDocSQL = 'DocSQL';
 $strDocu = 'Documentazione';
 $strDoYouReally = 'Confermi: ';
 $strDropDatabaseStrongWarning = 'Si sta per DISTRUGGERE COMPLETAMENTE un intero DataBase!';
@@ -270,15 +265,19 @@ $strEnglish = 'Inglese';
 $strEnglishPrivileges = 'Nota: i nomi dei privilegi di MySQL sono in Inglese';
 $strError = 'Errore';
 $strErrorInZipFile = 'Errore nell\'archivio ZIP:';
+$strErrorRelationAdded = 'Errore: relazione non aggiunta.';
+$strErrorRelationExists = 'Errore: relazione gi esistente.';
 $strErrorRenamingTable = 'Errore nel rinominare la tabella %1$s in %2$s';
+$strErrorSaveTable = 'Errore nel salvare le coordinate per il Designer.';
 $strEscapeWildcards = 'I caratteri jolly _ e % dovrebbero essere preceduti da un \ per l\'utilizzo letterale';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estone';
+$strEvent = 'Eventi';
 $strExcelEdition = 'Edizione Excel';
-$strExcelOptions = 'Opzioni di Excel';
 $strExecuteBookmarked = 'Esegue la query dalle preferite';
 $strExplain = 'Spiega SQL';
 $strExport = 'Esporta';
+$strExportImportToScale = 'Importa/esporta alla dimensione';
 $strExportMustBeFile = 'Il tipo di esportazione selezionato necessita di essere salvato in un file!';
 $strExtendedInserts = 'Inserimenti estesi';
 $strExtra = 'Extra';
@@ -286,8 +285,8 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Tentativi falliti';
 $strField = 'Campo';
 $strFieldHasBeenDropped = 'Il campo %s  stato eliminato';
+$strFieldInsertFromFileTempDirNotExists = 'Errore nello spostare il file caricato, vedi FAQ 1.11';
 $strFields = 'Campi';
-$strFieldsEmpty = ' Il contatore dei campi  vuoto! ';
 $strFieldsEnclosedBy = 'Campo composto da';
 $strFieldsEscapedBy = 'Campo impedito da';
 $strFieldsTerminatedBy = 'Campo terminato da';
@@ -299,6 +298,7 @@ $strFileNameTemplateDescriptionServer = 'nome server';
 $strFileNameTemplateDescriptionTable = 'nome tabella';
 $strFileNameTemplate = 'Nome file template';
 $strFileNameTemplateRemember = 'ricorda il template';
+$strFiles = 'File';
 $strFileToImport = 'File importato';
 $strFixed = 'fisso';
 $strFlushPrivilegesNote = 'N.B.: phpMyAdmin legge i privilegi degli utenti direttamente nella tabella dei privilegi di MySQL. Il contenuto di questa tabella pu differire dai privilegi usati dal server se sono stati fatti cambiamenti manuali. In questo caso, Si dovrebbero %srinfrescare i privilegi%s prima di continuare.';
@@ -306,6 +306,7 @@ $strFlushQueryCache = 'Rinfresca la cache delle query';
 $strFlushTable = 'Inizializza ("FLUSH") la tabella';
 $strFlushTables = 'Rinfresca (chiudi) tutte le tabelle';
 $strFontSize = 'Dimensione font';
+$strForeignKeyError = 'Errore creando una foreign key (controlla il tipo di dati)';
 $strFormat = 'Formato';
 $strFormEmpty = 'Valore mancante nel form!';
 $strFreePages = 'Pagine libere';
@@ -333,38 +334,38 @@ $strHasBeenAltered = ' stato modificato.';
 $strHasBeenCreated = ' stato creato.';
 $strHaveToShow = 'Devi scegliere almeno una Colonna da mostrare';
 $strHebrew = 'Ebreo';
-$strHexForBinary = 'Usa l\'esadecimale per i dati binari';
+$strHelp = 'Aiuto';
+$strHexForBLOB = 'Usa dati esadecimali per BLOB';
+$strHide         = 'Nascondi';
+$strHideShowAll = 'Mostra/nascondi tutto';
+$strHideShowNoRelation = 'Mostra/nascondi tabella senza relazioni';
 $strHome = 'Home';
 $strHomepageOfficial = 'Home page ufficiale di phpMyAdmin';
 $strHostEmpty = 'Il nome di host  vuoto!';
 $strHost = 'Host';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Opzioni di esportazione di Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Opzioni di esportazione di Microsoft Word 2000';
 $strHungarian = 'Ungherese';
 
 $strIcelandic = 'Islandese';
 $strId = 'ID';
 $strIdxFulltext = 'Testo completo';
+$strIEUnsupported = 'Internet explorer non supporta questa funzione.';
 $strIgnoreDuplicates = 'Ignora le righe duplicate';
 $strIgnore = 'Ignora';
 $strIgnoreInserts = 'Utilizza gli IGNORE INSERTS';
-$strIgnoringFile = 'File %s ignorato';
-$strImportDocSQL = 'Importa Files docSQL';
-$strImportFiles = 'Importa files';
+$strImportExportCoords = 'Importa/esporta le coordinate per PDF schema';
+$strImportFiles = 'Importa file';
 $strImportFormat = 'Formato del file importato';
 $strImport = 'Importa';
-$strImportSuccessfullyFinished = 'Importazione eseguita con successo, %d queries eseguite.';
+$strImportSuccessfullyFinished = 'Importazione eseguita con successo, %d query eseguite.';
 $strIndexes = 'Indici';
+$strIndexesSeemEqual = 'I seguenti indici sembrano essere uguali e uno di essi deve essere rimosso:';
 $strIndexHasBeenDropped = 'L\'indice %s  stato eliminato';
 $strIndex = 'Indice';
 $strIndexName = 'Nome dell\'indice&nbsp;:';
 $strIndexType = 'Tipo di indice&nbsp;:';
-$strIndexWarningMultiple = 'Pi di una chiave %s  stata creata per la colonna `%s`';
-$strIndexWarningPrimary = 'Le chiavi PRIMARY e INDEX non dovrebbero essere assegnate entrambe per la colonna `%s`';
 $strIndexWarningTable = 'Problemi con gli indici della tabella `%s`';
-$strIndexWarningUnique = 'Le chiavi UNIQUE e INDEX non dovrebbero essere assegnate entrambe per la colonna `%s`';
 $strInnoDBAutoextendIncrementDesc = ' La dimensione di incremento per aumentare la dimensione di una tabella autoextending quando diventa piena.';
 $strInnoDBAutoextendIncrement = 'Incremento autoextend';
 $strInnoDBBufferPoolSizeDesc = 'La dimensione del buffer di memoria InnoDB cacha dati e indici delle proprie tabelle.';
@@ -373,6 +374,7 @@ $strInnoDBDataFilePath = 'File dati';
 $strInnoDBDataHomeDirDesc = 'La parte comune del path della directory per tutti i file dati InnoDB.';
 $strInnoDBDataHomeDir = 'Home directory dei dati';
 $strInnoDBPages = 'pagine';
+$strInnoDBRelationAdded = 'Aggiunta relazione InnoDB';
 $strInnodbStat = 'Stato InnoDB';
 $strInsecureMySQL = 'Il file di configurazione in uso contiene impostazioni (root con nessuna password) che corrispondono ai privilegi dell\'account MySQL predefinito. Un server MySQL funzionante con queste impostazioni  aperto a intrusioni, e si dovrebbe realmente riparare a questa falla nella sicurezza.';
 $strInsertAsNewRow = 'Inserisci come nuova riga';
@@ -380,6 +382,7 @@ $strInsertedRowId = 'Inserito id riga:';
 $strInsertedRows = 'Righe inserite:';
 $strInsert = 'Inserisci';
 $strInternalNotNecessary = '* Non  necessaria una relazione interna quando gi esiste in InnoDB.';
+$strInternalRelationAdded = 'Aggiunte relazioni internet';
 $strInternalRelations = 'Relazioni interne';
 $strInUse = 'in uso';
 $strInvalidAuthMethod = 'Metodo di autenticazione settato nella configurazione non valido:';
@@ -407,10 +410,10 @@ $strKeepPass = 'Non cambiare la password';
 $strKeyCache = 'Key cache';
 $strKeyname = 'Nome chiave';
 $strKill = 'Rimuovi';
+$strKnownExternalBug = 'La %s funzionalit  affetta da un bug noto, vedi %s';
 $strKorean = 'Coreano';
 
 $strLandscape = 'Orizzontale';
-$strLanguageFileNotFound = 'File di lingua "%1$s" non trovato.';
 $strLanguage = 'Lingua';
 $strLanguageUnknown = 'Lingua non conosciuta : %1$s.';
 $strLatchedPages = 'Latched pages';
@@ -421,11 +424,9 @@ $strLatexContinued = '(continua)';
 $strLatexIncludeCaption = 'Includi sottotitolo della tabella';
 $strLatexLabel = 'Chiave etichetta';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'opzioni LaTeX';
 $strLatexStructure = 'Struttura della tabella __TABLE__';
 $strLatvian = 'Lituano';
 $strLDI = 'CSV usando LOAD DATA';
-$strLDIImportOptions = 'Opzione per importazione CSV usando LOAD DATA';
 $strLDILocal = 'Usa LOCAL keyword';
 $strLengthSet = 'Lunghezza/Set*';
 $strLimitNumRows = 'record per pagina';
@@ -454,7 +455,7 @@ $strMIME_description = 'Descrizione';
 $strMIME_MIMEtype = 'tipo MIME';
 $strMIME_nodescription = 'Nessuna descrizione  disponibile per questa trasformazione.<br />Prego, chiedere all\'autore cosa %s faccia.';
 $strMIME_transformation_note = 'Per una lista di opzioni di trasformazione disponibili e le loro rispettive trasformazioni di tipi-MIME, cliccate su %strasformazione descrizioni%s';
-$strMIME_transformation_options_note = 'Prego, immettere i valori per le opzioni di trasformazioneutilizzando questo formato: \'a\',\'b\',\'c\'...<br />Se c\' la necessit di immettere un backslash ("\") o un apostrofo ("\'") tra questi valori, essi vanno backslashati (per es. \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Prego, immettere i valori per le opzioni di trasformazioneutilizzando questo formato: \'a\', 100, b,\'c\'...<br />Se c\' la necessit di immettere un backslash ("\") o un apostrofo ("\'") tra questi valori, essi vanno backslashati (per es. \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_transformation_options = 'Opzioni di Transformation';
 $strMIME_transformation = 'Trasformazione del Browser';
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';
@@ -462,6 +463,7 @@ $strMIME_without = 'Tipi-MIME stampati in italics non hanno una funzione di tras
 $strModifications = 'Le modifiche sono state salvate';
 $strModifyIndexTopic = 'Modifica un indice';
 $strModify = 'Modifica';
+$strMoveMenu = 'Muovi men';
 $strMoveTableOK = 'La tabella %s  stata spostata in %s.';
 $strMoveTableSameNames = 'Impossibile spostare la tabella su se stessa!';
 $strMoveTable = 'Sposta la tabella nel (database<b>.</b>tabella):';
@@ -469,7 +471,7 @@ $strMultilingual = 'multilingua';
 $strMyISAMDataPointerSizeDesc = 'Dimensione del puntatore predefinito in Bytes, che deve essere usata da CREATE TABLE per le tabelle MyISAM quando non  stata specificata l\'opzione MAX_ROWS.';
 $strMyISAMDataPointerSize = 'Domensione del puntatore dati';
 $strMyISAMMaxExtraSortFileSizeDesc = 'Se il file temporaneo  usato per la creazione veloce di un indice MyISAM, occuperebbe pi spazio dell\'utilizzo del metodo key cache con la quantit ivi specificata: perci si deve prediligere il metodo key cache.';
-$strMyISAMMaxExtraSortFileSize = 'Dimensione massima per i files temporanei nella creazione di un indice';
+$strMyISAMMaxExtraSortFileSize = 'Dimensione massima per i file temporanei nella creazione di un indice';
 $strMyISAMMaxSortFileSizeDesc = 'La dimensione massima dei file temporanei MySQL pu essere utilizzata nella rigenerazione di un indice MyISAM (durante un REPAIR TABLE, ALTER TABLE, o LOAD DATA INFILE).';
 $strMyISAMMaxSortFileSize = 'Dimensione massima dei file temporanei di ordinamento';
 $strMyISAMRecoverOptionsDesc = 'La modalit di irppristino automatico di tabelle MyISAM corrotte, come impostato tramite l\'opzione di lan cio del server --myisam-recover.';
@@ -481,6 +483,7 @@ $strMyISAMSortBufferSize = 'Ordina la dimensione del buffer';
 $strMySQLCharset = 'Set di caratteri MySQL';
 $strMysqlClientVersion = 'Versione MySQL client';
 $strMySQLConnectionCollation = 'collazione della connessione di MySQL';
+$strMysqlLibDiffersServerVersion = 'Le tue librerie di PHP per MySQL versione %s sono diverse dalla versione di MySQL server %s. Potrebbe causare comportamenti imprevedibili.';
 $strMySQLSaid = 'Messaggio di MySQL: ';
 $strMySQLShowProcess = 'Visualizza processi in esecuzione';
 $strMySQLShowStatus = 'Visualizza informazioni di runtime di MySQL';
@@ -520,19 +523,19 @@ $strNoUsersFound = 'Nessun utente trovato.';
 $strNoValidateSQL = 'Non Validare SQL';
 $strNull = 'Null';
 $strNumberOfFields = 'Numero di campi';
+$strNumberOfTables = 'Numero di tabelle';
 $strNumSearchResultsInTable = '%s corrisponde/ono nella tabella <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Totale:</b> <i>%s</i> corrispondenza/e';
 $strNumTables = 'Tabelle';
 
 $strOK = 'OK';
 $strOpenDocumentSpreadsheet = 'Foglio di calcolo nel formato Open Document';
-$strOpenDocumentSpreadsheetOptions = 'Opzioni Open Document Spreadsheet';
-$strOpenDocumentTextOptions = 'Opzioni testo nel formato Open Document';
 $strOpenDocumentText = 'Testo nel formato Open Document';
 $strOpenNewWindow = 'Apri una nuova finestra di PhpMyAdmin';
 $strOperations = 'Operazioni';
 $strOperator = 'Operatore';
 $strOptimizeTable = 'Ottimizza tabella';
+$strOptions = 'Opzioni';
 $strOr = 'Oppure';
 $strOverhead = 'In eccesso';
 $strOverwriteExisting = 'Sovrascrivi file(s) esistente/i';
@@ -550,7 +553,6 @@ $strPassword = 'Password';
 $strPdfDbSchema = 'Schema del database "%s" - Pagina %s';
 $strPdfInvalidTblName = 'La tabella "%s" non esiste!';
 $strPdfNoTables = 'Nessuna Tabella';
-$strPDFOptions = 'Opzioni PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Genera un report contenete i dati di una singola tabella)';
 $strPDFReportTitle = 'Titolo del Report';
@@ -562,8 +564,10 @@ $strPhoneBook = 'rubrica';
 $strPHP40203 = 'Si sta utilizzando PHP 4.2.3, che presenta un serio bug con le stringhe multi-byte (mbstring). Vedi report PHP 19404. Questa versione di PHP non  raccomandata per l\'utilizzo con phpMyAdmin.';
 $strPhp = 'Crea il codice PHP';
 $strPHPVersion = 'Versione PHP';
+$strPleaseSelectPrimaryOrUniqueKey = 'Seleziona la chiave primaria o una chiave univoca';
 $strPmaDocumentation = 'Documentazione di phpMyAdmin';
 $strPmaUriError = 'La direttiva <tt>$cfg[\'PmaAbsoluteUri\']</tt> DEVE essere impostata nel file di configurazione!';
+$strPmaWiki = 'phpMyAdmin wiki';
 $strPolish = 'Polacco';
 $strPortrait = 'Verticale';
 $strPos1 = 'Inizio';
@@ -589,17 +593,17 @@ $strPrivDescDropDb = 'Permette di eliminare databases e tabelle.';
 $strPrivDescDropTbl = 'Permette di eliminare tabelle.';
 $strPrivDescExecute5 = 'Permette l\'esecuzione di routines memorizzate.';
 $strPrivDescExecute = 'Permette di eseguire procedure memorizzate; Non ha effetto in questa versione di MySQL.';
-$strPrivDescFile = 'Permette di importare dati da e esportare dati in files.';
+$strPrivDescFile = 'Permette di importare dati da e esportare dati in file.';
 $strPrivDescGrant = 'Permette di aggiungere utenti e privilegi senza ricaricare le tabelle dei privilegi.';
 $strPrivDescIndex = 'Permette di creare ed eliminare gli indici.';
 $strPrivDescInsert = 'Permette di inserire e sovrascrivere dati.';
 $strPrivDescLockTables = 'Permette di bloccare le tabelle per il thread corrente.';
 $strPrivDescMaxConnections = 'Limita il numero di nuove connessioni che un utente pu aprire in un\'ora.';
-$strPrivDescMaxQuestions = 'Limita il numero di queries che un utente pu mandare al server in un\'ora.';
+$strPrivDescMaxQuestions = 'Limita il numero di query che un utente pu mandare al server in un\'ora.';
 $strPrivDescMaxUpdates = 'Limita il numero di comandi che possono cambiare una tabella o un database che un utente pu eseguire in un\'ora.';
 $strPrivDescMaxUserConnections = 'Limite di connessioni simultanee che un utente pu fare.';
 $strPrivDescProcess3 = 'Permette di killare i processi di altri utenti.';
-$strPrivDescProcess4 = 'Permette di vedere le queries complete nella lista dei processi.';
+$strPrivDescProcess4 = 'Permette di vedere le query complete nella lista dei processi.';
 $strPrivDescReferences = 'Non ha alcun effetto in questa versione di MySQL.';
 $strPrivDescReload = 'Permette di ricaricare i parametri del server e di resettare la cache del server.';
 $strPrivDescReplClient = 'Accorda il diritto ad un utente di domandare dove sono i masters/slaves.';
@@ -616,6 +620,7 @@ $strPrivilegesReloaded = 'I privilegi sono stati ricaricati con successo.';
 $strProcedures = 'Procedure';
 $strProcesses = 'Processi';
 $strProcesslist = 'Lista Processi';
+$strProfiling = 'Profiling';
 $strProtocolVersion = 'Versione protocollo';
 $strPutColNames = 'Mette i nomi delle colonne alla prima riga';
 
@@ -627,23 +632,26 @@ $strQueryFrame = 'Finestra della Query';
 $strQueryOnDb = 'SQL-query sul database <b>%s</b>:';
 $strQueryResultsOperations = 'Risultato delle operazioni di Query';
 $strQuerySQLHistory = 'Storico dell\'SQL';
-$strQueryStatistics = '<b>Query delle Statistiche</b>: Dall\'avvio, %s queries sono state effettuate sul server.';
+$strQueryStatistics = '<b>Query delle Statistiche</b>: Dall\'avvio, %s query sono state effettuate sul server.';
 $strQueryTime = 'La query ha impiegato %01.4f sec';
 $strQueryType = 'Tipo di Query';
 $strQueryWindowLock = 'Non sovrascrivere questa query da fuori della finestra';
 
 $strReadRequests = 'Richieste di lettura';
 $strReceived = 'Ricevuti';
+$strRecommended = 'raccomandato';
 $strRecords = 'Record';
 $strReferentialIntegrity = 'Controlla l\'integrit delle referenze:';
 $strRefresh = 'Aggiorna';
 $strRelationalSchema = 'Schema relazionale';
+$strRelationDeleted = 'Relazione cancellata';
 $strRelationNotWorking = 'Le caratteristiche aggiuntive sono state disattivate per funzionare con le tabelle linkate. Per scoprire perch clicca %squi%s.';
 $strRelationsForTable = 'RELATIONS FOR TABLE';
 $strRelations = 'Relazioni';
 $strRelationView = 'Vedi relazioni';
 $strReloadingThePrivileges = 'Caricamento dei privilegi in corso';
 $strReloadPrivileges = 'Ricarica i privilegi';
+$strReload = 'Ricarica';
 $strRemoveSelectedUsers = 'Rimuove gli utenti selezionati';
 $strRenameDatabaseOK = 'Il DataBase %s  stato rinominato in %s';
 $strRenameTableOK = 'La tabella %s  stata rinominata %s';
@@ -654,12 +662,15 @@ $strReplaceTable = 'Sostituisci i dati della tabella col file';
 $strReplication = 'Replicazione';
 $strReset = 'Riavvia';
 $strResourceLimits = 'Limiti di risorse';
+$strRestartInsertion = 'Riprendi inserimento con la riga %s';
 $strReType = 'Reinserisci';
 $strRevokeAndDeleteDescr = 'Gli utenti UTILIZZERANNO comunque il privilegio finch i privilegi non saranno ricaricati.';
 $strRevokeAndDelete = 'Revoca tutti i privilegi attivi agli utenti e dopo li cancella.';
 $strRevokeMessage = 'Hai revocato i privilegi per %s';
 $strRevoke = 'Revoca';
 $strRomanian = 'Rumeno';
+$strRoutineReturnType = 'Tipo di risultato';
+$strRoutines = 'Routines';
 $strRowLength = 'Lunghezza riga';
 $strRowsFrom = 'righe a partire da';
 $strRowSize = 'Dimensione riga';
@@ -676,6 +687,7 @@ $strRunSQLQueryOnServer = 'Eseguendo query SQL sul server %s';
 $strRussian = 'Russo';
 
 $strSaveOnServer = 'Salva sul server nella directory %s';
+$strSavePosition = 'Salva la posizione';
 $strSave = 'Salva';
 $strScaleFactorSmall = 'Il fattore di scala  troppo piccolo per riempire lo schema nella pagina';
 $strSearch = 'Cerca';
@@ -693,7 +705,9 @@ $strSelectADb = 'Prego, selezionare un database';
 $strSelectAll = 'Seleziona Tutto';
 $strSelectBinaryLog = 'Selezionare il log binario da visualizzare';
 $strSelectFields = 'Seleziona campi (almeno uno):';
+$strSelectForeignKey = 'Seleziona Foreign Key';
 $strSelectNumRows = 'nella query';
+$strSelectReferencedKey = 'Seleziona le chiavi referenziali';
 $strSelectTables = 'Seleziona Tables';
 $strSend = 'Salva con nome...';
 $strSent = 'Spediti';
@@ -708,6 +722,7 @@ $strServerTabVariables = 'Variabili';
 $strServerTrafficNotes = '<b>Traffico del server</b>: Queste tabelle mostrano le statistiche del traffico di retedi questo server MySQL dal momento del suo avvio.';
 $strServerVars = 'Variabili e parametri del Server';
 $strServerVersion = 'Versione MySQL';
+$strSessionStartupErrorGeneral = 'Non posso far partire la sessione senza errori, controlla gli errori nel log di PHP e/o del tuo server web e configura correttamente la tua installazione di PHP.';
 $strSessionValue = 'Valore sessione';
 $strSetEnumVal = 'Se il tipo di campo  "enum" o "set", immettere i valori usando il formato: \'a\',\'b\',\'c\'...<br />Se comunque dovete mettere dei backslashes ("\") o dei single quote ("\'") davanti a questi valori, backslashateli (per esempio \'\\\\xyz\' o \'a\\\'b\').';
 $strShowAll = 'Mostra tutti';
@@ -715,8 +730,11 @@ $strShowColor = 'Mostra il colore';
 $strShowDatadictAs = 'Formato del Data Dictionary';
 $strShowFullQueries = 'Mostra query complete';
 $strShowGrid = 'Mostra la griglia';
+$strShowHideLeftMenu = 'Mostra/nascondi il men di sinistra';
 $strShowingBookmark = 'Mostrando i segnalibri';
+$strShowingPhp = 'Mostrando il codice PHP';
 $strShowingRecords = 'Visualizzazione record ';
+$strShowingSQL = 'Mostrando la query SQL';
 $strShow = 'Mostra';
 $strShowOpenTables = 'Mostra le tabelle aperte';
 $strShowPHPInfo = 'Mostra le info sul PHP';
@@ -725,7 +743,7 @@ $strShowSlaveStatus = 'Mostra lo stato degli slave';
 $strShowStatusBinlog_cache_disk_useDescr = 'Il numero delle transazioni che usano la cache temporanea del log binario, ma che oltrepassano il valore di binlog_cache_size e usano un file temporaneo per salvare gli statements dalle transazioni.';
 $strShowStatusBinlog_cache_useDescr = 'Il numero delle transazioni che usano la cache temporanea del log binario.';
 $strShowStatusCreated_tmp_disk_tablesDescr = 'Il numero delle tabelle temporanee create automaticamente sul disco dal server mentre esegue i comandi. Se il valore Created_tmp_disk_tables  grande, potresti voler aumentare il valore tmp_table_size, per fare im modo che le tabelle temporanee siano memory-based anzich disk-based.';
-$strShowStatusCreated_tmp_filesDescr = 'Numero di files temporanei che mysqld ha creato.';
+$strShowStatusCreated_tmp_filesDescr = 'Numero di file temporanei che mysqld ha creato.';
 $strShowStatusCreated_tmp_tablesDescr = 'Il numero di tabelle temporanee create automaticamente in memoria dal server durante l\'esecuzione dei comandi.';
 $strShowStatusDelayed_errorsDescr = 'Numero di righe scritte con INSERT DELAYED in cui ci sono stati degli errori (probabilmete chiave dublicata).';
 $strShowStatusDelayed_insert_threadsDescr = 'Il numero di processi INSERT DELAYED in uso. Ciascuna tabella su cui  usato INSERT DELAYED occupa un thread.';
@@ -794,9 +812,9 @@ $strShowStatusKey_readsDescr = 'Il numero di letture fisiche dal disco di un blo
 $strShowStatusKey_write_requestsDescr = 'Il numero di richieste per scrivere una blocco chiave nella cache.';
 $strShowStatusKey_writesDescr = 'Il numero di scritture fisiche di un blocco chiave sul disco.';
 $strShowStatusLast_query_costDescr = 'Il costo totale dell\'ultima query compilata cos come computato dall\'ottimizzatore delle query. Utile per comparare il costo di differenti query per la stessa operazione di query. Il valore di default  0, che significa che nessuna query  stata ancora compilata.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'In numero di righe in attesa di essere scritte nella coda INSERT DELAY.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'In numero di righe in attesa di essere scritte nella coda INSERT DELAYED.';
 $strShowStatusOpened_tablesDescr = 'Il numero di tabelle che sono state aperte. Se il valore opened_tables  grande, probabilmente il valore di table cache  troppo piccolo.';
-$strShowStatusOpen_filesDescr = 'Il numero di files che sono aperti.';
+$strShowStatusOpen_filesDescr = 'Il numero di file che sono aperti.';
 $strShowStatusOpen_streamsDescr = 'il numero di stream che sono aperti (usato principalmente per il logging).';
 $strShowStatusOpen_tablesDescr = 'Il numero di tabelle che sono aperte.';
 $strShowStatusQcache_free_blocksDescr = 'Il numero di blocchi di memoria liberi nella cache delle query.';
@@ -838,6 +856,8 @@ $strSize = 'Dimensione';
 $strSkipQueries = 'Numero di record (query) da saltare a partire dall\'inizio';
 $strSlovak = 'Slovacco';
 $strSlovenian = 'Sloveno';
+$strSmallBigAll = 'Piccolo/grande';
+$strSnapToGrid = 'Calamita alla griglia';
 $strSocketProblem = '(o il socket del server locale MySQL non  correttamente configurato)';
 $strSortByKey = 'Ordina per chiave';
 $strSorting = 'Ordinando';
@@ -847,8 +867,6 @@ $strSpanish = 'Spagnolo';
 $strSplitWordsWithSpace = 'Le parole sono spezzate sulle spaziature (" ").';
 $strSQLCompatibility = 'Modo di compatibilit SQL';
 $strSQLExportType = 'Tipo di esportazione';
-$strSQLImportOptions = 'Opzioni SQL';
-$strSQLOptions = 'Opzioni SQL';
 $strSQLParserBugMessage = 'C\' la possibilit che ci sia un bug nel parser SQL. Per favore, esaminate la query accuratamente, e controllate che le virgolette siano corrette e non sbagliate. Altre possibili cause d\'errori possono essere che si stia cercando di uploadare un file binario al di fuori di un\'area di testo virgolettata. Si pu anche provare la query MySQL dalla riga di comando di MySQL. L\'errore qui sotto restituito dal server MySQL, se ce n\' uno, pu anche aiutare nella diagnostica del problema. Se ci sono ancora problemi, o se il parser SQL di phpMyAdmin sbaglia quando invece l\'interfaccia a riga di comando non mostra problemi, si pu ridurre la query SQL in ingresso alla singola query che causa problemi, e inviare un bug report con i dati riportati nella sezione CUT qui sotto:';
 $strSQLParserUserError = 'Pare che ci sia un errore nella query SQL immessa. L\'errore del server MySQL mostrato qui sotto, se c\', pu anche aiutare nella risoluzione del problema';
 $strSQLQuery = 'query SQL';
@@ -857,6 +875,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Identificatore Non Valido';
 $strSQPBugUnclosedQuote = 'Virgolette Non Chiuse';
 $strSQPBugUnknownPunctuation = 'Stringa di Punctuation Sconosciuta';
+$strStandInStructureForView = 'Struttura Stand-in per le viste';
 $strStatCheckTime = 'Ultimo controllo';
 $strStatCreateTime = 'Creazione';
 $strStatement = 'Istruzioni';
@@ -869,9 +888,9 @@ $strStrucCSV = 'dati CSV';
 $strStrucData = 'Struttura e dati';
 $strStrucExcelCSV = 'CSV per dati MS Excel';
 $strStrucNativeExcel = 'Dati nativi di MS Excel';
-$strStrucNativeExcelOptions = 'Opzioni di esportazione Excel native';
 $strStrucOnly = 'Solo struttura';
 $strStructPropose = 'Proponi la struttura della tabella';
+$strStructureForView = 'Struttura per la vista';
 $strStructure = 'Struttura';
 $strSubmit = 'Invia';
 $strSuccess = 'La query  stata eseguita con successo';
@@ -886,7 +905,9 @@ $strTableEmpty = 'Il nome della tabella  vuoto!';
 $strTableHasBeenDropped = 'La tabella %s  stata eliminata';
 $strTableHasBeenEmptied = 'La tabella %s  stata svuotata';
 $strTableHasBeenFlushed = 'La tabella %s  stata inizializzata';
+$strTableIsEmpty = 'La tabella sembra essere vuota!';
 $strTableMaintenance = 'Amministrazione tabella';
+$strTableName = 'Nome tabella';
 $strTableOfContents = 'Tabella dei contenuti';
 $strTableOptions = 'Opzioni della tabella';
 $strTables = '%s tabella(e)';
@@ -904,14 +925,16 @@ $strThemeNoValidImgPath = 'Nessun percorso per le immagini per il tema %s trovat
 $strThemePathNotFound = 'Percorso per il tema non trovato %s!';
 $strTheme = 'Tema / Stile';
 $strThisHost = 'Questo Host';
-$strThisNotDirectory = 'Questa non  una directory';
 $strThreads = 'Processi';
 $strThreadSuccessfullyKilled = 'Il thread %s  stato terminato con successo.';
 $strTimeoutInfo = 'Una precedente importazione  entrata in timeout, dopo un nuovo inoltro riprender dalla posizione: %d.';
 $strTimeoutNothingParsed = 'Nell\'ultima esecuzione nessun dato  stato processato, questo, solitamente, vuole dire che che phpMyAdmin non  in grado di ultimare l\'operazione fino a che non verr aumentato il parametro php time limits.';
 $strTimeoutPassed = 'Superato il tempo limite dello script, se vuoi finire l\'importazione inoltra nuovamente il file e il processo riprender.';
 $strTime = 'Tempo';
+$strToFromPage = 'da/per pagina';
 $strToggleScratchboard = '(dis)attiva scratchboard';
+$strToggleSmallBig = 'Cambia grande/piccolo';
+$strToSelectRelation = 'Per selezionare una relazione, click :';
 $strTotal = 'Totali';
 $strTotalUC = 'Totale';
 $strTraditionalChinese = 'Cinese Tradizionale';
@@ -923,13 +946,14 @@ $strTransformation_application_octetstream__hex = 'Mostra una rappresentazione e
 $strTransformation_image_jpeg__inline = 'Mostra un thumbnalil cliccabile; opzioni: larghezza,altezza in pixel (mantiere la proporzione iniziale)';
 $strTransformation_image_jpeg__link = 'Mostra un link a questa immagine (download blob diretto, i.e.).';
 $strTransformation_image_png__inline = 'Vedi immagine/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Prende un campo TIME, TIMESTAMP o DATETIME e lo formatta utilizzando il formato data locale. La prima opzione  il time offset (in ore) il quale sar aggiunto al timestamp (Predefinito: 0). La seconda opzione  un formato data in linea con i parametri disponibili per la funzione strftime() del PHP.';
+$strTransformation_text_plain__dateformat = 'Mostra i campi TIME, TIMESTAMP, DATETIME o il TIMESTAMP UNIX come data formattata. La prima opzione  l\'offset (in ore) che verr aggiunto all\'ora (Default: 0). Usare la seconda opzione per specificare un differente formato di data/ora. La terza opzione determina se vuoi vedere l\'ora locale o UTC (usa "local" o "utc" per questo). In relazione a questo, il formato data ha differenti valori - per "local" guarda la documentazione della funzione PHP strftime(); per "utc" viene usata la funzione gmdate().';
 $strTransformation_text_plain__external = 'SOLO PER LINUX: Lancia un\'applicazione esterna e riempie i dati dei campi tramite lo standard input. Restituisce lo standard output dell\'applicazione. L\'impostazione predefinita  Tidy, per stampare in maniera corretta il codice HTML. Per motivi di sicurezza, dovete editare manualmente il file libraries/transformations/text_plain__external.inc.php e inserire gli strumenti che permettete di utilizzare. La prima opzione  cos il numero del programma che volete utilizzare e la seconda sono i parametri per il programma. Il terzo parametro, se impostato a 1 convertir l\'output utilizzando htmlspecialchars() (Predefinito: 1). Un quarto parametro, se impostato a 1 inserir un NOWRAP al contenuto della cella cos che l\'intero output sar mostrato senza essere riformattato (Predefinito: 1)';
 $strTransformation_text_plain__formatted = 'Preserva l\'originale formattazione del campo. Nessun Escaping viene applicato.';
 $strTransformation_text_plain__imagelink = 'Mostra un collegamento ad una immagine esterna; il campo contiene il nome del file; la prima opzione  un prefisso come "http://tuodominio.com/", la seconda opzione  la larghezza in pixel, la terza  l\'altezza.';
 $strTransformation_text_plain__link = 'Mostra un collegamento, il campo contiene il nome del file; la prima opzione  un prefisso come "http://tuodominio.com/", la seconda opzione  un titolo per il collegamento.';
 $strTransformation_text_plain__sql = 'Formatta il testo come query SQL con evidenziazione della sintassi.';
 $strTransformation_text_plain__substr = 'Mostra soltanto una parte della stringa. La prima opzione  l\'offset che serve a definire dove inizia l\'output del vostro testo (Prefinito: 0). La seconda opzione  un offset che indica quanto testo viene restituito. Se vuoto, restituisce tutto il testo rimanente. La terza opzione definisce quali caratteri saranno aggiunti in fondo all\'output quando una soptto-stringa viene restituita (Predefinito: ...) .';
+$strTriggers = 'Triggers';
 $strTruncateQueries = 'Tronca le Query Mostrate';
 $strTurkish = 'Turco';
 $strType = 'Tipo';
@@ -946,8 +970,15 @@ $strUpdateProfileMessage = 'Il profilo  stato aggiornato.';
 $strUpdateQuery = 'Aggiorna Query';
 $strUpdComTab = 'Prego leggere la documentazione su come aggiornare la vostra tabella Column_comments';
 $strUpgrade = 'Si dovrebbe aggiornare %s alla versione %s o successiva.';
+$strUploadErrorCantWrite = 'Non riesco a scrivere il file su disco.';
+$strUploadErrorExtension = 'Caricamento del file interrotto per estensione errata.';
+$strUploadErrorFormSize = 'Il file caricato eccede il parametro MAX_FILE_SIZE specificato nel form HTML.';
+$strUploadErrorIniSize = 'Il file caricato eccede il parametro upload_max_filesize in php.ini.';
+$strUploadErrorNoTempDir = 'Non trovo la cartella temporanea.';
+$strUploadErrorPartial = 'Il file  stato solo parzialmente caricato.';
+$strUploadErrorUnknown = 'Errore sconosciuto nel caricamento del file.';
 $strUploadLimit = 'Stai probabilmente cercando di uplodare un file troppo grosso. Fai riferimento alla documentazione %sdocumentation%s Per i modi di aggirare questo limite.';
-$strUploadsNotAllowed = 'Non  permesso l\'upload dei files su questo server.';
+$strUploadsNotAllowed = 'Non  permesso l\'upload dei file su questo server.';
 $strUsage = 'Utilizzo';
 $strUseBackquotes = 'Usa i backquotes con i nomi delle tabelle e dei campi';
 $strUsedPhpExtensions = 'Estensioni PHP usate';
@@ -975,6 +1006,7 @@ $strViewDumpDB = 'Visualizza dump (schema) del database';
 $strViewDump = 'Visualizza dump (schema) della tabella';
 $strViewHasBeenDropped = 'La vista %s  stata eliminata';
 $strViewMaxExactCount = 'Questa vista ha pi di %d righe. Per informazioni fare riferimento a %sdocumentation%s.';
+$strViewName = 'Nome VISTA';
 $strView = 'Vista';
 
 $strWebServerUploadDirectory = 'directory di upload del web-server';
@@ -985,11 +1017,8 @@ $strWildcard = 'wildcard';
 $strWindowNotFound = 'La finestra destinataria del browser non pu essere aggiornata. Pu darsi che sia stata chiusa la finestra madre o che il vostro browser stia bloccando gli aggiornamenti fra browsers a causa di qualche impostazione di sicurezza';
 $strWithChecked = 'Se selezionati:';
 $strWriteRequests = 'Richieste di scrittura';
-$strWritingCommentNotPossible = 'Impossibile scrivere il commento';
-$strWritingRelationNotPossible = 'Impossibile scrivere la Relazione';
 $strWrongUser = 'Nome utente o password errati. Accesso negato.';
 
-$strXMLOptions = 'Opzioni XML';
 $strXML = 'XML';
 
 $strYes = 'S';
