@@ -1,5 +1,5 @@
 <?php
-/* $Id: korean-euc-kr.inc.php,v 2.132 2006/08/09 12:55:38 lem9 Exp $ */
+/* $Id: korean-euc-kr.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /* Translated by WooSuhan <kjh@unews.NOSPAM.co.kr> */
 
@@ -45,7 +45,6 @@ $strAscending = '';
 $strAtBeginningOfTable = '̺ ó';
 $strAtEndOfTable = '̺ ';
 $strAttr = '';
-$strAutodetect = 'ڵ';
 
 $strBack = 'ڷ';
 $strBinary = '̳ʸ';
@@ -85,7 +84,6 @@ $strCreateIndexTopic = ' ε ';
 $strCreateNewDatabase = ' ͺ̽ ';
 $strCreateNewTable = 'ͺ̽ %s ο ̺ ϴ.';
 $strCreatePage = '  ';
-$strCSVOptions = 'CSV ɼ';
 
 $strData = '';
 $strDatabase = 'ͺ̽';
@@ -98,9 +96,6 @@ $strDatabasesStatsEnable = ' ';
 $strDatabasesStatsHeavyTraffic = ': ͺ̽    MySQL  ̿ ū ϸ ݴϴ.';
 $strDataDict = '  (ü )';
 $strDataOnly = '͸';
-$strDBGMaxTimeMs = 'ִð, ms';
-$strDBGMinTimeMs = 'ּҽð, ms';
-$strDBGModule = '';
 $strDbPrivileges = 'ͺ̽  ';
 $strDefault = '⺻';
 $strDefaultValueHelp = '⺻, ó ǥ   ϳ  ʽÿ. (: a)';
@@ -141,7 +136,6 @@ $strFailedAttempts = ' õ';
 $strField = 'ʵ';
 $strFieldHasBeenDropped = 'ʵ %s  ߽ϴ';
 $strFields = 'ʵ';
-$strFieldsEmpty = ' ʵ  ϴ! ';
 $strFieldsEnclosedBy = 'ʵ α';
 $strFieldsEscapedBy = 'ʵ Ư(escape) ó';
 $strFieldsTerminatedBy = 'ʵ  ';
@@ -165,7 +159,6 @@ $strHost = 'ȣƮ';
 $strHostEmpty = 'ȣƮ ϴ!';
 
 $strIgnore = 'Ignore';
-$strIgnoringFile = ' %s  մϴ';
 $strImportFiles = ' ';
 $strIndex = 'ε';
 $strIndexes = 'ε';
@@ -366,7 +359,6 @@ $strSize = 'ũ';
 $strSort = '';
 $strSpaceUsage = ' 뷮';
 $strSplitWordsWithSpace = 'ܾ ̽(" ") е˴ϴ.';
-$strSQLOptions = 'SQL ɼ';
 $strSQLParserUserError = 'SQL ǹ  ֽϴ. MySQL     ߽ϴ. ̰  ϴµ   Դϴ.';
 $strSQLQuery = 'SQL ';
 $strSQLResult = 'SQL ';
@@ -400,7 +392,6 @@ $strTables = '̺ %s ';
 $strTableStructure = '̺ ';
 $strTblPrivileges = '̺  ';
 $strTextAreaLength = ' ʵ  ,<br /> ʵ带   ϴ ';
-$strThisNotDirectory = '丮 ƴմϴ';
 $strThreadSuccessfullyKilled = ' %s  ׿ϴ.';
 $strTime = 'ð';
 $strTotal = 'հ';
@@ -446,13 +437,10 @@ $strZip = 'zip ';
 
 // To translate:
 $strAbortedClients = 'Aborted'; //to translate
-$strAbsolutePathToDocSqlDir = 'Please enter the absolute path on webserver to docSQL directory';  //to translate
 $strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
-$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in config.inc.php and make sure that they correspond to the information given by the administrator of the MySQL server.';  //to translate
+$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in your configuration and make sure that they correspond to the information given by the administrator of the MySQL server.';  //to translate
 $strAddAutoIncrement = 'Add AUTO_INCREMENT value';  //to translate
 $strAddConstraints = 'Add constraints';  //to translate
-$strAddedColumnComment = 'Added comment for column';  //to translate
-$strAddedColumnRelation = 'Added relation for column';  //to translate
 $strAddFields = 'Add %s field(s)';  //to translate
 $strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
 $strAddIntoComments = 'Add into comments';//to translate
@@ -534,7 +522,6 @@ $strCreationDates = 'Creation/Update/Check dates';  //to translate
 $strCriteria = 'Criteria'; // To translate
 $strCroatian = 'Croatian';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 $strCyrillic = 'Cyrillic';  //to translate
 $strCzech = 'Czech';  //to translate
 $strCzechSlovak = 'Czech-Slovak';  //to translate
@@ -542,16 +529,9 @@ $strCzechSlovak = 'Czech-Slovak';  //to translate
 $strDanish = 'Danish';  //to translate
 $strDatabaseEmpty = 'The database name is empty!';  //to translate
 $strDatabaseExportOptions = 'Database export options';//to translate
-$strDatabaseNoTable = 'This database contains no table!';//to translate
 $strDataPages = 'Pages containing data';  //to translate
 $strDBComment = 'Database comment: ';//to translate
 $strDBCopy = 'Copy database to';  //to translate
-$strDBGContext = 'Context';  //to translate
-$strDBGContextID = 'Context ID';  //to translate
-$strDBGHits = 'Hits';  //to translate
-$strDBGLine = 'Line';  //to translate
-$strDBGTimePerHitMs = 'Time/Hit, ms';  //to translate
-$strDBGTotalTimeMs = 'Total time, ms';  //to translate
 $strDBRename = 'Rename database to';  //to translate
 $strDbSpecific = 'database-specific';  //to translate
 $strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
@@ -581,7 +561,6 @@ $strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them
 $strEsperanto = 'Esperanto';  //to translate
 $strEstonian = 'Estonian';  //to translate
 $strExcelEdition = 'Excel edition';  //to translate
-$strExcelOptions = 'Excel options';  //to translate
 $strExecuteBookmarked = 'Execute bookmarked query';  //to translate
 
 $strFileAlreadyExists = 'File %s already exists on server, change filename or check overwrite option.';  //to translate
@@ -612,11 +591,8 @@ $strGreek = 'Greek';  //to translate
 
 $strHandler = 'Handler';  //to translate
 $strHebrew = 'Hebrew';  //to translate
-$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 $strHungarian = 'Hungarian';  //to translate
 
 $strIcelandic = 'Icelandic';  //to translate
@@ -624,14 +600,10 @@ $strId = 'ID'; //to translate
 $strIdxFulltext = 'Fulltext'; // To translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strIgnoreInserts = 'Use ignore inserts';  //to translate
-$strImportDocSQL = 'Import docSQL Files';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
 $strImport = 'Import';  //to translate
 $strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
 $strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
 $strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
 $strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
@@ -664,7 +636,6 @@ $strKeyCache = 'Key cache';  //to translate
 $strKorean = 'Korean';  //to translate
 
 $strLandscape = 'Landscape';  //to translate
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLatexCaption = 'Table caption';//to translate
@@ -674,11 +645,9 @@ $strLatexContinued = '(continued)';//to translate
 $strLatexIncludeCaption = 'Include table caption';//to translate
 $strLatexLabel = 'Label key';//to translate
 $strLaTeX = 'LaTeX';  //to translate
-$strLaTeXOptions = 'LaTeX options';  //to translate
 $strLatexStructure = 'Structure of table __TABLE__';//to translate
 $strLatvian = 'Latvian';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLinkNotFound = 'Link not found';  //to translate
 $strLinksTo = 'Links to';  //to translate
@@ -698,7 +667,7 @@ $strMIME_MIMEtype = 'MIME-type';//to translate
 $strMIME_nodescription = 'No Description is available for this transformation.<br />Please ask the author, what %s does.';//to translate
 $strMIME_transformation = 'Browser transformation';//to translate
 $strMIME_transformation_note = 'For a list of available transformation options and their MIME-type transformations, click on %stransformation descriptions%s';//to translate
-$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';//to translate
+$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\', 100, b,\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';//to translate
 $strMIME_transformation_options = 'Transformation options';//to translate
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
 $strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function';//to translate
@@ -746,7 +715,6 @@ $strPaperSize = 'Paper size';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strPartialText = 'Partial Texts'; // To translate
 $strPasswordHashing = 'Password Hashing';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPerHour = 'per hour'; //to translate
@@ -872,7 +840,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -918,7 +886,6 @@ $strSorting = 'Sorting';  //to translate
 $strSpanish = 'Spanish';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
 $strSQLExportType = 'Export type';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strSQLParserBugMessage = 'There is a chance that you may have found a bug in the SQL parser. Please examine your query closely, and check that the quotes are correct and not mis-matched. Other possible failure causes may be that you are uploading a file with binary outside of a quoted text area. You can also try your query on the MySQL command line interface. The MySQL server error output below, if there is any, may also help you in diagnosing the problem. If you still have problems or if the parser fails where the command line interface succeeds, please reduce your SQL query input to the single query that causes problems, and submit a bug report with the data chunk in the CUT section below:';  //to translate
 $strSQPBugUnknownPunctuation = 'Unknown Punctuation String';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
@@ -954,7 +921,6 @@ $strTransformation_application_octetstream__hex = 'Displays hexadecimal represen
 $strTransformation_image_jpeg__inline = 'Displays a clickable thumbnail; options: width,height in pixels (keeps the original ratio)';  //to translate
 $strTransformation_image_jpeg__link = 'Displays a link to this image (direct blob download, i.e.).';//to translate
 $strTransformation_image_png__inline = 'See image/jpeg: inline';  //to translate
-$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';//to translate
 $strTransformation_text_plain__external = 'LINUX ONLY: ܺ α׷ ϰ ǥ Է fielddata  մϴ. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';//to translate
 $strTransformation_text_plain__formatted = 'Preserves original formatting of the field. No Escaping is done.';//to translate
 $strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';  //to translate
@@ -987,8 +953,6 @@ $strWestEuropean = 'West European';  //to translate
 $strWildcard = 'wildcard';  //to translate
 $strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window or your browser is blocking cross-window updates of your security settings';  //to translate
 $strWriteRequests = 'Write requests';  //to translate
-$strWritingCommentNotPossible = 'Writing of comment not possible';  //to translate
-$strWritingRelationNotPossible = 'Writing of relation not possible';  //to translate
 
 $strXML = 'XML';//to translate
 
@@ -996,16 +960,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1018,4 +978,73 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
