@@ -1,5 +1,5 @@
 <?php
-/* $Id: latvian-windows-1257.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: latvian-windows-1257.inc.php 10478 2007-07-09 19:41:38Z lem9 $ */
 
 /**
  * Latvian language file by Sandis Jrics <sandisj at parks.lv>
@@ -7,7 +7,7 @@
 
 $charset = 'windows-1257';
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
-$number_thousands_separator = ' ';
+$number_thousands_separator = '';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('baiti', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
@@ -61,7 +61,6 @@ $strAscending = 'Augo secb';
 $strAtBeginningOfTable = 'Tabulas skum';
 $strAtEndOfTable = 'Tabulas beigs';
 $strAttr = 'Atribti';
-$strAutodetect = 'Noteikt automtiski';
 $strAutomaticLayout = 'Automtiskais izvietojums';
 
 $strBack = 'Atpaka';
@@ -150,7 +149,6 @@ $strCreatePdfFeat = 'PDF failu izveide';
 $strCreationDates = 'Izveidoanas/Atjaunoanas/Piekuves datumi';
 $strCriteria = 'Kritrijs';
 $strCroatian = 'Horvtu';
-$strCSVOptions = 'CSV opcijas';
 $strCyrillic = 'Kirilisks';
 $strCzech = 'ehu';
 $strCzechSlovak = 'ehu-Slovku';
@@ -160,7 +158,6 @@ $strDatabase = 'Datubze';
 $strDatabaseEmpty = 'Datubzes nosaukums ir tuks!';
 $strDatabaseExportOptions = 'Datubzu eksporta opcijas';
 $strDatabaseHasBeenDropped = 'Datubze %s tika izdzsta.';
-$strDatabaseNoTable = 'aj datubz nav tabulu!';
 $strDatabases = 'Datubzes';
 $strDatabasesDropped = '%s datubzes tika veiksmgi dzstas.';
 $strDatabasesStats = 'Datubzu statistika';
@@ -222,7 +219,6 @@ $strError = 'Kda';
 $strEscapeWildcards = 'Aizstjjzmes _ un % jaizsarg ar \ priek, lai izmantotu ts burtiski';
 $strEstonian = 'Igauu';
 $strExcelEdition = 'Excel redakcija';
-$strExcelOptions = 'Excel opcijas';
 $strExecuteBookmarked = 'Izpildt iegrmatoto vaicjumu';
 $strExplain = 'Izskaidrot SQL';
 $strExport = 'Eksports';
@@ -232,7 +228,6 @@ $strExtra = 'Ekstras';
 $strFailedAttempts = 'Neveiksmgi minjumi';
 $strFieldHasBeenDropped = 'Lauks %s tika izdzsts';
 $strField = 'Lauks';
-$strFieldsEmpty = ' Lauku skaits ir nulle! ';
 $strFieldsEnclosedBy = 'Lauki iekauti iek';
 $strFieldsEscapedBy = 'Glbjoa (escape) rakstzme ir';
 $strFields = 'Lauki';
@@ -266,7 +261,6 @@ $strHasBeenAltered = 'tika modificta.';
 $strHasBeenCreated = 'tika izveidota.';
 $strHaveToShow = 'Izvlieties vismaz vienu kolonnu attloanai';
 $strHebrew = 'Ebreju';
-$strHexForBinary = 'Lietot heksadecimlo formtu binrajiem laukiem';
 $strHomepageOfficial = 'Oficil phpMyAdmin mjaslapa';
 $strHome = 'Skumlapa';
 $strHostEmpty = 'Hosts nav nordts!';
@@ -284,10 +278,7 @@ $strIndexHasBeenDropped = 'Indekss %s tika izdzsts';
 $strIndex = 'Indekss';
 $strIndexName = 'Indeksa nosaukums&nbsp;:';
 $strIndexType = 'Indeksa tips&nbsp;:';
-$strIndexWarningMultiple = 'Vairk k viena %s atslga tika izveidota kolonnai `%s`';
-$strIndexWarningPrimary = 'PRIMARY un INDEX atslgas nevar abas reiz tikt uzliktas kolonnai `%s`';
 $strIndexWarningTable = 'Problmas ar indeksiem tabul `%s`';
-$strIndexWarningUnique = 'UNIQUE un INDEX atslgas nevar abas reiz tikt uzliktas kolonnai `%s`';
 $strInnodbStat = 'InnoDB statuss';
 $strInsecureMySQL = 'Jsu konfigurcijas fails satur iestdjumus (lietotjs "root" bez paroles), kas atbilst noklustajam MySQL privilitajam lietotjam. Jsu MySQL serveris strd ar o noklusto variantu, ir atvrts uzbrukumiem, un Jums tiem jaiztaisa is drobas caurums.';
 $strInsertAsNewRow = 'Ievietot k jaunu rindu';
@@ -316,7 +307,6 @@ $strLatexContinued = '(turpinjums)';
 $strLatexIncludeCaption = 'Iekaut tabulas virsrakstu';
 $strLatexLabel = 'Etietes atslga';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX opcijas';
 $strLatexStructure = 'Tabulas __TABLE__ struktra';
 $strLatvian = 'Latvieu';
 $strLengthSet = 'Garums/Vrtbas*';
@@ -574,7 +564,6 @@ $strSpaceUsage = 'Diska vietas lietoana';
 $strSpanish = 'Spu';
 $strSplitWordsWithSpace = 'Vrdi ir atdalti ar tukumu (" ").';
 $strSQLExportType = 'Eksporta veids';
-$strSQLOptions = 'SQL opcijas';
 $strSQLParserBugMessage = 'Iespjams, ka Js esat atradui kdu SQL interpretator. Ldzu apskatiet Jsu vaicjumu citgk, un prbaudiet, ka pdias ir pareizas un nav sajauktas. Cits kdas iemesls var bt tas, ka Js atstjt failu ar binro vrtbu rpus pdis iekaut teksta lauka. Js varat ar izmint savu vaicjumu MySQL komandrindas interfeis. MySQL servera kdas paziojums zemk, ja tds ir, var ar paldzt Jums diagnostict problmu. Ja problma paliek, vai ar iek phpMyAdmin kda ir, bet komandrind nav, ldzu samaziniet Jsu SQL vaicjumu ldz vienkram vaicjumam kas izsauc problmas, un atstiet mums ziojumu par kdu, iekaujot taj datus no IZGRIEZT sekcijas zemk:';
 $strSQLParserUserError = 'Izkats, ka Jsu SQL vaicajum ir kda. MySQL servera kdas pazinojums zemk, ja tds ir, var ar paldzet Jums diagnostict problmu.';
 $strSQLQuery = 'SQL vaicjums';
@@ -715,7 +704,6 @@ $strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"'
 $strCopy = 'Copy';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 
 $strDataPages = 'Pages containing data';  //to translate
 $strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
@@ -743,9 +731,7 @@ $strGeneratePassword = 'Generate Password';  //to translate
 
 $strHandler = 'Handler';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
@@ -776,11 +762,9 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
 
@@ -810,7 +794,6 @@ $strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
 
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
@@ -906,7 +889,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -945,7 +928,6 @@ $strSkipQueries = 'Number of records(queries) to skip from start';  //to transla
 $strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 $strSorting = 'Sorting';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
@@ -980,16 +962,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1005,7 +983,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1050,4 +1027,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
