@@ -1,9 +1,9 @@
 <?php
-/* $Id: polish-windows-1250.inc.php 9853 2007-01-19 18:14:44Z lem9 $ */
+/* $Id: polish-windows-1250.inc.php 10478 2007-07-09 19:41:38Z lem9 $ */
 
 $charset = 'windows-1250';
 $text_dir = 'ltr';
-$number_thousands_separator = ' ';
+$number_thousands_separator = '';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('bajtw', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
@@ -61,7 +61,6 @@ $strAscending = 'Rosnco';
 $strAtBeginningOfTable = 'Na pocztku tabeli';
 $strAtEndOfTable = 'Na kocu tabeli';
 $strAttr = 'Atrybuty';
-$strAutodetect = 'Rozpoznaj automatycznie';
 $strAutomaticLayout = 'Ukad automatyczny';
 
 $strBack = 'Powrt';
@@ -172,8 +171,6 @@ $strCreationDates = 'Daty utworzenia/aktualizacji/sprawdzenia';
 $strCriteria = 'Kryteria';
 $strCroatian = 'Chorwacki';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Opcje CSV';
-$strCSVOptions = 'Opcje CSV';
 $strCyrillic = 'Cyrylica';
 $strCzech = 'Czeski';
 $strCzechSlovak = 'Czesko-sowacki';
@@ -183,7 +180,6 @@ $strDatabase = 'Baza danych';
 $strDatabaseEmpty = 'Nazwa bazy danych jest pusta!';
 $strDatabaseExportOptions = 'Opcje eksportu bazy danych';
 $strDatabaseHasBeenDropped = 'Baza danych %s zostaa usunita.';
-$strDatabaseNoTable = 'Ta baza danych nie zawiera adnej tabeli!';
 $strDatabases = 'Bazy danych';
 $strDatabasesDropped = '%s baz danych zostao pomylnie usunitych.';
 $strDatabasesStatsDisable = 'Wycz statystyki';
@@ -257,7 +253,6 @@ $strEscapeWildcards = 'Aby uy symboli wieloznacznych _ i % w znaczeniu dosownym,
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estoski';
 $strExcelEdition = 'Wydanie Excela';
-$strExcelOptions = 'Opcje Excela';
 $strExecuteBookmarked = 'Wykonaj zapamitanego zapytania';
 $strExplain = 'Wyjanij SQL';
 $strExport = 'Eksport';
@@ -268,7 +263,6 @@ $strExtra = 'Dodatkowo';
 $strFailedAttempts = 'Nieudane prby';
 $strFieldHasBeenDropped = 'Pole %s zostao usunite';
 $strField = 'Pole';
-$strFieldsEmpty = ' Liczba pl jest pusta! ';
 $strFieldsEnclosedBy = 'Pola zawarte w';
 $strFieldsEscapedBy = 'Pola poprzedzone przez';
 $strFields = 'Pola';
@@ -315,15 +309,12 @@ $strHasBeenAltered = 'zostao zamienione.';
 $strHasBeenCreated = 'zostao utworzone.';
 $strHaveToShow = 'Naley wybra przynajmniej jedn kolumn do wywietlenia';
 $strHebrew = 'Hebrajski';
-$strHexForBinary = 'Uyj liczb szesnastkowych w przypadku pl binarnych';
 $strHomepageOfficial = 'Oficjalna strona phpMyAdmina';
 $strHome = 'Wejcie';
 $strHostEmpty = 'Brak nazwy hosta!';
 $strHost = 'Host';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Opcje eksportu do formatu Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Opcje eksportu do formatu Microsoft Word 2000';
 $strHungarian = 'Wgierski';
 
 $strIcelandic = 'Islandzki';
@@ -341,10 +332,7 @@ $strIndexHasBeenDropped = 'Klucz %s zosta usunity';
 $strIndex = 'Indeks';
 $strIndexName = 'Nazwa indeksu :';
 $strIndexType = 'Rodzaj indeksu :';
-$strIndexWarningMultiple = 'Dla kolumny `%s` zostao utworzonych wiele indeksw';
-$strIndexWarningPrimary = 'Klucze PRIMARY i INDEX nie powinny dotyczy tej samej kolumny `%s`';
 $strIndexWarningTable = 'Problemy z indeksami tabeli `%s`';
-$strIndexWarningUnique = 'Klucze UNIQUE i INDEX nie powinny dotyczy tej samej kolumny `%s`';
 $strInnoDBAutoextendIncrementDesc = 'Rozmiar o jaki automatycznie powikszy si tabela, kiedy zostanie zapeniona.';
 $strInnoDBAutoextendIncrement = 'Przyrost autoextend';
 $strInnoDBBufferPoolSizeDesc = 'Ilo pamici, ktrej InnoDB uywa do buforowania danych i indeksw swoich tabel.';
@@ -390,7 +378,6 @@ $strKill = 'Unicestwij';
 $strKorean = 'Koreaski';
 
 $strLandscape = 'Orientacja pozioma';
-$strLanguageFileNotFound = 'Nie znaleziono pliku jzykowego "%1$s".';
 $strLanguage = 'Jzyk';
 $strLanguageUnknown = 'Nieznany jzyk: %1$s.';
 $strLatchedPages = 'Stron zatrzanitych';
@@ -401,11 +388,9 @@ $strLatexContinued = '(kontynuacja)';
 $strLatexIncludeCaption = 'Zacz nagwek tabeli';
 $strLatexLabel = 'Etykieta klucza';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Opcje LaTeX-a';
 $strLatexStructure = 'Struktura tabeli __TABLE__';
 $strLatvian = 'otewski';
 $strLDI = 'CSV przy uyciu LOAD DATA';
-$strLDIImportOptions = 'Opcje importu CSV przy uyciu LOAD DATA';
 $strLDILocal = 'Uyj sowa kluczowego LOCAL';
 $strLengthSet = 'Dugo/Wartoci*';
 $strLimitNumRows = 'rekordw na stronie';
@@ -506,8 +491,6 @@ $strNumTables = 'Tabele';
 
 $strOK = 'OK';
 $strOpenDocumentSpreadsheet = 'arkusz kalkulacyjny w formacie Open Document';
-$strOpenDocumentSpreadsheetOptions = 'opcje arkusza kalkulacyjnego w formacie Open Document';
-$strOpenDocumentTextOptions = 'Opcje tekstu w formacie Open Document';
 $strOpenDocumentText = 'Tekst w formacie Open Document';
 $strOpenNewWindow = 'Otwrz nowe okno phpMyAdmina';
 $strOperations = 'Operacje';
@@ -530,7 +513,6 @@ $strPasswordNotSame = 'Hasa nie s identyczne!';
 $strPdfDbSchema = 'Schemat bazy danych "%s" - strona %s';
 $strPdfInvalidTblName = 'Tabela "%s" nie istnieje!';
 $strPdfNoTables = 'Brak tabel';
-$strPDFOptions = 'Opcje PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Generuje raport zawierajcy danej pojedynczej tabeli.)';
 $strPDFReportTitle = 'Tytu raportu';
@@ -774,7 +756,7 @@ $strShowStatusKey_readsDescr = 'Liczba fizycznych odczytw blokw indeksw z dysku.
 $strShowStatusKey_write_requestsDescr = 'Liczba da zapisw blokw indeksw to bufora podrcznego.';
 $strShowStatusKey_writesDescr = 'Liczba fizycznych zapisw blokw indeksw na dysk.';
 $strShowStatusLast_query_costDescr = 'Cakowity koszta ostatnio skompilowanego zapytania, wyliczony przez optymalizator zapyta. Przydatny do porwna kosztw rnych planw wykonania tego samego zapytania. Domylna warto 0 oznacza, e jeszcze adne zapytanie nie zostao skompilowane.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'Liczba rekordw oczekujcych na zapisanie w kolejkach INSERT DELAY.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'Liczba rekordw oczekujcych na zapisanie w kolejkach INSERT DELAYED.';
 $strShowStatusOpened_tablesDescr = 'Liczba kiedykolwiek otwartych tabel. Jeli ta warto jest dua, prawdopodobnie wielko pamici podrcznej tabel jest zbyt maa.';
 $strShowStatusOpen_filesDescr = 'Liczba otwartych plikw.';
 $strShowStatusOpen_streamsDescr = 'Liczba otwartych strumieni (uywanych gownie do rejestracji w dzienniku).';
@@ -827,8 +809,6 @@ $strSpanish = 'Hiszpaski';
 $strSplitWordsWithSpace = 'Sowa s rozdzielane znakiem spacji (" ").';
 $strSQLCompatibility = 'Tryb zgodnoci SQL';
 $strSQLExportType = 'Rodzaj eksportu';
-$strSQLImportOptions = 'Opcje SQL';
-$strSQLOptions = 'Opcje SQL';
 $strSQLParserBugMessage = 'Istnieje szansa, e wanie znaleziono bd w analizatorze skadni SQL. Prosz zbada bliej swoje zapytanie i sprawdzi, czy cudzysowy s poprawne i dobrze sparowane. Inn moliw przyczyn niepowodzenia moe by wysyanie pliku ze znakami binarnymi poza obszarem tekstu ujtego w cudzysowy. Mona rwnie sprawdzi zapytanie SQL poprzez lini polece MySQL-a. W znalezieniu przyczyny problemu moe pomc take - jeli si pojawi - poniszy opis bdu serwera MySQL. Jeli nadal wystpuj z problemy lub analizator skadni zgasza usterk a linia polece - nie, ogranicz sekwencj zapyta SQL do pojedynczego, ktre powoduje problemy i zgo bd, doczajc fragment danych zawarty w poniszej sekcji TNIJ:';
 $strSQLParserUserError = 'Wyglda na to, e w twoim zapytaniu SQL jest bd. W znalezieniu przyczyny problemu moe pomc take - jeli si pojawi - poniszy opis bdu serwera MySQL.';
 $strSQLQuery = 'zapytanie SQL';
@@ -849,7 +829,6 @@ $strStrucCSV = 'Dane CSV';
 $strStrucData = 'Struktura i dane';
 $strStrucExcelCSV = 'CSV dla MS Excel';
 $strStrucNativeExcel = 'Dane w formacie macierzystym MS Excela';
-$strStrucNativeExcelOptions = 'Opcje eksportu do macierzystego formatu Excela';
 $strStrucOnly = 'Tylko struktura';
 $strStructPropose = 'Analiza zawartoci';
 $strStructure = 'Struktura';
@@ -965,7 +944,6 @@ $strWithChecked = 'Zaznaczone:';
 $strWriteRequests = 'da zapisu';
 $strWrongUser = 'Bdne pola uytkownik/haso. Brak dostpu.';
 
-$strXMLOptions = 'Opcje formatu XML';
 $strXML = 'XML';
 
 $strYes = 'Tak';
@@ -976,7 +954,6 @@ $strZip = '".zip"';
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1021,4 +998,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
