@@ -1,5 +1,5 @@
 <?php
-/* $Id: serbian_latin-utf-8.inc.php,v 2.105 2005/10/30 10:03:50 nijel Exp $ */
+/* $Id: serbian_latin-utf-8.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /**
  * Translated by:
@@ -10,8 +10,6 @@
 $charset = 'utf-8';
 $allow_recoding = TRUE;
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
@@ -25,7 +23,6 @@ $datefmt = '%d. %B %Y. u %H:%M';
 $timespanfmt = '%s dana, %s sati, %s minuta i %s sekundi';
 
 $strAbortedClients = 'Prekinuto';
-$strAbsolutePathToDocSqlDir = 'Unesite kompletnu putanju do direktorijuma docSQL na veb serveru';
 $strAccessDeniedExplanation = 'phpMyAdmin je pokušao da se poveže na MySQL server, ali je server odbio povezivanje. Proverite naziv domaćina, korisničko ime i lozinku u config.inc.php i uverite se da odgovaraju podacima koje ste dobili od administratora MySQL servera.';
 $strAccessDenied = 'Pristup odbijen';
 $strAction = 'Akcija';
@@ -33,12 +30,8 @@ $strAddAutoIncrement = 'Dodaj AUTO_INCREMENT vrednost';
 $strAddConstraints = 'Dodaj ograničenja';
 $strAddDeleteColumn = 'Dodaj/obriši kolonu';
 $strAddDeleteRow = 'Dodaj/obriši polje za kriterijum';
-$strAddDropDatabase = 'Dodaj DROP DATABASE';
-$strAddedColumnComment = 'Dodat je komentar koloni';
-$strAddedColumnRelation = 'Dodata je relacija koloni';
 $strAddFields = 'Dodaj %s polja';
 $strAddHeaderComment = 'Dodaj komentar u zaglavlje (\\n razdvaja linije)';
-$strAddIfNotExists = 'Dodaj \'IF NOT EXISTS\'';
 $strAddIntoComments = 'Dodaj u komentare';
 $strAddNewField = 'Dodaj novo polje';
 $strAddPrivilegesOnDb = 'Dodaj privilegije na sledećoj bazi';
@@ -72,7 +65,6 @@ $strAscending = 'Rastući';
 $strAtBeginningOfTable = 'Na početku tabele';
 $strAtEndOfTable = 'Na kraju tabele';
 $strAttr = 'Atributi';
-$strAutodetect = 'automatski';
 $strAutomaticLayout = 'Automatski raspored';
 
 $strBack = 'Nazad';
@@ -171,7 +163,6 @@ $strCreatePdfFeat = 'Pravljenje PDF-ova';
 $strCreationDates = 'Datumi kreiranja/ažuriranja/provere';
 $strCriteria = 'Kriterijum';
 $strCroatian = 'Hrvatski';
-$strCSVOptions = 'CSV opcije';
 $strCyrillic = 'Ćirilični';
 $strCzech = 'Češki';
 $strCzechSlovak = 'Češko-slovački';
@@ -181,7 +172,6 @@ $strDatabase = 'Baza podataka';
 $strDatabaseEmpty = 'Ime baze nije zadato!';
 $strDatabaseExportOptions = 'Opcije za izvoz baze';
 $strDatabaseHasBeenDropped = 'Baza %s je odbačena.';
-$strDatabaseNoTable = 'Baza ne sadrži tabele!';
 $strDatabases = 'Baze';
 $strDatabasesDropped = '%s baza je uspešno odbačeno.';
 $strDatabasesStatsDisable = 'Isključi statistike';
@@ -194,15 +184,6 @@ $strDataPages = 'Strane sa podacima';
 $strData = 'Podaci';
 $strDBComment = 'Komentar baze:';
 $strDBCopy = 'Kopiraj bazu u';
-$strDBGContextID = 'Kontekst ID';
-$strDBGContext = 'Kontekst';
-$strDBGHits = 'Pogodaka';
-$strDBGLine = 'Linija';
-$strDBGMaxTimeMs = 'Max vreme, ms';
-$strDBGMinTimeMs = 'Min vreme, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Vreme/pogodak, ms';
-$strDBGTotalTimeMs = 'Ukupno vreme, ms';
 $strDbPrivileges = 'Privilegije vezane za bazu';
 $strDBRename = 'Preimenuj bazu u';
 $strDbSpecific = 'Specifično za bazu';
@@ -232,7 +213,6 @@ $strDocu = 'Dokumentacija';
 $strDoYouReally = 'Da li stvarno hoćete da ';
 $strDropDatabaseStrongWarning = 'Ovim ćete UNIŠTITI kompletnu bazu podataka!';
 $strDrop = 'Odbaci';
-$strDropSelectedDatabases = 'Odbaci izabrane baze';
 $strDropUsersDb = 'Odbaci baze koje se zovu isto kao korisnici.';
 $strDumpingData = 'Prikaz podataka tabele';
 $strDumpSaved = 'Sadržaj baze je sačuvan u datoteku %s.';
@@ -260,7 +240,6 @@ $strError = 'Greška';
 $strEscapeWildcards = 'Pre džokera _ i % treba staviti znak \ ako ih koristite samostalno';
 $strEstonian = 'Estonski';
 $strExcelEdition = 'Excel izdanje';
-$strExcelOptions = 'Excel opcije';
 $strExecuteBookmarked = 'Izvrši upamćen upit';
 $strExplain = 'Objasni SQL';
 $strExport = 'Izvoz';
@@ -270,16 +249,14 @@ $strExtra = 'Dodatno';
 $strFailedAttempts = 'Neuspelih pokušaja';
 $strFieldHasBeenDropped = 'Polje %s je obrisano';
 $strField = 'Polje';
-$strFieldsEmpty = ' Broj polja je nula! ';
 $strFieldsEnclosedBy = 'Polja ograničena sa';
 $strFieldsEscapedBy = 'Escape karakter &nbsp; &nbsp; &nbsp;';
 $strFields = 'Polja';
 $strFieldsTerminatedBy = 'Polja razdvojena sa';
 $strFileAlreadyExists = 'Datoteka %s već postoji na serveru, promenite ime datoteke ili uključite opciju prepisivanja.';
 $strFileCouldNotBeRead = 'Datoteku nije moguće pročitati';
-$strFileNameTemplate = 'Šablon imena datoteke';
-$strFileNameTemplateHelp = 'Koristi __DB__ za ime baze, __TABLE__ za ime tabele  i %sbilo koju strftime%s opciju za specifikaciju vremena, i ekstenzija će automatski biti dodata. Sav ostali tekst biće sačuvan.';
 $strFileNameTemplateRemember = 'zapamti šablon';
+$strFileNameTemplate = 'Šablon imena datoteke';
 $strFixed = 'sređeno';
 $strFlushPrivilegesNote = 'Napomena: phpMyAdmin uzima privilegije korisnika direktno iz MySQL tabela privilegija. Sadržaj ove tabele može se razlikovati od privilegija koje server koristi ako su vršene ručne izmene. U tom slučaju %sponovo učitajte privilegije%s pre nego što nastavite.';
 $strFlushTable = 'Osveži tabelu ("FLUSH")';
@@ -308,15 +285,12 @@ $strHasBeenAltered = 'je promenjen(a).';
 $strHasBeenCreated = 'je kreiran(a).';
 $strHaveToShow = 'Morate izabrati bar jednu kolonu za prikaz';
 $strHebrew = 'Hebrejski';
-$strHexForBinary = 'Koristi heksadecimalno za binarna polja';
 $strHomepageOfficial = 'phpMyAdmin veb sajt';
 $strHome = 'Početna strana';
 $strHost = 'Domaćin';
 $strHostEmpty = 'Ime domaćina je prazno!';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Opcije izvoza u Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Opcije izvoza u Microsoft Word 2000';
 $strHungarian = 'Mađarski';
 
 $strIcelandic = 'Islandski';
@@ -324,19 +298,13 @@ $strId = 'ID';
 $strIdxFulltext = 'Tekst ključ';
 $strIgnore = 'Ignoriši';
 $strIgnoreInserts = 'Ignoriši duplikate pri umetanju';
-$strIgnoringFile = 'Ignorišem datoteku %s';
-$strImportDocSQL = 'Uvoz docSQL datoteka';
 $strImportFiles = 'Uvoz datoteka';
-$strImportFinished = 'Uvoz završen';
 $strIndexes = 'Ključevi';
 $strIndexHasBeenDropped = 'Ključ %s je obrisan';
 $strIndex = 'Ključ';
 $strIndexName = 'Ime ključa :';
 $strIndexType = 'Tip ključa :';
-$strIndexWarningMultiple = 'Više od jednog %s ključa je napravljeno za kolonu `%s`';
-$strIndexWarningPrimary = 'PRIMARY i INDEX ključevi ne bi trebali da budu istovremeno postavljeni za kolonu `%s`';
 $strIndexWarningTable = 'Problem pri indeksiranju tabele `%s`';
-$strIndexWarningUnique = 'UNIQUE i INDEX ključevi ne bi trebali da budu istovremeno postavljeni za kolonu `%s`';
 $strInnoDBAutoextendIncrementDesc = ' Veličina koraka proširenja veličine tabela koje se automatski proširuju kada se napune.';
 $strInnoDBAutoextendIncrement = 'Korak automatskog proširenja';
 $strInnoDBBufferPoolSizeDesc = 'Veličina memorijskog prihvatnika koje InnoDB koristi za keširanje podataka i indeksa svojih tabela.';
@@ -350,7 +318,6 @@ $strInsecureMySQL = 'Vaša konfiguraciona datoteka sadrži podešavanja (root be
 $strInsertAsNewRow = 'Unesi kao novi red';
 $strInsertedRowId = 'ID umetnutih redova:';
 $strInsertedRows = 'Uneseno redova:';
-$strInsertNewRow = 'Unesi novi red';
 $strInsert = 'Novi zapis';
 $strInternalNotNecessary = '* Unutrašnja relacija nije neophodna kada postoji i u InnoDB.';
 $strInternalRelations = 'Unutrašnje relacije';
@@ -379,7 +346,6 @@ $strLatexContinued = '(nastavljeno)';
 $strLatexIncludeCaption = 'Uključi komentar tabele';
 $strLatexLabel = 'Oznaka ključa';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX opcije';
 $strLatexStructure = 'Struktura tabele __TABLE__';
 $strLatvian = 'Letonski';
 $strLengthSet = 'Dužina/Vrednost*';
@@ -407,7 +373,7 @@ $strMIME_description = 'Opis';
 $strMIME_MIMEtype = 'MIME-tipovi';
 $strMIME_nodescription = 'Nema opisa za ovu transformaciju.<br />Molimo pitajte autora šta %s radi.';
 $strMIME_transformation_note = 'Za listu dostupnih opcija transformacije i njihove transformacije MIME-tipova, kliknite na %sopise transformacija%s';
-$strMIME_transformation_options_note = 'Molimo unesite vrednosti za opcije transformacije koristeći ovaj oblik: \'a\',\'b\',\'c\'...<br />Ako treba da unesete obrnutu kosu crtu ("\\") ili apostrof ("\'") u te vrednosti, stavite obrnutu kosu crtu ispred njih (na primer \'\\\\xyz\' ili \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Molimo unesite vrednosti za opcije transformacije koristeći ovaj oblik: \'a\', 100, b,\'c\'...<br />Ako treba da unesete obrnutu kosu crtu ("\\") ili apostrof ("\'") u te vrednosti, stavite obrnutu kosu crtu ispred njih (na primer \'\\\\xyz\' ili \'a\\\'b\').';
 $strMIME_transformation_options = 'Opcije transformacije';
 $strMIME_transformation = 'Tranformacije čitača';
 $strMIMETypesForTable = 'MIME TIPOVI ZA TABELU';
@@ -433,9 +399,7 @@ $strMyISAMSortBufferSizeDesc = 'Prihvatnik koji se alocira pri sortiranju MyISAM
 $strMyISAMSortBufferSize = 'Veličina prihvatnika za sortiranje';
 $strMySQLCharset = 'MySQL set karaktera';
 $strMySQLConnectionCollation = 'Sortiranje za MySQL vezu';
-$strMySQLReloaded = 'MySQL ponovo pokrenut.';
 $strMySQLSaid = 'MySQL reče: ';
-$strMySQLServerProcess = 'MySQL %pma_s1% pokrenut na %pma_s2%, prijavljen kao %pma_s3%';
 $strMySQLShowProcess = 'Prikaži listu procesa';
 $strMySQLShowStatus = 'Prikaži MySQL informacije o toku rada';
 $strMySQLShowVars = 'Prikaži MySQL sistemske promenljive';
@@ -553,6 +517,7 @@ $strPrivDescUpdate = 'Dozvoljava izmenu podataka.';
 $strPrivDescUsage = 'Nema privilegija.';
 $strPrivileges = 'Privilegije';
 $strPrivilegesReloaded = 'Privilegije su uspešno ponovo učitane.';
+$strProcesses = 'Procesi';
 $strProcesslist = 'Lista procesa';
 $strPutColNames = 'Stavi imena polja u prvi red';
 
@@ -577,9 +542,7 @@ $strRelationNotWorking = 'Dodatne mogućnosti za rad sa povezanim tabelama su is
 $strRelationsForTable = 'RELACIJE TABELE';
 $strRelations = 'Relacije';
 $strRelationView = 'Relacioni pogled';
-$strReloadFailed = 'Ponovno pokretanje MySQL-a nije uspelo.';
 $strReloadingThePrivileges = 'Ponovo učitavam privilegije';
-$strReloadMySQL = 'Ponovo pokreni MySQL';
 $strRemoveSelectedUsers = 'Ukloni izabrane korisnike';
 $strRenameDatabaseOK = 'Baza %s je preimenovana u %s';
 $strRenameTableOK = 'Tabeli %s promenjeno ime u %s';
@@ -636,7 +599,6 @@ $strServerNotResponding = 'Server ne odgovara';
 $strServer = 'Server';
 $strServerStatus = 'Informacije o toku rada';
 $strServerStatusUptime = 'Ovaj MySQL server radi već %s. Pokrenut je %s.';
-$strServerTabProcesslist = 'Procesi';
 $strServerTabVariables = 'Promenljive';
 $strServerTrafficNotes = '<b>Saobraćaj servera</b>: Tabele pokazuju statistike mrežnog saobraćaja na ovom MySQL serveru od njegovog pokretanja.';
 $strServerVars = 'Serverske promenljive i podešavanja';
@@ -665,9 +627,7 @@ $strSort = 'Sortiranje';
 $strSpaceUsage = 'Zauzeće';
 $strSpanish = 'Španski';
 $strSplitWordsWithSpace = 'Reči se odvajaju razmakom (" ").';
-$strSQLExportCompatibility = 'Kompatibilnost SQL izvoza';
 $strSQLExportType = 'Tip izvoza';
-$strSQLOptions = 'SQL opcije';
 $strSQLParserBugMessage = 'Postoji mogućnost da ste pronašli bag u SQL parseru. Molimo ispitajte svoj upit pažljivo, i proverite da su navodnici ispravni i da ne nedostaju. Ostali mogući razlozi greške mogu biti da ste poslali binarnu datoteku van oblasti za običan tekst. Možete probati svoj upit u MySQL sučelju komandne linije. Donja poruka o grešci MySQL servera, ako je ima, može vam pomoći u otkrivanju problema. Ako i dalje imate probleme ili ako parser ne uspeva tamo gde uspeva sučelje komandne linije, svedite svoj SQL upit na jedan jedini upit koji stvara probleme i pošaljite nam izveštaj o grešci sa delom koda u donjoj REZ sekciji:';
 $strSQLParserUserError = 'Izgleda da postoji greška u vašem SQL upitu. Ovde je poruka o greški MySQL servera, koja vam može pomoći u otkrivanju problema';
 $strSQLQuery = 'SQL upit';
@@ -685,7 +645,6 @@ $strStorageEngine = 'Pogon skladištenja';
 $strStorageEngines = 'Pogoni skladištenja';
 $strStrucCSV = 'CSV format';
 $strStrucData = 'Struktura i podaci';
-$strStrucDrop = 'Dodaj \'DROP TABLE\'';
 $strStrucExcelCSV = 'CSV za MS Excel';
 $strStrucNativeExcel = 'Izvorni MS Excel podaci';
 $strStrucOnly = 'Samo struktura';
@@ -709,14 +668,12 @@ $strTableOptions = 'Opcije tabele';
 $strTables = '%s tabela';
 $strTableStructure = 'Struktura tabele';
 $strTable = 'Tabela';
-$strTableType = 'Tip tabele';
 $strTakeIt = 'preuzmi';
 $strTblPrivileges = 'Privilegije vezane za tabele';
 $strTextAreaLength = 'Zbog njehove veličine, polje<br />možda nećete moći da izmenite';
 $strThai = 'Tajski';
 $strTheme = 'Tema / stil';
 $strThisHost = 'Ovaj server';
-$strThisNotDirectory = 'Ovo nije direktorijum';
 $strThreadSuccessfullyKilled = 'Proces %s je uspešno prekinut.';
 $strTime = 'Vreme';
 $strToggleScratchboard = 'Uključi/isključi radnu tablu';
@@ -726,11 +683,10 @@ $strTraditionalChinese = 'Tradicionalni kineski';
 $strTraditionalSpanish = 'Tradicionalni španski';
 $strTraffic = 'Saobraćaj';
 $strTransformation_application_octetstream__download = 'Prikazuje vezu za preuzimanje binarnih podataka za polje. Prva opcija je ime binarne datoteke. Druga opcija je moguće ime polja reda tabele koji sadrži ime datoteke. Ako date drugu opciju, prva mora biti postavljena na prazan string';
-$strTransformation_application_octetstream__hex = 'Prikazuje heksadecimalni prikaz podataka.';
+$strTransformation_application_octetstream__hex = 'Prikazuje heksadecimalni prikaz podataka. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
 $strTransformation_image_jpeg__inline = 'Prikazuje umanjenu sliku na koju je moguće kliknuti; opcije: širina, visina u pikselima (čuva originalni odnos)';
 $strTransformation_image_jpeg__link = 'Prikazuje link ka ovoj slici (npr. direktno preuzimanje iz BLOB-a).';
 $strTransformation_image_png__inline = 'Prikaži JPEG slike na strani';
-$strTransformation_text_plain__dateformat = 'Uzima TIME, TIMESTAMP ili DATETIME polje i formatira ga koristeći lokalni oblik prikazivanja datuma. Prva opcija je ofset (u satima) koji se dodaje vremenskoj oznaci (podrazumevano: 0). Druga opcija je različit format datuma prema parametrima koji su dostupni za PHP-ov strftime().';
 $strTransformation_text_plain__external = 'SAMO LINUX: Pokreće eksternu aplikaciju i popunjava podatke u poljima preko standardnog ulaza. Vraća standardni izlaz aplikacije. Podrazumevano je Tidy, za lepši prikaz HTML koda. Zbog sigurnosnih razloga, morate ručno izmeniti datoteku libraries/transformations/text_plain__external.inc.php i dodati alate koje želite da koristite. Prva opcija je broj programa koje želite da koristite, a druga su parametri programa. Ako se treći parametar postavi na 1 izlaz će biti konvertovan koristeći htmlspecialchars() (podrazumevano je 1). Ako je četvrti parametar postavljen na 1, NOWRAP će biti dodato ćeliji sa sadržajem tako da će izlaz biti prikazan bez izmena. (podrazumevano 1)';
 $strTransformation_text_plain__formatted = 'Čuva originalno formatiranje polja. Escaping se ne vrši.';
 $strTransformation_text_plain__imagelink = 'Prikazuje sliku i link, polje sadrži naziv datoteke; prva opcija je prefiks kao "http://domain.com/", druga opcija je širina u pikselima, treća je visina.';
@@ -786,8 +742,6 @@ $strWildcard = 'džoker';
 $strWindowNotFound = 'Odredišni prozor pretraživača nije mogao da bude ažuriran. Možda ste zatvorili matični prozor, ili vaš pretraživač onemogućava ažuriranje među prozorima zbog sigurnosnih podešavanja';
 $strWithChecked = 'Označeno:';
 $strWriteRequests = 'Zahtevi za upis';
-$strWritingCommentNotPossible = 'Pisanje komentara nije moguće';
-$strWritingRelationNotPossible = 'Upisivanje relacije nije moguće';
 $strWrongUser = 'Pogrešno korisničko ime/lozinka. Pristup odbijen.';
 
 $strXML = 'XML';
@@ -797,42 +751,81 @@ $strYes = 'Da';
 $strZeroRemovesTheLimit = 'Napomena: Postavljanje ovih opcija na 0 (nulu) uklanja ograničenja.';
 $strZip = '"zipovano"';
 
-$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
-$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
-$strCSV = 'CSV';  //to translate
-$strImport = 'Import';  //to translate
-$strImportFormat = 'Format of imported file';  //to translate
-$strFileToImport = 'File to import';  //to translate
-$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
-$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
-$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
-$strPartialImport = 'Partial import';  //to translate
+// To translate:
+$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
 $strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
-$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
-$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
-$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
-$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
-$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
-$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
-$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
-$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
-$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
-$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
+
+$strBookmarkCreated = 'Bookmark %s created';  //to translate
+$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
+$strBrowseDistinctValues = 'Browse distinct values';  //to translate
+
+$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
+$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
+$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
+$strCSV = 'CSV';  //to translate
+
+$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
+
 $strErrorInZipFile = 'Error in ZIP archive:';  //to translate
+$strEsperanto = 'Esperanto';  //to translate
+
+$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
+$strFileNameTemplateDescriptionServer = 'server name';  //to translate
+$strFileNameTemplateDescriptionTable = 'table name';  //to translate
+$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
+$strFileToImport = 'File to import';  //to translate
 $strFlushQueryCache = 'Flush query cache';  //to translate
 $strFlushTables = 'Flush (close) all tables';  //to translate
+
 $strHandler = 'Handler';  //to translate
+
+$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
+$strImportFormat = 'Format of imported file';  //to translate
+$strImport = 'Import';  //to translate
+$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
+$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
+$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
+$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
+$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
+$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
+$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
+$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
+$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
+
 $strJoins = 'Joins';  //to translate
+
 $strKeyCache = 'Key cache';  //to translate
+
+$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
+$strLDI = 'CSV using LOAD DATA';  //to translate
+$strLDILocal = 'Use LOCAL keyword';  //to translate
+
 $strMaxConnects = 'max. concurrent connections';  //to translate
+$strMaximalQueryLength = 'Maximal length of created query';  //to translate
+$strMysqlClientVersion = 'MySQL client version';  //to translate
+
+$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
+$strNumberOfFields = 'Number of fields';  //to translate
+
+$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
+
+$strPartialImport = 'Partial import';  //to translate
+$strPDF = 'PDF';  //to translate
+$strPDFReportTitle = 'Report title';  //to translate
+$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
+$strProtocolVersion = 'Protocol version';  //to translate
+
 $strQueryCache = 'Query cache';  //to translate
+
+$strReloadPrivileges = 'Reload privileges';  //to translate
 $strReplication = 'Replication';  //to translate
+$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
+
 $strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
+$strShowingBookmark = 'Showing bookmark';  //to translate
 $strShowOpenTables = 'Show open tables';  //to translate
 $strShowSlaveHosts = 'Show slave hosts';  //to translate
 $strShowSlaveStatus = 'Show slave status';  //to translate
-$strShowStatusReset = 'Reset';  //to translate
 $strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
 $strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
 $strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
@@ -884,13 +877,13 @@ $strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to t
 $strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
 $strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
 $strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
-$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
 $strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
+$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
 $strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
 $strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
 $strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
-$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
 $strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
+$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
 $strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
 $strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
 $strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
@@ -905,11 +898,11 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
+$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
 $strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
-$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
 $strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
 $strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
@@ -918,11 +911,12 @@ $strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been
 $strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
 $strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
 $strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
+$strShowStatusReset = 'Reset';  //to translate
 $strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
 $strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
 $strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
-$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
 $strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
+$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
 $strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
 $strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
 $strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
@@ -939,23 +933,120 @@ $strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache.
 $strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
 $strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
 $strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
+$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
 $strSorting = 'Sorting';  //to translate
-$strTempData = 'Temporary data';  //to translate
-$strThreads = 'Threads';  //to translate
-$strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDILocal = 'Use LOCAL keyword';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
-$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
+$strSQLCompatibility = 'SQL compatibility mode';  //to translate
+$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
+
 $strTableAlreadyExists = 'Table %s already exists!';  //to translate
+$strTempData = 'Temporary data';  //to translate
+$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
+$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
+$strThemeNotFound = 'Theme %s not found!';  //to translate
+$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
+$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
+$strThreads = 'Threads';  //to translate
+$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
+$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
+$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
 $strTransactionCoordinator = 'Transaction coordinator';  //to translate
-$strNumberOfFields = 'Number of fields';  //to translate
-$strShowingBookmark = 'Showing bookmark';  //to translate
-$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
-$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
-$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
-$strMaximalQueryLength = 'Maximal length of created query';  //to translate
-$strBookmarkCreated = 'Bookmark %s created';  //to translate
-$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
 $strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
-$strEsperanto = 'Esperanto';  //to translate
+
+$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
+$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
+$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
+
+$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
+
+$strQueryResultsOperations = 'Query results operations';  //to translate
+$strAddClause = 'Add %s';  //to translate
+$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
+$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
+$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
+$strCreateUserDatabase = 'Database for user';  //to translate
+$strCreateUserDatabaseNone = 'None';  //to translate
+$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
+$strOpenDocumentText = 'Open Document Text';  //to translate
+$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
+$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
+$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
+$strInvalidTableName = 'Invalid table name';  //to translate
+$strInvalidDatabase = 'Invalid database';  //to translate
+$strServers = 'Servers';  //to translate
+$strDelimiter = 'Delimiter';  //to translate
+$strFunctions = 'Functions';  //to translate
+$strProcedures = 'Procedures';  //to translate
+$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
+$strFontSize = 'Font size';  //to translate
+$strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
