@@ -1,5 +1,5 @@
 <?php
-/* $Id: slovak-iso-8859-2.inc.php,v 2.150 2006/08/09 12:55:39 lem9 Exp $ */
+/* $Id: slovak-iso-8859-2.inc.php 10478 2007-07-09 19:41:38Z lem9 $ */
 
 /* By: lubos klokner <erkac@vault-tec.sk> */
 /* and Ivan Kuriscak <shylauda69@yahoo.com>
@@ -7,7 +7,7 @@
 
 $charset = 'iso-8859-2';
 $text_dir = 'ltr';
-$number_thousands_separator = ' ';
+$number_thousands_separator = '';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('Bajtov', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
@@ -20,7 +20,6 @@ $datefmt = '%d.%B, %Y - %H:%M';
 $timespanfmt = '%s dn, %s hodn, %s mint a %s seknd';
 
 $strAbortedClients = 'Preruen';
-$strAbsolutePathToDocSqlDir = 'Prosm zadajte absoltnu cestu k adresru docSQL na serveri.';
 $strAccessDeniedCreateConfig = 'Pravdepodobn prina je, e neexistuje konfiguran sbor. Na jeho vytvorenie mete poui %1$skonfiguran skript%2$s.';
 $strAccessDeniedExplanation = 'phpMyAdmin sa poksil pripoji k MySQL serveru ale ten spojenie odmietol. Skontrolujte prosm meno serveru, pouvatesk meno a heslo v sbore config.inc.php a s tm, ktor ste dostali o administrtora MySQL servera.';
 $strAccessDenied = 'Prstup zamietnut';
@@ -30,8 +29,6 @@ $strAddClause = 'Prida %s';
 $strAddConstraints = 'Prida obmedzenia';
 $strAddDeleteColumn = 'Prida/Odobra polia stpcov';
 $strAddDeleteRow = 'Prida/Odobra kritria riadku';
-$strAddedColumnComment = 'Pridan komentr k stpcu';
-$strAddedColumnRelation = 'Pridan vzah pre stpec';
 $strAddFields = 'Prida %s poloiek';
 $strAddHeaderComment = 'Prida vlastn komentr do hlaviky (\\n oddeuje riadky)';
 $strAddIntoComments = 'Prida do komentrov';
@@ -68,7 +65,6 @@ $strAscending = 'Vzostupne';
 $strAtBeginningOfTable = 'Na zaiatku tabuky';
 $strAtEndOfTable = 'Na konci tabuky';
 $strAttr = 'Atribty';
-$strAutodetect = 'Automaticky zisti';
 $strAutomaticLayout = 'Automatick rozvrhnutie';
 
 $strBack = 'Sp';
@@ -179,8 +175,6 @@ $strCreationDates = 'Dtum vytvorenia, poslednej zmeny a kontroly';
 $strCriteria = 'Kritria';
 $strCroatian = 'Chorvtsky';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Monosti CSV';
-$strCSVOptions = 'Nastavenia pre CSV';
 $strCyrillic = 'Cyrilika';
 $strCzech = 'esky';
 $strCzechSlovak = 'etina/Slovenina';
@@ -190,7 +184,6 @@ $strDatabase = 'Databza';
 $strDatabaseEmpty = 'Meno databzy je przdne!';
 $strDatabaseExportOptions = 'Nastavenia exportu databz';
 $strDatabaseHasBeenDropped = 'Databza %s bola zmazan.';
-$strDatabaseNoTable = 'Tto databza neobsahuje iadne tabuky!';
 $strDatabases = 'Databzy';
 $strDatabasesDropped = 'spene zruench databz: %s.';
 $strDatabasesStatsDisable = 'Skry tatistiky';
@@ -203,15 +196,6 @@ $strDataOnly = 'Iba dta';
 $strDataPages = 'Strnky obsahujce dta';
 $strDBComment = 'Komentr k databze: ';
 $strDBCopy = 'Skoprova databzu na';
-$strDBGContextID = 'Kontext ID';
-$strDBGContext = 'Kontext';
-$strDBGHits = 'Zsahov';
-$strDBGLine = 'Riadok';
-$strDBGMaxTimeMs = 'Max. as, ms';
-$strDBGMinTimeMs = 'Min as, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'as/Zsah, ms';
-$strDBGTotalTimeMs = 'Celkov as, ms';
 $strDbPrivileges = 'Oprvnenia pre jednotliv databzy';
 $strDBRename = 'Premenova databzu na';
 $strDbSpecific = 'zvisl na databze';
@@ -273,7 +257,6 @@ $strEscapeWildcards = 'Nhradzujcim znakom _ a % by mal predchdza znak \, pokia i
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estnsky';
 $strExcelEdition = 'Verzia Excelu';
-$strExcelOptions = 'Nastavenia CSV pre Excel';
 $strExecuteBookmarked = 'Spusti obben dopyt';
 $strExplain = 'Vysvetli SQL';
 $strExport = 'Exportova';
@@ -284,7 +267,6 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Nepodarench pokusov';
 $strFieldHasBeenDropped = 'Pole %s bolo odstrnen';
 $strField = 'Pole';
-$strFieldsEmpty = ' Poet pol je przdny! ';
 $strFieldsEnclosedBy = 'Polia uzatvoren';
 $strFieldsEscapedBy = 'Polia uveden pomocou';
 $strFields = 'Polia';
@@ -330,15 +312,12 @@ $strHasBeenAltered = 'bola zmenen.';
 $strHasBeenCreated = 'bola vytvoren.';
 $strHaveToShow = 'Zvolte prosm aspo jeden stpec, ktor chcete zobrazi';
 $strHebrew = 'Hebrejsky';
-$strHexForBinary = 'Binrne pole vypisova v estnstkovej sstave';
 $strHome = 'Domov';
 $strHomepageOfficial = 'Oficilne strnky phpMyAdmin';
 $strHostEmpty = 'Nzov hostitea je przdny!';
 $strHost = 'Hostite';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Nastavenia pre Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Nastavenia pre Microsoft Word 2000';
 $strHungarian = 'Maarsky';
 
 $strIcelandic = 'Islandina';
@@ -347,8 +326,6 @@ $strIdxFulltext = 'Cel text';
 $strIgnoreDuplicates = 'Ignorova opakujce sa riadky';
 $strIgnore = 'Ignorova';
 $strIgnoreInserts = 'Poui IGNORE';
-$strIgnoringFile = 'Ignorujem sbor %s';
-$strImportDocSQL = 'Importova sbory docSQL';
 $strImportFiles = 'Importova sbory';
 $strImportFormat = 'Formt importovanho sboru';
 $strImport = 'Import';
@@ -358,10 +335,7 @@ $strIndexHasBeenDropped = 'Index pre %s bol odstrnen';
 $strIndex = 'Index';
 $strIndexName = 'Meno indexu&nbsp;:';
 $strIndexType = 'Typ indexu&nbsp;:';
-$strIndexWarningMultiple = 'Pre stpec `%s` je vytvoren viac ako jeden %s k';
-$strIndexWarningPrimary = 'Na stpec `%s` by nemal by nastaven PRIMARY a zrove INDEX k';
 $strIndexWarningTable = 'Problmy s indexami v tabuke `%s`';
-$strIndexWarningUnique = 'Na stpec `%s` by nemal by nastaven UNIQUE a zrove INDEX k';
 $strInnoDBAutoextendIncrementDesc = ' Vekos, o ktor je zven automaticky sa zvujci priestor tabuky pri zaplnen.';
 $strInnoDBAutoextendIncrement = 'Navenie pri automatickom zvovan';
 $strInnoDBBufferPoolSizeDesc = 'Vekos pamte, ktor InnoDB pouva pre cachovanie dt a indexov tabuliek.';
@@ -407,7 +381,6 @@ $strKill = 'Zabi';
 $strKorean = 'Krejina';
 
 $strLandscape = 'Na rku';
-$strLanguageFileNotFound = 'Jazykov sbor "%1$s" nebol njden.';
 $strLanguageUnknown = 'Neznmy jazyk: %1$s.';
 $strLatchedPages = 'Uzavretch strnok';
 $strLatexCaption = 'Nadpis tabuky';
@@ -417,11 +390,9 @@ $strLatexContinued = '(pokraovanie)';
 $strLatexIncludeCaption = 'Zahrn nadpis tabuky';
 $strLatexLabel = 'Nvestie';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Nastavenia pre LaTeX';
 $strLatexStructure = 'truktra tabuky __TABLE__';
 $strLatvian = 'Lotystina';
 $strLDI = 'CSV pomocou LOAD DATA';
-$strLDIImportOptions = 'Nastavenia CSV importu pomocou LOAD DATA';
 $strLDILocal = 'Poui kov slovo LOCAL';
 $strLengthSet = 'Dka/Nastavi*';
 $strLimitNumRows = 'zznamov na strnku';
@@ -450,7 +421,7 @@ $strMIME_description = 'Popis';
 $strMIME_MIMEtype = 'MIME typ';
 $strMIME_nodescription = 'Nie je dostupn iadny popis pre tto transformciu.<br />Kontaktujte autora, ktor %s vytra.';
 $strMIME_transformation_note = 'Pre zoznam dostupnch parametrov a ich MIME typov kliknite na %spopisy transformci';
-$strMIME_transformation_options_note = 'Prosm zadajte hodnoty pre parametre transformcie v nasledujcom tvare: \'a\',\'b\',\'c\'...<br />Ak potrebujete poui sptn lomtko ("\") alebo jednoduch vodzovky ("\'") medzi tmito hodnotami, vlote pred nich sptn lomtko (napr. \'\\\\xyz\' alebo \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Prosm zadajte hodnoty pre parametre transformcie v nasledujcom tvare: \'a\', 100, b,\'c\'...<br />Ak potrebujete poui sptn lomtko ("\") alebo jednoduch vodzovky ("\'") medzi tmito hodnotami, vlote pred nich sptn lomtko (napr. \'\\\\xyz\' alebo \'a\\\'b\').';
 $strMIME_transformation_options = 'Parametre transformcie';
 $strMIME_transformation = 'Transformcia pri prehliadan';
 $strMIMETypesForTable = 'MIME TYPY PRE TABUKU';
@@ -521,10 +492,8 @@ $strNumSearchResultsTotal = '<b>Celkovo:</b> <i>%s</i> vskyt(ov)';
 $strNumTables = 'Tabuky';
 
 $strOK = 'OK';
-$strOpenDocumentSpreadsheetOptions = 'Nastavenia pre tabukov procesor Open Document';
 $strOpenDocumentSpreadsheet = 'Tabukov procesor Open Document';
 $strOpenDocumentText = 'Open Document Text';
-$strOpenDocumentTextOptions = 'Nastavenia pre Open Document Text';
 $strOpenNewWindow = 'Otvori nov okno phpMyAdmina';
 $strOperations = 'Opercie';
 $strOperator = 'Opertor';
@@ -546,7 +515,6 @@ $strPasswordNotSame = 'Hesl sa nezhoduj!';
 $strPdfDbSchema = 'Schma databzy "%s"  - Strana %s';
 $strPdfInvalidTblName = 'Tabuka "%s" neexistuje!';
 $strPdfNoTables = 'iadne tabuky';
-$strPDFOptions = 'Nastavenia pre PDF';
 $strPDF = 'PDF';
 $strPDFReportTitle = 'Titulok vpisu';
 $strPerHour = 'za hodinu';
@@ -788,7 +756,7 @@ $strShowStatusKey_readsDescr = 'Poet natan kovho bloku priamo z disku. Ak je tto
 $strShowStatusKey_write_requestsDescr = 'Poet poiadavkov na zpis kovho bloku do vyrovnvacej pamti.';
 $strShowStatusKey_writesDescr = 'Poet fyzickch zpisov kovho bloku na disk.';
 $strShowStatusLast_query_costDescr = 'Celkov nklady na posledn kompilovan prkaz, vypotan optimizrom prkazov. Uiton na porovnvanie nkladov na rzne prkazy pre t ist poiadavku. Prednastaven hodnota 0 znamen, e doposia neboli skompilovan iadne prkazy.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'Poet riadkov akajcich na zpis cez INSERT DELAY.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'Poet riadkov akajcich na zpis cez INSERT DELAYED.';
 $strShowStatusOpened_tablesDescr = 'Poet doposia otvorench tabuliek. Ak je tto hodnota prli vysok, pravdepodobne je vyrovnvacia pam pre tabuky prli mal.';
 $strShowStatusOpen_filesDescr = 'Poet otvorench sborov.';
 $strShowStatusOpen_streamsDescr = 'Poet otvorench streamov (vinou vyuvan na logovanie).';
@@ -842,8 +810,6 @@ $strSpanish = 'panielsky';
 $strSplitWordsWithSpace = 'Slov s rozdelen medzerou (" ").';
 $strSQLCompatibility = 'Reim kompatibility SQL';
 $strSQLExportType = 'Typ vytvorench dopytov';
-$strSQLImportOptions = 'Nastavenia SQL importu';
-$strSQLOptions = 'Nastavenia pre SQL';
 $strSQLParserBugMessage = 'Je mon, e ste nali chybu v SQL syntaktickom analyztore. Preskmajte podrobne SQL dopyt, predovetkm sprvnos umiestnenia vodzoviek. alia monos je, e nahrvate sbor s binrnymi dtami nezapsanmi v vodzovkch. Mete tie vyska poui prkazov riadok MySQL na odstrnenie problmu. Pokial stle mte problmy alebo syntaktick analyztor SQL stle hlsi chybu v dopyte, ktor v prkazovom riadku funguje, prosm pokste sa zredukova dopyt na o najmen, v ktorom sa problm ete vyskytuje a ohlste chybu na strnke phpMyAdmina spolu so sekciou VPIS uveden niie:';
 $strSQLParserUserError = 'Vyskytla sa chyba v SQL dopyte. Niie uveden MySQL vstup (ak je nejak) Vm me pomc odstrni problm';
 $strSQLQuery = 'SQL dopyt';
@@ -864,7 +830,6 @@ $strStrucCSV = 'CSV dta';
 $strStrucData = 'truktru a dta';
 $strStrucExcelCSV = 'CSV pre MS Excel dta';
 $strStrucNativeExcel = 'Natvne dta MS Excel';
-$strStrucNativeExcelOptions = 'Nastavenia pre natvny Excel';
 $strStrucOnly = 'Iba truktru';
 $strStructPropose = 'Navrhn truktru tabuky';
 $strStructure = 'truktra';
@@ -899,7 +864,6 @@ $strThemeNoValidImgPath = 'Nebola njden platn cesta k obrzkom pre vzhad %s!';
 $strThemePathNotFound = 'Nebola njden platn cesta ku vzhadu %s!';
 $strTheme = 'Vzhad';
 $strThisHost = 'Tento pota';
-$strThisNotDirectory = 'Nebol zadan adresr';
 $strThreads = 'Poet vlkien';
 $strThreadSuccessfullyKilled = 'Vlkno %s bol spene zabit.';
 $strTime = 'as';
@@ -918,7 +882,6 @@ $strTransformation_application_octetstream__hex = 'Zobraz dta v ich hexadecimlne
 $strTransformation_image_jpeg__inline = 'Zobraz nhad obrzku s odkazom na obrzok; parametre rka a vka v bodoch (pomer strn obrzku zostane zachovan)';
 $strTransformation_image_jpeg__link = 'Zobraz odkaz na obrzok (napr. stiahnutie poa blob).';
 $strTransformation_image_png__inline = 'Zobraz image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Zobraz dtum alebo as (TIME, TIMESTAMP alebo DATETIME) poda miestneho nastavenia. Prv parameter je posun (v hodinch), ktor bude pridan k zadanmu asu (predvolen je 0). Druh parameter je formtovac reazec pre php funkciu strftime().';
 $strTransformation_text_plain__external = 'PLAT IBA PRE LINUX: Spust extern aplikciu, na jej tandardn vstup pole pole a zobraz vstup programu. Predvolen program je Tidy, ktor pekne sformtuje HTML. Z bezpenostnch dvodov muste rune upravi obsah sboru libraries/transformations/text_plain__external.inc.php a prida do neho povolen aplikcie. Prv parameter je slo aplikcie, ktor chcete poui a druh parametre s parametre tejto aplikcie. Ak je tret parameter nastaven na 1, vstup bude skonvertovan funkciou htmlspecialchars() (predvolen je 1). tvrt parameter v prpade, e je nastaven na 1 prid k vstupnmu textu parameter NOWRAP, m zabezpe zachovanie formtovania (predvolen je 1)';
 $strTransformation_text_plain__formatted = 'Zachov pvodn formtovanie poa tak ako je uloen v databze.';
 $strTransformation_text_plain__imagelink = 'Zobraz obrzok a odkaz z poa obsahujceho odkaz na obrzok. Prv parameter je prefix URL (napr. "http://domena.sk/"), druh a tret parameter uruj rku a vku obrzku.';
@@ -980,11 +943,8 @@ $strWildcard = 'nahradzujci znak';
 $strWindowNotFound = 'Cieov okno prehliadaa nemohlo by aktualizovan. Mono ste zatvorili rodiovsk okno, alebo prehliada blokuje opercie medzi oknami z dvodu bezpenostnch nastaven';
 $strWithChecked = 'Vber:';
 $strWriteRequests = 'Poiadavkov na zpis';
-$strWritingCommentNotPossible = 'Komentr sa ned zapsa';
-$strWritingRelationNotPossible = 'Vzah sa ned zapsa';
 $strWrongUser = 'Zl pouvatesk meno alebo heslo. Prstup zamietnut.';
 
-$strXMLOptions = 'Nastavenia pre XML';
 $strXML = 'XML';
 
 $strYes = 'no';
@@ -998,4 +958,73 @@ $strPDFReportExplanation = '(Generates a report containing the data of a single
 
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
