@@ -1,18 +1,17 @@
 <?php
-/* $Id: swedish-iso-8859-1.inc.php,v 2.127.2.5 2006/03/23 17:42:16 lem9 Exp $ */
+/* $Id: swedish-iso-8859-1.inc.php 10499 2007-07-17 15:13:25Z lem9 $ */
 
 /*
  * Translated by Bjrn T. Hallberg <bjornth at users.sourceforge.net>
  */
 
 $charset = 'iso-8859-1';
+$allow_recoding = TRUE;
 $text_dir = 'ltr';
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'arial, helvetica, geneva, sans-serif';
-$number_thousands_separator = ' ';
+$number_thousands_separator = '';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
-$byteUnits = array('bytes', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB');
+$byteUnits = array('bytes', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');
 
 $day_of_week = array('Sn', 'Mn', 'Tis', 'Ons', 'Tors', 'Fre', 'Lr');
 $month = array('januari', 'februari', 'mars', 'april', 'maj', 'juni', 'juli', 'augusti', 'september', 'oktober', 'november', 'december');
@@ -22,21 +21,17 @@ $datefmt = '%d %B %Y kl %H:%M';
 $timespanfmt = '%s dagar, %s timmar, %s minuter och %s sekunder';
 
 $strAbortedClients = 'Avbrutna';
-$strAbsolutePathToDocSqlDir = 'Ange absolut skvg p webbservern till docSQL-katalog';
-$strAccessDenied = 'tkomst nekad';
 $strAccessDeniedCreateConfig = 'Trolig orsak till detta r att du inte skapade en konfigurationsfil. Du vill kanske anvnda %1$suppsttningsskript%2$s fr att skapa en.';
 $strAccessDeniedExplanation = 'phpMyAdmin frskte skapa en frbindelse till MySQL-servern, men servern nekade uppkopplingen. Kontrollera vrd, anvndarnamn och lsenord i config.inc.php och frvissa dig om att de stmmer verens med informationen frn administratren av MySQL-servern.';
+$strAccessDenied = 'tkomst nekad';
 $strAction = 'tgrd';
 $strAddAutoIncrement = 'Lgg till AUTO_INCREMENT-vrde';
+$strAddClause = 'Lgg till %s';
 $strAddConstraints = 'Lgg till restriktioner';
 $strAddDeleteColumn = 'Lgg till/ta bort fltkolumner';
 $strAddDeleteRow = 'Lgg till/ta bort villkorsrader';
-$strAddDropDatabase = 'Lgg till DROP DATABASE';
-$strAddedColumnComment = 'La till kommentar fr kolumn';
-$strAddedColumnRelation = 'La till relation fr kolumn';
 $strAddFields = 'Lgg till %s flt';
 $strAddHeaderComment = 'Lgg till egen kommentar i huvud (\\n delar rader)';
-$strAddIfNotExists = 'Lgg till IF NOT EXISTS';
 $strAddIntoComments = 'Lgg till i kommentarer';
 $strAddNewField = 'Lgg till flt';
 $strAddPrivilegesOnDb = 'Lgg till privilegier till fljande databas';
@@ -59,6 +54,7 @@ $strAlterOrderBy = 'Sortera om tabellen efter';
 $strAnalyzeTable = 'Analysera tabell';
 $strAnd = 'Och';
 $strAndThen = 'och sedan';
+$strAngularLinks = 'Vinklade lnkar';
 $strAnIndex = 'Ett index har lagts till fr %s';
 $strAnyHost = 'Vilken vrd som helst';
 $strAnyUser = 'Vilken anvndare som helst';
@@ -71,7 +67,6 @@ $strAscending = 'Stigande';
 $strAtBeginningOfTable = 'I brjan av tabellen';
 $strAtEndOfTable = 'I slutet av tabellen';
 $strAttr = 'Attribut';
-$strAutodetect = 'Autodetektera';
 $strAutomaticLayout = 'Automatisk layout';
 
 $strBack = 'Bakt';
@@ -111,6 +106,8 @@ $strBzError = 'phpMyAdmin kunde inte komprimera SQL-satserna p grund av ett tras
 $strBzip = '"bzippad"';
 
 $strCalendar = 'Kalender';
+$strCancel = 'Avbryt';
+$strCanNotLoadExportPlugins = 'Kunde inte ladda export-tillgg. Kontrollera din installation.';
 $strCanNotLoadImportPlugins = 'Kunde inte ladda tillgg fr import. Kontrollera din installation!';
 $strCannotLogin = 'Kan ej logga in p MySQL-server';
 $strCantLoad = 'kan inte ladda %s-tillgg,<br />var god kontrollera PHP-konfigurationen.';
@@ -121,7 +118,6 @@ $strCardinality = 'Kardinalitet';
 $strCaseInsensitive = 'skiftlgesoknsligt';
 $strCaseSensitive = 'skiftlgesknsligt';
 $strCentralEuropean = 'Centraleuropeisk';
-$strChange = 'ndra';
 $strChangeCopyModeCopy = '... behll den gamla.';
 $strChangeCopyModeDeleteAndReload = ' ... ta bort den gamla frn anvndartabellerna och ladda om privilegierna eftert.';
 $strChangeCopyModeJustDelete = ' ... ta bort den gamla frn anvndartabellerna.';
@@ -129,6 +125,7 @@ $strChangeCopyModeRevoke = ' ... upphv alla aktiva privilegier frn dan gamla och
 $strChangeCopyMode = 'Skapa en ny anvndare med samma privilegier och ...';
 $strChangeCopyUser = 'ndra inloggningsinformation / Kopiera anvndare';
 $strChangeDisplay = 'Vlj flt som ska visas';
+$strChange = 'ndra';
 $strChangePassword = 'Byt lsenord';
 $strCharsetOfFile = 'Filens teckenuppsttning:';
 $strCharsetsAndCollations = 'Teckenuppsttningar och kollationeringar';
@@ -158,6 +155,7 @@ $strConnectionError = 'Kan ej skapa frbindelse: ogiltiga instllningar.';
 $strConnections = 'Uppkopplingar';
 $strConstraintsForDumped = 'Restriktioner fr dumpade tabeller';
 $strConstraintsForTable = 'Restriktioner fr tabell';
+$strControluserFailed = 'Uppkoppling fr controluser enligt din konfiguration misslyckades.';
 $strCookiesRequired = 'Kakor (cookies) mste tilltas fr att g vidare.';
 $strCopyDatabaseOK = 'Databas %s har kopierats till %s';
 $strCopy = 'Kopiera';
@@ -172,13 +170,17 @@ $strCreateNewDatabase = 'Skapa ny databas';
 $strCreateNewTable = 'Skapa ny tabell i databas %s';
 $strCreatePage = 'Skapa en ny sida';
 $strCreatePdfFeat = 'Skapande av PDF-sidor';
+$strCreateRelation = 'Skapa relation';
 $strCreate = 'Skapa';
+$strCreateTable  = 'Skapa tabell';
+$strCreateUserDatabase = 'Databas fr anvndare';
+$strCreateUserDatabaseName = 'Skapa databas med samma namn och ge alla privilegier';
+$strCreateUserDatabaseNone = 'Ingen';
+$strCreateUserDatabaseWildcard = 'Ge alla privilegier till namn med jokertecken (username\_%)';
 $strCreationDates = 'Skapad/Uppdaterad/Kontrollerad datum';
 $strCriteria = 'Villkor';
 $strCroatian = 'Kroatisk';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'CSV-alternativ';
-$strCSVOptions = 'CSV-alternativ';
 $strCyrillic = 'Kyrillisk';
 $strCzechSlovak = 'Tjeckisk-Slovakisk';
 $strCzech = 'Tjeckisk';
@@ -188,7 +190,6 @@ $strDatabase = 'Databas';
 $strDatabaseEmpty = 'Databasens namn r tomt!';
 $strDatabaseExportOptions = 'Exportalternativ fr databas';
 $strDatabaseHasBeenDropped = 'Databasen %s har tagits bort.';
-$strDatabaseNoTable = 'Denna databas innehller ingen tabell!';
 $strDatabases = 'Databaser';
 $strDatabasesDropped = '%s databaser har tagits bort.';
 $strDatabasesStats = 'Databas-statistik';
@@ -201,15 +202,7 @@ $strDataOnly = 'Enbart data';
 $strDataPages = 'Sidor innehllande data';
 $strDBComment = 'Databaskommentar: ';
 $strDBCopy = 'Kopiera databas till';
-$strDBGContextID = 'Innehlls-ID';
-$strDBGContext = 'Innehll';
-$strDBGHits = 'Trffar';
-$strDBGLine = 'Rad';
-$strDBGMaxTimeMs = 'Max tid, ms';
-$strDBGMinTimeMs = 'Min tid, ms';
-$strDBGModule = 'Modul';
-$strDBGTimePerHitMs = 'Tid/trff, ms';
-$strDBGTotalTimeMs = 'Total tid, ms';
+$strDbIsEmpty = 'Databasen verkar vara tom!';
 $strDbPrivileges = 'Databasspecifika privilegier';
 $strDBRename = 'Dp om databasen till';
 $strDbSpecific = 'databasspecifik';
@@ -224,11 +217,16 @@ $strDeleted = 'Raden har raderats';
 $strDeletedRows = 'Raderade rader';
 $strDeleteNoUsersSelected = 'Inga anvndare valda fr borttagning!';
 $strDelete = 'Radera';
+$strDeleteRelation = 'Ta bort relation';
 $strDeleting = 'Tar bort %s';
+$strDelimiter = 'Avgrnsare';
 $strDelOld = 'Nuvarande sida har referenser till tabeller som inte lngre existerar. Vill du ta bort dessa referenser?';
 $strDescending = 'Fallande';
 $strDescription = 'Beskrivning';
+$strDesigner = 'Designer';
+$strDesignerHelpDisplayField = 'Visningsfltet visas i rosa. Fr att ange ett flt som visningsflt, klicka p ikonen "Vlj flt som ska visas" och klicka sedan p lmpligt fltnamn.';
 $strDictionary = 'lexikon';
+$strDirectLinks = 'Direkta lnkar';
 $strDirtyPages = 'Orena sidor';
 $strDisabled = 'Inaktiverat';
 $strDisableForeignChecks = 'Stng av kontroll av frmmande nycklar';
@@ -236,6 +234,7 @@ $strDisplayFeat = 'Visningsfunktionaliteter';
 $strDisplayOrder = 'Visningsordning:';
 $strDisplayPDF = 'Visa PDF-schema';
 $strDoAQuery = 'Utfr en "Query By Example" (jokertecken: "%")';
+$strDocSQL = 'DocSQL';
 $strDocu = 'Dokumentation';
 $strDoYouReally = 'Vill du verkligen ';
 $strDropDatabaseStrongWarning = 'Du hller p att FRGRA en hel databas!';
@@ -262,24 +261,30 @@ $strEngineDisabled = '%s har inaktiverats p denna MySQL-server.';
 $strEngines = 'Motorer';
 $strEngineUnsupported = 'Denna MySQL-server har inte std fr lagringsmotorn %s.';
 $strEnglish = 'Engelsk';
-$strEnglishPrivileges = ' Obs! MySQL-privilegiumnamn anges p engelska ';
+$strEnglishPrivileges = ' Obs! MySQL privilegiumnamn anges p engelska ';
 $strError = 'Fel';
 $strErrorInZipFile = 'Fel i ZIP-arkiv:';
+$strErrorRelationAdded = 'Fel: Relation inte tillagd.';
+$strErrorRelationExists = 'Fel: Relation finns redan.';
+$strErrorRenamingTable = 'Fel vid namnbyte p tabell %1$s till %2$s';
+$strErrorSaveTable = 'Fel vid sparande av koordinater fr Designer.';
 $strEscapeWildcards = 'Jokerteknen _ och % mste fregs av ett \ fr att anvndas i egentlig betydelse';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estnisk';
+$strEvent = 'Hndelse';
 $strExcelEdition = 'Excel-version';
-$strExcelOptions = 'Excel-alternativ';
 $strExecuteBookmarked = 'Utfr bokmrkt frga';
 $strExplain = 'Frklara SQL-kod';
 $strExport = 'Exportera';
+$strExportImportToScale = 'Exportera/importera till skala';
+$strExportMustBeFile = 'Vald export-typ mste sparas i fil!';
 $strExtendedInserts = 'Utkade infogningar';
 $strExtra = 'Extra';
 
 $strFailedAttempts = 'Misslyckade frsk';
 $strField = 'Flt';
 $strFieldHasBeenDropped = 'Fltet %s har tagits bort';
-$strFieldsEmpty = ' Antalet flt r noll! ';
+$strFieldInsertFromFileTempDirNotExists = 'Fel vid flytt av uppladdad fil, se FAQ 1.11';
 $strFieldsEnclosedBy = 'Flten omges av';
 $strFieldsEscapedBy = 'Specialtecken i flt fregs av';
 $strFields = 'Flt';
@@ -292,17 +297,21 @@ $strFileNameTemplateDescriptionServer = 'servernamn';
 $strFileNameTemplateDescriptionTable = 'tabellnamn';
 $strFileNameTemplate = 'Mall fr filnamn';
 $strFileNameTemplateRemember = 'kom ihg mall';
+$strFiles = 'Filer';
 $strFileToImport = 'Fil att importera';
 $strFixed = 'fast';
 $strFlushPrivilegesNote = 'Anm: phpMyAdmin hmtar anvndarnas privilegier direkt frn MySQL:s privilegiumtabeller. Innehllet i dessa tabeller kan skilja sig frn privilegierna som servern anvnder ifall manuella ndringar har gjorts. I detta fall br du %sladda om privilegierna%s innan du fortstter.';
 $strFlushQueryCache = 'Rensa frgecache';
 $strFlushTable = 'Rensa tabell';
 $strFlushTables = 'Stng alla tabeller';
+$strFontSize = 'Teckenstorlek';
+$strForeignKeyError = 'Fel vid skapande av frmmande nyckel (kontrollera datatyper)';
 $strFormat = 'Format';
 $strFormEmpty = 'Vrde saknas i formulret!';
 $strFreePages = 'Fria sidor';
 $strFullText = 'Fullstndiga texter';
 $strFunction = 'Funktion';
+$strFunctions = 'Funktioner';
 
 $strGenBy = 'Genererad av';
 $strGeneralRelationFeat = 'Allmnna relationsfunktionaliteter';
@@ -324,38 +333,38 @@ $strHasBeenAltered = 'har ndrats.';
 $strHasBeenCreated = 'har skapats.';
 $strHaveToShow = 'Du mste vlja minst en kolumn som ska visas';
 $strHebrew = 'Hebreisk';
-$strHexForBinary = 'Anvnd hexadecimalt fr binra flt';
+$strHelp = 'Hjlp';
+$strHexForBLOB = 'Anvnd hexadecimal fr BLOB';
+$strHide = 'Dlj';
+$strHideShowAll = 'Dlj/visa alla';
+$strHideShowNoRelation = 'Dlj/visa tabeller utan relationer';
 $strHome = 'Hem';
 $strHomepageOfficial = 'phpMyAdmin:s officiella hemsida';
 $strHostEmpty = 'Vrdnamnet r tomt!';
 $strHost = 'Vrd';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 exportalternativ';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 exportalternativ';
 $strHungarian = 'Ungersk';
 
 $strIcelandic = 'Islndska';
 $strId = 'ID';
 $strIdxFulltext = 'Heltext';
+$strIEUnsupported = 'Internet Explorer saknar std fr denna funktion.';
 $strIgnoreDuplicates = 'Ignorera dubblerade rader';
 $strIgnore = 'Ignorera';
 $strIgnoreInserts = 'Anvnd IGNORE i infogningar';
-$strIgnoringFile = 'Ignorerar fil %s';
-$strImportDocSQL = 'Importera docSQL-filer';
+$strImportExportCoords = 'Importera/exportera koordinater fr PDF-schema';
 $strImportFiles = 'Importera filer';
 $strImportFormat = 'Format p importerad fil';
 $strImport = 'Importera';
 $strImportSuccessfullyFinished = 'Importen har avslutats korrekt, %d frgor utfrda.';
 $strIndexes = 'Index';
+$strIndexesSeemEqual = 'Fljande index verkar vara lika och ett av dem br tas bort:';
 $strIndexHasBeenDropped = 'Index %s har tagits bort';
 $strIndex = 'Index';
 $strIndexName = 'Indexnamn&nbsp;:';
 $strIndexType = 'Indextyp&nbsp;:';
-$strIndexWarningMultiple = 'Mer n en %s-nyckel skapades fr kolumn `%s`';
-$strIndexWarningPrimary = 'PRIMARY- och INDEX-nycklar skall inte bda sttas fr kolumn `%s`';
 $strIndexWarningTable = 'Problem med index fr tabell `%s`';
-$strIndexWarningUnique = 'UNIQUE- och INDEX-nycklar skall inte bda sttas fr kolumn `%s`';
 $strInnoDBAutoextendIncrement = 'Automatisk utkningsstorlek';
 $strInnoDBAutoextendIncrementDesc = 'Tillkningsstorleken vid automatisk utkning av tabellutrymme nr det blir fullt.';
 $strInnoDBBufferPoolSize = 'Buffertstorlek';
@@ -364,14 +373,15 @@ $strInnoDBDataFilePath = 'Datafiler';
 $strInnoDBDataHomeDirDesc = 'Den gemensamma delen av skvgen fr alla InnoDB-datafiler.';
 $strInnoDBDataHomeDir = 'Hemkatalog fr data';
 $strInnoDBPages = 'sidor';
+$strInnoDBRelationAdded = 'InnoDB relation tillagd';
 $strInnodbStat = 'InnoDB-status';
 $strInsecureMySQL = 'Din konfigurationsfil innehller instllningar (root-konto utan lsenord) som motsvarar MySQL:s privilegierade standardkonto. Din MySQL-server krs med denna standardinstllning och r ppen fr intrng, s du br verkligen tppa till detta skerhetshl.';
 $strInsertAsNewRow = 'Lgg till som ny rad';
 $strInsertedRowId = 'Tillagd rads id:';
 $strInsertedRows = 'Tillagda rader:';
 $strInsert = 'Lgg till';
-$strInsertNewRow = 'Lgg till ny rad';
 $strInternalNotNecessary = '* En intern relation r inte ndvndig nr den ven finns i InnoDB.';
+$strInternalRelationAdded = 'Intern relation tillagd';
 $strInternalRelations = 'Interna relationer';
 $strInUse = 'anvnds';
 $strInvalidAuthMethod = 'Ogiltig metod fr autentisering angiven i konfiguration:';
@@ -380,12 +390,14 @@ $strInvalidColumn = 'Ogiltig kolumn (%s) angiven!';
 $strInvalidCSVFieldCount = 'Ogiltigt antal flt i CSV-indata p rad %d.';
 $strInvalidCSVFormat = 'Ogiltigt format i CSV-indata p rad %d.';
 $strInvalidCSVParameter = 'Ogiltig parameter fr CSV-import: %s';
+$strInvalidDatabase = 'Ogiltig databas';
 $strInvalidFieldAddCount = 'Du mste lgga till tminstone ett flt.';
 $strInvalidFieldCount = 'Tabell mste ha tminstone ett flt.';
 $strInvalidLDIImport = 'Detta tillgg stder inte komprimerade importer!';
 $strInvalidRowNumber = '%d r inte ett giltigt radnummer.';
 $strInvalidServerHostname = 'Ogiltigt vrdnamn fr server %1$s. Var god granska din konfiguration.';
 $strInvalidServerIndex = 'Ogiltigt serverindex: "%s"';
+$strInvalidTableName = 'Ogiltigt tabellnamn';
 
 $strJapanese = 'Japansk';
 $strJoins = 'Freningar';
@@ -397,10 +409,11 @@ $strKeepPass = 'ndra inte lsenordet';
 $strKeyCache = 'Nyckelcache';
 $strKeyname = 'Nyckel';;
 $strKill = 'Dda';
+$strKnownExternalBug = 'Funktionaliteten fr %s pverkas av en knd bugg, se %s';
 $strKorean = 'Koreansk';
 
 $strLandscape = 'Liggande';
-$strLanguageFileNotFound = 'Sprkfil "%1$s" hittades inte.';
+$strLanguage = 'Sprk';
 $strLanguageUnknown = 'Oknt sprk: %1$s.';
 $strLatchedPages = 'Lsta sidor';
 $strLatexCaption = 'Tabellrubrik';
@@ -410,11 +423,9 @@ $strLatexContinued = '(fortsttning)';
 $strLatexIncludeCaption = 'Inkludera tabellrubrik';
 $strLatexLabel = 'Etikett';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX-alternativ';
 $strLatexStructure = 'Struktur fr tabell __TABLE__';
 $strLatvian = 'Lettiska';
 $strLDI = 'CSV mha LOAD DATA';
-$strLDIImportOptions = 'Alternativ fr CSV-import mha LOAD DATA';
 $strLDILocal = 'Anvnd nyckelordet LOCAL';
 $strLengthSet = 'Lngd/Vrden*';
 $strLimitNumRows = 'Rader per sida';
@@ -443,14 +454,15 @@ $strMIME_description = 'Beskrivning';
 $strMIME_MIMEtype = 'MIME-typ';
 $strMIME_nodescription = 'Ingen beskrivning fr denna omvandling finns tillgnglig.<br />Vnligen frga upphovsmannen vad %s gr.';
 $strMIME_transformation_note = 'Fr en lista med tillgngliga omvandlingsparametrar och deras MIME-typomvandlingar, klicka p %somvandlingsbeskrivningar%s';
-$strMIME_transformation_options_note = 'Ange vrdena fr omvandlingsparametrar enligt fljande format: \'a\',\'b\',\'c\'...<br />Om du behver lgga till ett baktstreck ("\") eller ett enkelcitat ("\'") i vrdena, skriv ett baktstreck fre tecknet (t.ex. \'\\\\xyz\' eller \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Ange vrdena fr omvandlingsparametrar enligt fljande format: \'a\', 100, b,\'c\'...<br />Om du behver lgga till ett baktstreck ("\") eller ett enkelcitat ("\'") i vrdena, skriv ett baktstreck fre tecknet (t.ex. \'\\\\xyz\' eller \'a\\\'b\').';
 $strMIME_transformation_options = 'Omvandlingsparametrar';
 $strMIME_transformation = 'Webblsaromvandling';
 $strMIMETypesForTable = 'MIME-TYPER FR TABELL';
 $strMIME_without = 'Kursiverade MIME-typer har inte ngon separat omvandlingsfunktion';
 $strModifications = 'ndringarna har sparats';
-$strModify = 'ndra';
 $strModifyIndexTopic = 'ndra ett index';
+$strModify = 'ndra';
+$strMoveMenu = 'Flytta meny';
 $strMoveTable = 'Flytta tabellen till (databas<b>.</b>tabell):';
 $strMoveTableOK = 'Tabellen %s har flyttats till %s.';
 $strMoveTableSameNames = 'Kan inte flytta tabell till samma namn!';
@@ -470,16 +482,18 @@ $strMyISAMSortBufferSize = 'Storlek fr sorteringsbuffert';
 $strMySQLCharset = 'MySQL teckenuppsttning';
 $strMysqlClientVersion = 'MySQL klientversion';
 $strMySQLConnectionCollation = 'Kollation fr MySQL-uppkoppling';
+$strMysqlLibDiffersServerVersion = 'Din PHP MySQL bibliotekversion %s skiljer sig frn din MySQL serverversion %s. Detta kan orsaka ofrutsgbara beteenden.';
 $strMySQLSaid = 'MySQL sa: ';
 $strMySQLShowProcess = 'Visa processer';
-$strMySQLShowStatus = 'Visa MySQL-krningsinformation';
-$strMySQLShowVars = 'Visa MySQL:s systemvariabler';
+$strMySQLShowStatus = 'Visa MySQL krningsinformation';
+$strMySQLShowVars = 'Visa MySQL systemvariabler';
 
 $strName = 'Namn';
 $strNext = 'Nsta';
 $strNoActivity = 'Ingen aktivitet sedan %s sekunder eller mer. Var god logga in igen';
 $strNoDatabases = 'Inga databaser';
 $strNoDatabasesSelected = 'Inga databaser markerade.';
+$strNoDataReceived = 'Inga data att importera mottogs. Antingen skickades inget filnamn eller s versteg filens storlek den maximala som tillts av din PHP-konfiguration.. Se FAQ 1.16.';
 $strNoDescription = 'Ingen beskrivning';
 $strNoDetailsForEngine = 'Det finns ingen tillgnglig detaljerad statusinformation fr denna lagringsmotor.';
 $strNoDropDatabases = '"DROP DATABASE"-satser r inaktiverade.';
@@ -501,7 +515,6 @@ $strNoRowsSelected = 'Inga rader valda';
 $strNoSpace = 'Otillrckligt utrymme fr att spara filen %s.';
 $strNoTablesFound = 'Inga tabeller funna i databasen.';
 $strNoThemeSupport = 'Std fr teman saknas. Kontrollera din konfiguration och/eller dina teman i katalog %s.';
-$strNothingToImport = 'Du fyllde inte i ngra data att importera!';
 $strNotNumber = 'Det r inte ett nummer!';
 $strNotOK = 'Inte OK';
 $strNotSet = '<b>%s</b>-tabellen ej funnen eller ej angiven i %s';
@@ -509,15 +522,19 @@ $strNoUsersFound = 'Hittade ingen anvndare.';
 $strNoValidateSQL = 'Utan SQL-validering';
 $strNull = 'Null';
 $strNumberOfFields = 'Antal flt';
+$strNumberOfTables = 'Antal tabeller';
 $strNumSearchResultsInTable = '%s trff(ar) i tabell <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Totalt:</b> <i>%s</i> trff(ar)';
 $strNumTables = 'Tabeller';
 
 $strOK = 'OK';
+$strOpenDocumentSpreadsheet = 'OpenDocument-kalkylblad';
+$strOpenDocumentText = 'OpenDocument-text';
 $strOpenNewWindow = 'ppna nytt phpMyAdmin-fnster';
 $strOperations = 'Operationer';
 $strOperator = 'Operator';
 $strOptimizeTable = 'Optimera tabell';
+$strOptions = 'Alternativ';
 $strOr = 'Eller';
 $strOverhead = 'Outnyttjat';
 $strOverwriteExisting = 'Skriv ver befintlig fil(er)';
@@ -535,8 +552,8 @@ $strPasswordNotSame = 'Lsenorden r inte lika!';
 $strPdfDbSchema = 'Schema fr databasen "%s" - Sidan %s';
 $strPdfInvalidTblName = 'Tabellen "%s" finns inte!';
 $strPdfNoTables = 'Inga tabeller';
-$strPDFOptions = 'PDF-alternativ';
 $strPDF = 'PDF';
+$strPDFReportExplanation = '(Skapar en rapport som innehller data frn en enstaka tabell)';
 $strPDFReportTitle = 'Rapportrubrik';
 $strPerHour = 'per timme';
 $strPerMinute = 'per minut';
@@ -546,8 +563,10 @@ $strPhoneBook = 'telefonbok';
 $strPHP40203 = 'Du anvnder PHP 4.2.3, vilken har en allvarlig bugg med multi-byte-strngar (mbstring). Se PHP:s buggrapport 19404. Denna version av PHP r inte rekommenderad fr anvndning tillsammans med phpMyAdmin.';
 $strPhp = 'Skapa PHP-kod';
 $strPHPVersion = 'PHP-version';
+$strPleaseSelectPrimaryOrUniqueKey = 'Vlj den primra nyckeln eller en unik nyckel';
 $strPmaDocumentation = 'phpMyAdmin dokumentation';
 $strPmaUriError = 'Variabeln <tt>$cfg[\'PmaAbsoluteUri\']</tt> MSTE anges i din konfigurationsfil!';
+$strPmaWiki = 'phpMyAdmin wiki';
 $strPolish = 'Polska';
 $strPortrait = 'Stende';
 $strPos1 = 'Brjan';
@@ -597,7 +616,10 @@ $strPrivDescUpdate = 'Tillter ndring av data.';
 $strPrivDescUsage = 'Inga privilegier.';
 $strPrivileges = 'Privilegier';
 $strPrivilegesReloaded = 'Privilegierna har laddats om.';
+$strProcedures = 'Procedurer';
+$strProcesses = 'Processer';
 $strProcesslist = 'Processlista';
+$strProfiling = 'Under produktion';
 $strProtocolVersion = 'Protokollversion';
 $strPutColNames = 'Ange fltnamn p frsta raden';
 
@@ -607,6 +629,7 @@ $strQBE = 'Skapa frga';
 $strQueryCache = 'Frgecache';
 $strQueryFrame = 'Frgefnster';
 $strQueryOnDb = 'SQL-frga i databas <b>%s</b>:';
+$strQueryResultsOperations = 'Operationer fr frgeresultat';
 $strQuerySQLHistory = 'SQL-historik';
 $strQueryStatistics = '<b>Frgestatistik</b>: %s frgor har skickats till servern sedan den startade.';
 $strQueryTime = 'Frgan tog %01.4f sek';
@@ -615,16 +638,19 @@ $strQueryWindowLock = 'Skriv inte ver denna frga utifrn detta fnster';
 
 $strReadRequests = 'Lsefterfrgningar';
 $strReceived = 'Mottagna';
+$strRecommended = 'rekommenderad';
 $strRecords = 'Rader';
 $strReferentialIntegrity = 'Kontrollera referensintegritet:';
 $strRefresh = 'Uppdatera';
 $strRelationalSchema = 'Relationsschema';
+$strRelationDeleted = 'Relation borttagen';
 $strRelationNotWorking = 'Den extra funktionaliteten fr att hantera lnkade tabeller har inaktiverats. %sVisa orsaken%s.';
 $strRelationsForTable = 'RELATIONER FR TABELL';
 $strRelations = 'Relationer';
 $strRelationView = 'Visa relationer';
 $strReloadingThePrivileges = 'Laddar om privilegierna';
-$strReloadMySQL = 'Ladda om MySQL';
+$strReloadPrivileges = 'Ladda om privilegier';
+$strReload = 'Uppdatera';
 $strRemoveSelectedUsers = 'Ta bort markerade anvndare';
 $strRenameDatabaseOK = 'Databas %s har dpts om till %s';
 $strRenameTable = 'Dp om tabellen till';
@@ -635,12 +661,15 @@ $strReplaceTable = 'Erstt data i tabell';
 $strReplication = 'Replikering';
 $strReset = 'Nollstll';
 $strResourceLimits = 'Resursbegrnsningar';
+$strRestartInsertion = 'Brja om infogning med %s rader';
 $strReType = 'Skriv igen';
 $strRevokeAndDeleteDescr = 'Anvndarna kommer fortfarande ha kvar privilegiet USAGE tills privilegierna laddas om.';
 $strRevokeAndDelete = 'Upphv anvndarnas alla aktiva privilegier och ta bort anvndarna eftert.';
 $strRevokeMessage = 'Du har upphvt privilegierna fr %s';
 $strRevoke = 'Upphv';
 $strRomanian = 'Rumnska';
+$strRoutineReturnType = 'Returtyp';
+$strRoutines = 'Rutiner';
 $strRowLength = 'Radlngd';
 $strRowsFrom = 'rader med brjan frn';
 $strRowSize = 'Radstorlek';
@@ -657,6 +686,7 @@ $strRunSQLQueryOnServer = 'Kr SQL-frga/frgor p server %s';
 $strRussian = 'Rysk';
 
 $strSaveOnServer = 'Spara p servern i katalogen %s';
+$strSavePosition = 'Spara position';
 $strSave = 'Spara';
 $strScaleFactorSmall = 'Skalfaktorn r fr liten fr att schemat ska f plats p en sida';
 $strSearchFormTitle = 'Sk i databas';
@@ -674,21 +704,24 @@ $strSelectADb = 'Vlj en databas';
 $strSelectAll = 'Markera alla';
 $strSelectBinaryLog = 'Vlj binr logg att visa';
 $strSelectFields = 'Vlj flt (minst ett):';
+$strSelectForeignKey = 'Vlj frmmande nyckel';
 $strSelectNumRows = 'i frga';
+$strSelectReferencedKey = 'Vlj refererad nyckel';
 $strSelectTables = 'Vlj tabeller';
 $strSend = 'Spara som fil';
 $strSent = 'Skickade';
 $strServerChoice = 'Serverval';
 $strServerNotResponding = 'Servern svarar inte';
 $strServer = 'Server';
+$strServers = 'Servrar';
 $strServerStatusDelayedInserts = 'Frdrjda infogningar';
 $strServerStatus = 'Krningsinformation';
 $strServerStatusUptime = 'Denna MySQL-server har krts i %s. Den startade den %s.';
-$strServerTabProcesslist = 'Processer';
 $strServerTabVariables = 'Variabler';
 $strServerTrafficNotes = '<b>Servertrafik</b>: Dessa tabeller visar statistik fr ntverkstrafiken hos denna MySQL-server sedan den startade.';
 $strServerVars = 'Servervariabler och instllningar';
 $strServerVersion = 'Serverversion';
+$strSessionStartupErrorGeneral = 'Kan inte starta session utan fel. Kontrollera felmeddelanden i din PHP:s och/eller webbservers loggfil och konfigurera din PHP-installation korrekt.';
 $strSessionValue = 'Sessionsvrde';
 $strSetEnumVal = 'Om en flttyp r "enum" eller "set", ange vrden enligt fljande format: \'a\',\'b\',\'c\'...<br />Om du behver lgga till ett baktstreck ("\") eller ett enkelcitat ("\'") i vrdena, skriv ett baktstreck fre tecknet (t.ex. \'\\\\xyz\' eller \'a\\\'b\').';
 $strShowAll = 'Visa alla';
@@ -696,8 +729,11 @@ $strShowColor = 'Visa frger';
 $strShowDatadictAs = 'Format fr datalexikon';
 $strShowFullQueries = 'Visa fullstndiga frgor';
 $strShowGrid = 'Visa rutnt';
+$strShowHideLeftMenu = 'Visa/Dlj vnster meny';
 $strShowingBookmark = 'Visar bokmrke';
+$strShowingPhp = 'Visar som PHP-kod';
 $strShowingRecords = 'Visar rader ';
+$strShowingSQL = 'Visar SQL-frga';
 $strShowOpenTables = 'Visa ppna tabeller';
 $strShowPHPInfo = 'Visa PHP-information';
 $strShowSlaveHosts = 'Visa slav-vrdar';
@@ -819,6 +855,8 @@ $strSize = 'Storlek';
 $strSkipQueries = 'Antal poster (rader) att hoppa ver frn brjan';
 $strSlovak = 'Slovakiska';
 $strSlovenian = 'Slovenska';
+$strSmallBigAll = 'Sm/stora alla';
+$strSnapToGrid = 'Fst vid rutnt';
 $strSocketProblem = '(eller den lokala MySQL-serverns socket r inte korrekt konfigurerad)';
 $strSortByKey = 'Sortera efter nyckel';
 $strSorting = 'Sortering';
@@ -826,10 +864,8 @@ $strSort = 'Sortering';
 $strSpaceUsage = 'Utrymmesanvndning';
 $strSpanish = 'Spanska';
 $strSplitWordsWithSpace = 'Ord separeras med mellanslag (" ").';
-$strSQLExportCompatibility = 'SQL-export-kompatibilitet';
+$strSQLCompatibility = 'SQL-kompatibilitet';
 $strSQLExportType = 'Export-typ';
-$strSQLImportOptions = 'SQL-alternativ';
-$strSQLOptions = 'SQL-alternativ';
 $strSQLParserBugMessage = 'Det r mjligt att du har hittat en bugg i SQL-analysatorn. Var god granska din frga noga och kontrollera att citationstecknen r korrekta och matchar varandra. En annan mjlig felorsak kan vara att du verfr en fil med binrkod som inte ligger inom citationstecken. Du kan ven testa din frga i MySQL:s kommandoradsgrnssnitt. Felmeddelandet frn MySQL-servern nedan, om det finns ngot, kan ocks hjlpa dig att analysera problemet. Om du fortfarande har problem eller om SQL-analysatorn misslyckas nr kommandoradsgrnssnittet lyckas, var vnlig reducera din inmatning av SQL-frgor till den enda frga som orsakar problem och skicka en buggrapport med datastycket i URKLIPP-sektionen nedan:';
 $strSQLParserUserError = 'Det verkar vara ett fel i din SQL-frga. Felmeddelandet frn MySQL-servern nedan, om det finns ngot, kan ocks hjlpa dig att analysera problemet.';
 $strSQLQuery = 'SQL-frga';
@@ -838,6 +874,7 @@ $strSQL = 'SQL';
 $strSQPBugInvalidIdentifer = 'Ogiltig identifierare';
 $strSQPBugUnclosedQuote = 'Oavslutat citat';
 $strSQPBugUnknownPunctuation = 'Oknd interpunktion i strng';
+$strStandInStructureForView = 'Ersttningsstruktur fr visning';
 $strStatCheckTime = 'Senaste kontroll';
 $strStatCreateTime = 'Skapades';
 $strStatement = 'Uppgift';
@@ -848,11 +885,11 @@ $strStorageEngine = 'Lagringsmotor';
 $strStorageEngines = 'Lagringsmotorer';
 $strStrucCSV = 'CSV';
 $strStrucData = 'Struktur och data';
-$strStrucDrop = 'Lgg till DROP TABLE';
 $strStrucExcelCSV = 'CSV fr MS Excel';
 $strStrucNativeExcel = 'Naturlig MS Excel-data';
 $strStrucOnly = 'Enbart struktur';
 $strStructPropose = 'Fresl tabellstruktur';
+$strStructureForView = 'Struktur fr visning';
 $strStructure = 'Struktur';
 $strSubmit = 'Snd';
 $strSuccess = 'Din SQL-frga utfrdes korrekt';
@@ -867,13 +904,14 @@ $strTableEmpty = 'Tabellnamnet r tomt!';
 $strTableHasBeenDropped = 'Tabellen %s har tagits bort';
 $strTableHasBeenEmptied = 'Tabellen %s har tmts';
 $strTableHasBeenFlushed = 'Tabellen %s har rensats';
+$strTableIsEmpty = 'Tabellen verkar vara tom!';
 $strTableMaintenance = 'Tabellunderhll';
+$strTableName = 'Tabellnamn';
 $strTableOfContents = 'Innehllsfrteckning';
 $strTableOptions = 'Tabellalternativ';
 $strTables = '%s tabell(er)';
 $strTableStructure = 'Struktur fr tabell';
 $strTable = 'Tabell';
-$strTableType = 'Tabelltyp';
 $strTakeIt = 'anvnd detta';
 $strTblPrivileges = 'Tabellspecifika privilegier';
 $strTempData = 'Temporra data';
@@ -886,14 +924,16 @@ $strThemeNoValidImgPath = 'Ingen giltig skvg till bilder fr tema %s hittades!';
 $strThemePathNotFound = 'Temats skvg fr tema %s hittades inte!';
 $strTheme = 'Tema / Stil';
 $strThisHost = 'Denna vrd';
-$strThisNotDirectory = 'Detta var inte en katalog';
 $strThreads = 'Trdar';
 $strThreadSuccessfullyKilled = 'Trd %s ddades med framgng.';
 $strTimeoutInfo = 'Tidsbegrnsningen verskreds vid fregende import. Efter terupptagning av importen kommer den fortstta frn position %d.';
-$strTimeoutNothingParsed = 'Dock blev inga data bearbetade i senaste krningen. Detta betyder vanligtvis att phpMyAdmin inte kan slutfra denna import svida du inte kar php:s tidsbegrnsningar.';
+$strTimeoutNothingParsed = 'Dock blev inga data bearbetade i senaste krningen. Detta betyder vanligtvis att phpMyAdmin inte kan slutfra denna import svida du inte kar PHP:s tidsbegrnsningar.';
 $strTimeoutPassed = 'Skriptets tidsbegrnsning har verskridits. Om du vill slutfra importen, importera samma fil igen s kommer importen att terupptas.';
 $strTime = 'Tid';
+$strToFromPage = 'till/frn sida';
 $strToggleScratchboard = 'Visa/dlj skisstavla';
+$strToggleSmallBig = 'Vxla liten/stor';
+$strToSelectRelation = 'Fr att vlja relation, klicka :';
 $strTotal = 'totalt';
 $strTotalUC = 'Totalt';
 $strTraditionalChinese = 'Traditionell kinesiska';
@@ -905,13 +945,14 @@ $strTransformation_application_octetstream__hex = 'Visar hexadecimal representat
 $strTransformation_image_jpeg__inline = 'Visar en klickbar tumnagelbild. Parametrarna r maximal bredd och hjd i pixlar. Bildens ursprungliga proportioner bibehlls.';
 $strTransformation_image_jpeg__link = 'Visar en lnk fr att ladda ner denna bild.';
 $strTransformation_image_png__inline = 'Se image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Visar ett TIME, TIMESTAMP eller DATETIME-flt enligt ditt lokala datum-/tidsformat. Frsta parametern r frskjutningen (i timmar) som kommer att lggas till tidsstmpeln (standardvrde: 0). Anvnd andra parametern fr att ange ett annat datum-/tidsformat; se dokumentationen fr PHP:s funktion strftime().';
+$strTransformation_text_plain__dateformat = 'Visar en TIME, TIMESTAMP, DATETIME eller numerisk unix tidsstmpel som ett formaterat datum. Frsta parametern r frskjutning (i timmar) som kommer adderas till tidsstmpeln (standardvrde: 0). Anvnd andra parametern fr att ange ett annorlunda datum/tid-format. Tredje parametern avgr ifall du vill se lokalt datum eller UTC (ange "local" eller "utc"). Enligt detta har datumformatet olika vrden - fr "local" se dokumentationen fr PHP:s funktion strftime() och fr "utc" se funktionen gmdate().';
 $strTransformation_text_plain__external = 'ENDAST LINUX: Startar en extern applikation och skickar fltdata till den via standard-indata. Returnerar applikationens standard-utdata. Standard r Tidy, fr att snygga till HTML-kod. Av skerhetsskl mste du manuellt redigera filen libraries/transformations/text_plain__external.inc.php och infoga verktygen du vill tillta ska f kras. Den frsta parametern r d numret fr det program som du vill anvnda och den andra parametern r parametrarna fr programmet. Om den tredje parametern stts till 1 kommer utdata konverteras mha htmlspecialchars() (standardvrde: 1). Om den fjrde parametern stts till 1 kommer radbrytning att undvikas s att all utdata kommer att visas p en rad (standardvrde: 1).';
 $strTransformation_text_plain__formatted = 'Visar innehllet i fltet som det r, utan att kra det genom htmlspecialchars(). Det innebr att fltet antas innehlla korrekt HTML-kod.';
 $strTransformation_text_plain__imagelink = 'Visar en bild och en lnk; fltet innehller filnamnet. Frsta parametern r ett URL-prefix ssom "http://www.example.com/". Andra och tredje parametern r bredden och hjden i pixlar.';
 $strTransformation_text_plain__link = 'Visar en lnk; fltet innehller filnamnet. Frsta parametern r ett URL-prefix ssom "http://www.example.com/". Andra parametern r en titel fr lnken.';
 $strTransformation_text_plain__sql = 'Formaterar text som en SQL-frga med markerade satser.';
 $strTransformation_text_plain__substr = 'Visar del av en strng. Frsta parametern r antalet tecken att hoppa ver frn brjan p strngen (standardvrde: 0). Andra parametern r antalet tecken som ska returneras (standardvrde: till slutet p strngen). Den tredje parametern r en strng som lggs till i slutet och/eller brjan nr trunkering utfrs (standardvrde: "...").';
+$strTriggers = 'Utlsare';
 $strTruncateQueries = 'Korta av visade frgor';
 $strTurkish = 'Turkisk';
 $strType = 'Typ';
@@ -928,7 +969,15 @@ $strUpdateProfileMessage = 'Profilen har uppdaterats.';
 $strUpdateQuery = 'Uppdatera frga';
 $strUpdComTab = 'Se dokumentationen fr uppdatering av din tabell column_comments';
 $strUpgrade = 'Du br uppgradera till %s %s eller senare.';
+$strUploadErrorCantWrite = 'Misslyckades att skriva fil till disk.';
+$strUploadErrorExtension = 'Filuppladdning stoppades av tillgg.';
+$strUploadErrorFormSize = 'Den uppladdade filen verskrider direktivet MAX_FILE_SIZE som specificerades i HTML-formulret.';
+$strUploadErrorIniSize = 'Den uppladdade filen verskrider direktivet upload_max_filesize i php.ini.';
+$strUploadErrorNoTempDir = 'Saknar en temporr katalog.';
+$strUploadErrorPartial = 'Den uppladdade filen var endast delvis uplladdad.';
+$strUploadErrorUnknown = 'Oknt fel i filuppladdning.';
 $strUploadLimit = 'Du frskte frmodligen ladda upp en fr stor fil. Se %sdokumentationen%s fr metoder att g runt denna begrnsning.';
+$strUploadsNotAllowed = 'Filuppladdningar r inte tilltna p denna server.';
 $strUsage = 'Anvndning';
 $strUseBackquotes = 'Anvnd baktcitat runt tabell- och fltnamn';
 $strUsedPhpExtensions = 'Anvnda PHP-tillgg';
@@ -956,6 +1005,7 @@ $strViewDumpDB = 'Visa SQL-satser fr databasen';
 $strViewDump = 'Visa SQL-satser fr tabellen';
 $strViewHasBeenDropped = 'Vyn %s har tagits bort';
 $strViewMaxExactCount = 'Denna vy har mer n %s rader. Var god se %sdokumentationen%s.';
+$strViewName = 'Namn p vy';
 $strView = 'Vy';
 
 $strWebServerUploadDirectoryError = 'Katalogen som du konfigurerat fr uppladdning kan inte ns';
@@ -966,8 +1016,6 @@ $strWildcard = 'jokertecken';
 $strWindowNotFound = 'Mlfnstret kunde inte uppdateras. Orsaken kan vara att du stngt frldrafnstret eller att din webblsares skerhetsinstllningar blockerar uppdateringar mellan fnster.';
 $strWithChecked = 'Med markerade:';
 $strWriteRequests = 'Skrivefterfrgningar';
-$strWritingCommentNotPossible = 'Skrivning av kommentar inte mjlig';
-$strWritingRelationNotPossible = 'Skrivning av relation inte mjlig';
 $strWrongUser = 'Fel anvndarnamn/lsenord. tkomst nekad.';
 
 $strXML = 'XML';
