@@ -1,5 +1,5 @@
 <?php
-/* $Id: tatarish-iso-8859-9.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: tatarish-iso-8859-9.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 $charset = 'iso-8859-9';
 $allow_recoding = TRUE;
@@ -60,7 +60,6 @@ $strAscending = 'Artp';
 $strAtBeginningOfTable = 'Tm Bana';
 $strAtEndOfTable = 'Tm azana';
 $strAttr = 'zenlek';
-$strAutodetect = 'ze tan';
 $strAutomaticLayout = 'Zihenle urnatru';
 
 $strBack = 'Kire';
@@ -166,8 +165,6 @@ $strCreationDates = 'Yaratlu/zgrel/Tiker aqlar';
 $strCriteria = 'art';
 $strCroatian = 'Kroata';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'CSV kylnee';
-$strCSVOptions = 'CSV kylnee';
 $strCyrillic = 'Urslif';
 $strCzech = 'ex';
 $strCzechSlovak = 'ex-Slovak';
@@ -177,7 +174,6 @@ $strDatabase = 'Biremlek';
 $strDatabaseEmpty = 'Biremlek iseme bu!';
 $strDatabaseExportOptions = 'Biremlek saqlaw kylnee';
 $strDatabaseHasBeenDropped = '%s biremlege beterelde.';
-$strDatabaseNoTable = 'Bu biremlekt tmlr ber gen d yuq!';
 $strDatabases = 'Biremleklr';
 $strDatabasesDropped = '"%s" biremlegen beter ul uzd.';
 $strDatabasesStats = 'Biremlek nfslre';
@@ -250,7 +246,6 @@ $strEscapeWildcards = '_ beln % bilgelren ul kile ken qullanu en \ beln tkrerg k
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estona';
 $strExcelEdition = 'Excel sreme';
-$strExcelOptions = 'Excel kylnee';
 $strExecuteBookmarked = 'Tamalanan soraw cibr';
 $strExplain = 'SQL Centeklw';
 $strExport = 'Export';
@@ -261,7 +256,6 @@ $strFailedAttempts = 'Failed attempts';
 $strField = 'Alan';
 $strFieldHasBeenDropped = '%s isemle alan beterelde';
 $strFields = 'Alan';
-$strFieldsEmpty = ' Alan oznl ytelmde!';
 $strFieldsEnclosedBy = 'Alan yaptru bilge';
 $strFieldsEscapedBy = 'Alan uzdru bilgese';
 $strFieldsTerminatedBy = 'Alan arasnda bilge';
@@ -304,15 +298,12 @@ $strHasBeenAltered = 'zgrtelde.';
 $strHasBeenCreated = 'yaratld.';
 $strHaveToShow = 'You have to choose at least one Column to display';
 $strHebrew = 'Yhd';
-$strHexForBinary = 'Binar alan kertknd 16\'l san qullanas';
 $strHome = 'Babit';
 $strHomepageOfficial = 'phpMyAdmin sxifse';
 $strHostEmpty = 'Host ad bu!';
 $strHost = 'Host';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 kebek aru kylwe';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 kebek aru kylwe';
 $strHungarian = 'Macara';
 
 $strIcelandic = 'clanda';
@@ -329,10 +320,7 @@ $strIndexHasBeenDropped = '"%s" dign teze salnd';
 $strIndexName = 'Teze ad&nbsp;:';
 $strIndex = 'Teze';
 $strIndexType = 'Teze tre&nbsp;:';
-$strIndexWarningMultiple = '`%s` alannda qabatlanan %s atl teze bar';
-$strIndexWarningPrimary = '`%s` alannda PRIMARY beln INDEX tezelren berg yasap bulmy';
 $strIndexWarningTable = '`%s` atl tw tezelre beln nidider tiskrlek bar';
-$strIndexWarningUnique = '`%s` alannda UNIQUE beln INDEX tezelren berg yasap bulmy';
 $strInnoDBAutoextendIncrement = 'Biremlekt arttru adm';
 $strInnoDBAutoextendIncrementDesc = 'Tm alan tula, an arttru adm bu.';
 $strInnoDBBufferPoolSize = 'Bufer pul oll';
@@ -371,7 +359,6 @@ $strKill = 'ter';
 $strKorean = 'Korey';
 
 $strLandscape = 'Yatqrp';
-$strLanguageFileNotFound = '"%1$s" dign tellter bireme tablmad.';
 $strLanguageUnknown = 'Belgesez tel: %1$s.';
 $strLatchedPages = 'Berketelgn bit';
 $strLatexCaption = 'Tm bal';
@@ -381,10 +368,8 @@ $strLatexContinued = '(dawaml)';
 $strLatexIncludeCaption = 'Tm baln stise';
 $strLatexLabel = 'Aq yazmas';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX kylnee';
 $strLatexStructure = '__TABLE__ atl tm tzelee';
 $strLatvian = 'Lata';
-$strLDIImportOptions = 'LOAD DATA qullanp CSV yklw kylnee';
 $strLDI = 'LOAD DATA qullanp CSV';
 $strLDILocal = 'LOCAL dign sz qullanp';
 $strLengthSet = 'Oznlq/By*';
@@ -504,7 +489,6 @@ $strPassword = 'Sersz';
 $strPdfDbSchema = '"%s" biremlek tzelee - %s. bit';
 $strPdfInvalidTblName = '"%s" atl tm yuq le!';
 $strPdfNoTables = 'Berr gen d tm yuq';
-$strPDFOptions = 'PDF kylnee';
 $strPDF = 'PDF';
 $strPDFReportTitle = 'Yomaq bal';
 $strPerHour = 'st sayn';
@@ -700,8 +684,6 @@ $strSpanish = 'spana';
 $strSplitWordsWithSpace = 'Szlrne bulq bilgese beln ayras (" ").';
 $strSQLCompatibility = 'SQL, kileter sul';
 $strSQLExportType = 'aru sul';
-$strSQLImportOptions = 'SQL kylnee';
-$strSQLOptions = 'SQL kylnee';
 $strSQLParserBugMessage = 'There is a chance that you may have found a bug in the SQL parser. Please examine your query closely, and check that the quotes are correct and not mis-matched. Other possible failure causes may be that you are uploading a file with binary outside of a quoted text area. You can also try your query on the MySQL command line interface. The MySQL server error output below, if there is any, may also help you in diagnosing the problem. If you still have problems or if the parser fails where the command line interface succeeds, please reduce your SQL query input to the single query that causes problems, and submit a bug report with the data chunk in the CUT section below:';
 $strSQLParserUserError = 'There seems to be an error in your SQL query. The MySQL server error output below, if there is any, may also help you in diagnosing the problem';
 $strSQLQuery = 'SQL-soraw';
@@ -826,7 +808,6 @@ $strWithChecked = 'Saylanann:';
 $strWriteRequests = 'Yazua soraw';
 $strWrongUser = 'Atama/sersze yal buluna kr ireep bulmad.';
 
-$strXMLOptions = 'XML kylnee';
 $strXML = 'XML';
 
 $strYes = 'ye';
@@ -865,9 +846,7 @@ $strMaxConnects = 'max. concurrent connections';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 
 $strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
 
@@ -941,7 +920,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
 $strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
@@ -971,7 +950,6 @@ $strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache.
 $strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
 $strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 
 $strThemeNoPreviewAvailable = 'No preview available.';  //to translate
 $strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
@@ -994,7 +972,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1039,4 +1016,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
