@@ -1,11 +1,16 @@
 <?php
-/* $Id: check_user_privileges.lib.php 9438 2006-09-21 14:28:46Z cybot_tm $ */
-// vim: expandtab sw=4 ts=4 sts=4:
-
-// Get user's global privileges and some db-specific privileges
-// ($controllink and $userlink are links to MySQL defined in the "common.lib.php" library)
-// Note: if no controluser is defined, $controllink contains $userlink
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ * Get user's global privileges and some db-specific privileges
+ * ($controllink and $userlink are links to MySQL defined in the "common.inc.php" library)
+ * Note: if no controluser is defined, $controllink contains $userlink
+ *
+ * @version $Id: check_user_privileges.lib.php 10405 2007-05-19 18:08:38Z lem9 $
+ */
 
+/**
+ *
+ */
 $is_create_db_priv  = false;
 $is_process_priv = true;
 $is_reload_priv  = false;
@@ -28,7 +33,11 @@ function PMA_analyseShowGrant($rs_usr, &$is_create_db_priv, &$db_to_create, &$is
         if ($show_grants_str == 'RELOAD') {
             $is_reload_priv = true;
         }
-        if (($show_grants_str == 'ALL') || ($show_grants_str == 'ALL PRIVILEGES') || ($show_grants_str == 'CREATE') || strpos($show_grants_str, 'CREATE')) {
+        /**
+         * @todo if we find CREATE VIEW but not CREATE, do not offer  
+         * the create database dialog box
+         */
+        if (($show_grants_str == 'ALL') || ($show_grants_str == 'ALL PRIVILEGES') || ($show_grants_str == 'CREATE') || strpos($show_grants_str, 'CREATE,') !== false) {
             if ($show_grants_dbname == '*') {
                 // a global CREATE privilege
                 $is_create_db_priv = true;
