@@ -1,4 +1,13 @@
 <?php
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ * navigation css file from theme Original
+ *
+ * @version $Id: theme_left.css.php 10520 2007-07-22 19:05:42Z lem9 $
+ * @package phpMyAdmin-theme
+ * @subpackage Original
+ */
+
 // unplanned execution path
 if (!defined('PMA_MINIMUM_COMMON')) {
     exit();
@@ -21,13 +30,18 @@ a img {
     border: 0;
 }
 
+ul {
+	margin:0;
+}	
+
 form {
     margin:             0;
     padding:            0;
     display:            inline;
 }
 
-select {
+select#select_server,
+select#lightm_db {
     width:              100%;
 }
 
@@ -48,10 +62,18 @@ button {
     margin-left:        0.3em;
 }
 
+.navi_dbName {
+    font-weight:    bold;
+    color:          <?php echo $GLOBALS['cfg']['NaviDatabaseNameColor']; ?>;
+}
 
 /******************************************************************************/
 /* specific elements */
 
+div#pmalogo {
+    background-color: #D0DCE0<?php //better echo $GLOBALS['cfg']['logoBGC']; ?>;
+    padding:.3em;
+}
 div#pmalogo,
 div#leftframelinks,
 div#databaseList {
@@ -65,11 +87,15 @@ ul#databaseList {
     border-bottom:      0.05em solid <?php echo $GLOBALS['cfg']['NaviColor']; ?>;
     margin-bottom:      0.5em;
     padding-bottom:     0.5em;
-    padding-left: 	1.5em;
+    padding-<?php echo $left; ?>:     1.5em;
 }
 
 ul#databaseList a {
     display: block;
+}
+
+div#navidbpageselector a,
+ul#databaseList a {
     background:         <?php echo $GLOBALS['cfg']['NaviBackground']; ?>;
     color:              <?php echo $GLOBALS['cfg']['NaviColor']; ?>;
 }
@@ -102,7 +128,7 @@ div#leftframelinks a:hover {
 
 /* serverlist */
 #body_leftFrame #list_server {
-    list-style-image: url(../<?php echo $GLOBALS['cfg']['ThemePath']; ?>/original/img/s_host.png);
+    list-style-image: url(<?php echo $GLOBALS['cfg']['ThemePath']; ?>/original/img/s_host.png);
     list-style-position: inside;
     list-style-type: none;
     margin: 0;
@@ -116,6 +142,10 @@ div#leftframelinks a:hover {
 }
 
 /* leftdatabaselist */
+div#left_tableList {
+    border-bottom:      0.05em solid <?php echo $GLOBALS['cfg']['NaviColor']; ?>;
+}
+
 div#left_tableList ul {
     list-style-type:    none;
     list-style-position: outside;
@@ -156,7 +186,7 @@ div#left_tableList > ul li.marked {
 }
 <?php } ?>
 
-<?php if ( $GLOBALS['cfg']['LeftPointerEnable'] ) { ?>
+<?php if ($GLOBALS['cfg']['LeftPointerEnable']) { ?>
 div#left_tableList > ul li:hover > a,
 div#left_tableList > ul li:hover {
     background:         <?php echo $GLOBALS['cfg']['NaviPointerBackground']; ?>;
@@ -170,9 +200,18 @@ div#left_tableList img {
 }
 
 div#left_tableList ul ul {
-    margin-left:        0;
-    padding-left:       0.1em;
-    border-left:        0.1em solid <?php echo $GLOBALS['cfg']['NaviColor']; ?>;
+    margin-<?php echo $left; ?>:        0;
+    padding-<?php echo $left; ?>:       0.1em;
+    border-<?php echo $left; ?>:        0.1em solid <?php echo $GLOBALS['cfg']['NaviColor']; ?>;
     padding-bottom:     0.1em;
     border-bottom:      0.1em solid <?php echo $GLOBALS['cfg']['NaviColor']; ?>;
 }
+/* for the servers list in navi panel */
+#serverinfo .item {
+    white-space:        nowrap;
+    color:              <?php echo $GLOBALS['cfg']['NaviColor']; ?>;
+}
+#serverinfo a:hover {
+    background:         <?php echo $GLOBALS['cfg']['NaviPointerBackground']; ?>;
+    color:              <?php echo $GLOBALS['cfg']['NaviPointerColor']; ?>;
+}
